#################
# HPV simulation study
# Citation: Goldstein ND, LeVasseur MT, Eppes SC. Scaling up HPV vaccination among high-risk men who have sex with men: a comparison of prevention strategies. Manuscript in preparation.
# 1/24/17 -- Neal Goldstein
#################


### FUNCTIONS ###

prevention_paradigm = function(rand_vector, prevention_var, dataset, intervention_level=NA)
{
  if (prevention_var=="TAPVL") {
    #TAPVL (viral load under TAP, 1=suppressed, 2=not suppressed)
    starting_vals = ifelse(dataset$STATUS==3 & rand_vector<=0.42, 1, ifelse(dataset$STATUS==3 & rand_vector>0.42, 2, ifelse(dataset$STATUS==2 & dataset$HIV==1, 2, -1)))
  } else if (prevention_var=="PROBCOND") {
    #PROBCOND (condom probability)
    starting_vals = ifelse(rand_vector<=0.25, 1, ifelse(rand_vector<=0.49, 0, ifelse(rand_vector<=0.70, 0.75, ifelse(rand_vector<=0.86, 0.50, 0.25))))
  } else if (prevention_var=="SEROTYPE") {
    #SEROTYPE (1=seropositioning/insertive, 2=seropositioning/receptive, 3=serosorting, 4=no seroadaptive behavior)
    starting_vals = ifelse(dataset$STATUS==3 & rand_vector<=0.133, 2, ifelse(dataset$STATUS==3 & rand_vector<=0.347, 3, ifelse(dataset$STATUS==3 & rand_vector>0.347, 4, ifelse(dataset$STATUS==2 & rand_vector<=0.053, 1, ifelse(dataset$STATUS==2 & rand_vector<=0.374, 3, ifelse(dataset$STATUS==2 & rand_vector>0.374, 4, ifelse(dataset$STATUS==1 & rand_vector<=0.095, 1, ifelse(dataset$STATUS==1 & rand_vector<=0.402, 3, ifelse(dataset$STATUS==1 & rand_vector>0.402, 4, NA)))))))))
  } else if (prevention_var=="ONPREP") {
    #ONPREP (0=not on prep, 1=on prep)
    starting_vals = ifelse(dataset$STATUS==1 & rand_vector<=(intervention_level/((1-0.19)-((1-0.19)*0.369))), 1, 0)
  } else if (prevention_var=="HPVDOSES") {
    #HPVDOSES (number of doses of HPV vaccine)
    starting_vals = ifelse(rand_vector<=(1-intervention_level), 0, ifelse(rand_vector<=(intervention_level*(4/13)+(1-intervention_level)), 1, ifelse(rand_vector<=(intervention_level*((4+2)/13)+(1-intervention_level)), 2, 3)))
  }

  return(starting_vals)
}


### STEP0: GLOBAL INITIATION ###

#ensuring that all datasets are same
set.seed(777)

#ensure that each of 50 simulations is unique
seed_val_population = sample(1:1000,50,replace=F)

#initialize container for results of all simulations
prep_sims_50 = list(NA)
nsims=50
for (sims in 1:nsims)
{
  cat("\n\n************** ","Simulation: ",sims," **************\n",sep="")
  
  
  ### STEP1: INITIALIZING BASE POPULATION ###
  
  #counterfactual within each simulation: ensures that characteristics of the population are the same within each simulation
  set.seed(seed_val_population[sims])
  
  #generate an initial population of 10,000 men, with same characteristics for all prevention scenarios
  baseline_pop = data.frame("ID"=1:10000, "HIV"=NA, "VL"=NA, "STATUS"=NA, "HPV_ANAL"=NA, "HPV_ORAL"=NA, "HPV6_ANAL"=NA, "HPV6_ORAL"=NA, "HPV11_ANAL"=NA, "HPV11_ORAL"=NA, "HPV16_ANAL"=NA, "HPV16_ORAL"=NA, "HPV18_ANAL"=NA, "HPV18_ORAL"=NA, "HPV31_ANAL"=NA, "HPV31_ORAL"=NA, "HPV33_ANAL"=NA, "HPV33_ORAL"=NA, "HPV45_ANAL"=NA, "HPV45_ORAL"=NA, "HPV52_ANAL"=NA, "HPV52_ORAL"=NA, "HPV58_ANAL"=NA, "HPV58_ORAL"=NA, "HPV6_ANAL_CLEARED"=0, "HPV6_ORAL_CLEARED"=0, "HPV11_ANAL_CLEARED"=0, "HPV11_ORAL_CLEARED"=0, "HPV16_ANAL_CLEARED"=0, "HPV16_ORAL_CLEARED"=0, "HPV18_ANAL_CLEARED"=0, "HPV18_ORAL_CLEARED"=0, "HPV31_ANAL_CLEARED"=0, "HPV31_ORAL_CLEARED"=0, "HPV33_ANAL_CLEARED"=0, "HPV33_ORAL_CLEARED"=0, "HPV45_ANAL_CLEARED"=0, "HPV45_ORAL_CLEARED"=0, "HPV52_ANAL_CLEARED"=0, "HPV52_ORAL_CLEARED"=0, "HPV58_ANAL_CLEARED"=0, "HPV58_ORAL_CLEARED"=0, "CIRC"=NA, "SEX_ACT"=NA, "SEX_POSITION_ANAL_PREF"=NA, "SEX_POSITION_ORAL_PREF"=NA, "SEX_POSITION_ANAL"=NA, "SEX_POSITION_ORAL"=NA, "TEST_DAY"=NA, "MAX_PARTNERS"=NA, "SEX_PARTNERS"=0, "ORIGINAL_STATUS_HIV"=NA, "ORIGINAL_STATUS_HPV_ANAL"=NA, "ORIGINAL_STATUS_HPV_ORAL"=NA, "ORIGINAL_STATUS_HPV6_ANAL"=NA, "ORIGINAL_STATUS_HPV6_ORAL"=NA, "ORIGINAL_STATUS_HPV11_ANAL"=NA, "ORIGINAL_STATUS_HPV11_ORAL"=NA, "ORIGINAL_STATUS_HPV16_ANAL"=NA, "ORIGINAL_STATUS_HPV16_ORAL"=NA, "ORIGINAL_STATUS_HPV18_ANAL"=NA, "ORIGINAL_STATUS_HPV18_ORAL"=NA, "ORIGINAL_STATUS_HPV31_ANAL"=NA, "ORIGINAL_STATUS_HPV31_ORAL"=NA, "ORIGINAL_STATUS_HPV33_ANAL"=NA, "ORIGINAL_STATUS_HPV33_ORAL"=NA, "ORIGINAL_STATUS_HPV45_ANAL"=NA, "ORIGINAL_STATUS_HPV45_ORAL"=NA, "ORIGINAL_STATUS_HPV52_ANAL"=NA, "ORIGINAL_STATUS_HPV52_ORAL"=NA, "ORIGINAL_STATUS_HPV58_ANAL"=NA, "ORIGINAL_STATUS_HPV58_ORAL"=NA, "PREP_PREVENT"=0, "TAP_PREVENT"=0, "SERO_PREVENT"=0, "COND_PREVENT_ANAL"=0, "COND_PREVENT_ORAL"=0, "VAX_PREVENT_ANAL"=0, "VAX_PREVENT_ORAL"=0,"OVERALL_PREVENT_ANAL"=0,"OVERALL_PREVENT_ORAL"=0, "DISCORDANT"=0, "CAUSE_INFECT"=0, "FINISHED_SEX"=0, "DAYS_KNOWN_POSITIVE"=-1, "INCIDENT_DAYS_HIV"=-1, "INCIDENCE_DAYS_HPV6_ANAL"=-1, "INCIDENCE_DAYS_HPV6_ORAL"=-1, "INCIDENCE_DAYS_HPV11_ANAL"=-1, "INCIDENCE_DAYS_HPV11_ORAL"=-1, "INCIDENCE_DAYS_HPV16_ANAL"=-1, "INCIDENCE_DAYS_HPV16_ORAL"=-1, "INCIDENCE_DAYS_HPV18_ANAL"=-1, "INCIDENCE_DAYS_HPV18_ORAL"=-1, "INCIDENCE_DAYS_HPV31_ANAL"=-1, "INCIDENCE_DAYS_HPV31_ORAL"=-1, "INCIDENCE_DAYS_HPV33_ANAL"=-1, "INCIDENCE_DAYS_HPV33_ORAL"=-1, "INCIDENCE_DAYS_HPV45_ANAL"=-1, "INCIDENCE_DAYS_HPV45_ORAL"=-1, "INCIDENCE_DAYS_HPV52_ANAL"=-1, "INCIDENCE_DAYS_HPV52_ORAL"=-1, "INCIDENCE_DAYS_HPV58_ANAL"=-1, "INCIDENCE_DAYS_HPV58_ORAL"=-1, stringsAsFactors=F)
  
  #infect initial population with HIV
  baseline_pop$HIV = ifelse(runif(10000,0,1)<=0.19, 1, 0)
  
  #viral load category: 1=chronic, 2=acute (everyone at baseline is chronic)
  baseline_pop$VL = ifelse(baseline_pop$HIV==1, 1, -1)

  #knowledge of HIV status: 1=HIV negative and aware (63%), 2=unknown, 3=HIV positive and aware (66%); data from CDC
  baseline_pop$STATUS = ifelse(baseline_pop$HIV==0 & runif(10000,0,1)<=0.369, 2, ifelse(baseline_pop$HIV==0, 1, NA))
  baseline_pop$STATUS = ifelse(is.na(baseline_pop$STATUS) & baseline_pop$HIV==1 & runif(10000,0,1)<=0.440, 2, ifelse(baseline_pop$HIV==1, 3, baseline_pop$STATUS))
  
  #infect intial population with HPV contingent upon HIV status
  baseline_pop$HPV6_ANAL = ifelse(baseline_pop$HIV==1, ifelse(runif(10000,0,1)<=0.329, 1, 0), ifelse(runif(10000,0,1)<=0.154, 1, 0))
  baseline_pop$HPV6_ORAL = ifelse(baseline_pop$HIV==1, ifelse(runif(10000,0,1)<=0.034, 1, 0), ifelse(runif(10000,0,1)<=0.008, 1, 0))
  baseline_pop$HPV11_ANAL = ifelse(baseline_pop$HIV==1, ifelse(runif(10000,0,1)<=0.182, 1, 0), ifelse(runif(10000,0,1)<=0.074, 1, 0))
  baseline_pop$HPV11_ORAL = ifelse(baseline_pop$HIV==1, ifelse(runif(10000,0,1)<=0.011, 1, 0), ifelse(runif(10000,0,1)<=0, 1, 0))
  baseline_pop$HPV16_ANAL = ifelse(baseline_pop$HIV==1, ifelse(runif(10000,0,1)<=0.364, 1, 0), ifelse(runif(10000,0,1)<=0.125, 1, 0))
  baseline_pop$HPV16_ORAL = ifelse(baseline_pop$HIV==1, ifelse(runif(10000,0,1)<=0.023, 1, 0), ifelse(runif(10000,0,1)<=0.011, 1, 0))
  baseline_pop$HPV18_ANAL = ifelse(baseline_pop$HIV==1, ifelse(runif(10000,0,1)<=0.329, 1, 0), ifelse(runif(10000,0,1)<=0.073, 1, 0))
  baseline_pop$HPV18_ORAL = ifelse(baseline_pop$HIV==1, ifelse(runif(10000,0,1)<=0.034, 1, 0), ifelse(runif(10000,0,1)<=0.005, 1, 0))
  baseline_pop$HPV31_ANAL = ifelse(baseline_pop$HIV==1, ifelse(runif(10000,0,1)<=0.141, 1, 0), ifelse(runif(10000,0,1)<=0.036, 1, 0))
  baseline_pop$HPV31_ORAL = ifelse(baseline_pop$HIV==1, ifelse(runif(10000,0,1)<=0.025, 1, 0), ifelse(runif(10000,0,1)<=0.002, 1, 0))
  baseline_pop$HPV33_ANAL = ifelse(baseline_pop$HIV==1, ifelse(runif(10000,0,1)<=0.069, 1, 0), ifelse(runif(10000,0,1)<=0.064, 1, 0))
  baseline_pop$HPV33_ORAL = ifelse(baseline_pop$HIV==1, ifelse(runif(10000,0,1)<=0.051, 1, 0), ifelse(runif(10000,0,1)<=0.010, 1, 0))
  baseline_pop$HPV45_ANAL = ifelse(baseline_pop$HIV==1, ifelse(runif(10000,0,1)<=0.152, 1, 0), ifelse(runif(10000,0,1)<=0.121, 1, 0))
  baseline_pop$HPV45_ORAL = ifelse(baseline_pop$HIV==1, ifelse(runif(10000,0,1)<=0.018, 1, 0), ifelse(runif(10000,0,1)<=0.002, 1, 0))
  baseline_pop$HPV52_ANAL = ifelse(baseline_pop$HIV==1, ifelse(runif(10000,0,1)<=0.242, 1, 0), ifelse(runif(10000,0,1)<=0.090, 1, 0))
  baseline_pop$HPV52_ORAL = ifelse(baseline_pop$HIV==1, ifelse(runif(10000,0,1)<=0.018, 1, 0), ifelse(runif(10000,0,1)<=0.010, 1, 0))
  baseline_pop$HPV58_ANAL = ifelse(baseline_pop$HIV==1, ifelse(runif(10000,0,1)<=0.211, 1, 0), ifelse(runif(10000,0,1)<=0.098, 1, 0))
  baseline_pop$HPV58_ORAL = ifelse(baseline_pop$HIV==1, ifelse(runif(10000,0,1)<=0.007, 1, 0), ifelse(runif(10000,0,1)<=0, 1, 0))
  baseline_pop$HPV_ANAL = ifelse(baseline_pop$HPV6_ANAL==1 | baseline_pop$HPV11_ANAL==1 | baseline_pop$HPV16_ANAL==1 | baseline_pop$HPV18_ANAL==1 | baseline_pop$HPV31_ANAL==1 | baseline_pop$HPV33_ANAL==1 | baseline_pop$HPV45_ANAL==1 | baseline_pop$HPV52_ANAL==1 | baseline_pop$HPV58_ANAL==1, 1, 0)
  baseline_pop$HPV_ORAL = ifelse(baseline_pop$HPV6_ORAL==1 | baseline_pop$HPV11_ORAL==1 | baseline_pop$HPV16_ORAL==1 | baseline_pop$HPV18_ORAL==1 | baseline_pop$HPV31_ORAL==1 | baseline_pop$HPV33_ORAL==1 | baseline_pop$HPV45_ORAL==1 | baseline_pop$HPV52_ORAL==1 | baseline_pop$HPV58_ORAL==1, 1, 0)
  
  #set proportion of prevalent cases as incident
  baseline_pop$INCIDENCE_DAYS_HPV6_ANAL = ifelse(baseline_pop$HPV6_ANAL==1 & runif(10000,0,1)<=0.19, round(runif(sum(baseline_pop$HPV6_ANAL),0,228)), baseline_pop$INCIDENCE_DAYS_HPV6_ANAL)
  baseline_pop$INCIDENCE_DAYS_HPV6_ORAL = ifelse(baseline_pop$HPV6_ORAL==1 & runif(10000,0,1)<=0.16, round(runif(sum(baseline_pop$HPV6_ORAL),0,228)), baseline_pop$INCIDENCE_DAYS_HPV6_ORAL)
  baseline_pop$INCIDENCE_DAYS_HPV11_ANAL = ifelse(baseline_pop$HPV11_ANAL==1 & runif(10000,0,1)<=0.19, round(runif(sum(baseline_pop$HPV11_ANAL),0,228)), baseline_pop$INCIDENCE_DAYS_HPV11_ANAL)
  baseline_pop$INCIDENCE_DAYS_HPV11_ORAL = ifelse(baseline_pop$HPV11_ORAL==1 & runif(10000,0,1)<=0.16, round(runif(sum(baseline_pop$HPV11_ORAL),0,228)), baseline_pop$INCIDENCE_DAYS_HPV11_ORAL)
  baseline_pop$INCIDENCE_DAYS_HPV16_ANAL = ifelse(baseline_pop$HPV16_ANAL==1 & runif(10000,0,1)<=0.19, round(runif(sum(baseline_pop$HPV16_ANAL),0,228)), baseline_pop$INCIDENCE_DAYS_HPV16_ANAL)
  baseline_pop$INCIDENCE_DAYS_HPV16_ORAL = ifelse(baseline_pop$HPV16_ORAL==1 & runif(10000,0,1)<=0.16, round(runif(sum(baseline_pop$HPV16_ORAL),0,228)), baseline_pop$INCIDENCE_DAYS_HPV16_ORAL)
  baseline_pop$INCIDENCE_DAYS_HPV18_ANAL = ifelse(baseline_pop$HPV18_ANAL==1 & runif(10000,0,1)<=0.19, round(runif(sum(baseline_pop$HPV18_ANAL),0,228)), baseline_pop$INCIDENCE_DAYS_HPV18_ANAL)
  baseline_pop$INCIDENCE_DAYS_HPV18_ORAL = ifelse(baseline_pop$HPV18_ORAL==1 & runif(10000,0,1)<=0.16, round(runif(sum(baseline_pop$HPV18_ORAL),0,228)), baseline_pop$INCIDENCE_DAYS_HPV18_ORAL)
  baseline_pop$INCIDENCE_DAYS_HPV31_ANAL = ifelse(baseline_pop$HPV31_ANAL==1 & runif(10000,0,1)<=0.19, round(runif(sum(baseline_pop$HPV31_ANAL),0,228)), baseline_pop$INCIDENCE_DAYS_HPV31_ANAL)
  baseline_pop$INCIDENCE_DAYS_HPV31_ORAL = ifelse(baseline_pop$HPV31_ORAL==1 & runif(10000,0,1)<=0.16, round(runif(sum(baseline_pop$HPV31_ORAL),0,228)), baseline_pop$INCIDENCE_DAYS_HPV31_ORAL)
  baseline_pop$INCIDENCE_DAYS_HPV33_ANAL = ifelse(baseline_pop$HPV33_ANAL==1 & runif(10000,0,1)<=0.19, round(runif(sum(baseline_pop$HPV33_ANAL),0,228)), baseline_pop$INCIDENCE_DAYS_HPV33_ANAL)
  baseline_pop$INCIDENCE_DAYS_HPV33_ORAL = ifelse(baseline_pop$HPV33_ORAL==1 & runif(10000,0,1)<=0.16, round(runif(sum(baseline_pop$HPV33_ORAL),0,228)), baseline_pop$INCIDENCE_DAYS_HPV33_ORAL)
  baseline_pop$INCIDENCE_DAYS_HPV45_ANAL = ifelse(baseline_pop$HPV45_ANAL==1 & runif(10000,0,1)<=0.19, round(runif(sum(baseline_pop$HPV45_ANAL),0,228)), baseline_pop$INCIDENCE_DAYS_HPV45_ANAL)
  baseline_pop$INCIDENCE_DAYS_HPV45_ORAL = ifelse(baseline_pop$HPV45_ORAL==1 & runif(10000,0,1)<=0.16, round(runif(sum(baseline_pop$HPV45_ORAL),0,228)), baseline_pop$INCIDENCE_DAYS_HPV45_ORAL)
  baseline_pop$INCIDENCE_DAYS_HPV52_ANAL = ifelse(baseline_pop$HPV52_ANAL==1 & runif(10000,0,1)<=0.19, round(runif(sum(baseline_pop$HPV52_ANAL),0,228)), baseline_pop$INCIDENCE_DAYS_HPV52_ANAL)
  baseline_pop$INCIDENCE_DAYS_HPV52_ORAL = ifelse(baseline_pop$HPV52_ORAL==1 & runif(10000,0,1)<=0.16, round(runif(sum(baseline_pop$HPV52_ORAL),0,228)), baseline_pop$INCIDENCE_DAYS_HPV52_ORAL)
  baseline_pop$INCIDENCE_DAYS_HPV58_ANAL = ifelse(baseline_pop$HPV58_ANAL==1 & runif(10000,0,1)<=0.19, round(runif(sum(baseline_pop$HPV58_ANAL),0,228)), baseline_pop$INCIDENCE_DAYS_HPV58_ANAL)
  baseline_pop$INCIDENCE_DAYS_HPV58_ORAL = ifelse(baseline_pop$HPV58_ORAL==1 & runif(10000,0,1)<=0.16, round(runif(sum(baseline_pop$HPV58_ORAL),0,228)), baseline_pop$INCIDENCE_DAYS_HPV58_ORAL)  

  #circumcision status
  baseline_pop$CIRC = ifelse(runif(10000,0,1)<=0.647, 1, 0)
  
  #sex act preference, 1=anal only, 2=oral only, 3=both
  randact = runif(10000,0,1)
  baseline_pop$SEX_ACT = ifelse(randact<=0.22, 1, ifelse(randact<=0.66, 2, 3))
  rm(randact)
  #baseline_pop$SEX_ACT = 1 #force everyone to have anal sex
  #baseline_pop$SEX_ACT = 2 #force everyone to have oral sex
  
  #sex_position preference, 1=insertive, 2=receptive, 3=both
  analpref = runif(10000,0,1)
  oralpref = runif(10000,0,1)
  baseline_pop$SEX_POSITION_ANAL_PREF = ifelse(analpref<=0.39, 1, ifelse(analpref<=0.62, 2, 3))
  baseline_pop$SEX_POSITION_ORAL_PREF = ifelse(oralpref<=0.16, 1, ifelse(oralpref<=0.30, 2, 3))
  rm(analpref,oralpref)
  
  #sex position (scale of dominance), if preference cannot be honored
  baseline_pop$SEX_POSITION_ANAL = runif(10000,0,1)
  baseline_pop$SEX_POSITION_ORAL = runif(10000,0,1)
  
  #day of year will be tested for HIV, based on a future test probability of 1=tested 1/3 of year, 2=tested 2/3 of year, 3=tested 3/3 of year, 4=not tested; data from Kaiser Family Foundation
  testprob = runif(10000,0,1)
  baseline_pop$futuretest = ifelse(baseline_pop$STATUS==3, 4, ifelse(testprob<=0.19, 1, ifelse(testprob<=0.30, 2, ifelse(testprob<=0.70, 3, 4))))
  probdaytest = runif(10000,0,1)
  baseline_pop$TEST_DAY = ifelse(baseline_pop$futuretest==1, round(1+(110-1)*probdaytest), ifelse(baseline_pop$futuretest==2, round(111+(220-111)*probdaytest), ifelse(baseline_pop$futuretest==3, round(221+(330-221)*probdaytest), -1)))
  rm(testprob,probdaytest)
  baseline_pop$futuretest = NULL
  
  #partner distribution, based on a gamma distribution
  baseline_pop$MAX_PARTNERS = round(rgamma(10000, shape=0.5, scale=10)+1) #using Project Male-Call
  
  #original status of infections
  baseline_pop$ORIGINAL_STATUS_HIV = baseline_pop$HIV
  baseline_pop$ORIGINAL_STATUS_HPV6_ANAL = baseline_pop$HPV6_ANAL
  baseline_pop$ORIGINAL_STATUS_HPV6_ORAL = baseline_pop$HPV6_ORAL
  baseline_pop$ORIGINAL_STATUS_HPV11_ANAL = baseline_pop$HPV11_ANAL
  baseline_pop$ORIGINAL_STATUS_HPV11_ORAL = baseline_pop$HPV11_ORAL
  baseline_pop$ORIGINAL_STATUS_HPV16_ANAL = baseline_pop$HPV16_ANAL
  baseline_pop$ORIGINAL_STATUS_HPV16_ORAL = baseline_pop$HPV16_ORAL
  baseline_pop$ORIGINAL_STATUS_HPV18_ANAL = baseline_pop$HPV18_ANAL
  baseline_pop$ORIGINAL_STATUS_HPV18_ORAL = baseline_pop$HPV18_ORAL
  baseline_pop$ORIGINAL_STATUS_HPV31_ANAL = baseline_pop$HPV31_ANAL
  baseline_pop$ORIGINAL_STATUS_HPV31_ORAL = baseline_pop$HPV31_ORAL
  baseline_pop$ORIGINAL_STATUS_HPV33_ANAL = baseline_pop$HPV33_ANAL
  baseline_pop$ORIGINAL_STATUS_HPV33_ORAL = baseline_pop$HPV33_ORAL
  baseline_pop$ORIGINAL_STATUS_HPV45_ANAL = baseline_pop$HPV45_ANAL
  baseline_pop$ORIGINAL_STATUS_HPV45_ORAL = baseline_pop$HPV45_ORAL
  baseline_pop$ORIGINAL_STATUS_HPV52_ANAL = baseline_pop$HPV52_ANAL
  baseline_pop$ORIGINAL_STATUS_HPV52_ORAL = baseline_pop$HPV52_ORAL
  baseline_pop$ORIGINAL_STATUS_HPV58_ANAL = baseline_pop$HPV58_ANAL
  baseline_pop$ORIGINAL_STATUS_HPV58_ORAL = baseline_pop$HPV58_ORAL
  baseline_pop$ORIGINAL_STATUS_HPV_ANAL = baseline_pop$HPV_ANAL
  baseline_pop$ORIGINAL_STATUS_HPV_ORAL = baseline_pop$HPV_ORAL
  
  
  ### STEP2: ASSIGNMENT OF PREVENTION PARADIGMS ###

  randprep = runif(10000,0,1)
  randtap = runif(10000,0,1)
  randcond = runif(10000,0,1)
  randsero = runif(10000,0,1)
  randvax =  runif(10000,0,1)

  #create prevention paradigm datasets: abcde where a=prep, b=treatment as prevention, c=condom use, d=seroadaption, e=vaccination
  paradigm11111 = baseline_pop

  #PrEP, TasP, condoms, seroadaption, vaccination
  paradigm11111$PREP = 1
  paradigm11111$TAP = 1
  paradigm11111$COND = 1
  paradigm11111$SERO = 1
  paradigm11111$VAX = 1
  paradigm11111$ONPREP = prevention_paradigm(randprep,"ONPREP",paradigm11111,0.01)
  paradigm11111$TAPVL = prevention_paradigm(randtap,"TAPVL",paradigm11111)
  paradigm11111$PROBCOND = prevention_paradigm(randcond,"PROBCOND",paradigm11111)
  paradigm11111$SEROTYPE = prevention_paradigm(randsero,"SEROTYPE",paradigm11111)

  #assign into lists by vaccination coverage
  prep_sims = list("Paradigm11111Vax0"=cbind(paradigm11111,"HPVDOSES"=prevention_paradigm(randvax,"HPVDOSES",paradigm11111,0)),
                   "Paradigm11111Vax13"=cbind(paradigm11111,"HPVDOSES"=prevention_paradigm(randvax,"HPVDOSES",paradigm11111,0.13)),
                   "Paradigm11111Vax25"=cbind(paradigm11111,"HPVDOSES"=prevention_paradigm(randvax,"HPVDOSES",paradigm11111,0.25)),
                   "Paradigm11111Vax50"=cbind(paradigm11111,"HPVDOSES"=prevention_paradigm(randvax,"HPVDOSES",paradigm11111,0.50)),
                   "Paradigm11111Vax80"=cbind(paradigm11111,"HPVDOSES"=prevention_paradigm(randvax,"HPVDOSES",paradigm11111,0.80)),
                   "Paradigm11111Vax100"=cbind(paradigm11111,"HPVDOSES"=prevention_paradigm(randvax,"HPVDOSES",paradigm11111,1)))

  #cleanup
  rm(randtap,randcond,randsero,randprep,randvax,baseline_pop,paradigm11111)
  gc()

  
  ### STEP3: SIMULATE ###
  
  #ensure that each day is unique
  seed_val_day = sample(1:1000,365,replace=F)
  
  for (day in 1:365)
  {
    cat("\n\n************** ","Day: ",day," **************\n",sep="")
    
    #go through each scenario
    for (current_data in 1:length(prep_sims))
    {
      #cat("\n\n************** ","Scenario: ",current_data," **************\n",sep="")
      
      ## SET DAILY VARIABLES ##
      
      #ensure each scenario is identical for a given day
      set.seed(seed_val_day[day])
      
      #check if reached max number of partners
      prep_sims[[current_data]]$FINISHED_SEX = ifelse(prep_sims[[current_data]]$SEX_PARTNERS>=prep_sims[[current_data]]$MAX_PARTNERS, 1, 0)
      
      #HIV testing today?
      prep_sims[[current_data]]$STATUS = ifelse(day==prep_sims[[current_data]]$TEST_DAY & prep_sims[[current_data]]$HIV==1, 3, prep_sims[[current_data]]$STATUS)
      
      #check if testing identify as positive, used for TAP, after 30 days you may be virally suppressed
      prep_sims[[current_data]]$DAYS_KNOWN_POSITIVE = ifelse(day==prep_sims[[current_data]]$TEST_DAY & prep_sims[[current_data]]$HIV==1, 1, prep_sims[[current_data]]$DAYS_KNOWN_POSITIVE)
      
      #increment days positive, if positive
      prep_sims[[current_data]]$DAYS_KNOWN_POSITIVE = ifelse(prep_sims[[current_data]]$DAYS_KNOWN_POSITIVE>=0, prep_sims[[current_data]]$DAYS_KNOWN_POSITIVE+1, prep_sims[[current_data]]$DAYS_KNOWN_POSITIVE)
      
      #in a TAP scenario, if put on treatment, after 30 days viral load goes to undetectable
      prep_sims[[current_data]]$TAPVL = ifelse(prep_sims[[current_data]]$TAP==1 & prep_sims[[current_data]]$DAYS_KNOWN_POSITIVE==30 & prep_sims[[current_data]]$HIV==1 & runif(nrow(prep_sims[[current_data]]),0,1)<=0.42, 1, prep_sims[[current_data]]$TAPVL)
      
      #increment HIV incident days
      prep_sims[[current_data]]$INCIDENT_DAYS_HIV = ifelse(prep_sims[[current_data]]$INCIDENT_DAYS_HIV>=0, prep_sims[[current_data]]$INCIDENT_DAYS_HIV+1, prep_sims[[current_data]]$INCIDENT_DAYS_HIV)
      
      #resolve acute phase of HIV infection
      prep_sims[[current_data]]$VL = ifelse(prep_sims[[current_data]]$VL==2 & prep_sims[[current_data]]$INCIDENT_DAYS_HIV==30, 1, prep_sims[[current_data]]$VL)
      
      #if HIV positive and aware and set as receptive
      prep_sims[[current_data]]$SEROTYPE = ifelse(prep_sims[[current_data]]$STATUS==3 & prep_sims[[current_data]]$SEROTYPE==1, 2, prep_sims[[current_data]]$SEROTYPE) 
      
      #increment HPV incident days
      prep_sims[[current_data]]$INCIDENCE_DAYS_HPV6_ANAL = ifelse(prep_sims[[current_data]]$INCIDENCE_DAYS_HPV6_ANAL>=0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV6_ANAL+1, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV6_ANAL)
      prep_sims[[current_data]]$INCIDENCE_DAYS_HPV6_ORAL = ifelse(prep_sims[[current_data]]$INCIDENCE_DAYS_HPV6_ORAL>=0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV6_ORAL+1, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV6_ORAL)
      prep_sims[[current_data]]$INCIDENCE_DAYS_HPV11_ANAL = ifelse(prep_sims[[current_data]]$INCIDENCE_DAYS_HPV11_ANAL>=0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV11_ANAL+1, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV11_ANAL)
      prep_sims[[current_data]]$INCIDENCE_DAYS_HPV11_ORAL = ifelse(prep_sims[[current_data]]$INCIDENCE_DAYS_HPV11_ORAL>=0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV11_ORAL+1, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV11_ORAL)
      prep_sims[[current_data]]$INCIDENCE_DAYS_HPV16_ANAL = ifelse(prep_sims[[current_data]]$INCIDENCE_DAYS_HPV16_ANAL>=0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV16_ANAL+1, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV16_ANAL)
      prep_sims[[current_data]]$INCIDENCE_DAYS_HPV16_ORAL = ifelse(prep_sims[[current_data]]$INCIDENCE_DAYS_HPV16_ORAL>=0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV16_ORAL+1, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV16_ORAL)
      prep_sims[[current_data]]$INCIDENCE_DAYS_HPV18_ANAL = ifelse(prep_sims[[current_data]]$INCIDENCE_DAYS_HPV18_ANAL>=0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV18_ANAL+1, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV18_ANAL)
      prep_sims[[current_data]]$INCIDENCE_DAYS_HPV18_ORAL = ifelse(prep_sims[[current_data]]$INCIDENCE_DAYS_HPV18_ORAL>=0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV18_ORAL+1, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV18_ORAL)
      prep_sims[[current_data]]$INCIDENCE_DAYS_HPV31_ANAL = ifelse(prep_sims[[current_data]]$INCIDENCE_DAYS_HPV31_ANAL>=0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV31_ANAL+1, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV31_ANAL)
      prep_sims[[current_data]]$INCIDENCE_DAYS_HPV31_ORAL = ifelse(prep_sims[[current_data]]$INCIDENCE_DAYS_HPV31_ORAL>=0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV31_ORAL+1, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV31_ORAL)
      prep_sims[[current_data]]$INCIDENCE_DAYS_HPV33_ANAL = ifelse(prep_sims[[current_data]]$INCIDENCE_DAYS_HPV33_ANAL>=0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV33_ANAL+1, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV33_ANAL)
      prep_sims[[current_data]]$INCIDENCE_DAYS_HPV33_ORAL = ifelse(prep_sims[[current_data]]$INCIDENCE_DAYS_HPV33_ORAL>=0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV33_ORAL+1, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV33_ORAL)
      prep_sims[[current_data]]$INCIDENCE_DAYS_HPV45_ANAL = ifelse(prep_sims[[current_data]]$INCIDENCE_DAYS_HPV45_ANAL>=0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV45_ANAL+1, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV45_ANAL)
      prep_sims[[current_data]]$INCIDENCE_DAYS_HPV45_ORAL = ifelse(prep_sims[[current_data]]$INCIDENCE_DAYS_HPV45_ORAL>=0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV45_ORAL+1, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV45_ORAL)
      prep_sims[[current_data]]$INCIDENCE_DAYS_HPV52_ANAL = ifelse(prep_sims[[current_data]]$INCIDENCE_DAYS_HPV52_ANAL>=0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV52_ANAL+1, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV52_ANAL)
      prep_sims[[current_data]]$INCIDENCE_DAYS_HPV52_ORAL = ifelse(prep_sims[[current_data]]$INCIDENCE_DAYS_HPV52_ORAL>=0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV52_ORAL+1, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV52_ORAL)
      prep_sims[[current_data]]$INCIDENCE_DAYS_HPV58_ANAL = ifelse(prep_sims[[current_data]]$INCIDENCE_DAYS_HPV58_ANAL>=0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV58_ANAL+1, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV58_ANAL)
      prep_sims[[current_data]]$INCIDENCE_DAYS_HPV58_ORAL = ifelse(prep_sims[[current_data]]$INCIDENCE_DAYS_HPV58_ORAL>=0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV58_ORAL+1, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV58_ORAL)
      
      #resolve spontaneous HPV clearance
      prep_sims[[current_data]]$HPV6_ANAL = ifelse(prep_sims[[current_data]]$HPV6_ANAL==1 & prep_sims[[current_data]]$INCIDENCE_DAYS_HPV6_ANAL==228 & runif(nrow(prep_sims[[current_data]]),0,1)<=0.50, -1, prep_sims[[current_data]]$HPV6_ANAL)
      prep_sims[[current_data]]$HPV6_ORAL = ifelse(prep_sims[[current_data]]$HPV6_ORAL==1 & prep_sims[[current_data]]$INCIDENCE_DAYS_HPV6_ORAL==228 & runif(nrow(prep_sims[[current_data]]),0,1)<=0.50, -1, prep_sims[[current_data]]$HPV6_ORAL)
      prep_sims[[current_data]]$HPV11_ANAL = ifelse(prep_sims[[current_data]]$HPV11_ANAL==1 & prep_sims[[current_data]]$INCIDENCE_DAYS_HPV11_ANAL==228 & runif(nrow(prep_sims[[current_data]]),0,1)<=0.50, -1, prep_sims[[current_data]]$HPV11_ANAL)
      prep_sims[[current_data]]$HPV11_ORAL = ifelse(prep_sims[[current_data]]$HPV11_ORAL==1 & prep_sims[[current_data]]$INCIDENCE_DAYS_HPV11_ORAL==228 & runif(nrow(prep_sims[[current_data]]),0,1)<=0.50, -1, prep_sims[[current_data]]$HPV11_ORAL)
      prep_sims[[current_data]]$HPV16_ANAL = ifelse(prep_sims[[current_data]]$HPV16_ANAL==1 & prep_sims[[current_data]]$INCIDENCE_DAYS_HPV16_ANAL==228 & runif(nrow(prep_sims[[current_data]]),0,1)<=0.50, -1, prep_sims[[current_data]]$HPV16_ANAL)
      prep_sims[[current_data]]$HPV16_ORAL = ifelse(prep_sims[[current_data]]$HPV16_ORAL==1 & prep_sims[[current_data]]$INCIDENCE_DAYS_HPV16_ORAL==228 & runif(nrow(prep_sims[[current_data]]),0,1)<=0.50, -1, prep_sims[[current_data]]$HPV16_ORAL)
      prep_sims[[current_data]]$HPV18_ANAL = ifelse(prep_sims[[current_data]]$HPV18_ANAL==1 & prep_sims[[current_data]]$INCIDENCE_DAYS_HPV18_ANAL==228 & runif(nrow(prep_sims[[current_data]]),0,1)<=0.50, -1, prep_sims[[current_data]]$HPV18_ANAL)
      prep_sims[[current_data]]$HPV18_ORAL = ifelse(prep_sims[[current_data]]$HPV18_ORAL==1 & prep_sims[[current_data]]$INCIDENCE_DAYS_HPV18_ORAL==228 & runif(nrow(prep_sims[[current_data]]),0,1)<=0.50, -1, prep_sims[[current_data]]$HPV18_ORAL)
      prep_sims[[current_data]]$HPV31_ANAL = ifelse(prep_sims[[current_data]]$HPV31_ANAL==1 & prep_sims[[current_data]]$INCIDENCE_DAYS_HPV31_ANAL==228 & runif(nrow(prep_sims[[current_data]]),0,1)<=0.50, -1, prep_sims[[current_data]]$HPV31_ANAL)
      prep_sims[[current_data]]$HPV31_ORAL = ifelse(prep_sims[[current_data]]$HPV31_ORAL==1 & prep_sims[[current_data]]$INCIDENCE_DAYS_HPV31_ORAL==228 & runif(nrow(prep_sims[[current_data]]),0,1)<=0.50, -1, prep_sims[[current_data]]$HPV31_ORAL)
      prep_sims[[current_data]]$HPV33_ANAL = ifelse(prep_sims[[current_data]]$HPV33_ANAL==1 & prep_sims[[current_data]]$INCIDENCE_DAYS_HPV33_ANAL==228 & runif(nrow(prep_sims[[current_data]]),0,1)<=0.50, -1, prep_sims[[current_data]]$HPV33_ANAL)
      prep_sims[[current_data]]$HPV33_ORAL = ifelse(prep_sims[[current_data]]$HPV33_ORAL==1 & prep_sims[[current_data]]$INCIDENCE_DAYS_HPV33_ORAL==228 & runif(nrow(prep_sims[[current_data]]),0,1)<=0.50, -1, prep_sims[[current_data]]$HPV33_ORAL)
      prep_sims[[current_data]]$HPV45_ANAL = ifelse(prep_sims[[current_data]]$HPV45_ANAL==1 & prep_sims[[current_data]]$INCIDENCE_DAYS_HPV45_ANAL==228 & runif(nrow(prep_sims[[current_data]]),0,1)<=0.50, -1, prep_sims[[current_data]]$HPV45_ANAL)
      prep_sims[[current_data]]$HPV45_ORAL = ifelse(prep_sims[[current_data]]$HPV45_ORAL==1 & prep_sims[[current_data]]$INCIDENCE_DAYS_HPV45_ORAL==228 & runif(nrow(prep_sims[[current_data]]),0,1)<=0.50, -1, prep_sims[[current_data]]$HPV45_ORAL)
      prep_sims[[current_data]]$HPV52_ANAL = ifelse(prep_sims[[current_data]]$HPV52_ANAL==1 & prep_sims[[current_data]]$INCIDENCE_DAYS_HPV52_ANAL==228 & runif(nrow(prep_sims[[current_data]]),0,1)<=0.50, -1, prep_sims[[current_data]]$HPV52_ANAL)
      prep_sims[[current_data]]$HPV52_ORAL = ifelse(prep_sims[[current_data]]$HPV52_ORAL==1 & prep_sims[[current_data]]$INCIDENCE_DAYS_HPV52_ORAL==228 & runif(nrow(prep_sims[[current_data]]),0,1)<=0.50, -1, prep_sims[[current_data]]$HPV52_ORAL)
      prep_sims[[current_data]]$HPV58_ANAL = ifelse(prep_sims[[current_data]]$HPV58_ANAL==1 & prep_sims[[current_data]]$INCIDENCE_DAYS_HPV58_ANAL==228 & runif(nrow(prep_sims[[current_data]]),0,1)<=0.50, -1, prep_sims[[current_data]]$HPV58_ANAL)
      prep_sims[[current_data]]$HPV58_ORAL = ifelse(prep_sims[[current_data]]$HPV58_ORAL==1 & prep_sims[[current_data]]$INCIDENCE_DAYS_HPV58_ORAL==228 & runif(nrow(prep_sims[[current_data]]),0,1)<=0.50, -1, prep_sims[[current_data]]$HPV58_ORAL)
      prep_sims[[current_data]]$HPV6_ANAL_CLEARED = ifelse(prep_sims[[current_data]]$HPV6_ANAL==-1, prep_sims[[current_data]]$HPV6_ANAL_CLEARED+1, prep_sims[[current_data]]$HPV6_ANAL_CLEARED)
      prep_sims[[current_data]]$HPV6_ANAL[prep_sims[[current_data]]$HPV6_ANAL==-1] = 0
      prep_sims[[current_data]]$HPV6_ORAL_CLEARED = ifelse(prep_sims[[current_data]]$HPV6_ORAL==-1, prep_sims[[current_data]]$HPV6_ORAL_CLEARED+1, prep_sims[[current_data]]$HPV6_ORAL_CLEARED)
      prep_sims[[current_data]]$HPV6_ORAL[prep_sims[[current_data]]$HPV6_ORAL==-1] = 0
      prep_sims[[current_data]]$HPV11_ANAL_CLEARED = ifelse(prep_sims[[current_data]]$HPV11_ANAL==-1, prep_sims[[current_data]]$HPV11_ANAL_CLEARED+1, prep_sims[[current_data]]$HPV11_ANAL_CLEARED)
      prep_sims[[current_data]]$HPV11_ANAL[prep_sims[[current_data]]$HPV11_ANAL==-1] = 0
      prep_sims[[current_data]]$HPV11_ORAL_CLEARED = ifelse(prep_sims[[current_data]]$HPV11_ORAL==-1, prep_sims[[current_data]]$HPV11_ORAL_CLEARED+1, prep_sims[[current_data]]$HPV11_ORAL_CLEARED)
      prep_sims[[current_data]]$HPV11_ORAL[prep_sims[[current_data]]$HPV11_ORAL==-1] = 0
      prep_sims[[current_data]]$HPV16_ANAL_CLEARED = ifelse(prep_sims[[current_data]]$HPV16_ANAL==-1, prep_sims[[current_data]]$HPV16_ANAL_CLEARED+1, prep_sims[[current_data]]$HPV16_ANAL_CLEARED)
      prep_sims[[current_data]]$HPV16_ANAL[prep_sims[[current_data]]$HPV16_ANAL==-1] = 0
      prep_sims[[current_data]]$HPV16_ORAL_CLEARED = ifelse(prep_sims[[current_data]]$HPV16_ORAL==-1, prep_sims[[current_data]]$HPV16_ORAL_CLEARED+1, prep_sims[[current_data]]$HPV16_ORAL_CLEARED)
      prep_sims[[current_data]]$HPV16_ORAL[prep_sims[[current_data]]$HPV16_ORAL==-1] = 0
      prep_sims[[current_data]]$HPV18_ANAL_CLEARED = ifelse(prep_sims[[current_data]]$HPV18_ANAL==-1, prep_sims[[current_data]]$HPV18_ANAL_CLEARED+1, prep_sims[[current_data]]$HPV18_ANAL_CLEARED)
      prep_sims[[current_data]]$HPV18_ANAL[prep_sims[[current_data]]$HPV18_ANAL==-1] = 0
      prep_sims[[current_data]]$HPV18_ORAL_CLEARED = ifelse(prep_sims[[current_data]]$HPV18_ORAL==-1, prep_sims[[current_data]]$HPV18_ORAL_CLEARED+1, prep_sims[[current_data]]$HPV18_ORAL_CLEARED)
      prep_sims[[current_data]]$HPV18_ORAL[prep_sims[[current_data]]$HPV18_ORAL==-1] = 0
      prep_sims[[current_data]]$HPV31_ANAL_CLEARED = ifelse(prep_sims[[current_data]]$HPV31_ANAL==-1, prep_sims[[current_data]]$HPV31_ANAL_CLEARED+1, prep_sims[[current_data]]$HPV31_ANAL_CLEARED)
      prep_sims[[current_data]]$HPV31_ANAL[prep_sims[[current_data]]$HPV31_ANAL==-1] = 0
      prep_sims[[current_data]]$HPV31_ORAL_CLEARED = ifelse(prep_sims[[current_data]]$HPV31_ORAL==-1, prep_sims[[current_data]]$HPV31_ORAL_CLEARED+1, prep_sims[[current_data]]$HPV31_ORAL_CLEARED)
      prep_sims[[current_data]]$HPV31_ORAL[prep_sims[[current_data]]$HPV31_ORAL==-1] = 0
      prep_sims[[current_data]]$HPV33_ANAL_CLEARED = ifelse(prep_sims[[current_data]]$HPV33_ANAL==-1, prep_sims[[current_data]]$HPV33_ANAL_CLEARED+1, prep_sims[[current_data]]$HPV33_ANAL_CLEARED)
      prep_sims[[current_data]]$HPV33_ANAL[prep_sims[[current_data]]$HPV33_ANAL==-1] = 0
      prep_sims[[current_data]]$HPV33_ORAL_CLEARED = ifelse(prep_sims[[current_data]]$HPV33_ORAL==-1, prep_sims[[current_data]]$HPV33_ORAL_CLEARED+1, prep_sims[[current_data]]$HPV33_ORAL_CLEARED)
      prep_sims[[current_data]]$HPV33_ORAL[prep_sims[[current_data]]$HPV33_ORAL==-1] = 0
      prep_sims[[current_data]]$HPV45_ANAL_CLEARED = ifelse(prep_sims[[current_data]]$HPV45_ANAL==-1, prep_sims[[current_data]]$HPV45_ANAL_CLEARED+1, prep_sims[[current_data]]$HPV45_ANAL_CLEARED)
      prep_sims[[current_data]]$HPV45_ANAL[prep_sims[[current_data]]$HPV45_ANAL==-1] = 0
      prep_sims[[current_data]]$HPV45_ORAL_CLEARED = ifelse(prep_sims[[current_data]]$HPV45_ORAL==-1, prep_sims[[current_data]]$HPV45_ORAL_CLEARED+1, prep_sims[[current_data]]$HPV45_ORAL_CLEARED)
      prep_sims[[current_data]]$HPV45_ORAL[prep_sims[[current_data]]$HPV45_ORAL==-1] = 0
      prep_sims[[current_data]]$HPV52_ANAL_CLEARED = ifelse(prep_sims[[current_data]]$HPV52_ANAL==-1, prep_sims[[current_data]]$HPV52_ANAL_CLEARED+1, prep_sims[[current_data]]$HPV52_ANAL_CLEARED)
      prep_sims[[current_data]]$HPV52_ANAL[prep_sims[[current_data]]$HPV52_ANAL==-1] = 0
      prep_sims[[current_data]]$HPV52_ORAL_CLEARED = ifelse(prep_sims[[current_data]]$HPV52_ORAL==-1, prep_sims[[current_data]]$HPV52_ORAL_CLEARED+1, prep_sims[[current_data]]$HPV52_ORAL_CLEARED)
      prep_sims[[current_data]]$HPV52_ORAL[prep_sims[[current_data]]$HPV52_ORAL==-1] = 0
      prep_sims[[current_data]]$HPV58_ANAL_CLEARED = ifelse(prep_sims[[current_data]]$HPV58_ANAL==-1, prep_sims[[current_data]]$HPV58_ANAL_CLEARED+1, prep_sims[[current_data]]$HPV58_ANAL_CLEARED)
      prep_sims[[current_data]]$HPV58_ANAL[prep_sims[[current_data]]$HPV58_ANAL==-1] = 0
      prep_sims[[current_data]]$HPV58_ORAL_CLEARED = ifelse(prep_sims[[current_data]]$HPV58_ORAL==-1, prep_sims[[current_data]]$HPV58_ORAL_CLEARED+1, prep_sims[[current_data]]$HPV58_ORAL_CLEARED)
      prep_sims[[current_data]]$HPV58_ORAL[prep_sims[[current_data]]$HPV58_ORAL==-1] = 0
      prep_sims[[current_data]]$HPV_ANAL = ifelse(prep_sims[[current_data]]$HPV6_ANAL==1 | prep_sims[[current_data]]$HPV11_ANAL==1 | prep_sims[[current_data]]$HPV16_ANAL==1 | prep_sims[[current_data]]$HPV18_ANAL==1 | prep_sims[[current_data]]$HPV31_ANAL==1 | prep_sims[[current_data]]$HPV33_ANAL==1 | prep_sims[[current_data]]$HPV45_ANAL==1 | prep_sims[[current_data]]$HPV52_ANAL==1 | prep_sims[[current_data]]$HPV58_ANAL==1, 1, 0)
      prep_sims[[current_data]]$HPV_ORAL = ifelse(prep_sims[[current_data]]$HPV6_ORAL==1 | prep_sims[[current_data]]$HPV11_ORAL==1 | prep_sims[[current_data]]$HPV16_ORAL==1 | prep_sims[[current_data]]$HPV18_ORAL==1 | prep_sims[[current_data]]$HPV31_ORAL==1 | prep_sims[[current_data]]$HPV33_ORAL==1 | prep_sims[[current_data]]$HPV45_ORAL==1 | prep_sims[[current_data]]$HPV52_ORAL==1 | prep_sims[[current_data]]$HPV58_ORAL==1, 1, 0)
      
      ## ENGAGE IN SEX ##
      
      #determine who has sex today
      sex_list = prep_sims[[current_data]]$ID[prep_sims[[current_data]]$FINISHED_SEX==0 & (((prep_sims[[current_data]]$MAX_PARTNERS-prep_sims[[current_data]]$SEX_PARTNERS)/(366-day))>=runif(nrow(prep_sims[[current_data]]),0,1))]
      
      #now allocate those individuals randomly to two even groups to see who has sex; if sex_list is an odd length, one individual will not have sex
      sex_list1 = sample(sex_list, floor(length(sex_list)/2), replace=F)
      sex_list2 = sample(sex_list[!sex_list %in% sex_list1], length(sex_list1), replace=F)

      #create the exposure matrix for each pathogen
      sex_exposed = data.frame("Ego"=sex_list1, "Partner"=sex_list2, "Exposed"=0, "HIV"=0, "HPV6_ANAL"=0, "HPV6_ORAL"=0, "HPV11_ANAL"=0, "HPV11_ORAL"=0, "HPV16_ANAL"=0, "HPV16_ORAL"=0, "HPV18_ANAL"=0, "HPV18_ORAL"=0, "HPV31_ANAL"=0, "HPV31_ORAL"=0, "HPV33_ANAL"=0, "HPV33_ORAL"=0, "HPV45_ANAL"=0, "HPV45_ORAL"=0, "HPV52_ANAL"=0, "HPV52_ORAL"=0, "HPV58_ANAL"=0, "HPV58_ORAL"=0, stringsAsFactors=F)
      sex_exposed$HIV[which((prep_sims[[current_data]]$HIV[sex_list1] + prep_sims[[current_data]]$HIV[sex_list2])==1)] = 1
      sex_exposed$HPV6_ANAL[which((prep_sims[[current_data]]$HPV6_ANAL[sex_list1] + prep_sims[[current_data]]$HPV6_ANAL[sex_list2])==1)] = 1
      sex_exposed$HPV11_ANAL[which((prep_sims[[current_data]]$HPV11_ANAL[sex_list1] + prep_sims[[current_data]]$HPV11_ANAL[sex_list2])==1)] = 1
      sex_exposed$HPV16_ANAL[which((prep_sims[[current_data]]$HPV16_ANAL[sex_list1] + prep_sims[[current_data]]$HPV16_ANAL[sex_list2])==1)] = 1
      sex_exposed$HPV18_ANAL[which((prep_sims[[current_data]]$HPV18_ANAL[sex_list1] + prep_sims[[current_data]]$HPV18_ANAL[sex_list2])==1)] = 1
      sex_exposed$HPV31_ANAL[which((prep_sims[[current_data]]$HPV31_ANAL[sex_list1] + prep_sims[[current_data]]$HPV31_ANAL[sex_list2])==1)] = 1
      sex_exposed$HPV33_ANAL[which((prep_sims[[current_data]]$HPV33_ANAL[sex_list1] + prep_sims[[current_data]]$HPV33_ANAL[sex_list2])==1)] = 1
      sex_exposed$HPV45_ANAL[which((prep_sims[[current_data]]$HPV45_ANAL[sex_list1] + prep_sims[[current_data]]$HPV45_ANAL[sex_list2])==1)] = 1
      sex_exposed$HPV52_ANAL[which((prep_sims[[current_data]]$HPV52_ANAL[sex_list1] + prep_sims[[current_data]]$HPV52_ANAL[sex_list2])==1)] = 1
      sex_exposed$HPV58_ANAL[which((prep_sims[[current_data]]$HPV58_ANAL[sex_list1] + prep_sims[[current_data]]$HPV58_ANAL[sex_list2])==1)] = 1
      sex_exposed$HPV6_ORAL[which((prep_sims[[current_data]]$HPV6_ORAL[sex_list1] + prep_sims[[current_data]]$HPV6_ANAL[sex_list2])==1)] = 1
      sex_exposed$HPV6_ORAL[which((prep_sims[[current_data]]$HPV6_ANAL[sex_list1] + prep_sims[[current_data]]$HPV6_ORAL[sex_list2])==1)] = 1
      sex_exposed$HPV11_ORAL[which((prep_sims[[current_data]]$HPV11_ORAL[sex_list1] + prep_sims[[current_data]]$HPV11_ANAL[sex_list2])==1)] = 1
      sex_exposed$HPV11_ORAL[which((prep_sims[[current_data]]$HPV11_ANAL[sex_list1] + prep_sims[[current_data]]$HPV11_ORAL[sex_list2])==1)] = 1
      sex_exposed$HPV16_ORAL[which((prep_sims[[current_data]]$HPV16_ORAL[sex_list1] + prep_sims[[current_data]]$HPV16_ANAL[sex_list2])==1)] = 1
      sex_exposed$HPV16_ORAL[which((prep_sims[[current_data]]$HPV16_ANAL[sex_list1] + prep_sims[[current_data]]$HPV16_ORAL[sex_list2])==1)] = 1
      sex_exposed$HPV18_ORAL[which((prep_sims[[current_data]]$HPV18_ORAL[sex_list1] + prep_sims[[current_data]]$HPV18_ANAL[sex_list2])==1)] = 1
      sex_exposed$HPV18_ORAL[which((prep_sims[[current_data]]$HPV18_ANAL[sex_list1] + prep_sims[[current_data]]$HPV18_ORAL[sex_list2])==1)] = 1
      sex_exposed$HPV31_ORAL[which((prep_sims[[current_data]]$HPV31_ORAL[sex_list1] + prep_sims[[current_data]]$HPV31_ANAL[sex_list2])==1)] = 1
      sex_exposed$HPV31_ORAL[which((prep_sims[[current_data]]$HPV31_ANAL[sex_list1] + prep_sims[[current_data]]$HPV31_ORAL[sex_list2])==1)] = 1
      sex_exposed$HPV33_ORAL[which((prep_sims[[current_data]]$HPV33_ORAL[sex_list1] + prep_sims[[current_data]]$HPV33_ANAL[sex_list2])==1)] = 1
      sex_exposed$HPV33_ORAL[which((prep_sims[[current_data]]$HPV33_ANAL[sex_list1] + prep_sims[[current_data]]$HPV33_ORAL[sex_list2])==1)] = 1
      sex_exposed$HPV45_ORAL[which((prep_sims[[current_data]]$HPV45_ORAL[sex_list1] + prep_sims[[current_data]]$HPV45_ANAL[sex_list2])==1)] = 1
      sex_exposed$HPV45_ORAL[which((prep_sims[[current_data]]$HPV45_ANAL[sex_list1] + prep_sims[[current_data]]$HPV45_ORAL[sex_list2])==1)] = 1
      sex_exposed$HPV52_ORAL[which((prep_sims[[current_data]]$HPV52_ORAL[sex_list1] + prep_sims[[current_data]]$HPV52_ANAL[sex_list2])==1)] = 1
      sex_exposed$HPV52_ORAL[which((prep_sims[[current_data]]$HPV52_ANAL[sex_list1] + prep_sims[[current_data]]$HPV52_ORAL[sex_list2])==1)] = 1
      sex_exposed$HPV58_ORAL[which((prep_sims[[current_data]]$HPV58_ORAL[sex_list1] + prep_sims[[current_data]]$HPV58_ANAL[sex_list2])==1)] = 1
      sex_exposed$HPV58_ORAL[which((prep_sims[[current_data]]$HPV58_ANAL[sex_list1] + prep_sims[[current_data]]$HPV58_ORAL[sex_list2])==1)] = 1
      
      #collapse HPV types into single HPV variable
      #sex_exposed$HPV_ANAL = ifelse(sex_exposed$HPV6_ANAL==1 | sex_exposed$HPV11_ANAL==1 | sex_exposed$HPV16_ANAL==1 | sex_exposed$HPV18_ANAL==1 | sex_exposed$HPV31_ANAL==1 | sex_exposed$HPV33_ANAL==1 | sex_exposed$HPV45_ANAL==1 | sex_exposed$HPV52_ANAL==1 | sex_exposed$HPV58_ANAL==1, 1, 0)
      #sex_exposed$HPV_ORAL = ifelse(sex_exposed$HPV6_ORAL==1 | sex_exposed$HPV11_ORAL==1 | sex_exposed$HPV16_ORAL==1 | sex_exposed$HPV18_ORAL==1 | sex_exposed$HPV31_ORAL==1 | sex_exposed$HPV33_ORAL==1 | sex_exposed$HPV45_ORAL==1 | sex_exposed$HPV52_ORAL==1 | sex_exposed$HPV58_ORAL==1, 1, 0)
      
      #HIV/HPV anal coinfections (used for seroadaption scenario)
      #sex_exposed$HIV_HPV_ANAL = sex_exposed$HIV * sex_exposed$HPV_ANAL
      sex_exposed$HIV_HPV6_ANAL = sex_exposed$HIV * sex_exposed$HPV6_ANAL
      sex_exposed$HIV_HPV11_ANAL = sex_exposed$HIV * sex_exposed$HPV11_ANAL
      sex_exposed$HIV_HPV16_ANAL = sex_exposed$HIV * sex_exposed$HPV16_ANAL
      sex_exposed$HIV_HPV18_ANAL = sex_exposed$HIV * sex_exposed$HPV18_ANAL
      sex_exposed$HIV_HPV31_ANAL = sex_exposed$HIV * sex_exposed$HPV31_ANAL
      sex_exposed$HIV_HPV33_ANAL = sex_exposed$HIV * sex_exposed$HPV33_ANAL
      sex_exposed$HIV_HPV45_ANAL = sex_exposed$HIV * sex_exposed$HPV45_ANAL
      sex_exposed$HIV_HPV52_ANAL = sex_exposed$HIV * sex_exposed$HPV52_ANAL
      sex_exposed$HIV_HPV58_ANAL = sex_exposed$HIV * sex_exposed$HPV58_ANAL
      
      #check for unexposed
      sex_exposed$Exposed = rowSums(sex_exposed[,c("HIV","HPV6_ANAL","HPV6_ORAL","HPV11_ANAL","HPV11_ORAL","HPV16_ANAL","HPV16_ORAL","HPV18_ANAL","HPV18_ORAL","HPV31_ANAL","HPV31_ORAL","HPV33_ANAL","HPV33_ORAL","HPV45_ANAL","HPV45_ORAL","HPV52_ANAL","HPV52_ORAL","HPV58_ANAL","HPV58_ORAL")])
      sex_unexposed = c(sex_exposed$Ego[sex_exposed$Exposed==0], sex_exposed$Partner[sex_exposed$Exposed==0])
      sex_exposed = sex_exposed[sex_exposed$Exposed!=0, ]
      rm(sex_list,sex_list1,sex_list2)
  
      #assign for anal intercourse (AI) sex position, 1=ego receptive/partner insertive, 2=ego insertive/partner receptive, 3=flip fuck 
      #based on preference first, then scale of dominance if preference cannot be honored
      sex_exposed$simAI = ifelse(prep_sims[[current_data]]$SEX_POSITION_ANAL_PREF[sex_exposed$Ego]==1 & prep_sims[[current_data]]$SEX_POSITION_ANAL_PREF[sex_exposed$Partner]==2, 2, ifelse(prep_sims[[current_data]]$SEX_POSITION_ANAL_PREF[sex_exposed$Ego]==2 & prep_sims[[current_data]]$SEX_POSITION_ANAL_PREF[sex_exposed$Partner]==1, 1, ifelse(prep_sims[[current_data]]$SEX_POSITION_ANAL_PREF[sex_exposed$Ego]==3 & prep_sims[[current_data]]$SEX_POSITION_ANAL_PREF[sex_exposed$Partner]==3, 3, NA)))
      sex_exposed$simAI = ifelse(is.na(sex_exposed$simAI), ifelse(abs(prep_sims[[current_data]]$SEX_POSITION_ANAL[sex_exposed$Ego]-prep_sims[[current_data]]$SEX_POSITION_ANAL[sex_exposed$Partner])<=0.15, 3, ifelse(prep_sims[[current_data]]$SEX_POSITION_ANAL[sex_exposed$Ego]<prep_sims[[current_data]]$SEX_POSITION_ANAL[sex_exposed$Partner], 1, 2)), sex_exposed$simAI)
      
      #assign for oral intercourse (OI) sex position, 1=ego receptive/partner insertive, 2=ego insertive/partner receptive, 3=flip fuck 
      #based on preference first, then scale of dominance if preference cannot be honored
      sex_exposed$simOI = ifelse(prep_sims[[current_data]]$SEX_POSITION_ORAL_PREF[sex_exposed$Ego]==1 & prep_sims[[current_data]]$SEX_POSITION_ORAL_PREF[sex_exposed$Partner]==2, 2, ifelse(prep_sims[[current_data]]$SEX_POSITION_ORAL_PREF[sex_exposed$Ego]==2 & prep_sims[[current_data]]$SEX_POSITION_ORAL_PREF[sex_exposed$Partner]==1, 1, ifelse(prep_sims[[current_data]]$SEX_POSITION_ORAL_PREF[sex_exposed$Ego]==3 & prep_sims[[current_data]]$SEX_POSITION_ORAL_PREF[sex_exposed$Partner]==3, 3, NA)))
      sex_exposed$simOI = ifelse(is.na(sex_exposed$simOI), ifelse(abs(prep_sims[[current_data]]$SEX_POSITION_ORAL[sex_exposed$Ego]-prep_sims[[current_data]]$SEX_POSITION_ORAL[sex_exposed$Partner])<=0.15, 3, ifelse(prep_sims[[current_data]]$SEX_POSITION_ORAL[sex_exposed$Ego]<prep_sims[[current_data]]$SEX_POSITION_ORAL[sex_exposed$Partner], 1, 2)), sex_exposed$simOI)

      #determine sex type, 1=anal (both consent to anal only), 2=oral (one does not consent to anal), 3=both (both consent to anal but one, or both, would also like oral)
      sex_exposed$sex = ifelse(prep_sims[[current_data]]$SEX_ACT[sex_exposed$Ego]==1 & prep_sims[[current_data]]$SEX_ACT[sex_exposed$Partner]==1, 1, ifelse(prep_sims[[current_data]]$SEX_ACT[sex_exposed$Ego]==2 & prep_sims[[current_data]]$SEX_ACT[sex_exposed$Partner]==2, 2, ifelse(prep_sims[[current_data]]$SEX_ACT[sex_exposed$Ego]==3 & prep_sims[[current_data]]$SEX_ACT[sex_exposed$Partner]==3, 3, ifelse(prep_sims[[current_data]]$SEX_ACT[sex_exposed$Ego]==3 & prep_sims[[current_data]]$SEX_ACT[sex_exposed$Partner]==2, 3, ifelse(prep_sims[[current_data]]$SEX_ACT[sex_exposed$Ego]==2 & prep_sims[[current_data]]$SEX_ACT[sex_exposed$Partner]==3, 3, 2)))))

      if (sum(sex_exposed$Exposed)>0)
      {
        #pathogen discordance in at least one partnership
        
        ## DETERMINE INFECTION STATUS ##
        
        #create exposure lists of ego/partner IDs
        exposed_hiv_ego = sex_exposed$Ego[sex_exposed$HIV==1]
        exposed_hiv_partner = sex_exposed$Partner[sex_exposed$HIV==1]
        #exposed_hpv_anal_ego = sex_exposed$Ego[sex_exposed$HPV_ANAL==1]
        #exposed_hpv_anal_partner = sex_exposed$Partner[sex_exposed$HPV_ANAL==1]
        exposed_hpv6_anal_ego = sex_exposed$Ego[sex_exposed$HPV6_ANAL==1]
        exposed_hpv6_anal_partner = sex_exposed$Partner[sex_exposed$HPV6_ANAL==1]
        exposed_hpv11_anal_ego = sex_exposed$Ego[sex_exposed$HPV11_ANAL==1]
        exposed_hpv11_anal_partner = sex_exposed$Partner[sex_exposed$HPV11_ANAL==1]
        exposed_hpv16_anal_ego = sex_exposed$Ego[sex_exposed$HPV16_ANAL==1]
        exposed_hpv16_anal_partner = sex_exposed$Partner[sex_exposed$HPV16_ANAL==1]
        exposed_hpv18_anal_ego = sex_exposed$Ego[sex_exposed$HPV18_ANAL==1]
        exposed_hpv18_anal_partner = sex_exposed$Partner[sex_exposed$HPV18_ANAL==1]
        exposed_hpv31_anal_ego = sex_exposed$Ego[sex_exposed$HPV31_ANAL==1]
        exposed_hpv31_anal_partner = sex_exposed$Partner[sex_exposed$HPV31_ANAL==1]
        exposed_hpv33_anal_ego = sex_exposed$Ego[sex_exposed$HPV33_ANAL==1]
        exposed_hpv33_anal_partner = sex_exposed$Partner[sex_exposed$HPV33_ANAL==1]
        exposed_hpv45_anal_ego = sex_exposed$Ego[sex_exposed$HPV45_ANAL==1]
        exposed_hpv45_anal_partner = sex_exposed$Partner[sex_exposed$HPV45_ANAL==1]
        exposed_hpv52_anal_ego = sex_exposed$Ego[sex_exposed$HPV52_ANAL==1]
        exposed_hpv52_anal_partner = sex_exposed$Partner[sex_exposed$HPV52_ANAL==1]
        exposed_hpv58_anal_ego = sex_exposed$Ego[sex_exposed$HPV58_ANAL==1]
        exposed_hpv58_anal_partner = sex_exposed$Partner[sex_exposed$HPV58_ANAL==1]
        exposed_hpv6_oral_ego = sex_exposed$Ego[sex_exposed$HPV6_ORAL==1]
        exposed_hpv6_oral_partner = sex_exposed$Partner[sex_exposed$HPV6_ORAL==1]
        exposed_hpv11_oral_ego = sex_exposed$Ego[sex_exposed$HPV11_ORAL==1]
        exposed_hpv11_oral_partner = sex_exposed$Partner[sex_exposed$HPV11_ORAL==1]
        exposed_hpv16_oral_ego = sex_exposed$Ego[sex_exposed$HPV16_ORAL==1]
        exposed_hpv16_oral_partner = sex_exposed$Partner[sex_exposed$HPV16_ORAL==1]
        exposed_hpv18_oral_ego = sex_exposed$Ego[sex_exposed$HPV18_ORAL==1]
        exposed_hpv18_oral_partner = sex_exposed$Partner[sex_exposed$HPV18_ORAL==1]
        exposed_hpv31_oral_ego = sex_exposed$Ego[sex_exposed$HPV31_ORAL==1]
        exposed_hpv31_oral_partner = sex_exposed$Partner[sex_exposed$HPV31_ORAL==1]
        exposed_hpv33_oral_ego = sex_exposed$Ego[sex_exposed$HPV33_ORAL==1]
        exposed_hpv33_oral_partner = sex_exposed$Partner[sex_exposed$HPV33_ORAL==1]
        exposed_hpv45_oral_ego = sex_exposed$Ego[sex_exposed$HPV45_ORAL==1]
        exposed_hpv45_oral_partner = sex_exposed$Partner[sex_exposed$HPV45_ORAL==1]
        exposed_hpv52_oral_ego = sex_exposed$Ego[sex_exposed$HPV52_ORAL==1]
        exposed_hpv52_oral_partner = sex_exposed$Partner[sex_exposed$HPV52_ORAL==1]
        exposed_hpv58_oral_ego = sex_exposed$Ego[sex_exposed$HPV58_ORAL==1]
        exposed_hpv58_oral_partner = sex_exposed$Partner[sex_exposed$HPV58_ORAL==1]
        
        #check for who is exposed, 1=ego, 2=partner, 3=both (oral)
        sex_exposed$exposure_hiv[sex_exposed$HIV==1] = ifelse(prep_sims[[current_data]]$HIV[exposed_hiv_ego]<prep_sims[[current_data]]$HIV[exposed_hiv_partner], 1, 2)
        #sex_exposed$exposure_hpv_anal[sex_exposed$HPV_ANAL==1] = ifelse(prep_sims[[current_data]]$HPV_ANAL[exposed_hpv_anal_ego]<prep_sims[[current_data]]$HPV_ANAL[exposed_hpv_anal_partner], 1, ifelse(prep_sims[[current_data]]$HPV_ANAL[exposed_hpv_anal_ego]>prep_sims[[current_data]]$HPV_ANAL[exposed_hpv_anal_partner], 2, 3))
        sex_exposed$exposure_hpv6_anal[sex_exposed$HPV6_ANAL==1] = ifelse(prep_sims[[current_data]]$HPV6_ANAL[exposed_hpv6_anal_ego]<prep_sims[[current_data]]$HPV6_ANAL[exposed_hpv6_anal_partner], 1, 2)
        sex_exposed$exposure_hpv11_anal[sex_exposed$HPV11_ANAL==1] = ifelse(prep_sims[[current_data]]$HPV11_ANAL[exposed_hpv11_anal_ego]<prep_sims[[current_data]]$HPV11_ANAL[exposed_hpv11_anal_partner], 1, 2)
        sex_exposed$exposure_hpv16_anal[sex_exposed$HPV16_ANAL==1] = ifelse(prep_sims[[current_data]]$HPV16_ANAL[exposed_hpv16_anal_ego]<prep_sims[[current_data]]$HPV16_ANAL[exposed_hpv16_anal_partner], 1, 2)
        sex_exposed$exposure_hpv18_anal[sex_exposed$HPV18_ANAL==1] = ifelse(prep_sims[[current_data]]$HPV18_ANAL[exposed_hpv18_anal_ego]<prep_sims[[current_data]]$HPV18_ANAL[exposed_hpv18_anal_partner], 1, 2)
        sex_exposed$exposure_hpv31_anal[sex_exposed$HPV31_ANAL==1] = ifelse(prep_sims[[current_data]]$HPV31_ANAL[exposed_hpv31_anal_ego]<prep_sims[[current_data]]$HPV31_ANAL[exposed_hpv31_anal_partner], 1, 2)
        sex_exposed$exposure_hpv33_anal[sex_exposed$HPV33_ANAL==1] = ifelse(prep_sims[[current_data]]$HPV33_ANAL[exposed_hpv33_anal_ego]<prep_sims[[current_data]]$HPV33_ANAL[exposed_hpv33_anal_partner], 1, 2)
        sex_exposed$exposure_hpv45_anal[sex_exposed$HPV45_ANAL==1] = ifelse(prep_sims[[current_data]]$HPV45_ANAL[exposed_hpv45_anal_ego]<prep_sims[[current_data]]$HPV45_ANAL[exposed_hpv45_anal_partner], 1, 2)
        sex_exposed$exposure_hpv52_anal[sex_exposed$HPV52_ANAL==1] = ifelse(prep_sims[[current_data]]$HPV52_ANAL[exposed_hpv52_anal_ego]<prep_sims[[current_data]]$HPV52_ANAL[exposed_hpv52_anal_partner], 1, 2)
        sex_exposed$exposure_hpv58_anal[sex_exposed$HPV58_ANAL==1] = ifelse(prep_sims[[current_data]]$HPV58_ANAL[exposed_hpv58_anal_ego]<prep_sims[[current_data]]$HPV58_ANAL[exposed_hpv58_anal_partner], 1, 2)
        sex_exposed$exposure_hpv6_oral[sex_exposed$HPV6_ORAL==1] = ifelse((prep_sims[[current_data]]$HPV6_ORAL[exposed_hpv6_oral_ego]<prep_sims[[current_data]]$HPV6_ANAL[exposed_hpv6_oral_partner]) & (prep_sims[[current_data]]$HPV6_ANAL[exposed_hpv6_oral_ego]>prep_sims[[current_data]]$HPV6_ORAL[exposed_hpv6_oral_partner]), 3, ifelse((prep_sims[[current_data]]$HPV6_ORAL[exposed_hpv6_oral_ego]>prep_sims[[current_data]]$HPV6_ANAL[exposed_hpv6_oral_partner]) & (prep_sims[[current_data]]$HPV6_ANAL[exposed_hpv6_oral_ego]<prep_sims[[current_data]]$HPV6_ORAL[exposed_hpv6_oral_partner]), 3, ifelse((prep_sims[[current_data]]$HPV6_ORAL[exposed_hpv6_oral_ego]<prep_sims[[current_data]]$HPV6_ANAL[exposed_hpv6_oral_partner]) | (prep_sims[[current_data]]$HPV6_ANAL[exposed_hpv6_oral_ego]<prep_sims[[current_data]]$HPV6_ORAL[exposed_hpv6_oral_partner]), 1, ifelse((prep_sims[[current_data]]$HPV6_ORAL[exposed_hpv6_oral_ego]>prep_sims[[current_data]]$HPV6_ANAL[exposed_hpv6_oral_partner]) | (prep_sims[[current_data]]$HPV6_ANAL[exposed_hpv6_oral_ego]>prep_sims[[current_data]]$HPV6_ORAL[exposed_hpv6_oral_partner]), 2, NA))))
        sex_exposed$exposure_hpv11_oral[sex_exposed$HPV11_ORAL==1] = ifelse((prep_sims[[current_data]]$HPV11_ORAL[exposed_hpv11_oral_ego]<prep_sims[[current_data]]$HPV11_ANAL[exposed_hpv11_oral_partner]) & (prep_sims[[current_data]]$HPV11_ANAL[exposed_hpv11_oral_ego]>prep_sims[[current_data]]$HPV11_ORAL[exposed_hpv11_oral_partner]), 3, ifelse((prep_sims[[current_data]]$HPV11_ORAL[exposed_hpv11_oral_ego]>prep_sims[[current_data]]$HPV11_ANAL[exposed_hpv11_oral_partner]) & (prep_sims[[current_data]]$HPV11_ANAL[exposed_hpv11_oral_ego]<prep_sims[[current_data]]$HPV11_ORAL[exposed_hpv11_oral_partner]), 3, ifelse((prep_sims[[current_data]]$HPV11_ORAL[exposed_hpv11_oral_ego]<prep_sims[[current_data]]$HPV11_ANAL[exposed_hpv11_oral_partner]) | (prep_sims[[current_data]]$HPV11_ANAL[exposed_hpv11_oral_ego]<prep_sims[[current_data]]$HPV11_ORAL[exposed_hpv11_oral_partner]), 1, ifelse((prep_sims[[current_data]]$HPV11_ORAL[exposed_hpv11_oral_ego]>prep_sims[[current_data]]$HPV11_ANAL[exposed_hpv11_oral_partner]) | (prep_sims[[current_data]]$HPV11_ANAL[exposed_hpv11_oral_ego]>prep_sims[[current_data]]$HPV11_ORAL[exposed_hpv11_oral_partner]), 2, NA))))
        sex_exposed$exposure_hpv16_oral[sex_exposed$HPV16_ORAL==1] = ifelse((prep_sims[[current_data]]$HPV16_ORAL[exposed_hpv16_oral_ego]<prep_sims[[current_data]]$HPV16_ANAL[exposed_hpv16_oral_partner]) & (prep_sims[[current_data]]$HPV16_ANAL[exposed_hpv16_oral_ego]>prep_sims[[current_data]]$HPV16_ORAL[exposed_hpv16_oral_partner]), 3, ifelse((prep_sims[[current_data]]$HPV16_ORAL[exposed_hpv16_oral_ego]>prep_sims[[current_data]]$HPV16_ANAL[exposed_hpv16_oral_partner]) & (prep_sims[[current_data]]$HPV16_ANAL[exposed_hpv16_oral_ego]<prep_sims[[current_data]]$HPV16_ORAL[exposed_hpv16_oral_partner]), 3, ifelse((prep_sims[[current_data]]$HPV16_ORAL[exposed_hpv16_oral_ego]<prep_sims[[current_data]]$HPV16_ANAL[exposed_hpv16_oral_partner]) | (prep_sims[[current_data]]$HPV16_ANAL[exposed_hpv16_oral_ego]<prep_sims[[current_data]]$HPV16_ORAL[exposed_hpv16_oral_partner]), 1, ifelse((prep_sims[[current_data]]$HPV16_ORAL[exposed_hpv16_oral_ego]>prep_sims[[current_data]]$HPV16_ANAL[exposed_hpv16_oral_partner]) | (prep_sims[[current_data]]$HPV16_ANAL[exposed_hpv16_oral_ego]>prep_sims[[current_data]]$HPV16_ORAL[exposed_hpv16_oral_partner]), 2, NA))))
        sex_exposed$exposure_hpv18_oral[sex_exposed$HPV18_ORAL==1] = ifelse((prep_sims[[current_data]]$HPV18_ORAL[exposed_hpv18_oral_ego]<prep_sims[[current_data]]$HPV18_ANAL[exposed_hpv18_oral_partner]) & (prep_sims[[current_data]]$HPV18_ANAL[exposed_hpv18_oral_ego]>prep_sims[[current_data]]$HPV18_ORAL[exposed_hpv18_oral_partner]), 3, ifelse((prep_sims[[current_data]]$HPV18_ORAL[exposed_hpv18_oral_ego]>prep_sims[[current_data]]$HPV18_ANAL[exposed_hpv18_oral_partner]) & (prep_sims[[current_data]]$HPV18_ANAL[exposed_hpv18_oral_ego]<prep_sims[[current_data]]$HPV18_ORAL[exposed_hpv18_oral_partner]), 3, ifelse((prep_sims[[current_data]]$HPV18_ORAL[exposed_hpv18_oral_ego]<prep_sims[[current_data]]$HPV18_ANAL[exposed_hpv18_oral_partner]) | (prep_sims[[current_data]]$HPV18_ANAL[exposed_hpv18_oral_ego]<prep_sims[[current_data]]$HPV18_ORAL[exposed_hpv18_oral_partner]), 1, ifelse((prep_sims[[current_data]]$HPV18_ORAL[exposed_hpv18_oral_ego]>prep_sims[[current_data]]$HPV18_ANAL[exposed_hpv18_oral_partner]) | (prep_sims[[current_data]]$HPV18_ANAL[exposed_hpv18_oral_ego]>prep_sims[[current_data]]$HPV18_ORAL[exposed_hpv18_oral_partner]), 2, NA))))
        sex_exposed$exposure_hpv31_oral[sex_exposed$HPV31_ORAL==1] = ifelse((prep_sims[[current_data]]$HPV31_ORAL[exposed_hpv31_oral_ego]<prep_sims[[current_data]]$HPV31_ANAL[exposed_hpv31_oral_partner]) & (prep_sims[[current_data]]$HPV31_ANAL[exposed_hpv31_oral_ego]>prep_sims[[current_data]]$HPV31_ORAL[exposed_hpv31_oral_partner]), 3, ifelse((prep_sims[[current_data]]$HPV31_ORAL[exposed_hpv31_oral_ego]>prep_sims[[current_data]]$HPV31_ANAL[exposed_hpv31_oral_partner]) & (prep_sims[[current_data]]$HPV31_ANAL[exposed_hpv31_oral_ego]<prep_sims[[current_data]]$HPV31_ORAL[exposed_hpv31_oral_partner]), 3, ifelse((prep_sims[[current_data]]$HPV31_ORAL[exposed_hpv31_oral_ego]<prep_sims[[current_data]]$HPV31_ANAL[exposed_hpv31_oral_partner]) | (prep_sims[[current_data]]$HPV31_ANAL[exposed_hpv31_oral_ego]<prep_sims[[current_data]]$HPV31_ORAL[exposed_hpv31_oral_partner]), 1, ifelse((prep_sims[[current_data]]$HPV31_ORAL[exposed_hpv31_oral_ego]>prep_sims[[current_data]]$HPV31_ANAL[exposed_hpv31_oral_partner]) | (prep_sims[[current_data]]$HPV31_ANAL[exposed_hpv31_oral_ego]>prep_sims[[current_data]]$HPV31_ORAL[exposed_hpv31_oral_partner]), 2, NA))))
        sex_exposed$exposure_hpv33_oral[sex_exposed$HPV33_ORAL==1] = ifelse((prep_sims[[current_data]]$HPV33_ORAL[exposed_hpv33_oral_ego]<prep_sims[[current_data]]$HPV33_ANAL[exposed_hpv33_oral_partner]) & (prep_sims[[current_data]]$HPV33_ANAL[exposed_hpv33_oral_ego]>prep_sims[[current_data]]$HPV33_ORAL[exposed_hpv33_oral_partner]), 3, ifelse((prep_sims[[current_data]]$HPV33_ORAL[exposed_hpv33_oral_ego]>prep_sims[[current_data]]$HPV33_ANAL[exposed_hpv33_oral_partner]) & (prep_sims[[current_data]]$HPV33_ANAL[exposed_hpv33_oral_ego]<prep_sims[[current_data]]$HPV33_ORAL[exposed_hpv33_oral_partner]), 3, ifelse((prep_sims[[current_data]]$HPV33_ORAL[exposed_hpv33_oral_ego]<prep_sims[[current_data]]$HPV33_ANAL[exposed_hpv33_oral_partner]) | (prep_sims[[current_data]]$HPV33_ANAL[exposed_hpv33_oral_ego]<prep_sims[[current_data]]$HPV33_ORAL[exposed_hpv33_oral_partner]), 1, ifelse((prep_sims[[current_data]]$HPV33_ORAL[exposed_hpv33_oral_ego]>prep_sims[[current_data]]$HPV33_ANAL[exposed_hpv33_oral_partner]) | (prep_sims[[current_data]]$HPV33_ANAL[exposed_hpv33_oral_ego]>prep_sims[[current_data]]$HPV33_ORAL[exposed_hpv33_oral_partner]), 2, NA))))
        sex_exposed$exposure_hpv45_oral[sex_exposed$HPV45_ORAL==1] = ifelse((prep_sims[[current_data]]$HPV45_ORAL[exposed_hpv45_oral_ego]<prep_sims[[current_data]]$HPV45_ANAL[exposed_hpv45_oral_partner]) & (prep_sims[[current_data]]$HPV45_ANAL[exposed_hpv45_oral_ego]>prep_sims[[current_data]]$HPV45_ORAL[exposed_hpv45_oral_partner]), 3, ifelse((prep_sims[[current_data]]$HPV45_ORAL[exposed_hpv45_oral_ego]>prep_sims[[current_data]]$HPV45_ANAL[exposed_hpv45_oral_partner]) & (prep_sims[[current_data]]$HPV45_ANAL[exposed_hpv45_oral_ego]<prep_sims[[current_data]]$HPV45_ORAL[exposed_hpv45_oral_partner]), 3, ifelse((prep_sims[[current_data]]$HPV45_ORAL[exposed_hpv45_oral_ego]<prep_sims[[current_data]]$HPV45_ANAL[exposed_hpv45_oral_partner]) | (prep_sims[[current_data]]$HPV45_ANAL[exposed_hpv45_oral_ego]<prep_sims[[current_data]]$HPV45_ORAL[exposed_hpv45_oral_partner]), 1, ifelse((prep_sims[[current_data]]$HPV45_ORAL[exposed_hpv45_oral_ego]>prep_sims[[current_data]]$HPV45_ANAL[exposed_hpv45_oral_partner]) | (prep_sims[[current_data]]$HPV45_ANAL[exposed_hpv45_oral_ego]>prep_sims[[current_data]]$HPV45_ORAL[exposed_hpv45_oral_partner]), 2, NA))))
        sex_exposed$exposure_hpv52_oral[sex_exposed$HPV52_ORAL==1] = ifelse((prep_sims[[current_data]]$HPV52_ORAL[exposed_hpv52_oral_ego]<prep_sims[[current_data]]$HPV52_ANAL[exposed_hpv52_oral_partner]) & (prep_sims[[current_data]]$HPV52_ANAL[exposed_hpv52_oral_ego]>prep_sims[[current_data]]$HPV52_ORAL[exposed_hpv52_oral_partner]), 3, ifelse((prep_sims[[current_data]]$HPV52_ORAL[exposed_hpv52_oral_ego]>prep_sims[[current_data]]$HPV52_ANAL[exposed_hpv52_oral_partner]) & (prep_sims[[current_data]]$HPV52_ANAL[exposed_hpv52_oral_ego]<prep_sims[[current_data]]$HPV52_ORAL[exposed_hpv52_oral_partner]), 3, ifelse((prep_sims[[current_data]]$HPV52_ORAL[exposed_hpv52_oral_ego]<prep_sims[[current_data]]$HPV52_ANAL[exposed_hpv52_oral_partner]) | (prep_sims[[current_data]]$HPV52_ANAL[exposed_hpv52_oral_ego]<prep_sims[[current_data]]$HPV52_ORAL[exposed_hpv52_oral_partner]), 1, ifelse((prep_sims[[current_data]]$HPV52_ORAL[exposed_hpv52_oral_ego]>prep_sims[[current_data]]$HPV52_ANAL[exposed_hpv52_oral_partner]) | (prep_sims[[current_data]]$HPV52_ANAL[exposed_hpv52_oral_ego]>prep_sims[[current_data]]$HPV52_ORAL[exposed_hpv52_oral_partner]), 2, NA))))
        sex_exposed$exposure_hpv58_oral[sex_exposed$HPV58_ORAL==1] = ifelse((prep_sims[[current_data]]$HPV58_ORAL[exposed_hpv58_oral_ego]<prep_sims[[current_data]]$HPV58_ANAL[exposed_hpv58_oral_partner]) & (prep_sims[[current_data]]$HPV58_ANAL[exposed_hpv58_oral_ego]>prep_sims[[current_data]]$HPV58_ORAL[exposed_hpv58_oral_partner]), 3, ifelse((prep_sims[[current_data]]$HPV58_ORAL[exposed_hpv58_oral_ego]>prep_sims[[current_data]]$HPV58_ANAL[exposed_hpv58_oral_partner]) & (prep_sims[[current_data]]$HPV58_ANAL[exposed_hpv58_oral_ego]<prep_sims[[current_data]]$HPV58_ORAL[exposed_hpv58_oral_partner]), 3, ifelse((prep_sims[[current_data]]$HPV58_ORAL[exposed_hpv58_oral_ego]<prep_sims[[current_data]]$HPV58_ANAL[exposed_hpv58_oral_partner]) | (prep_sims[[current_data]]$HPV58_ANAL[exposed_hpv58_oral_ego]<prep_sims[[current_data]]$HPV58_ORAL[exposed_hpv58_oral_partner]), 1, ifelse((prep_sims[[current_data]]$HPV58_ORAL[exposed_hpv58_oral_ego]>prep_sims[[current_data]]$HPV58_ANAL[exposed_hpv58_oral_partner]) | (prep_sims[[current_data]]$HPV58_ANAL[exposed_hpv58_oral_ego]>prep_sims[[current_data]]$HPV58_ORAL[exposed_hpv58_oral_partner]), 2, NA))))
        
        #indicators for various metrics
        sex_exposed$condct_hiv = 0            #HIV infection blocked from condom use, ego
        #sex_exposed$condct_hpv_anal = 0      #HPV anal infection blocked from condom use, ego
        sex_exposed$condct_hpv6_anal = 0      #HPV6 anal infection blocked from condom use, ego
        sex_exposed$condct_hpv11_anal = 0     #HPV11 anal infection blocked from condom use, ego
        sex_exposed$condct_hpv16_anal = 0     #HPV16 anal infection blocked from condom use, ego
        sex_exposed$condct_hpv18_anal = 0     #HPV18 anal infection blocked from condom use, ego
        sex_exposed$condct_hpv31_anal = 0     #HPV31 anal infection blocked from condom use, ego
        sex_exposed$condct_hpv33_anal = 0     #HPV33 anal infection blocked from condom use, ego
        sex_exposed$condct_hpv45_anal = 0     #HPV45 anal infection blocked from condom use, ego
        sex_exposed$condct_hpv52_anal = 0     #HPV52 anal infection blocked from condom use, ego
        sex_exposed$condct_hpv58_anal = 0     #HPV58 anal infection blocked from condom use, ego
        sex_exposed$condct_hpv6_oral = 0      #HPV6 oral infection blocked from condom use, ego
        sex_exposed$condct_hpv11_oral = 0     #HPV11 oral infection blocked from condom use, ego
        sex_exposed$condct_hpv16_oral = 0     #HPV16 oral infection blocked from condom use, ego
        sex_exposed$condct_hpv18_oral = 0     #HPV18 oral infection blocked from condom use, ego
        sex_exposed$condct_hpv31_oral = 0     #HPV31 oral infection blocked from condom use, ego
        sex_exposed$condct_hpv33_oral = 0     #HPV33 oral infection blocked from condom use, ego
        sex_exposed$condct_hpv45_oral = 0     #HPV45 oral infection blocked from condom use, ego
        sex_exposed$condct_hpv52_oral = 0     #HPV52 oral infection blocked from condom use, ego
        sex_exposed$condct_hpv58_oral = 0     #HPV58 oral infection blocked from condom use, ego
        sex_exposed$prepct = 0                #infection blocked from PrEP, ego
        sex_exposed$tapct = 0                 #infection blocked from TAP, ego
        sex_exposed$seroct_hiv = 0            #HIV infection blocked from seroadapation, ego
        sex_exposed$seroct_hpv = 0            #HPV anal infection blocked from seroadapation, ego
        sex_exposed$seroct_hpv6 = 0           #HPV6 anal infection blocked from seroadapation, ego
        sex_exposed$seroct_hpv11 = 0          #HPV11 anal infection blocked from seroadapation, ego
        sex_exposed$seroct_hpv16 = 0          #HPV16 anal infection blocked from seroadapation, ego
        sex_exposed$seroct_hpv18 = 0          #HPV18 anal infection blocked from seroadapation, ego
        sex_exposed$seroct_hpv31 = 0          #HPV31 anal infection blocked from seroadapation, ego
        sex_exposed$seroct_hpv33 = 0          #HPV33 anal infection blocked from seroadapation, ego
        sex_exposed$seroct_hpv45 = 0          #HPV45 anal infection blocked from seroadapation, ego
        sex_exposed$seroct_hpv52 = 0          #HPV52 anal infection blocked from seroadapation, ego
        sex_exposed$seroct_hpv58 = 0          #HPV58 anal infection blocked from seroadapation, ego
        #sex_exposed$vaxct_hpv_anal = 0       #HPV anal infection blocked from vaccination, ego
        sex_exposed$vaxct_hpv6_anal = 0       #HPV6 anal infection blocked from vaccination, ego
        sex_exposed$vaxct_hpv11_anal = 0      #HPV11 anal infection blocked from vaccination, ego
        sex_exposed$vaxct_hpv16_anal = 0      #HPV16 anal infection blocked from vaccination, ego
        sex_exposed$vaxct_hpv18_anal = 0      #HPV18 anal infection blocked from vaccination, ego
        sex_exposed$vaxct_hpv31_anal = 0      #HPV31 anal infection blocked from vaccination, ego
        sex_exposed$vaxct_hpv33_anal = 0      #HPV33 anal infection blocked from vaccination, ego
        sex_exposed$vaxct_hpv45_anal = 0      #HPV45 anal infection blocked from vaccination, ego
        sex_exposed$vaxct_hpv52_anal = 0      #HPV52 anal infection blocked from vaccination, ego
        sex_exposed$vaxct_hpv58_anal = 0      #HPV58 anal infection blocked from vaccination, ego
        sex_exposed$vaxct_hpv6_oral = 0       #HPV6 oral infection blocked from vaccination, ego
        sex_exposed$vaxct_hpv11_oral = 0      #HPV11 oral infection blocked from vaccination, ego
        sex_exposed$vaxct_hpv16_oral = 0      #HPV16 oral infection blocked from vaccination, ego
        sex_exposed$vaxct_hpv18_oral = 0      #HPV18 oral infection blocked from vaccination, ego
        sex_exposed$vaxct_hpv31_oral = 0      #HPV31 oral infection blocked from vaccination, ego
        sex_exposed$vaxct_hpv33_oral = 0      #HPV33 oral infection blocked from vaccination, ego
        sex_exposed$vaxct_hpv45_oral = 0      #HPV45 oral infection blocked from vaccination, ego
        sex_exposed$vaxct_hpv52_oral = 0      #HPV52 oral infection blocked from vaccination, ego
        sex_exposed$vaxct_hpv58_oral = 0      #HPV58 oral infection blocked from vaccination, ego
        #sex_exposed$prevct_hpv_anal = 0      #HPV anal infection blocked from any prevention strategy, ego
        sex_exposed$prevct_hpv6_anal = 0      #HPV6 anal infection blocked from any prevention strategy, ego
        sex_exposed$prevct_hpv11_anal = 0     #HPV11 anal infection blocked from any prevention strategy, ego
        sex_exposed$prevct_hpv16_anal = 0     #HPV16 anal infection blocked from any prevention strategy, ego
        sex_exposed$prevct_hpv18_anal = 0     #HPV18 anal infection blocked from any prevention strategy, ego
        sex_exposed$prevct_hpv31_anal = 0     #HPV31 anal infection blocked from any prevention strategy, ego
        sex_exposed$prevct_hpv33_anal = 0     #HPV33 anal infection blocked from any prevention strategy, ego
        sex_exposed$prevct_hpv45_anal = 0     #HPV45 anal infection blocked from any prevention strategy, ego
        sex_exposed$prevct_hpv52_anal = 0     #HPV52 anal infection blocked from any prevention strategy, ego
        sex_exposed$prevct_hpv58_anal = 0     #HPV58 anal infection blocked from any prevention strategy, ego
        sex_exposed$prevct_hpv6_oral = 0      #HPV6 oral infection blocked from any prevention strategy, ego
        sex_exposed$prevct_hpv11_oral = 0     #HPV11 oral infection blocked from any prevention strategy, ego
        sex_exposed$prevct_hpv16_oral = 0     #HPV16 oral infection blocked from any prevention strategy, ego
        sex_exposed$prevct_hpv18_oral = 0     #HPV18 oral infection blocked from any prevention strategy, ego
        sex_exposed$prevct_hpv31_oral = 0     #HPV31 oral infection blocked from any prevention strategy, ego
        sex_exposed$prevct_hpv33_oral = 0     #HPV33 oral infection blocked from any prevention strategy, ego
        sex_exposed$prevct_hpv45_oral = 0     #HPV45 oral infection blocked from any prevention strategy, ego
        sex_exposed$prevct_hpv52_oral = 0     #HPV52 oral infection blocked from any prevention strategy, ego
        sex_exposed$prevct_hpv58_oral = 0     #HPV58 oral infection blocked from any prevention strategy, ego
        sex_exposed$infectct = 0              #ego caused a new HPV anal infection to partner
        sex_exposed$newHIV = 0                #new HIV infection, ego
        sex_exposed$newVL = -1                #set VL to acute if new infection, ego
        #sex_exposed$newHPV_ANAL = 0          #new HPV anal infection, ego
        sex_exposed$newHPV6_ANAL = 0          #new HPV6 anal infection, ego
        sex_exposed$newHPV11_ANAL = 0         #new HPV11 anal infection, ego
        sex_exposed$newHPV16_ANAL = 0         #new HPV16 anal infection, ego
        sex_exposed$newHPV18_ANAL = 0         #new HPV18 anal infection, ego
        sex_exposed$newHPV31_ANAL = 0         #new HPV31 anal infection, ego
        sex_exposed$newHPV33_ANAL = 0         #new HPV33 anal infection, ego
        sex_exposed$newHPV45_ANAL = 0         #new HPV45 anal infection, ego
        sex_exposed$newHPV52_ANAL = 0         #new HPV52 anal infection, ego
        sex_exposed$newHPV58_ANAL = 0         #new HPV58 anal infection, ego
        sex_exposed$newHPV6_ORAL = 0          #new HPV6 oral infection, ego
        sex_exposed$newHPV11_ORAL = 0         #new HPV11 oral infection, ego
        sex_exposed$newHPV16_ORAL = 0         #new HPV16 oral infection, ego
        sex_exposed$newHPV18_ORAL = 0         #new HPV18 oral infection, ego
        sex_exposed$newHPV31_ORAL = 0         #new HPV31 oral infection, ego
        sex_exposed$newHPV33_ORAL = 0         #new HPV33 oral infection, ego
        sex_exposed$newHPV45_ORAL = 0         #new HPV45 oral infection, ego
        sex_exposed$newHPV52_ORAL = 0         #new HPV52 oral infection, ego
        sex_exposed$newHPV58_ORAL = 0         #new HPV58 oral infection, ego
        sex_exposed$partcondct_hiv = 0        #HIV infection blocked from condom use, partner
        #sex_exposed$partcondct_hpv_anal = 0  #HPV anal infection blocked from condom use, partner
        sex_exposed$partcondct_hpv6_anal = 0  #HPV6 anal infection blocked from condom use, partner
        sex_exposed$partcondct_hpv11_anal = 0 #HPV11 anal infection blocked from condom use, partner
        sex_exposed$partcondct_hpv16_anal = 0 #HPV16 anal infection blocked from condom use, partner
        sex_exposed$partcondct_hpv18_anal = 0 #HPV18 anal infection blocked from condom use, partner
        sex_exposed$partcondct_hpv31_anal = 0 #HPV31 anal infection blocked from condom use, partner
        sex_exposed$partcondct_hpv33_anal = 0 #HPV33 anal infection blocked from condom use, partner
        sex_exposed$partcondct_hpv45_anal = 0 #HPV45 anal infection blocked from condom use, partner
        sex_exposed$partcondct_hpv52_anal = 0 #HPV52 anal infection blocked from condom use, partner
        sex_exposed$partcondct_hpv58_anal = 0 #HPV58 anal infection blocked from condom use, partner
        sex_exposed$partcondct_hpv6_oral = 0  #HPV6 oral infection blocked from condom use, partner
        sex_exposed$partcondct_hpv11_oral = 0 #HPV11 oral infection blocked from condom use, partner
        sex_exposed$partcondct_hpv16_oral = 0 #HPV16 oral infection blocked from condom use, partner
        sex_exposed$partcondct_hpv18_oral = 0 #HPV18 oral infection blocked from condom use, partner
        sex_exposed$partcondct_hpv31_oral = 0 #HPV31 oral infection blocked from condom use, partner
        sex_exposed$partcondct_hpv33_oral = 0 #HPV33 oral infection blocked from condom use, partner
        sex_exposed$partcondct_hpv45_oral = 0 #HPV45 oral infection blocked from condom use, partner
        sex_exposed$partcondct_hpv52_oral = 0 #HPV52 oral infection blocked from condom use, partner
        sex_exposed$partcondct_hpv58_oral = 0 #HPV58 oral infection blocked from condom use, partner
        sex_exposed$partprepct = 0            #infection blocked from PrEP, partner
        sex_exposed$parttapct = 0             #infection blocked from TAP, partner
        sex_exposed$partseroct_hiv = 0        #HIV infection blocked from seroadapation, partner
        sex_exposed$partseroct_hpv = 0        #HPV anal infection blocked from seroadapation, partner
        sex_exposed$partseroct_hpv6 = 0       #HPV6 anal infection blocked from seroadapation, partner
        sex_exposed$partseroct_hpv11 = 0      #HPV11 anal infection blocked from seroadapation, partner
        sex_exposed$partseroct_hpv16 = 0      #HPV16 anal infection blocked from seroadapation, partner
        sex_exposed$partseroct_hpv18 = 0      #HPV18 anal infection blocked from seroadapation, partner
        sex_exposed$partseroct_hpv31 = 0      #HPV31 anal infection blocked from seroadapation, partner
        sex_exposed$partseroct_hpv33 = 0      #HPV33 anal infection blocked from seroadapation, partner
        sex_exposed$partseroct_hpv45 = 0      #HPV45 anal infection blocked from seroadapation, partner
        sex_exposed$partseroct_hpv52 = 0      #HPV52 anal infection blocked from seroadapation, partner
        sex_exposed$partseroct_hpv58 = 0      #HPV58 anal infection blocked from seroadapation, partner
        #sex_exposed$partvaxct_hpv_anal = 0   #HPV anal infection blocked from vaccination, partner
        sex_exposed$partvaxct_hpv6_anal = 0   #HPV6 anal infection blocked from vaccination, partner
        sex_exposed$partvaxct_hpv11_anal = 0  #HPV11 anal infection blocked from vaccination, partner
        sex_exposed$partvaxct_hpv16_anal = 0  #HPV16 anal infection blocked from vaccination, partner
        sex_exposed$partvaxct_hpv18_anal = 0  #HPV18 anal infection blocked from vaccination, partner
        sex_exposed$partvaxct_hpv31_anal = 0  #HPV31 anal infection blocked from vaccination, partner
        sex_exposed$partvaxct_hpv33_anal = 0  #HPV33 anal infection blocked from vaccination, partner
        sex_exposed$partvaxct_hpv45_anal = 0  #HPV45 anal infection blocked from vaccination, partner
        sex_exposed$partvaxct_hpv52_anal = 0  #HPV52 anal infection blocked from vaccination, partner
        sex_exposed$partvaxct_hpv58_anal = 0  #HPV58 anal infection blocked from vaccination, partner
        sex_exposed$partvaxct_hpv6_oral = 0   #HPV6 oral infection blocked from vaccination, partner
        sex_exposed$partvaxct_hpv11_oral = 0  #HPV11 oral infection blocked from vaccination, partner
        sex_exposed$partvaxct_hpv16_oral = 0  #HPV16 oral infection blocked from vaccination, partner
        sex_exposed$partvaxct_hpv18_oral = 0  #HPV18 oral infection blocked from vaccination, partner
        sex_exposed$partvaxct_hpv31_oral = 0  #HPV31 oral infection blocked from vaccination, partner
        sex_exposed$partvaxct_hpv33_oral = 0  #HPV33 oral infection blocked from vaccination, partner
        sex_exposed$partvaxct_hpv45_oral = 0  #HPV45 oral infection blocked from vaccination, partner
        sex_exposed$partvaxct_hpv52_oral = 0  #HPV52 oral infection blocked from vaccination, partner
        sex_exposed$partvaxct_hpv58_oral = 0  #HPV58 oral infection blocked from vaccination, partner
        #sex_exposed$partprevct_hpv_anal = 0  #HPV anal infection blocked from any prevention strategy, partner
        sex_exposed$partprevct_hpv6_anal = 0  #HPV6 anal infection blocked from any prevention strategy, partner
        sex_exposed$partprevct_hpv11_anal = 0 #HPV11 anal infection blocked from any prevention strategy, partner
        sex_exposed$partprevct_hpv16_anal = 0 #HPV16 anal infection blocked from any prevention strategy, partner
        sex_exposed$partprevct_hpv18_anal = 0 #HPV18 anal infection blocked from any prevention strategy, partner
        sex_exposed$partprevct_hpv31_anal = 0 #HPV31 anal infection blocked from any prevention strategy, partner
        sex_exposed$partprevct_hpv33_anal = 0 #HPV33 anal infection blocked from any prevention strategy, partner
        sex_exposed$partprevct_hpv45_anal = 0 #HPV45 anal infection blocked from any prevention strategy, partner
        sex_exposed$partprevct_hpv52_anal = 0 #HPV52 anal infection blocked from any prevention strategy, partner
        sex_exposed$partprevct_hpv58_anal = 0 #HPV58 anal infection blocked from any prevention strategy, partner
        sex_exposed$partprevct_hpv6_oral = 0  #HPV6 oral infection blocked from any prevention strategy, partner
        sex_exposed$partprevct_hpv11_oral = 0 #HPV11 oral infection blocked from any prevention strategy, partner
        sex_exposed$partprevct_hpv16_oral = 0 #HPV16 oral infection blocked from any prevention strategy, partner
        sex_exposed$partprevct_hpv18_oral = 0 #HPV18 oral infection blocked from any prevention strategy, partner
        sex_exposed$partprevct_hpv31_oral = 0 #HPV31 oral infection blocked from any prevention strategy, partner
        sex_exposed$partprevct_hpv33_oral = 0 #HPV33 oral infection blocked from any prevention strategy, partner
        sex_exposed$partprevct_hpv45_oral = 0 #HPV45 oral infection blocked from any prevention strategy, partner
        sex_exposed$partprevct_hpv52_oral = 0 #HPV52 oral infection blocked from any prevention strategy, partner
        sex_exposed$partprevct_hpv58_oral = 0 #HPV58 oral infection blocked from any prevention strategy, partner
        sex_exposed$partinfectct = 0          #partner caused a new HPV anal infection to ego
        sex_exposed$partnewHIV = 0            #new HIV infection, partner
        sex_exposed$partnewVL = -1            #set VL to acute if new infection, partner
        #sex_exposed$partnewHPV_ANAL = 0      #new HPV anal infection, partner
        sex_exposed$partnewHPV6_ANAL = 0      #new HPV6 anal infection, partner
        sex_exposed$partnewHPV11_ANAL = 0     #new HPV11 anal infection, partner
        sex_exposed$partnewHPV16_ANAL = 0     #new HPV16 anal infection, partner
        sex_exposed$partnewHPV18_ANAL = 0     #new HPV18 anal infection, partner
        sex_exposed$partnewHPV31_ANAL = 0     #new HPV31 anal infection, partner
        sex_exposed$partnewHPV33_ANAL = 0     #new HPV33 anal infection, partner
        sex_exposed$partnewHPV45_ANAL = 0     #new HPV45 anal infection, partner
        sex_exposed$partnewHPV52_ANAL = 0     #new HPV52 anal infection, partner
        sex_exposed$partnewHPV58_ANAL = 0     #new HPV58 anal infection, partner
        sex_exposed$partnewHPV6_ORAL = 0      #new HPV6 oral infection, partner
        sex_exposed$partnewHPV11_ORAL = 0     #new HPV11 oral infection, partner
        sex_exposed$partnewHPV16_ORAL = 0     #new HPV16 oral infection, partner
        sex_exposed$partnewHPV18_ORAL = 0     #new HPV18 oral infection, partner
        sex_exposed$partnewHPV31_ORAL = 0     #new HPV31 oral infection, partner
        sex_exposed$partnewHPV33_ORAL = 0     #new HPV33 oral infection, partner
        sex_exposed$partnewHPV45_ORAL = 0     #new HPV45 oral infection, partner
        sex_exposed$partnewHPV52_ORAL = 0     #new HPV52 oral infection, partner
        sex_exposed$partnewHPV58_ORAL = 0     #new HPV58 oral infection, partner
        
        #calculate probabilities of infection
        probinfect1_hiv = runif(nrow(sex_exposed),0,1)
        probinfect2_hiv = runif(nrow(sex_exposed),0,1)
        #probinfect1_hpv_anal = runif(nrow(sex_exposed),0,1)
        #probinfect2_hpv_anal = runif(nrow(sex_exposed),0,1)
        probinfect1_hpv6_anal = runif(nrow(sex_exposed),0,1)
        probinfect2_hpv6_anal = runif(nrow(sex_exposed),0,1)
        probinfect1_hpv11_anal = runif(nrow(sex_exposed),0,1)
        probinfect2_hpv11_anal = runif(nrow(sex_exposed),0,1)
        probinfect1_hpv16_anal = runif(nrow(sex_exposed),0,1)
        probinfect2_hpv16_anal = runif(nrow(sex_exposed),0,1)
        probinfect1_hpv18_anal = runif(nrow(sex_exposed),0,1)
        probinfect2_hpv18_anal = runif(nrow(sex_exposed),0,1)
        probinfect1_hpv31_anal = runif(nrow(sex_exposed),0,1)
        probinfect2_hpv31_anal = runif(nrow(sex_exposed),0,1)
        probinfect1_hpv33_anal = runif(nrow(sex_exposed),0,1)
        probinfect2_hpv33_anal = runif(nrow(sex_exposed),0,1)
        probinfect1_hpv45_anal = runif(nrow(sex_exposed),0,1)
        probinfect2_hpv45_anal = runif(nrow(sex_exposed),0,1)
        probinfect1_hpv52_anal = runif(nrow(sex_exposed),0,1)
        probinfect2_hpv52_anal = runif(nrow(sex_exposed),0,1)
        probinfect1_hpv58_anal = runif(nrow(sex_exposed),0,1)
        probinfect2_hpv58_anal = runif(nrow(sex_exposed),0,1)
        probinfect1_hpv6_oral = runif(nrow(sex_exposed),0,1)
        probinfect2_hpv6_oral = runif(nrow(sex_exposed),0,1)
        probinfect1_hpv11_oral = runif(nrow(sex_exposed),0,1)
        probinfect2_hpv11_oral = runif(nrow(sex_exposed),0,1)
        probinfect1_hpv16_oral = runif(nrow(sex_exposed),0,1)
        probinfect2_hpv16_oral = runif(nrow(sex_exposed),0,1)
        probinfect1_hpv18_oral = runif(nrow(sex_exposed),0,1)
        probinfect2_hpv18_oral = runif(nrow(sex_exposed),0,1)
        probinfect1_hpv31_oral = runif(nrow(sex_exposed),0,1)
        probinfect2_hpv31_oral = runif(nrow(sex_exposed),0,1)
        probinfect1_hpv33_oral = runif(nrow(sex_exposed),0,1)
        probinfect2_hpv33_oral = runif(nrow(sex_exposed),0,1)
        probinfect1_hpv45_oral = runif(nrow(sex_exposed),0,1)
        probinfect2_hpv45_oral = runif(nrow(sex_exposed),0,1)
        probinfect1_hpv52_oral = runif(nrow(sex_exposed),0,1)
        probinfect2_hpv52_oral = runif(nrow(sex_exposed),0,1)
        probinfect1_hpv58_oral = runif(nrow(sex_exposed),0,1)
        probinfect2_hpv58_oral = runif(nrow(sex_exposed),0,1)
        
        #determine infection under no prevention for each pathogen
        
        #hiv anal, ego then partner for chronic then acute
        sex_exposed$infection_hiv[sex_exposed$HIV==1] = ifelse(sex_exposed$sex[sex_exposed$HIV==1]!=2 & sex_exposed$exposure_hiv[sex_exposed$HIV==1]==1 & sex_exposed$simAI[sex_exposed$HIV==1]==1 & prep_sims[[current_data]]$VL[exposed_hiv_partner]==1 & probinfect1_hiv[sex_exposed$HIV==1] <= 0.0134, 1, ifelse(sex_exposed$sex[sex_exposed$HIV==1]!=2 & sex_exposed$exposure_hiv[sex_exposed$HIV==1]==1 & sex_exposed$simAI[sex_exposed$HIV==1]==2 & prep_sims[[current_data]]$VL[exposed_hiv_partner]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==1 & probinfect1_hiv[sex_exposed$HIV==1] <= 0.0010, 1, ifelse(sex_exposed$sex[sex_exposed$HIV==1]!=2 & sex_exposed$exposure_hiv[sex_exposed$HIV==1]==1 & sex_exposed$simAI[sex_exposed$HIV==1]==2 & prep_sims[[current_data]]$VL[exposed_hiv_partner]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==0 & probinfect1_hiv[sex_exposed$HIV==1] <= 0.0059, 1, ifelse(sex_exposed$sex[sex_exposed$HIV==1]!=2 & sex_exposed$exposure_hiv[sex_exposed$HIV==1]==1 & sex_exposed$simAI[sex_exposed$HIV==1]==3 & prep_sims[[current_data]]$VL[exposed_hiv_partner]==1 & probinfect1_hiv[sex_exposed$HIV==1] <= 0.0134, 1, ifelse(sex_exposed$sex[sex_exposed$HIV==1]!=2 & sex_exposed$exposure_hiv[sex_exposed$HIV==1]==1 & sex_exposed$simAI[sex_exposed$HIV==1]==3 & prep_sims[[current_data]]$VL[exposed_hiv_partner]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==1 & probinfect2_hiv[sex_exposed$HIV==1] <= 0.0010, 1, ifelse(sex_exposed$sex[sex_exposed$HIV==1]!=2 & sex_exposed$exposure_hiv[sex_exposed$HIV==1]==1 & sex_exposed$simAI[sex_exposed$HIV==1]==3 & prep_sims[[current_data]]$VL[exposed_hiv_partner]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==0 & probinfect2_hiv[sex_exposed$HIV==1] <= 0.0059, 1, 0))))))
        sex_exposed$infection_hiv[sex_exposed$HIV==1] = ifelse(sex_exposed$sex[sex_exposed$HIV==1]!=2 & sex_exposed$exposure_hiv[sex_exposed$HIV==1]==1 & sex_exposed$simAI[sex_exposed$HIV==1]==1 & prep_sims[[current_data]]$VL[exposed_hiv_partner]==2 & probinfect1_hiv[sex_exposed$HIV==1] <= 0.1284, 1, ifelse(sex_exposed$sex[sex_exposed$HIV==1]!=2 & sex_exposed$exposure_hiv[sex_exposed$HIV==1]==1 & sex_exposed$simAI[sex_exposed$HIV==1]==2 & prep_sims[[current_data]]$VL[exposed_hiv_partner]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==1 & probinfect1_hiv[sex_exposed$HIV==1] <= 0.0101, 1, ifelse(sex_exposed$sex[sex_exposed$HIV==1]!=2 & sex_exposed$exposure_hiv[sex_exposed$HIV==1]==1 & sex_exposed$simAI[sex_exposed$HIV==1]==2 & prep_sims[[current_data]]$VL[exposed_hiv_partner]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==0 & probinfect1_hiv[sex_exposed$HIV==1] <= 0.0569, 1, ifelse(sex_exposed$sex[sex_exposed$HIV==1]!=2 & sex_exposed$exposure_hiv[sex_exposed$HIV==1]==1 & sex_exposed$simAI[sex_exposed$HIV==1]==3 & prep_sims[[current_data]]$VL[exposed_hiv_partner]==2 & probinfect1_hiv[sex_exposed$HIV==1] <= 0.1284, 1, ifelse(sex_exposed$sex[sex_exposed$HIV==1]!=2 & sex_exposed$exposure_hiv[sex_exposed$HIV==1]==1 & sex_exposed$simAI[sex_exposed$HIV==1]==3 & prep_sims[[current_data]]$VL[exposed_hiv_partner]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==1 & probinfect2_hiv[sex_exposed$HIV==1] <= 0.0101, 1, ifelse(sex_exposed$sex[sex_exposed$HIV==1]!=2 & sex_exposed$exposure_hiv[sex_exposed$HIV==1]==1 & sex_exposed$simAI[sex_exposed$HIV==1]==3 & prep_sims[[current_data]]$VL[exposed_hiv_partner]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==0 & probinfect2_hiv[sex_exposed$HIV==1] <= 0.0569, 1, sex_exposed$infection_hiv[sex_exposed$HIV==1]))))))
        sex_exposed$partinfection_hiv[sex_exposed$HIV==1] = ifelse(sex_exposed$sex[sex_exposed$HIV==1]!=2 & sex_exposed$exposure_hiv[sex_exposed$HIV==1]==2 & sex_exposed$simAI[sex_exposed$HIV==1]==2 & prep_sims[[current_data]]$VL[exposed_hiv_ego]==1 & probinfect1_hiv[sex_exposed$HIV==1] <= 0.0134, 1, ifelse(sex_exposed$sex[sex_exposed$HIV==1]!=2 & sex_exposed$exposure_hiv[sex_exposed$HIV==1]==2 & sex_exposed$simAI[sex_exposed$HIV==1]==1 & prep_sims[[current_data]]$VL[exposed_hiv_ego]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==1 & probinfect1_hiv[sex_exposed$HIV==1] <= 0.0010, 1, ifelse(sex_exposed$sex[sex_exposed$HIV==1]!=2 & sex_exposed$exposure_hiv[sex_exposed$HIV==1]==2 & sex_exposed$simAI[sex_exposed$HIV==1]==1 & prep_sims[[current_data]]$VL[exposed_hiv_ego]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==0 & probinfect1_hiv[sex_exposed$HIV==1] <= 0.0059, 1, ifelse(sex_exposed$sex[sex_exposed$HIV==1]!=2 & sex_exposed$exposure_hiv[sex_exposed$HIV==1]==2 & sex_exposed$simAI[sex_exposed$HIV==1]==3 & prep_sims[[current_data]]$VL[exposed_hiv_ego]==1 & probinfect1_hiv[sex_exposed$HIV==1] <= 0.0134, 1, ifelse(sex_exposed$sex[sex_exposed$HIV==1]!=2 & sex_exposed$exposure_hiv[sex_exposed$HIV==1]==2 & sex_exposed$simAI[sex_exposed$HIV==1]==3 & prep_sims[[current_data]]$VL[exposed_hiv_ego]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==1 & probinfect2_hiv[sex_exposed$HIV==1] <= 0.0010, 1, ifelse(sex_exposed$sex[sex_exposed$HIV==1]!=2 & sex_exposed$exposure_hiv[sex_exposed$HIV==1]==2 & sex_exposed$simAI[sex_exposed$HIV==1]==3 & prep_sims[[current_data]]$VL[exposed_hiv_ego]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==0 & probinfect2_hiv[sex_exposed$HIV==1] <= 0.0059, 1, 0))))))
        sex_exposed$partinfection_hiv[sex_exposed$HIV==1] = ifelse(sex_exposed$sex[sex_exposed$HIV==1]!=2 & sex_exposed$exposure_hiv[sex_exposed$HIV==1]==2 & sex_exposed$simAI[sex_exposed$HIV==1]==2 & prep_sims[[current_data]]$VL[exposed_hiv_ego]==2 & probinfect1_hiv[sex_exposed$HIV==1] <= 0.1284, 1, ifelse(sex_exposed$sex[sex_exposed$HIV==1]!=2 & sex_exposed$exposure_hiv[sex_exposed$HIV==1]==2 & sex_exposed$simAI[sex_exposed$HIV==1]==1 & prep_sims[[current_data]]$VL[exposed_hiv_ego]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==1 & probinfect1_hiv[sex_exposed$HIV==1] <= 0.0101, 1, ifelse(sex_exposed$sex[sex_exposed$HIV==1]!=2 & sex_exposed$exposure_hiv[sex_exposed$HIV==1]==2 & sex_exposed$simAI[sex_exposed$HIV==1]==1 & prep_sims[[current_data]]$VL[exposed_hiv_ego]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==0 & probinfect1_hiv[sex_exposed$HIV==1] <= 0.0569, 1, ifelse(sex_exposed$sex[sex_exposed$HIV==1]!=2 & sex_exposed$exposure_hiv[sex_exposed$HIV==1]==2 & sex_exposed$simAI[sex_exposed$HIV==1]==3 & prep_sims[[current_data]]$VL[exposed_hiv_ego]==2 & probinfect1_hiv[sex_exposed$HIV==1] <= 0.1284, 1, ifelse(sex_exposed$sex[sex_exposed$HIV==1]!=2 & sex_exposed$exposure_hiv[sex_exposed$HIV==1]==2 & sex_exposed$simAI[sex_exposed$HIV==1]==3 & prep_sims[[current_data]]$VL[exposed_hiv_ego]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==1 & probinfect2_hiv[sex_exposed$HIV==1] <= 0.0101, 1, ifelse(sex_exposed$sex[sex_exposed$HIV==1]!=2 & sex_exposed$exposure_hiv[sex_exposed$HIV==1]==2 & sex_exposed$simAI[sex_exposed$HIV==1]==3 & prep_sims[[current_data]]$VL[exposed_hiv_ego]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==0 & probinfect2_hiv[sex_exposed$HIV==1] <= 0.0569, 1, sex_exposed$partinfection_hiv[sex_exposed$HIV==1]))))))
        
        #hpv anal, ego then partner then both
        #sex_exposed$infection_hpv_anal[sex_exposed$HPV_ANAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV_ANAL==1]!=2 & sex_exposed$exposure_hpv_anal[sex_exposed$HPV_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV_ANAL==1]==1 & probinfect1_hpv_anal[sex_exposed$HPV_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV_ANAL==1]!=2 & sex_exposed$exposure_hpv_anal[sex_exposed$HPV_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv_anal_ego]==1 & probinfect1_hpv_anal[sex_exposed$HPV_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV_ANAL==1]!=2 & sex_exposed$exposure_hpv_anal[sex_exposed$HPV_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv_anal_ego]==0 & probinfect1_hpv_anal[sex_exposed$HPV_ANAL==1] <= 0.071, 1, ifelse(sex_exposed$sex[sex_exposed$HPV_ANAL==1]!=2 & sex_exposed$exposure_hpv_anal[sex_exposed$HPV_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV_ANAL==1]==3 & probinfect1_hpv_anal[sex_exposed$HPV_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV_ANAL==1]!=2 & sex_exposed$exposure_hpv_anal[sex_exposed$HPV_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv_anal_ego]==1 & probinfect2_hpv_anal[sex_exposed$HPV_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV_ANAL==1]!=2 & sex_exposed$exposure_hpv_anal[sex_exposed$HPV_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv_anal_ego]==0 & probinfect2_hpv_anal[sex_exposed$HPV_ANAL==1] <= 0.071, 1, 0))))))
        #sex_exposed$partinfection_hpv_anal[sex_exposed$HPV_ANAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV_ANAL==1]!=2 & sex_exposed$exposure_hpv_anal[sex_exposed$HPV_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV_ANAL==1]==1 & probinfect1_hpv_anal[sex_exposed$HPV_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV_ANAL==1]!=2 & sex_exposed$exposure_hpv_anal[sex_exposed$HPV_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv_anal_ego]==1 & probinfect1_hpv_anal[sex_exposed$HPV_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV_ANAL==1]!=2 & sex_exposed$exposure_hpv_anal[sex_exposed$HPV_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv_anal_ego]==0 & probinfect1_hpv_anal[sex_exposed$HPV_ANAL==1] <= 0.071, 1, ifelse(sex_exposed$sex[sex_exposed$HPV_ANAL==1]!=2 & sex_exposed$exposure_hpv_anal[sex_exposed$HPV_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV_ANAL==1]==3 & probinfect1_hpv_anal[sex_exposed$HPV_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV_ANAL==1]!=2 & sex_exposed$exposure_hpv_anal[sex_exposed$HPV_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv_anal_ego]==1 & probinfect2_hpv_anal[sex_exposed$HPV_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV_ANAL==1]!=2 & sex_exposed$exposure_hpv_anal[sex_exposed$HPV_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv_anal_ego]==0 & probinfect2_hpv_anal[sex_exposed$HPV_ANAL==1] <= 0.071, 1, 0))))))
        #sex_exposed$infection_hpv_anal[sex_exposed$HPV_ANAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV_ANAL==1]!=2 & sex_exposed$exposure_hpv_anal[sex_exposed$HPV_ANAL==1]==3 & sex_exposed$simAI[sex_exposed$HPV_ANAL==1]==1 & probinfect1_hpv_anal[sex_exposed$HPV_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV_ANAL==1]!=2 & sex_exposed$exposure_hpv_anal[sex_exposed$HPV_ANAL==1]==3 & sex_exposed$simAI[sex_exposed$HPV_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv_anal_ego]==1 & probinfect1_hpv_anal[sex_exposed$HPV_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV_ANAL==1]!=2 & sex_exposed$exposure_hpv_anal[sex_exposed$HPV_ANAL==1]==3 & sex_exposed$simAI[sex_exposed$HPV_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv_anal_ego]==0 & probinfect1_hpv_anal[sex_exposed$HPV_ANAL==1] <= 0.071, 1, ifelse(sex_exposed$sex[sex_exposed$HPV_ANAL==1]!=2 & sex_exposed$exposure_hpv_anal[sex_exposed$HPV_ANAL==1]==3 & sex_exposed$simAI[sex_exposed$HPV_ANAL==1]==3 & probinfect1_hpv_anal[sex_exposed$HPV_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV_ANAL==1]!=2 & sex_exposed$exposure_hpv_anal[sex_exposed$HPV_ANAL==1]==3 & sex_exposed$simAI[sex_exposed$HPV_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv_anal_ego]==1 & probinfect2_hpv_anal[sex_exposed$HPV_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV_ANAL==1]!=2 & sex_exposed$exposure_hpv_anal[sex_exposed$HPV_ANAL==1]==3 & sex_exposed$simAI[sex_exposed$HPV_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv_anal_ego]==0 & probinfect2_hpv_anal[sex_exposed$HPV_ANAL==1] <= 0.071, 1, sex_exposed$infection_hpv_anal[sex_exposed$HPV_ANAL==1]))))))
        #sex_exposed$partinfection_hpv_anal[sex_exposed$HPV_ANAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV_ANAL==1]!=2 & sex_exposed$exposure_hpv_anal[sex_exposed$HPV_ANAL==1]==3 & sex_exposed$simAI[sex_exposed$HPV_ANAL==1]==1 & probinfect1_hpv_anal[sex_exposed$HPV_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV_ANAL==1]!=2 & sex_exposed$exposure_hpv_anal[sex_exposed$HPV_ANAL==1]==3 & sex_exposed$simAI[sex_exposed$HPV_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv_anal_ego]==1 & probinfect1_hpv_anal[sex_exposed$HPV_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV_ANAL==1]!=2 & sex_exposed$exposure_hpv_anal[sex_exposed$HPV_ANAL==1]==3 & sex_exposed$simAI[sex_exposed$HPV_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv_anal_ego]==0 & probinfect1_hpv_anal[sex_exposed$HPV_ANAL==1] <= 0.071, 1, ifelse(sex_exposed$sex[sex_exposed$HPV_ANAL==1]!=2 & sex_exposed$exposure_hpv_anal[sex_exposed$HPV_ANAL==1]==3 & sex_exposed$simAI[sex_exposed$HPV_ANAL==1]==3 & probinfect1_hpv_anal[sex_exposed$HPV_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV_ANAL==1]!=2 & sex_exposed$exposure_hpv_anal[sex_exposed$HPV_ANAL==1]==3 & sex_exposed$simAI[sex_exposed$HPV_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv_anal_ego]==1 & probinfect2_hpv_anal[sex_exposed$HPV_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV_ANAL==1]!=2 & sex_exposed$exposure_hpv_anal[sex_exposed$HPV_ANAL==1]==3 & sex_exposed$simAI[sex_exposed$HPV_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv_anal_ego]==0 & probinfect2_hpv_anal[sex_exposed$HPV_ANAL==1] <= 0.071, 1, sex_exposed$partinfection_hpv_anal[sex_exposed$HPV_ANAL==1]))))))
        
        #hpv type specific anal, ego then partner
        sex_exposed$infection_hpv6_anal[sex_exposed$HPV6_ANAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV6_ANAL==1]!=2 & sex_exposed$exposure_hpv6_anal[sex_exposed$HPV6_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV6_ANAL==1]==1 & probinfect1_hpv6_anal[sex_exposed$HPV6_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV6_ANAL==1]!=2 & sex_exposed$exposure_hpv6_anal[sex_exposed$HPV6_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV6_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv6_anal_ego]==1 & probinfect1_hpv6_anal[sex_exposed$HPV6_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV6_ANAL==1]!=2 & sex_exposed$exposure_hpv6_anal[sex_exposed$HPV6_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV6_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv6_anal_ego]==0 & probinfect1_hpv6_anal[sex_exposed$HPV6_ANAL==1] <= 0.071, 1, ifelse(sex_exposed$sex[sex_exposed$HPV6_ANAL==1]!=2 & sex_exposed$exposure_hpv6_anal[sex_exposed$HPV6_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV6_ANAL==1]==3 & probinfect1_hpv6_anal[sex_exposed$HPV6_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV6_ANAL==1]!=2 & sex_exposed$exposure_hpv6_anal[sex_exposed$HPV6_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV6_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv6_anal_ego]==1 & probinfect2_hpv6_anal[sex_exposed$HPV6_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV6_ANAL==1]!=2 & sex_exposed$exposure_hpv6_anal[sex_exposed$HPV6_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV6_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv6_anal_ego]==0 & probinfect2_hpv6_anal[sex_exposed$HPV6_ANAL==1] <= 0.071, 1, 0))))))
        sex_exposed$partinfection_hpv6_anal[sex_exposed$HPV6_ANAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV6_ANAL==1]!=2 & sex_exposed$exposure_hpv6_anal[sex_exposed$HPV6_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV6_ANAL==1]==1 & probinfect1_hpv6_anal[sex_exposed$HPV6_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV6_ANAL==1]!=2 & sex_exposed$exposure_hpv6_anal[sex_exposed$HPV6_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV6_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv6_anal_partner]==1 & probinfect1_hpv6_anal[sex_exposed$HPV6_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV6_ANAL==1]!=2 & sex_exposed$exposure_hpv6_anal[sex_exposed$HPV6_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV6_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv6_anal_partner]==0 & probinfect1_hpv6_anal[sex_exposed$HPV6_ANAL==1] <= 0.071, 1, ifelse(sex_exposed$sex[sex_exposed$HPV6_ANAL==1]!=2 & sex_exposed$exposure_hpv6_anal[sex_exposed$HPV6_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV6_ANAL==1]==3 & probinfect1_hpv6_anal[sex_exposed$HPV6_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV6_ANAL==1]!=2 & sex_exposed$exposure_hpv6_anal[sex_exposed$HPV6_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV6_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv6_anal_partner]==1 & probinfect2_hpv6_anal[sex_exposed$HPV6_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV6_ANAL==1]!=2 & sex_exposed$exposure_hpv6_anal[sex_exposed$HPV6_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV6_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv6_anal_partner]==0 & probinfect2_hpv6_anal[sex_exposed$HPV6_ANAL==1] <= 0.071, 1, 0))))))
        sex_exposed$infection_hpv11_anal[sex_exposed$HPV11_ANAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV11_ANAL==1]!=2 & sex_exposed$exposure_hpv11_anal[sex_exposed$HPV11_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV11_ANAL==1]==1 & probinfect1_hpv11_anal[sex_exposed$HPV11_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV11_ANAL==1]!=2 & sex_exposed$exposure_hpv11_anal[sex_exposed$HPV11_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV11_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv11_anal_ego]==1 & probinfect1_hpv11_anal[sex_exposed$HPV11_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV11_ANAL==1]!=2 & sex_exposed$exposure_hpv11_anal[sex_exposed$HPV11_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV11_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv11_anal_ego]==0 & probinfect1_hpv11_anal[sex_exposed$HPV11_ANAL==1] <= 0.071, 1, ifelse(sex_exposed$sex[sex_exposed$HPV11_ANAL==1]!=2 & sex_exposed$exposure_hpv11_anal[sex_exposed$HPV11_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV11_ANAL==1]==3 & probinfect1_hpv11_anal[sex_exposed$HPV11_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV11_ANAL==1]!=2 & sex_exposed$exposure_hpv11_anal[sex_exposed$HPV11_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV11_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv11_anal_ego]==1 & probinfect2_hpv11_anal[sex_exposed$HPV11_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV11_ANAL==1]!=2 & sex_exposed$exposure_hpv11_anal[sex_exposed$HPV11_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV11_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv11_anal_ego]==0 & probinfect2_hpv11_anal[sex_exposed$HPV11_ANAL==1] <= 0.071, 1, 0))))))
        sex_exposed$partinfection_hpv11_anal[sex_exposed$HPV11_ANAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV11_ANAL==1]!=2 & sex_exposed$exposure_hpv11_anal[sex_exposed$HPV11_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV11_ANAL==1]==1 & probinfect1_hpv11_anal[sex_exposed$HPV11_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV11_ANAL==1]!=2 & sex_exposed$exposure_hpv11_anal[sex_exposed$HPV11_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV11_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv11_anal_partner]==1 & probinfect1_hpv11_anal[sex_exposed$HPV11_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV11_ANAL==1]!=2 & sex_exposed$exposure_hpv11_anal[sex_exposed$HPV11_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV11_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv11_anal_partner]==0 & probinfect1_hpv11_anal[sex_exposed$HPV11_ANAL==1] <= 0.071, 1, ifelse(sex_exposed$sex[sex_exposed$HPV11_ANAL==1]!=2 & sex_exposed$exposure_hpv11_anal[sex_exposed$HPV11_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV11_ANAL==1]==3 & probinfect1_hpv11_anal[sex_exposed$HPV11_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV11_ANAL==1]!=2 & sex_exposed$exposure_hpv11_anal[sex_exposed$HPV11_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV11_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv11_anal_partner]==1 & probinfect2_hpv11_anal[sex_exposed$HPV11_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV11_ANAL==1]!=2 & sex_exposed$exposure_hpv11_anal[sex_exposed$HPV11_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV11_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv11_anal_partner]==0 & probinfect2_hpv11_anal[sex_exposed$HPV11_ANAL==1] <= 0.071, 1, 0))))))
        sex_exposed$infection_hpv16_anal[sex_exposed$HPV16_ANAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV16_ANAL==1]!=2 & sex_exposed$exposure_hpv16_anal[sex_exposed$HPV16_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV16_ANAL==1]==1 & probinfect1_hpv16_anal[sex_exposed$HPV16_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV16_ANAL==1]!=2 & sex_exposed$exposure_hpv16_anal[sex_exposed$HPV16_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV16_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv16_anal_ego]==1 & probinfect1_hpv16_anal[sex_exposed$HPV16_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV16_ANAL==1]!=2 & sex_exposed$exposure_hpv16_anal[sex_exposed$HPV16_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV16_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv16_anal_ego]==0 & probinfect1_hpv16_anal[sex_exposed$HPV16_ANAL==1] <= 0.071, 1, ifelse(sex_exposed$sex[sex_exposed$HPV16_ANAL==1]!=2 & sex_exposed$exposure_hpv16_anal[sex_exposed$HPV16_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV16_ANAL==1]==3 & probinfect1_hpv16_anal[sex_exposed$HPV16_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV16_ANAL==1]!=2 & sex_exposed$exposure_hpv16_anal[sex_exposed$HPV16_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV16_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv16_anal_ego]==1 & probinfect2_hpv16_anal[sex_exposed$HPV16_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV16_ANAL==1]!=2 & sex_exposed$exposure_hpv16_anal[sex_exposed$HPV16_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV16_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv16_anal_ego]==0 & probinfect2_hpv16_anal[sex_exposed$HPV16_ANAL==1] <= 0.071, 1, 0))))))
        sex_exposed$partinfection_hpv16_anal[sex_exposed$HPV16_ANAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV16_ANAL==1]!=2 & sex_exposed$exposure_hpv16_anal[sex_exposed$HPV16_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV16_ANAL==1]==1 & probinfect1_hpv16_anal[sex_exposed$HPV16_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV16_ANAL==1]!=2 & sex_exposed$exposure_hpv16_anal[sex_exposed$HPV16_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV16_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv16_anal_partner]==1 & probinfect1_hpv16_anal[sex_exposed$HPV16_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV16_ANAL==1]!=2 & sex_exposed$exposure_hpv16_anal[sex_exposed$HPV16_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV16_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv16_anal_partner]==0 & probinfect1_hpv16_anal[sex_exposed$HPV16_ANAL==1] <= 0.071, 1, ifelse(sex_exposed$sex[sex_exposed$HPV16_ANAL==1]!=2 & sex_exposed$exposure_hpv16_anal[sex_exposed$HPV16_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV16_ANAL==1]==3 & probinfect1_hpv16_anal[sex_exposed$HPV16_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV16_ANAL==1]!=2 & sex_exposed$exposure_hpv16_anal[sex_exposed$HPV16_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV16_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv16_anal_partner]==1 & probinfect2_hpv16_anal[sex_exposed$HPV16_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV16_ANAL==1]!=2 & sex_exposed$exposure_hpv16_anal[sex_exposed$HPV16_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV16_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv16_anal_partner]==0 & probinfect2_hpv16_anal[sex_exposed$HPV16_ANAL==1] <= 0.071, 1, 0))))))
        sex_exposed$infection_hpv18_anal[sex_exposed$HPV18_ANAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV18_ANAL==1]!=2 & sex_exposed$exposure_hpv18_anal[sex_exposed$HPV18_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV18_ANAL==1]==1 & probinfect1_hpv18_anal[sex_exposed$HPV18_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV18_ANAL==1]!=2 & sex_exposed$exposure_hpv18_anal[sex_exposed$HPV18_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV18_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv18_anal_ego]==1 & probinfect1_hpv18_anal[sex_exposed$HPV18_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV18_ANAL==1]!=2 & sex_exposed$exposure_hpv18_anal[sex_exposed$HPV18_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV18_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv18_anal_ego]==0 & probinfect1_hpv18_anal[sex_exposed$HPV18_ANAL==1] <= 0.071, 1, ifelse(sex_exposed$sex[sex_exposed$HPV18_ANAL==1]!=2 & sex_exposed$exposure_hpv18_anal[sex_exposed$HPV18_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV18_ANAL==1]==3 & probinfect1_hpv18_anal[sex_exposed$HPV18_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV18_ANAL==1]!=2 & sex_exposed$exposure_hpv18_anal[sex_exposed$HPV18_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV18_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv18_anal_ego]==1 & probinfect2_hpv18_anal[sex_exposed$HPV18_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV18_ANAL==1]!=2 & sex_exposed$exposure_hpv18_anal[sex_exposed$HPV18_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV18_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv18_anal_ego]==0 & probinfect2_hpv18_anal[sex_exposed$HPV18_ANAL==1] <= 0.071, 1, 0))))))
        sex_exposed$partinfection_hpv18_anal[sex_exposed$HPV18_ANAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV18_ANAL==1]!=2 & sex_exposed$exposure_hpv18_anal[sex_exposed$HPV18_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV18_ANAL==1]==1 & probinfect1_hpv18_anal[sex_exposed$HPV18_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV18_ANAL==1]!=2 & sex_exposed$exposure_hpv18_anal[sex_exposed$HPV18_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV18_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv18_anal_partner]==1 & probinfect1_hpv18_anal[sex_exposed$HPV18_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV18_ANAL==1]!=2 & sex_exposed$exposure_hpv18_anal[sex_exposed$HPV18_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV18_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv18_anal_partner]==0 & probinfect1_hpv18_anal[sex_exposed$HPV18_ANAL==1] <= 0.071, 1, ifelse(sex_exposed$sex[sex_exposed$HPV18_ANAL==1]!=2 & sex_exposed$exposure_hpv18_anal[sex_exposed$HPV18_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV18_ANAL==1]==3 & probinfect1_hpv18_anal[sex_exposed$HPV18_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV18_ANAL==1]!=2 & sex_exposed$exposure_hpv18_anal[sex_exposed$HPV18_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV18_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv18_anal_partner]==1 & probinfect2_hpv18_anal[sex_exposed$HPV18_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV18_ANAL==1]!=2 & sex_exposed$exposure_hpv18_anal[sex_exposed$HPV18_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV18_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv18_anal_partner]==0 & probinfect2_hpv18_anal[sex_exposed$HPV18_ANAL==1] <= 0.071, 1, 0))))))
        sex_exposed$infection_hpv31_anal[sex_exposed$HPV31_ANAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV31_ANAL==1]!=2 & sex_exposed$exposure_hpv31_anal[sex_exposed$HPV31_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV31_ANAL==1]==1 & probinfect1_hpv31_anal[sex_exposed$HPV31_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV31_ANAL==1]!=2 & sex_exposed$exposure_hpv31_anal[sex_exposed$HPV31_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV31_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv31_anal_ego]==1 & probinfect1_hpv31_anal[sex_exposed$HPV31_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV31_ANAL==1]!=2 & sex_exposed$exposure_hpv31_anal[sex_exposed$HPV31_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV31_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv31_anal_ego]==0 & probinfect1_hpv31_anal[sex_exposed$HPV31_ANAL==1] <= 0.071, 1, ifelse(sex_exposed$sex[sex_exposed$HPV31_ANAL==1]!=2 & sex_exposed$exposure_hpv31_anal[sex_exposed$HPV31_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV31_ANAL==1]==3 & probinfect1_hpv31_anal[sex_exposed$HPV31_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV31_ANAL==1]!=2 & sex_exposed$exposure_hpv31_anal[sex_exposed$HPV31_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV31_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv31_anal_ego]==1 & probinfect2_hpv31_anal[sex_exposed$HPV31_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV31_ANAL==1]!=2 & sex_exposed$exposure_hpv31_anal[sex_exposed$HPV31_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV31_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv31_anal_ego]==0 & probinfect2_hpv31_anal[sex_exposed$HPV31_ANAL==1] <= 0.071, 1, 0))))))
        sex_exposed$partinfection_hpv31_anal[sex_exposed$HPV31_ANAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV31_ANAL==1]!=2 & sex_exposed$exposure_hpv31_anal[sex_exposed$HPV31_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV31_ANAL==1]==1 & probinfect1_hpv31_anal[sex_exposed$HPV31_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV31_ANAL==1]!=2 & sex_exposed$exposure_hpv31_anal[sex_exposed$HPV31_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV31_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv31_anal_partner]==1 & probinfect1_hpv31_anal[sex_exposed$HPV31_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV31_ANAL==1]!=2 & sex_exposed$exposure_hpv31_anal[sex_exposed$HPV31_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV31_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv31_anal_partner]==0 & probinfect1_hpv31_anal[sex_exposed$HPV31_ANAL==1] <= 0.071, 1, ifelse(sex_exposed$sex[sex_exposed$HPV31_ANAL==1]!=2 & sex_exposed$exposure_hpv31_anal[sex_exposed$HPV31_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV31_ANAL==1]==3 & probinfect1_hpv31_anal[sex_exposed$HPV31_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV31_ANAL==1]!=2 & sex_exposed$exposure_hpv31_anal[sex_exposed$HPV31_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV31_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv31_anal_partner]==1 & probinfect2_hpv31_anal[sex_exposed$HPV31_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV31_ANAL==1]!=2 & sex_exposed$exposure_hpv31_anal[sex_exposed$HPV31_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV31_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv31_anal_partner]==0 & probinfect2_hpv31_anal[sex_exposed$HPV31_ANAL==1] <= 0.071, 1, 0))))))
        sex_exposed$infection_hpv33_anal[sex_exposed$HPV33_ANAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV33_ANAL==1]!=2 & sex_exposed$exposure_hpv33_anal[sex_exposed$HPV33_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV33_ANAL==1]==1 & probinfect1_hpv33_anal[sex_exposed$HPV33_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV33_ANAL==1]!=2 & sex_exposed$exposure_hpv33_anal[sex_exposed$HPV33_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV33_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv33_anal_ego]==1 & probinfect1_hpv33_anal[sex_exposed$HPV33_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV33_ANAL==1]!=2 & sex_exposed$exposure_hpv33_anal[sex_exposed$HPV33_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV33_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv33_anal_ego]==0 & probinfect1_hpv33_anal[sex_exposed$HPV33_ANAL==1] <= 0.071, 1, ifelse(sex_exposed$sex[sex_exposed$HPV33_ANAL==1]!=2 & sex_exposed$exposure_hpv33_anal[sex_exposed$HPV33_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV33_ANAL==1]==3 & probinfect1_hpv33_anal[sex_exposed$HPV33_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV33_ANAL==1]!=2 & sex_exposed$exposure_hpv33_anal[sex_exposed$HPV33_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV33_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv33_anal_ego]==1 & probinfect2_hpv33_anal[sex_exposed$HPV33_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV33_ANAL==1]!=2 & sex_exposed$exposure_hpv33_anal[sex_exposed$HPV33_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV33_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv33_anal_ego]==0 & probinfect2_hpv33_anal[sex_exposed$HPV33_ANAL==1] <= 0.071, 1, 0))))))
        sex_exposed$partinfection_hpv33_anal[sex_exposed$HPV33_ANAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV33_ANAL==1]!=2 & sex_exposed$exposure_hpv33_anal[sex_exposed$HPV33_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV33_ANAL==1]==1 & probinfect1_hpv33_anal[sex_exposed$HPV33_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV33_ANAL==1]!=2 & sex_exposed$exposure_hpv33_anal[sex_exposed$HPV33_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV33_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv33_anal_partner]==1 & probinfect1_hpv33_anal[sex_exposed$HPV33_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV33_ANAL==1]!=2 & sex_exposed$exposure_hpv33_anal[sex_exposed$HPV33_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV33_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv33_anal_partner]==0 & probinfect1_hpv33_anal[sex_exposed$HPV33_ANAL==1] <= 0.071, 1, ifelse(sex_exposed$sex[sex_exposed$HPV33_ANAL==1]!=2 & sex_exposed$exposure_hpv33_anal[sex_exposed$HPV33_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV33_ANAL==1]==3 & probinfect1_hpv33_anal[sex_exposed$HPV33_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV33_ANAL==1]!=2 & sex_exposed$exposure_hpv33_anal[sex_exposed$HPV33_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV33_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv33_anal_partner]==1 & probinfect2_hpv33_anal[sex_exposed$HPV33_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV33_ANAL==1]!=2 & sex_exposed$exposure_hpv33_anal[sex_exposed$HPV33_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV33_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv33_anal_partner]==0 & probinfect2_hpv33_anal[sex_exposed$HPV33_ANAL==1] <= 0.071, 1, 0))))))
        sex_exposed$infection_hpv45_anal[sex_exposed$HPV45_ANAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV45_ANAL==1]!=2 & sex_exposed$exposure_hpv45_anal[sex_exposed$HPV45_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV45_ANAL==1]==1 & probinfect1_hpv45_anal[sex_exposed$HPV45_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV45_ANAL==1]!=2 & sex_exposed$exposure_hpv45_anal[sex_exposed$HPV45_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV45_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv45_anal_ego]==1 & probinfect1_hpv45_anal[sex_exposed$HPV45_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV45_ANAL==1]!=2 & sex_exposed$exposure_hpv45_anal[sex_exposed$HPV45_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV45_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv45_anal_ego]==0 & probinfect1_hpv45_anal[sex_exposed$HPV45_ANAL==1] <= 0.071, 1, ifelse(sex_exposed$sex[sex_exposed$HPV45_ANAL==1]!=2 & sex_exposed$exposure_hpv45_anal[sex_exposed$HPV45_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV45_ANAL==1]==3 & probinfect1_hpv45_anal[sex_exposed$HPV45_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV45_ANAL==1]!=2 & sex_exposed$exposure_hpv45_anal[sex_exposed$HPV45_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV45_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv45_anal_ego]==1 & probinfect2_hpv45_anal[sex_exposed$HPV45_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV45_ANAL==1]!=2 & sex_exposed$exposure_hpv45_anal[sex_exposed$HPV45_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV45_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv45_anal_ego]==0 & probinfect2_hpv45_anal[sex_exposed$HPV45_ANAL==1] <= 0.071, 1, 0))))))
        sex_exposed$partinfection_hpv45_anal[sex_exposed$HPV45_ANAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV45_ANAL==1]!=2 & sex_exposed$exposure_hpv45_anal[sex_exposed$HPV45_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV45_ANAL==1]==1 & probinfect1_hpv45_anal[sex_exposed$HPV45_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV45_ANAL==1]!=2 & sex_exposed$exposure_hpv45_anal[sex_exposed$HPV45_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV45_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv45_anal_partner]==1 & probinfect1_hpv45_anal[sex_exposed$HPV45_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV45_ANAL==1]!=2 & sex_exposed$exposure_hpv45_anal[sex_exposed$HPV45_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV45_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv45_anal_partner]==0 & probinfect1_hpv45_anal[sex_exposed$HPV45_ANAL==1] <= 0.071, 1, ifelse(sex_exposed$sex[sex_exposed$HPV45_ANAL==1]!=2 & sex_exposed$exposure_hpv45_anal[sex_exposed$HPV45_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV45_ANAL==1]==3 & probinfect1_hpv45_anal[sex_exposed$HPV45_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV45_ANAL==1]!=2 & sex_exposed$exposure_hpv45_anal[sex_exposed$HPV45_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV45_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv45_anal_partner]==1 & probinfect2_hpv45_anal[sex_exposed$HPV45_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV45_ANAL==1]!=2 & sex_exposed$exposure_hpv45_anal[sex_exposed$HPV45_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV45_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv45_anal_partner]==0 & probinfect2_hpv45_anal[sex_exposed$HPV45_ANAL==1] <= 0.071, 1, 0))))))
        sex_exposed$infection_hpv52_anal[sex_exposed$HPV52_ANAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV52_ANAL==1]!=2 & sex_exposed$exposure_hpv52_anal[sex_exposed$HPV52_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV52_ANAL==1]==1 & probinfect1_hpv52_anal[sex_exposed$HPV52_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV52_ANAL==1]!=2 & sex_exposed$exposure_hpv52_anal[sex_exposed$HPV52_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV52_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv52_anal_ego]==1 & probinfect1_hpv52_anal[sex_exposed$HPV52_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV52_ANAL==1]!=2 & sex_exposed$exposure_hpv52_anal[sex_exposed$HPV52_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV52_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv52_anal_ego]==0 & probinfect1_hpv52_anal[sex_exposed$HPV52_ANAL==1] <= 0.071, 1, ifelse(sex_exposed$sex[sex_exposed$HPV52_ANAL==1]!=2 & sex_exposed$exposure_hpv52_anal[sex_exposed$HPV52_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV52_ANAL==1]==3 & probinfect1_hpv52_anal[sex_exposed$HPV52_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV52_ANAL==1]!=2 & sex_exposed$exposure_hpv52_anal[sex_exposed$HPV52_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV52_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv52_anal_ego]==1 & probinfect2_hpv52_anal[sex_exposed$HPV52_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV52_ANAL==1]!=2 & sex_exposed$exposure_hpv52_anal[sex_exposed$HPV52_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV52_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv52_anal_ego]==0 & probinfect2_hpv52_anal[sex_exposed$HPV52_ANAL==1] <= 0.071, 1, 0))))))
        sex_exposed$partinfection_hpv52_anal[sex_exposed$HPV52_ANAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV52_ANAL==1]!=2 & sex_exposed$exposure_hpv52_anal[sex_exposed$HPV52_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV52_ANAL==1]==1 & probinfect1_hpv52_anal[sex_exposed$HPV52_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV52_ANAL==1]!=2 & sex_exposed$exposure_hpv52_anal[sex_exposed$HPV52_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV52_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv52_anal_partner]==1 & probinfect1_hpv52_anal[sex_exposed$HPV52_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV52_ANAL==1]!=2 & sex_exposed$exposure_hpv52_anal[sex_exposed$HPV52_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV52_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv52_anal_partner]==0 & probinfect1_hpv52_anal[sex_exposed$HPV52_ANAL==1] <= 0.071, 1, ifelse(sex_exposed$sex[sex_exposed$HPV52_ANAL==1]!=2 & sex_exposed$exposure_hpv52_anal[sex_exposed$HPV52_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV52_ANAL==1]==3 & probinfect1_hpv52_anal[sex_exposed$HPV52_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV52_ANAL==1]!=2 & sex_exposed$exposure_hpv52_anal[sex_exposed$HPV52_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV52_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv52_anal_partner]==1 & probinfect2_hpv52_anal[sex_exposed$HPV52_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV52_ANAL==1]!=2 & sex_exposed$exposure_hpv52_anal[sex_exposed$HPV52_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV52_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv52_anal_partner]==0 & probinfect2_hpv52_anal[sex_exposed$HPV52_ANAL==1] <= 0.071, 1, 0))))))
        sex_exposed$infection_hpv58_anal[sex_exposed$HPV58_ANAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV58_ANAL==1]!=2 & sex_exposed$exposure_hpv58_anal[sex_exposed$HPV58_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV58_ANAL==1]==1 & probinfect1_hpv58_anal[sex_exposed$HPV58_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV58_ANAL==1]!=2 & sex_exposed$exposure_hpv58_anal[sex_exposed$HPV58_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV58_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv58_anal_ego]==1 & probinfect1_hpv58_anal[sex_exposed$HPV58_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV58_ANAL==1]!=2 & sex_exposed$exposure_hpv58_anal[sex_exposed$HPV58_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV58_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv58_anal_ego]==0 & probinfect1_hpv58_anal[sex_exposed$HPV58_ANAL==1] <= 0.071, 1, ifelse(sex_exposed$sex[sex_exposed$HPV58_ANAL==1]!=2 & sex_exposed$exposure_hpv58_anal[sex_exposed$HPV58_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV58_ANAL==1]==3 & probinfect1_hpv58_anal[sex_exposed$HPV58_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV58_ANAL==1]!=2 & sex_exposed$exposure_hpv58_anal[sex_exposed$HPV58_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV58_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv58_anal_ego]==1 & probinfect2_hpv58_anal[sex_exposed$HPV58_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV58_ANAL==1]!=2 & sex_exposed$exposure_hpv58_anal[sex_exposed$HPV58_ANAL==1]==1 & sex_exposed$simAI[sex_exposed$HPV58_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv58_anal_ego]==0 & probinfect2_hpv58_anal[sex_exposed$HPV58_ANAL==1] <= 0.071, 1, 0))))))
        sex_exposed$partinfection_hpv58_anal[sex_exposed$HPV58_ANAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV58_ANAL==1]!=2 & sex_exposed$exposure_hpv58_anal[sex_exposed$HPV58_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV58_ANAL==1]==1 & probinfect1_hpv58_anal[sex_exposed$HPV58_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV58_ANAL==1]!=2 & sex_exposed$exposure_hpv58_anal[sex_exposed$HPV58_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV58_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv58_anal_partner]==1 & probinfect1_hpv58_anal[sex_exposed$HPV58_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV58_ANAL==1]!=2 & sex_exposed$exposure_hpv58_anal[sex_exposed$HPV58_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV58_ANAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv58_anal_partner]==0 & probinfect1_hpv58_anal[sex_exposed$HPV58_ANAL==1] <= 0.071, 1, ifelse(sex_exposed$sex[sex_exposed$HPV58_ANAL==1]!=2 & sex_exposed$exposure_hpv58_anal[sex_exposed$HPV58_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV58_ANAL==1]==3 & probinfect1_hpv58_anal[sex_exposed$HPV58_ANAL==1] <= 0.546, 1, ifelse(sex_exposed$sex[sex_exposed$HPV58_ANAL==1]!=2 & sex_exposed$exposure_hpv58_anal[sex_exposed$HPV58_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV58_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv58_anal_partner]==1 & probinfect2_hpv58_anal[sex_exposed$HPV58_ANAL==1] <= 0.038, 1, ifelse(sex_exposed$sex[sex_exposed$HPV58_ANAL==1]!=2 & sex_exposed$exposure_hpv58_anal[sex_exposed$HPV58_ANAL==1]==2 & sex_exposed$simAI[sex_exposed$HPV58_ANAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv58_anal_partner]==0 & probinfect2_hpv58_anal[sex_exposed$HPV58_ANAL==1] <= 0.071, 1, 0))))))

        #hpv type specific oral, ego then partner, 1=new oral HPV infection, 2=new genital HPV infection, 3=new oral & genital HPV infection
        sex_exposed$infection_hpv6_oral[sex_exposed$HPV6_ORAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV6_ORAL==1]!=1 & sex_exposed$exposure_hpv6_oral[sex_exposed$HPV6_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV6_ORAL==1]==1 & probinfect1_hpv6_oral[sex_exposed$HPV6_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV6_ORAL==1]!=1 & sex_exposed$exposure_hpv6_oral[sex_exposed$HPV6_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV6_ORAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv6_oral_ego]==1 & probinfect1_hpv6_oral[sex_exposed$HPV6_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV6_ORAL==1]!=1 & sex_exposed$exposure_hpv6_oral[sex_exposed$HPV6_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV6_ORAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv6_oral_ego]==0 & probinfect1_hpv6_oral[sex_exposed$HPV6_ORAL==1] <= 0.014, 2, ifelse((sex_exposed$sex[sex_exposed$HPV6_ORAL==1]!=1 & sex_exposed$exposure_hpv6_oral[sex_exposed$HPV6_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV6_ORAL==1]==3 & probinfect1_hpv6_oral[sex_exposed$HPV6_ORAL==1] <= 0.032) & ((sex_exposed$sex[sex_exposed$HPV6_ORAL==1]!=1 & sex_exposed$exposure_hpv6_oral[sex_exposed$HPV6_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV6_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv6_oral_ego]==1 & probinfect2_hpv6_oral[sex_exposed$HPV6_ORAL==1] <= 0.008) | (sex_exposed$sex[sex_exposed$HPV6_ORAL==1]!=1 & sex_exposed$exposure_hpv6_oral[sex_exposed$HPV6_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV6_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv6_oral_ego]==0 & probinfect2_hpv6_oral[sex_exposed$HPV6_ORAL==1] <= 0.014)), 3, ifelse(sex_exposed$sex[sex_exposed$HPV6_ORAL==1]!=1 & sex_exposed$exposure_hpv6_oral[sex_exposed$HPV6_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV6_ORAL==1]==3 & probinfect1_hpv6_oral[sex_exposed$HPV6_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV6_ORAL==1]!=1 & sex_exposed$exposure_hpv6_oral[sex_exposed$HPV6_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV6_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv6_oral_ego]==1 & probinfect2_hpv6_oral[sex_exposed$HPV6_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV6_ORAL==1]!=1 & sex_exposed$exposure_hpv6_oral[sex_exposed$HPV6_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV6_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv6_oral_ego]==0 & probinfect2_hpv6_oral[sex_exposed$HPV6_ORAL==1] <= 0.014, 2, 0)))))))
        sex_exposed$partinfection_hpv6_oral[sex_exposed$HPV6_ORAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV6_ORAL==1]!=1 & sex_exposed$exposure_hpv6_oral[sex_exposed$HPV6_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV6_ORAL==1]==2 & probinfect1_hpv6_oral[sex_exposed$HPV6_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV6_ORAL==1]!=1 & sex_exposed$exposure_hpv6_oral[sex_exposed$HPV6_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV6_ORAL==1]==1 & prep_sims[[current_data]]$CIRC[exposed_hpv6_oral_partner]==1 & probinfect1_hpv6_oral[sex_exposed$HPV6_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV6_ORAL==1]!=1 & sex_exposed$exposure_hpv6_oral[sex_exposed$HPV6_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV6_ORAL==1]==1 & prep_sims[[current_data]]$CIRC[exposed_hpv6_oral_partner]==0 & probinfect1_hpv6_oral[sex_exposed$HPV6_ORAL==1] <= 0.014, 2, ifelse((sex_exposed$sex[sex_exposed$HPV6_ORAL==1]!=1 & sex_exposed$exposure_hpv6_oral[sex_exposed$HPV6_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV6_ORAL==1]==3 & probinfect1_hpv6_oral[sex_exposed$HPV6_ORAL==1] <= 0.032) & ((sex_exposed$sex[sex_exposed$HPV6_ORAL==1]!=1 & sex_exposed$exposure_hpv6_oral[sex_exposed$HPV6_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV6_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv6_oral_partner]==1 & probinfect2_hpv6_oral[sex_exposed$HPV6_ORAL==1] <= 0.008) | (sex_exposed$sex[sex_exposed$HPV6_ORAL==1]!=1 & sex_exposed$exposure_hpv6_oral[sex_exposed$HPV6_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV6_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv6_oral_partner]==0 & probinfect2_hpv6_oral[sex_exposed$HPV6_ORAL==1] <= 0.014)), 3, ifelse(sex_exposed$sex[sex_exposed$HPV6_ORAL==1]!=1 & sex_exposed$exposure_hpv6_oral[sex_exposed$HPV6_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV6_ORAL==1]==3 & probinfect1_hpv6_oral[sex_exposed$HPV6_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV6_ORAL==1]!=1 & sex_exposed$exposure_hpv6_oral[sex_exposed$HPV6_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV6_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv6_oral_partner]==1 & probinfect2_hpv6_oral[sex_exposed$HPV6_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV6_ORAL==1]!=1 & sex_exposed$exposure_hpv6_oral[sex_exposed$HPV6_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV6_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv6_oral_partner]==0 & probinfect2_hpv6_oral[sex_exposed$HPV6_ORAL==1] <= 0.014, 2, 0)))))))
        sex_exposed$infection_hpv11_oral[sex_exposed$HPV11_ORAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV11_ORAL==1]!=1 & sex_exposed$exposure_hpv11_oral[sex_exposed$HPV11_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV11_ORAL==1]==1 & probinfect1_hpv11_oral[sex_exposed$HPV11_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV11_ORAL==1]!=1 & sex_exposed$exposure_hpv11_oral[sex_exposed$HPV11_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV11_ORAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv11_oral_ego]==1 & probinfect1_hpv11_oral[sex_exposed$HPV11_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV11_ORAL==1]!=1 & sex_exposed$exposure_hpv11_oral[sex_exposed$HPV11_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV11_ORAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv11_oral_ego]==0 & probinfect1_hpv11_oral[sex_exposed$HPV11_ORAL==1] <= 0.014, 2, ifelse((sex_exposed$sex[sex_exposed$HPV11_ORAL==1]!=1 & sex_exposed$exposure_hpv11_oral[sex_exposed$HPV11_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV11_ORAL==1]==3 & probinfect1_hpv11_oral[sex_exposed$HPV11_ORAL==1] <= 0.032) & ((sex_exposed$sex[sex_exposed$HPV11_ORAL==1]!=1 & sex_exposed$exposure_hpv11_oral[sex_exposed$HPV11_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV11_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv11_oral_ego]==1 & probinfect2_hpv11_oral[sex_exposed$HPV11_ORAL==1] <= 0.008) | (sex_exposed$sex[sex_exposed$HPV11_ORAL==1]!=1 & sex_exposed$exposure_hpv11_oral[sex_exposed$HPV11_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV11_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv11_oral_ego]==0 & probinfect2_hpv11_oral[sex_exposed$HPV11_ORAL==1] <= 0.014)), 3, ifelse(sex_exposed$sex[sex_exposed$HPV11_ORAL==1]!=1 & sex_exposed$exposure_hpv11_oral[sex_exposed$HPV11_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV11_ORAL==1]==3 & probinfect1_hpv11_oral[sex_exposed$HPV11_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV11_ORAL==1]!=1 & sex_exposed$exposure_hpv11_oral[sex_exposed$HPV11_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV11_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv11_oral_ego]==1 & probinfect2_hpv11_oral[sex_exposed$HPV11_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV11_ORAL==1]!=1 & sex_exposed$exposure_hpv11_oral[sex_exposed$HPV11_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV11_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv11_oral_ego]==0 & probinfect2_hpv11_oral[sex_exposed$HPV11_ORAL==1] <= 0.014, 2, 0)))))))
        sex_exposed$partinfection_hpv11_oral[sex_exposed$HPV11_ORAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV11_ORAL==1]!=1 & sex_exposed$exposure_hpv11_oral[sex_exposed$HPV11_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV11_ORAL==1]==2 & probinfect1_hpv11_oral[sex_exposed$HPV11_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV11_ORAL==1]!=1 & sex_exposed$exposure_hpv11_oral[sex_exposed$HPV11_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV11_ORAL==1]==1 & prep_sims[[current_data]]$CIRC[exposed_hpv11_oral_partner]==1 & probinfect1_hpv11_oral[sex_exposed$HPV11_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV11_ORAL==1]!=1 & sex_exposed$exposure_hpv11_oral[sex_exposed$HPV11_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV11_ORAL==1]==1 & prep_sims[[current_data]]$CIRC[exposed_hpv11_oral_partner]==0 & probinfect1_hpv11_oral[sex_exposed$HPV11_ORAL==1] <= 0.014, 2, ifelse((sex_exposed$sex[sex_exposed$HPV11_ORAL==1]!=1 & sex_exposed$exposure_hpv11_oral[sex_exposed$HPV11_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV11_ORAL==1]==3 & probinfect1_hpv11_oral[sex_exposed$HPV11_ORAL==1] <= 0.032) & ((sex_exposed$sex[sex_exposed$HPV11_ORAL==1]!=1 & sex_exposed$exposure_hpv11_oral[sex_exposed$HPV11_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV11_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv11_oral_partner]==1 & probinfect2_hpv11_oral[sex_exposed$HPV11_ORAL==1] <= 0.008) | (sex_exposed$sex[sex_exposed$HPV11_ORAL==1]!=1 & sex_exposed$exposure_hpv11_oral[sex_exposed$HPV11_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV11_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv11_oral_partner]==0 & probinfect2_hpv11_oral[sex_exposed$HPV11_ORAL==1] <= 0.014)), 3, ifelse(sex_exposed$sex[sex_exposed$HPV11_ORAL==1]!=1 & sex_exposed$exposure_hpv11_oral[sex_exposed$HPV11_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV11_ORAL==1]==3 & probinfect1_hpv11_oral[sex_exposed$HPV11_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV11_ORAL==1]!=1 & sex_exposed$exposure_hpv11_oral[sex_exposed$HPV11_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV11_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv11_oral_partner]==1 & probinfect2_hpv11_oral[sex_exposed$HPV11_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV11_ORAL==1]!=1 & sex_exposed$exposure_hpv11_oral[sex_exposed$HPV11_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV11_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv11_oral_partner]==0 & probinfect2_hpv11_oral[sex_exposed$HPV11_ORAL==1] <= 0.014, 2, 0)))))))
        sex_exposed$infection_hpv16_oral[sex_exposed$HPV16_ORAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV16_ORAL==1]!=1 & sex_exposed$exposure_hpv16_oral[sex_exposed$HPV16_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV16_ORAL==1]==1 & probinfect1_hpv16_oral[sex_exposed$HPV16_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV16_ORAL==1]!=1 & sex_exposed$exposure_hpv16_oral[sex_exposed$HPV16_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV16_ORAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv16_oral_ego]==1 & probinfect1_hpv16_oral[sex_exposed$HPV16_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV16_ORAL==1]!=1 & sex_exposed$exposure_hpv16_oral[sex_exposed$HPV16_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV16_ORAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv16_oral_ego]==0 & probinfect1_hpv16_oral[sex_exposed$HPV16_ORAL==1] <= 0.014, 2, ifelse((sex_exposed$sex[sex_exposed$HPV16_ORAL==1]!=1 & sex_exposed$exposure_hpv16_oral[sex_exposed$HPV16_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV16_ORAL==1]==3 & probinfect1_hpv16_oral[sex_exposed$HPV16_ORAL==1] <= 0.032) & ((sex_exposed$sex[sex_exposed$HPV16_ORAL==1]!=1 & sex_exposed$exposure_hpv16_oral[sex_exposed$HPV16_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV16_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv16_oral_ego]==1 & probinfect2_hpv16_oral[sex_exposed$HPV16_ORAL==1] <= 0.008) | (sex_exposed$sex[sex_exposed$HPV16_ORAL==1]!=1 & sex_exposed$exposure_hpv16_oral[sex_exposed$HPV16_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV16_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv16_oral_ego]==0 & probinfect2_hpv16_oral[sex_exposed$HPV16_ORAL==1] <= 0.014)), 3, ifelse(sex_exposed$sex[sex_exposed$HPV16_ORAL==1]!=1 & sex_exposed$exposure_hpv16_oral[sex_exposed$HPV16_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV16_ORAL==1]==3 & probinfect1_hpv16_oral[sex_exposed$HPV16_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV16_ORAL==1]!=1 & sex_exposed$exposure_hpv16_oral[sex_exposed$HPV16_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV16_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv16_oral_ego]==1 & probinfect2_hpv16_oral[sex_exposed$HPV16_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV16_ORAL==1]!=1 & sex_exposed$exposure_hpv16_oral[sex_exposed$HPV16_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV16_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv16_oral_ego]==0 & probinfect2_hpv16_oral[sex_exposed$HPV16_ORAL==1] <= 0.014, 2, 0)))))))
        sex_exposed$partinfection_hpv16_oral[sex_exposed$HPV16_ORAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV16_ORAL==1]!=1 & sex_exposed$exposure_hpv16_oral[sex_exposed$HPV16_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV16_ORAL==1]==2 & probinfect1_hpv16_oral[sex_exposed$HPV16_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV16_ORAL==1]!=1 & sex_exposed$exposure_hpv16_oral[sex_exposed$HPV16_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV16_ORAL==1]==1 & prep_sims[[current_data]]$CIRC[exposed_hpv16_oral_partner]==1 & probinfect1_hpv16_oral[sex_exposed$HPV16_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV16_ORAL==1]!=1 & sex_exposed$exposure_hpv16_oral[sex_exposed$HPV16_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV16_ORAL==1]==1 & prep_sims[[current_data]]$CIRC[exposed_hpv16_oral_partner]==0 & probinfect1_hpv16_oral[sex_exposed$HPV16_ORAL==1] <= 0.014, 2, ifelse((sex_exposed$sex[sex_exposed$HPV16_ORAL==1]!=1 & sex_exposed$exposure_hpv16_oral[sex_exposed$HPV16_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV16_ORAL==1]==3 & probinfect1_hpv16_oral[sex_exposed$HPV16_ORAL==1] <= 0.032) & ((sex_exposed$sex[sex_exposed$HPV16_ORAL==1]!=1 & sex_exposed$exposure_hpv16_oral[sex_exposed$HPV16_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV16_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv16_oral_partner]==1 & probinfect2_hpv16_oral[sex_exposed$HPV16_ORAL==1] <= 0.008) | (sex_exposed$sex[sex_exposed$HPV16_ORAL==1]!=1 & sex_exposed$exposure_hpv16_oral[sex_exposed$HPV16_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV16_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv16_oral_partner]==0 & probinfect2_hpv16_oral[sex_exposed$HPV16_ORAL==1] <= 0.014)), 3, ifelse(sex_exposed$sex[sex_exposed$HPV16_ORAL==1]!=1 & sex_exposed$exposure_hpv16_oral[sex_exposed$HPV16_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV16_ORAL==1]==3 & probinfect1_hpv16_oral[sex_exposed$HPV16_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV16_ORAL==1]!=1 & sex_exposed$exposure_hpv16_oral[sex_exposed$HPV16_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV16_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv16_oral_partner]==1 & probinfect2_hpv16_oral[sex_exposed$HPV16_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV16_ORAL==1]!=1 & sex_exposed$exposure_hpv16_oral[sex_exposed$HPV16_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV16_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv16_oral_partner]==0 & probinfect2_hpv16_oral[sex_exposed$HPV16_ORAL==1] <= 0.014, 2, 0)))))))
        sex_exposed$infection_hpv18_oral[sex_exposed$HPV18_ORAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV18_ORAL==1]!=1 & sex_exposed$exposure_hpv18_oral[sex_exposed$HPV18_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV18_ORAL==1]==1 & probinfect1_hpv18_oral[sex_exposed$HPV18_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV18_ORAL==1]!=1 & sex_exposed$exposure_hpv18_oral[sex_exposed$HPV18_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV18_ORAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv18_oral_ego]==1 & probinfect1_hpv18_oral[sex_exposed$HPV18_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV18_ORAL==1]!=1 & sex_exposed$exposure_hpv18_oral[sex_exposed$HPV18_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV18_ORAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv18_oral_ego]==0 & probinfect1_hpv18_oral[sex_exposed$HPV18_ORAL==1] <= 0.014, 2, ifelse((sex_exposed$sex[sex_exposed$HPV18_ORAL==1]!=1 & sex_exposed$exposure_hpv18_oral[sex_exposed$HPV18_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV18_ORAL==1]==3 & probinfect1_hpv18_oral[sex_exposed$HPV18_ORAL==1] <= 0.032) & ((sex_exposed$sex[sex_exposed$HPV18_ORAL==1]!=1 & sex_exposed$exposure_hpv18_oral[sex_exposed$HPV18_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV18_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv18_oral_ego]==1 & probinfect2_hpv18_oral[sex_exposed$HPV18_ORAL==1] <= 0.008) | (sex_exposed$sex[sex_exposed$HPV18_ORAL==1]!=1 & sex_exposed$exposure_hpv18_oral[sex_exposed$HPV18_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV18_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv18_oral_ego]==0 & probinfect2_hpv18_oral[sex_exposed$HPV18_ORAL==1] <= 0.014)), 3, ifelse(sex_exposed$sex[sex_exposed$HPV18_ORAL==1]!=1 & sex_exposed$exposure_hpv18_oral[sex_exposed$HPV18_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV18_ORAL==1]==3 & probinfect1_hpv18_oral[sex_exposed$HPV18_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV18_ORAL==1]!=1 & sex_exposed$exposure_hpv18_oral[sex_exposed$HPV18_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV18_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv18_oral_ego]==1 & probinfect2_hpv18_oral[sex_exposed$HPV18_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV18_ORAL==1]!=1 & sex_exposed$exposure_hpv18_oral[sex_exposed$HPV18_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV18_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv18_oral_ego]==0 & probinfect2_hpv18_oral[sex_exposed$HPV18_ORAL==1] <= 0.014, 2, 0)))))))
        sex_exposed$partinfection_hpv18_oral[sex_exposed$HPV18_ORAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV18_ORAL==1]!=1 & sex_exposed$exposure_hpv18_oral[sex_exposed$HPV18_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV18_ORAL==1]==2 & probinfect1_hpv18_oral[sex_exposed$HPV18_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV18_ORAL==1]!=1 & sex_exposed$exposure_hpv18_oral[sex_exposed$HPV18_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV18_ORAL==1]==1 & prep_sims[[current_data]]$CIRC[exposed_hpv18_oral_partner]==1 & probinfect1_hpv18_oral[sex_exposed$HPV18_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV18_ORAL==1]!=1 & sex_exposed$exposure_hpv18_oral[sex_exposed$HPV18_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV18_ORAL==1]==1 & prep_sims[[current_data]]$CIRC[exposed_hpv18_oral_partner]==0 & probinfect1_hpv18_oral[sex_exposed$HPV18_ORAL==1] <= 0.014, 2, ifelse((sex_exposed$sex[sex_exposed$HPV18_ORAL==1]!=1 & sex_exposed$exposure_hpv18_oral[sex_exposed$HPV18_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV18_ORAL==1]==3 & probinfect1_hpv18_oral[sex_exposed$HPV18_ORAL==1] <= 0.032) & ((sex_exposed$sex[sex_exposed$HPV18_ORAL==1]!=1 & sex_exposed$exposure_hpv18_oral[sex_exposed$HPV18_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV18_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv18_oral_partner]==1 & probinfect2_hpv18_oral[sex_exposed$HPV18_ORAL==1] <= 0.008) | (sex_exposed$sex[sex_exposed$HPV18_ORAL==1]!=1 & sex_exposed$exposure_hpv18_oral[sex_exposed$HPV18_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV18_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv18_oral_partner]==0 & probinfect2_hpv18_oral[sex_exposed$HPV18_ORAL==1] <= 0.014)), 3, ifelse(sex_exposed$sex[sex_exposed$HPV18_ORAL==1]!=1 & sex_exposed$exposure_hpv18_oral[sex_exposed$HPV18_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV18_ORAL==1]==3 & probinfect1_hpv18_oral[sex_exposed$HPV18_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV18_ORAL==1]!=1 & sex_exposed$exposure_hpv18_oral[sex_exposed$HPV18_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV18_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv18_oral_partner]==1 & probinfect2_hpv18_oral[sex_exposed$HPV18_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV18_ORAL==1]!=1 & sex_exposed$exposure_hpv18_oral[sex_exposed$HPV18_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV18_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv18_oral_partner]==0 & probinfect2_hpv18_oral[sex_exposed$HPV18_ORAL==1] <= 0.014, 2, 0)))))))
        sex_exposed$infection_hpv31_oral[sex_exposed$HPV31_ORAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV31_ORAL==1]!=1 & sex_exposed$exposure_hpv31_oral[sex_exposed$HPV31_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV31_ORAL==1]==1 & probinfect1_hpv31_oral[sex_exposed$HPV31_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV31_ORAL==1]!=1 & sex_exposed$exposure_hpv31_oral[sex_exposed$HPV31_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV31_ORAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv31_oral_ego]==1 & probinfect1_hpv31_oral[sex_exposed$HPV31_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV31_ORAL==1]!=1 & sex_exposed$exposure_hpv31_oral[sex_exposed$HPV31_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV31_ORAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv31_oral_ego]==0 & probinfect1_hpv31_oral[sex_exposed$HPV31_ORAL==1] <= 0.014, 2, ifelse((sex_exposed$sex[sex_exposed$HPV31_ORAL==1]!=1 & sex_exposed$exposure_hpv31_oral[sex_exposed$HPV31_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV31_ORAL==1]==3 & probinfect1_hpv31_oral[sex_exposed$HPV31_ORAL==1] <= 0.032) & ((sex_exposed$sex[sex_exposed$HPV31_ORAL==1]!=1 & sex_exposed$exposure_hpv31_oral[sex_exposed$HPV31_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV31_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv31_oral_ego]==1 & probinfect2_hpv31_oral[sex_exposed$HPV31_ORAL==1] <= 0.008) | (sex_exposed$sex[sex_exposed$HPV31_ORAL==1]!=1 & sex_exposed$exposure_hpv31_oral[sex_exposed$HPV31_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV31_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv31_oral_ego]==0 & probinfect2_hpv31_oral[sex_exposed$HPV31_ORAL==1] <= 0.014)), 3, ifelse(sex_exposed$sex[sex_exposed$HPV31_ORAL==1]!=1 & sex_exposed$exposure_hpv31_oral[sex_exposed$HPV31_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV31_ORAL==1]==3 & probinfect1_hpv31_oral[sex_exposed$HPV31_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV31_ORAL==1]!=1 & sex_exposed$exposure_hpv31_oral[sex_exposed$HPV31_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV31_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv31_oral_ego]==1 & probinfect2_hpv31_oral[sex_exposed$HPV31_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV31_ORAL==1]!=1 & sex_exposed$exposure_hpv31_oral[sex_exposed$HPV31_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV31_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv31_oral_ego]==0 & probinfect2_hpv31_oral[sex_exposed$HPV31_ORAL==1] <= 0.014, 2, 0)))))))
        sex_exposed$partinfection_hpv31_oral[sex_exposed$HPV31_ORAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV31_ORAL==1]!=1 & sex_exposed$exposure_hpv31_oral[sex_exposed$HPV31_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV31_ORAL==1]==2 & probinfect1_hpv31_oral[sex_exposed$HPV31_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV31_ORAL==1]!=1 & sex_exposed$exposure_hpv31_oral[sex_exposed$HPV31_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV31_ORAL==1]==1 & prep_sims[[current_data]]$CIRC[exposed_hpv31_oral_partner]==1 & probinfect1_hpv31_oral[sex_exposed$HPV31_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV31_ORAL==1]!=1 & sex_exposed$exposure_hpv31_oral[sex_exposed$HPV31_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV31_ORAL==1]==1 & prep_sims[[current_data]]$CIRC[exposed_hpv31_oral_partner]==0 & probinfect1_hpv31_oral[sex_exposed$HPV31_ORAL==1] <= 0.014, 2, ifelse((sex_exposed$sex[sex_exposed$HPV31_ORAL==1]!=1 & sex_exposed$exposure_hpv31_oral[sex_exposed$HPV31_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV31_ORAL==1]==3 & probinfect1_hpv31_oral[sex_exposed$HPV31_ORAL==1] <= 0.032) & ((sex_exposed$sex[sex_exposed$HPV31_ORAL==1]!=1 & sex_exposed$exposure_hpv31_oral[sex_exposed$HPV31_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV31_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv31_oral_partner]==1 & probinfect2_hpv31_oral[sex_exposed$HPV31_ORAL==1] <= 0.008) | (sex_exposed$sex[sex_exposed$HPV31_ORAL==1]!=1 & sex_exposed$exposure_hpv31_oral[sex_exposed$HPV31_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV31_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv31_oral_partner]==0 & probinfect2_hpv31_oral[sex_exposed$HPV31_ORAL==1] <= 0.014)), 3, ifelse(sex_exposed$sex[sex_exposed$HPV31_ORAL==1]!=1 & sex_exposed$exposure_hpv31_oral[sex_exposed$HPV31_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV31_ORAL==1]==3 & probinfect1_hpv31_oral[sex_exposed$HPV31_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV31_ORAL==1]!=1 & sex_exposed$exposure_hpv31_oral[sex_exposed$HPV31_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV31_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv31_oral_partner]==1 & probinfect2_hpv31_oral[sex_exposed$HPV31_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV31_ORAL==1]!=1 & sex_exposed$exposure_hpv31_oral[sex_exposed$HPV31_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV31_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv31_oral_partner]==0 & probinfect2_hpv31_oral[sex_exposed$HPV31_ORAL==1] <= 0.014, 2, 0)))))))
        sex_exposed$infection_hpv33_oral[sex_exposed$HPV33_ORAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV33_ORAL==1]!=1 & sex_exposed$exposure_hpv33_oral[sex_exposed$HPV33_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV33_ORAL==1]==1 & probinfect1_hpv33_oral[sex_exposed$HPV33_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV33_ORAL==1]!=1 & sex_exposed$exposure_hpv33_oral[sex_exposed$HPV33_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV33_ORAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv33_oral_ego]==1 & probinfect1_hpv33_oral[sex_exposed$HPV33_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV33_ORAL==1]!=1 & sex_exposed$exposure_hpv33_oral[sex_exposed$HPV33_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV33_ORAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv33_oral_ego]==0 & probinfect1_hpv33_oral[sex_exposed$HPV33_ORAL==1] <= 0.014, 2, ifelse((sex_exposed$sex[sex_exposed$HPV33_ORAL==1]!=1 & sex_exposed$exposure_hpv33_oral[sex_exposed$HPV33_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV33_ORAL==1]==3 & probinfect1_hpv33_oral[sex_exposed$HPV33_ORAL==1] <= 0.032) & ((sex_exposed$sex[sex_exposed$HPV33_ORAL==1]!=1 & sex_exposed$exposure_hpv33_oral[sex_exposed$HPV33_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV33_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv33_oral_ego]==1 & probinfect2_hpv33_oral[sex_exposed$HPV33_ORAL==1] <= 0.008) | (sex_exposed$sex[sex_exposed$HPV33_ORAL==1]!=1 & sex_exposed$exposure_hpv33_oral[sex_exposed$HPV33_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV33_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv33_oral_ego]==0 & probinfect2_hpv33_oral[sex_exposed$HPV33_ORAL==1] <= 0.014)), 3, ifelse(sex_exposed$sex[sex_exposed$HPV33_ORAL==1]!=1 & sex_exposed$exposure_hpv33_oral[sex_exposed$HPV33_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV33_ORAL==1]==3 & probinfect1_hpv33_oral[sex_exposed$HPV33_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV33_ORAL==1]!=1 & sex_exposed$exposure_hpv33_oral[sex_exposed$HPV33_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV33_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv33_oral_ego]==1 & probinfect2_hpv33_oral[sex_exposed$HPV33_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV33_ORAL==1]!=1 & sex_exposed$exposure_hpv33_oral[sex_exposed$HPV33_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV33_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv33_oral_ego]==0 & probinfect2_hpv33_oral[sex_exposed$HPV33_ORAL==1] <= 0.014, 2, 0)))))))
        sex_exposed$partinfection_hpv33_oral[sex_exposed$HPV33_ORAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV33_ORAL==1]!=1 & sex_exposed$exposure_hpv33_oral[sex_exposed$HPV33_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV33_ORAL==1]==2 & probinfect1_hpv33_oral[sex_exposed$HPV33_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV33_ORAL==1]!=1 & sex_exposed$exposure_hpv33_oral[sex_exposed$HPV33_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV33_ORAL==1]==1 & prep_sims[[current_data]]$CIRC[exposed_hpv33_oral_partner]==1 & probinfect1_hpv33_oral[sex_exposed$HPV33_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV33_ORAL==1]!=1 & sex_exposed$exposure_hpv33_oral[sex_exposed$HPV33_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV33_ORAL==1]==1 & prep_sims[[current_data]]$CIRC[exposed_hpv33_oral_partner]==0 & probinfect1_hpv33_oral[sex_exposed$HPV33_ORAL==1] <= 0.014, 2, ifelse((sex_exposed$sex[sex_exposed$HPV33_ORAL==1]!=1 & sex_exposed$exposure_hpv33_oral[sex_exposed$HPV33_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV33_ORAL==1]==3 & probinfect1_hpv33_oral[sex_exposed$HPV33_ORAL==1] <= 0.032) & ((sex_exposed$sex[sex_exposed$HPV33_ORAL==1]!=1 & sex_exposed$exposure_hpv33_oral[sex_exposed$HPV33_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV33_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv33_oral_partner]==1 & probinfect2_hpv33_oral[sex_exposed$HPV33_ORAL==1] <= 0.008) | (sex_exposed$sex[sex_exposed$HPV33_ORAL==1]!=1 & sex_exposed$exposure_hpv33_oral[sex_exposed$HPV33_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV33_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv33_oral_partner]==0 & probinfect2_hpv33_oral[sex_exposed$HPV33_ORAL==1] <= 0.014)), 3, ifelse(sex_exposed$sex[sex_exposed$HPV33_ORAL==1]!=1 & sex_exposed$exposure_hpv33_oral[sex_exposed$HPV33_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV33_ORAL==1]==3 & probinfect1_hpv33_oral[sex_exposed$HPV33_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV33_ORAL==1]!=1 & sex_exposed$exposure_hpv33_oral[sex_exposed$HPV33_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV33_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv33_oral_partner]==1 & probinfect2_hpv33_oral[sex_exposed$HPV33_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV33_ORAL==1]!=1 & sex_exposed$exposure_hpv33_oral[sex_exposed$HPV33_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV33_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv33_oral_partner]==0 & probinfect2_hpv33_oral[sex_exposed$HPV33_ORAL==1] <= 0.014, 2, 0)))))))
        sex_exposed$infection_hpv45_oral[sex_exposed$HPV45_ORAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV45_ORAL==1]!=1 & sex_exposed$exposure_hpv45_oral[sex_exposed$HPV45_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV45_ORAL==1]==1 & probinfect1_hpv45_oral[sex_exposed$HPV45_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV45_ORAL==1]!=1 & sex_exposed$exposure_hpv45_oral[sex_exposed$HPV45_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV45_ORAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv45_oral_ego]==1 & probinfect1_hpv45_oral[sex_exposed$HPV45_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV45_ORAL==1]!=1 & sex_exposed$exposure_hpv45_oral[sex_exposed$HPV45_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV45_ORAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv45_oral_ego]==0 & probinfect1_hpv45_oral[sex_exposed$HPV45_ORAL==1] <= 0.014, 2, ifelse((sex_exposed$sex[sex_exposed$HPV45_ORAL==1]!=1 & sex_exposed$exposure_hpv45_oral[sex_exposed$HPV45_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV45_ORAL==1]==3 & probinfect1_hpv45_oral[sex_exposed$HPV45_ORAL==1] <= 0.032) & ((sex_exposed$sex[sex_exposed$HPV45_ORAL==1]!=1 & sex_exposed$exposure_hpv45_oral[sex_exposed$HPV45_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV45_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv45_oral_ego]==1 & probinfect2_hpv45_oral[sex_exposed$HPV45_ORAL==1] <= 0.008) | (sex_exposed$sex[sex_exposed$HPV45_ORAL==1]!=1 & sex_exposed$exposure_hpv45_oral[sex_exposed$HPV45_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV45_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv45_oral_ego]==0 & probinfect2_hpv45_oral[sex_exposed$HPV45_ORAL==1] <= 0.014)), 3, ifelse(sex_exposed$sex[sex_exposed$HPV45_ORAL==1]!=1 & sex_exposed$exposure_hpv45_oral[sex_exposed$HPV45_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV45_ORAL==1]==3 & probinfect1_hpv45_oral[sex_exposed$HPV45_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV45_ORAL==1]!=1 & sex_exposed$exposure_hpv45_oral[sex_exposed$HPV45_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV45_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv45_oral_ego]==1 & probinfect2_hpv45_oral[sex_exposed$HPV45_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV45_ORAL==1]!=1 & sex_exposed$exposure_hpv45_oral[sex_exposed$HPV45_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV45_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv45_oral_ego]==0 & probinfect2_hpv45_oral[sex_exposed$HPV45_ORAL==1] <= 0.014, 2, 0)))))))
        sex_exposed$partinfection_hpv45_oral[sex_exposed$HPV45_ORAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV45_ORAL==1]!=1 & sex_exposed$exposure_hpv45_oral[sex_exposed$HPV45_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV45_ORAL==1]==2 & probinfect1_hpv45_oral[sex_exposed$HPV45_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV45_ORAL==1]!=1 & sex_exposed$exposure_hpv45_oral[sex_exposed$HPV45_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV45_ORAL==1]==1 & prep_sims[[current_data]]$CIRC[exposed_hpv45_oral_partner]==1 & probinfect1_hpv45_oral[sex_exposed$HPV45_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV45_ORAL==1]!=1 & sex_exposed$exposure_hpv45_oral[sex_exposed$HPV45_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV45_ORAL==1]==1 & prep_sims[[current_data]]$CIRC[exposed_hpv45_oral_partner]==0 & probinfect1_hpv45_oral[sex_exposed$HPV45_ORAL==1] <= 0.014, 2, ifelse((sex_exposed$sex[sex_exposed$HPV45_ORAL==1]!=1 & sex_exposed$exposure_hpv45_oral[sex_exposed$HPV45_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV45_ORAL==1]==3 & probinfect1_hpv45_oral[sex_exposed$HPV45_ORAL==1] <= 0.032) & ((sex_exposed$sex[sex_exposed$HPV45_ORAL==1]!=1 & sex_exposed$exposure_hpv45_oral[sex_exposed$HPV45_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV45_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv45_oral_partner]==1 & probinfect2_hpv45_oral[sex_exposed$HPV45_ORAL==1] <= 0.008) | (sex_exposed$sex[sex_exposed$HPV45_ORAL==1]!=1 & sex_exposed$exposure_hpv45_oral[sex_exposed$HPV45_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV45_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv45_oral_partner]==0 & probinfect2_hpv45_oral[sex_exposed$HPV45_ORAL==1] <= 0.014)), 3, ifelse(sex_exposed$sex[sex_exposed$HPV45_ORAL==1]!=1 & sex_exposed$exposure_hpv45_oral[sex_exposed$HPV45_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV45_ORAL==1]==3 & probinfect1_hpv45_oral[sex_exposed$HPV45_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV45_ORAL==1]!=1 & sex_exposed$exposure_hpv45_oral[sex_exposed$HPV45_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV45_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv45_oral_partner]==1 & probinfect2_hpv45_oral[sex_exposed$HPV45_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV45_ORAL==1]!=1 & sex_exposed$exposure_hpv45_oral[sex_exposed$HPV45_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV45_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv45_oral_partner]==0 & probinfect2_hpv45_oral[sex_exposed$HPV45_ORAL==1] <= 0.014, 2, 0)))))))
        sex_exposed$infection_hpv52_oral[sex_exposed$HPV52_ORAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV52_ORAL==1]!=1 & sex_exposed$exposure_hpv52_oral[sex_exposed$HPV52_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV52_ORAL==1]==1 & probinfect1_hpv52_oral[sex_exposed$HPV52_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV52_ORAL==1]!=1 & sex_exposed$exposure_hpv52_oral[sex_exposed$HPV52_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV52_ORAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv52_oral_ego]==1 & probinfect1_hpv52_oral[sex_exposed$HPV52_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV52_ORAL==1]!=1 & sex_exposed$exposure_hpv52_oral[sex_exposed$HPV52_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV52_ORAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv52_oral_ego]==0 & probinfect1_hpv52_oral[sex_exposed$HPV52_ORAL==1] <= 0.014, 2, ifelse((sex_exposed$sex[sex_exposed$HPV52_ORAL==1]!=1 & sex_exposed$exposure_hpv52_oral[sex_exposed$HPV52_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV52_ORAL==1]==3 & probinfect1_hpv52_oral[sex_exposed$HPV52_ORAL==1] <= 0.032) & ((sex_exposed$sex[sex_exposed$HPV52_ORAL==1]!=1 & sex_exposed$exposure_hpv52_oral[sex_exposed$HPV52_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV52_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv52_oral_ego]==1 & probinfect2_hpv52_oral[sex_exposed$HPV52_ORAL==1] <= 0.008) | (sex_exposed$sex[sex_exposed$HPV52_ORAL==1]!=1 & sex_exposed$exposure_hpv52_oral[sex_exposed$HPV52_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV52_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv52_oral_ego]==0 & probinfect2_hpv52_oral[sex_exposed$HPV52_ORAL==1] <= 0.014)), 3, ifelse(sex_exposed$sex[sex_exposed$HPV52_ORAL==1]!=1 & sex_exposed$exposure_hpv52_oral[sex_exposed$HPV52_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV52_ORAL==1]==3 & probinfect1_hpv52_oral[sex_exposed$HPV52_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV52_ORAL==1]!=1 & sex_exposed$exposure_hpv52_oral[sex_exposed$HPV52_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV52_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv52_oral_ego]==1 & probinfect2_hpv52_oral[sex_exposed$HPV52_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV52_ORAL==1]!=1 & sex_exposed$exposure_hpv52_oral[sex_exposed$HPV52_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV52_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv52_oral_ego]==0 & probinfect2_hpv52_oral[sex_exposed$HPV52_ORAL==1] <= 0.014, 2, 0)))))))
        sex_exposed$partinfection_hpv52_oral[sex_exposed$HPV52_ORAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV52_ORAL==1]!=1 & sex_exposed$exposure_hpv52_oral[sex_exposed$HPV52_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV52_ORAL==1]==2 & probinfect1_hpv52_oral[sex_exposed$HPV52_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV52_ORAL==1]!=1 & sex_exposed$exposure_hpv52_oral[sex_exposed$HPV52_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV52_ORAL==1]==1 & prep_sims[[current_data]]$CIRC[exposed_hpv52_oral_partner]==1 & probinfect1_hpv52_oral[sex_exposed$HPV52_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV52_ORAL==1]!=1 & sex_exposed$exposure_hpv52_oral[sex_exposed$HPV52_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV52_ORAL==1]==1 & prep_sims[[current_data]]$CIRC[exposed_hpv52_oral_partner]==0 & probinfect1_hpv52_oral[sex_exposed$HPV52_ORAL==1] <= 0.014, 2, ifelse((sex_exposed$sex[sex_exposed$HPV52_ORAL==1]!=1 & sex_exposed$exposure_hpv52_oral[sex_exposed$HPV52_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV52_ORAL==1]==3 & probinfect1_hpv52_oral[sex_exposed$HPV52_ORAL==1] <= 0.032) & ((sex_exposed$sex[sex_exposed$HPV52_ORAL==1]!=1 & sex_exposed$exposure_hpv52_oral[sex_exposed$HPV52_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV52_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv52_oral_partner]==1 & probinfect2_hpv52_oral[sex_exposed$HPV52_ORAL==1] <= 0.008) | (sex_exposed$sex[sex_exposed$HPV52_ORAL==1]!=1 & sex_exposed$exposure_hpv52_oral[sex_exposed$HPV52_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV52_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv52_oral_partner]==0 & probinfect2_hpv52_oral[sex_exposed$HPV52_ORAL==1] <= 0.014)), 3, ifelse(sex_exposed$sex[sex_exposed$HPV52_ORAL==1]!=1 & sex_exposed$exposure_hpv52_oral[sex_exposed$HPV52_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV52_ORAL==1]==3 & probinfect1_hpv52_oral[sex_exposed$HPV52_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV52_ORAL==1]!=1 & sex_exposed$exposure_hpv52_oral[sex_exposed$HPV52_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV52_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv52_oral_partner]==1 & probinfect2_hpv52_oral[sex_exposed$HPV52_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV52_ORAL==1]!=1 & sex_exposed$exposure_hpv52_oral[sex_exposed$HPV52_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV52_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv52_oral_partner]==0 & probinfect2_hpv52_oral[sex_exposed$HPV52_ORAL==1] <= 0.014, 2, 0)))))))
        sex_exposed$infection_hpv58_oral[sex_exposed$HPV58_ORAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV58_ORAL==1]!=1 & sex_exposed$exposure_hpv58_oral[sex_exposed$HPV58_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV58_ORAL==1]==1 & probinfect1_hpv58_oral[sex_exposed$HPV58_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV58_ORAL==1]!=1 & sex_exposed$exposure_hpv58_oral[sex_exposed$HPV58_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV58_ORAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv58_oral_ego]==1 & probinfect1_hpv58_oral[sex_exposed$HPV58_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV58_ORAL==1]!=1 & sex_exposed$exposure_hpv58_oral[sex_exposed$HPV58_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV58_ORAL==1]==2 & prep_sims[[current_data]]$CIRC[exposed_hpv58_oral_ego]==0 & probinfect1_hpv58_oral[sex_exposed$HPV58_ORAL==1] <= 0.014, 2, ifelse((sex_exposed$sex[sex_exposed$HPV58_ORAL==1]!=1 & sex_exposed$exposure_hpv58_oral[sex_exposed$HPV58_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV58_ORAL==1]==3 & probinfect1_hpv58_oral[sex_exposed$HPV58_ORAL==1] <= 0.032) & ((sex_exposed$sex[sex_exposed$HPV58_ORAL==1]!=1 & sex_exposed$exposure_hpv58_oral[sex_exposed$HPV58_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV58_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv58_oral_ego]==1 & probinfect2_hpv58_oral[sex_exposed$HPV58_ORAL==1] <= 0.008) | (sex_exposed$sex[sex_exposed$HPV58_ORAL==1]!=1 & sex_exposed$exposure_hpv58_oral[sex_exposed$HPV58_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV58_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv58_oral_ego]==0 & probinfect2_hpv58_oral[sex_exposed$HPV58_ORAL==1] <= 0.014)), 3, ifelse(sex_exposed$sex[sex_exposed$HPV58_ORAL==1]!=1 & sex_exposed$exposure_hpv58_oral[sex_exposed$HPV58_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV58_ORAL==1]==3 & probinfect1_hpv58_oral[sex_exposed$HPV58_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV58_ORAL==1]!=1 & sex_exposed$exposure_hpv58_oral[sex_exposed$HPV58_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV58_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv58_oral_ego]==1 & probinfect2_hpv58_oral[sex_exposed$HPV58_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV58_ORAL==1]!=1 & sex_exposed$exposure_hpv58_oral[sex_exposed$HPV58_ORAL==1]!=2 & sex_exposed$simOI[sex_exposed$HPV58_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv58_oral_ego]==0 & probinfect2_hpv58_oral[sex_exposed$HPV58_ORAL==1] <= 0.014, 2, 0)))))))
        sex_exposed$partinfection_hpv58_oral[sex_exposed$HPV58_ORAL==1] = ifelse(sex_exposed$sex[sex_exposed$HPV58_ORAL==1]!=1 & sex_exposed$exposure_hpv58_oral[sex_exposed$HPV58_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV58_ORAL==1]==2 & probinfect1_hpv58_oral[sex_exposed$HPV58_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV58_ORAL==1]!=1 & sex_exposed$exposure_hpv58_oral[sex_exposed$HPV58_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV58_ORAL==1]==1 & prep_sims[[current_data]]$CIRC[exposed_hpv58_oral_partner]==1 & probinfect1_hpv58_oral[sex_exposed$HPV58_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV58_ORAL==1]!=1 & sex_exposed$exposure_hpv58_oral[sex_exposed$HPV58_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV58_ORAL==1]==1 & prep_sims[[current_data]]$CIRC[exposed_hpv58_oral_partner]==0 & probinfect1_hpv58_oral[sex_exposed$HPV58_ORAL==1] <= 0.014, 2, ifelse((sex_exposed$sex[sex_exposed$HPV58_ORAL==1]!=1 & sex_exposed$exposure_hpv58_oral[sex_exposed$HPV58_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV58_ORAL==1]==3 & probinfect1_hpv58_oral[sex_exposed$HPV58_ORAL==1] <= 0.032) & ((sex_exposed$sex[sex_exposed$HPV58_ORAL==1]!=1 & sex_exposed$exposure_hpv58_oral[sex_exposed$HPV58_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV58_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv58_oral_partner]==1 & probinfect2_hpv58_oral[sex_exposed$HPV58_ORAL==1] <= 0.008) | (sex_exposed$sex[sex_exposed$HPV58_ORAL==1]!=1 & sex_exposed$exposure_hpv58_oral[sex_exposed$HPV58_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV58_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv58_oral_partner]==0 & probinfect2_hpv58_oral[sex_exposed$HPV58_ORAL==1] <= 0.014)), 3, ifelse(sex_exposed$sex[sex_exposed$HPV58_ORAL==1]!=1 & sex_exposed$exposure_hpv58_oral[sex_exposed$HPV58_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV58_ORAL==1]==3 & probinfect1_hpv58_oral[sex_exposed$HPV58_ORAL==1] <= 0.032, 1, ifelse(sex_exposed$sex[sex_exposed$HPV58_ORAL==1]!=1 & sex_exposed$exposure_hpv58_oral[sex_exposed$HPV58_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV58_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv58_oral_partner]==1 & probinfect2_hpv58_oral[sex_exposed$HPV58_ORAL==1] <= 0.008, 2, ifelse(sex_exposed$sex[sex_exposed$HPV58_ORAL==1]!=1 & sex_exposed$exposure_hpv58_oral[sex_exposed$HPV58_ORAL==1]!=1 & sex_exposed$simOI[sex_exposed$HPV58_ORAL==1]==3 & prep_sims[[current_data]]$CIRC[exposed_hpv58_oral_partner]==0 & probinfect2_hpv58_oral[sex_exposed$HPV58_ORAL==1] <= 0.014, 2, 0)))))))
        
        #determine infection under seroadaption scenarios
        if (unique(prep_sims[[current_data]]$SERO)==1)
        {
          #check if avoiding sex: both insertive seroadapters, or serosorter (ego/partner) and partner is aware HIV+
          avoid = ifelse(sex_exposed$infection_hiv[sex_exposed$HIV==1]==1 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1, 1, ifelse(sex_exposed$infection_hiv[sex_exposed$HIV==1]==1 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==3 & prep_sims[[current_data]]$STATUS[exposed_hiv_partner]==3, 1, ifelse(sex_exposed$infection_hiv[sex_exposed$HIV==1]==1 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==3 & prep_sims[[current_data]]$STATUS[exposed_hiv_partner]==3, 1, 0)))
          partavoid = ifelse(sex_exposed$partinfection_hiv[sex_exposed$HIV==1]==1 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1, 1, ifelse(sex_exposed$partinfection_hiv[sex_exposed$HIV==1]==1 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==3 & prep_sims[[current_data]]$STATUS[exposed_hiv_ego]==3, 1, ifelse(sex_exposed$partinfection_hiv[sex_exposed$HIV==1]==1 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==3 & prep_sims[[current_data]]$STATUS[exposed_hiv_ego]==3, 1, 0)))
    
          #seroadaption strategies for HIV
          seroblock_hiv = ifelse(sex_exposed$infection_hiv[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & prep_sims[[current_data]]$VL[exposed_hiv_partner]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==1 & probinfect1_hiv[sex_exposed$HIV==1] > 0.0010, 1, ifelse(sex_exposed$infection_hiv[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & prep_sims[[current_data]]$VL[exposed_hiv_partner]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==2 & probinfect1_hiv[sex_exposed$HIV==1] > 0.0059, 1, ifelse(sex_exposed$infection_hiv[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & prep_sims[[current_data]]$VL[exposed_hiv_partner]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==1 & probinfect1_hiv[sex_exposed$HIV==1] > 0.0101, 1, ifelse(sex_exposed$infection_hiv[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & prep_sims[[current_data]]$VL[exposed_hiv_partner]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==2 & probinfect1_hiv[sex_exposed$HIV==1] > 0.0569, 1, ifelse(sex_exposed$infection_hiv[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==2 & prep_sims[[current_data]]$VL[exposed_hiv_partner]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==1 & probinfect1_hiv[sex_exposed$HIV==1] > 0.0010, 1, ifelse(sex_exposed$infection_hiv[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==2 & prep_sims[[current_data]]$VL[exposed_hiv_partner]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==2 & probinfect1_hiv[sex_exposed$HIV==1] > 0.0059, 1, ifelse(sex_exposed$infection_hiv[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==2 & prep_sims[[current_data]]$VL[exposed_hiv_partner]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==1 & probinfect1_hiv[sex_exposed$HIV==1] > 0.0101, 1, ifelse(sex_exposed$infection_hiv[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==2 & prep_sims[[current_data]]$VL[exposed_hiv_partner]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==2 & probinfect1_hiv[sex_exposed$HIV==1] > 0.0569, 1, ifelse(sex_exposed$infection_hiv[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & prep_sims[[current_data]]$VL[exposed_hiv_partner]==1 & probinfect1_hiv[sex_exposed$HIV==1] > 0.0134, 1, ifelse(sex_exposed$infection_hiv[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & prep_sims[[current_data]]$VL[exposed_hiv_partner]==2 & probinfect1_hiv[sex_exposed$HIV==1] > 0.1284, 1, 0))))))))))
          partseroblock_hiv = ifelse(sex_exposed$partinfection_hiv[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & prep_sims[[current_data]]$VL[exposed_hiv_ego]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==1 & probinfect1_hiv[sex_exposed$HIV==1] > 0.0010, 1, ifelse(sex_exposed$partinfection_hiv[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & prep_sims[[current_data]]$VL[exposed_hiv_ego]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==2 & probinfect1_hiv[sex_exposed$HIV==1] > 0.0059, 1, ifelse(sex_exposed$partinfection_hiv[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & prep_sims[[current_data]]$VL[exposed_hiv_ego]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==1 & probinfect1_hiv[sex_exposed$HIV==1] > 0.0101, 1, ifelse(sex_exposed$partinfection_hiv[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & prep_sims[[current_data]]$VL[exposed_hiv_ego]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==2 & probinfect1_hiv[sex_exposed$HIV==1] > 0.0569, 1, ifelse(sex_exposed$partinfection_hiv[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==2 & prep_sims[[current_data]]$VL[exposed_hiv_ego]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==1 & probinfect1_hiv[sex_exposed$HIV==1] > 0.0010, 1, ifelse(sex_exposed$partinfection_hiv[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==2 & prep_sims[[current_data]]$VL[exposed_hiv_ego]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==2 & probinfect1_hiv[sex_exposed$HIV==1] > 0.0059, 1, ifelse(sex_exposed$partinfection_hiv[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==2 & prep_sims[[current_data]]$VL[exposed_hiv_ego]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==1 & probinfect1_hiv[sex_exposed$HIV==1] > 0.0101, 1, ifelse(sex_exposed$partinfection_hiv[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==2 & prep_sims[[current_data]]$VL[exposed_hiv_ego]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==2 & probinfect1_hiv[sex_exposed$HIV==1] > 0.0569, 1, ifelse(sex_exposed$partinfection_hiv[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & prep_sims[[current_data]]$VL[exposed_hiv_ego]==1 & probinfect1_hiv[sex_exposed$HIV==1] > 0.0134, 1, ifelse(sex_exposed$partinfection_hiv[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & prep_sims[[current_data]]$VL[exposed_hiv_ego]==2 & probinfect1_hiv[sex_exposed$HIV==1] > 0.1284, 1, 0))))))))))

          #check if infection blocked for HIV
          sex_exposed$seroct_hiv[sex_exposed$HIV==1] = ifelse(sex_exposed$infection_hiv[sex_exposed$HIV==1]==1 & avoid==1, 1, ifelse(sex_exposed$infection_hiv[sex_exposed$HIV==1]==1 & avoid==0 & seroblock_hiv==1, 1, 0))
          sex_exposed$partseroct_hiv[sex_exposed$HIV==1] = ifelse(sex_exposed$partinfection_hiv[sex_exposed$HIV==1]==1 & partavoid==1, 1, ifelse(sex_exposed$partinfection_hiv[sex_exposed$HIV==1]==1 & partavoid==0 & partseroblock_hiv==1, 1, 0))

          #seroadaption strategies for HIV, HPV implications; NAs (and possibly 0s) get returned for HIV infections without correspoding HPV infection
          #seroblock_hpv = ifelse(sex_exposed$infection_hpv_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==1 & probinfect1_hpv_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$infection_hpv_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==2 & probinfect1_hpv_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$infection_hpv_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==1 & probinfect1_hpv_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$infection_hpv_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==2 & probinfect1_hpv_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$infection_hpv_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & probinfect1_hpv_anal[sex_exposed$HIV==1] > 0.546, 1, 0)))))
          #partseroblock_hpv = ifelse(sex_exposed$partinfection_hpv_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==1 & probinfect1_hpv_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$partinfection_hpv_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==2 & probinfect1_hpv_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$partinfection_hpv_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==1 & probinfect1_hpv_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$partinfection_hpv_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==2 & probinfect1_hpv_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$partinfection_hpv_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & probinfect1_hpv_anal[sex_exposed$HIV==1] > 0.546, 1, 0)))))
          seroblock_hpv6 = ifelse(sex_exposed$infection_hpv6_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==1 & probinfect1_hpv6_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$infection_hpv6_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==2 & probinfect1_hpv6_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$infection_hpv6_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==1 & probinfect1_hpv6_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$infection_hpv6_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==2 & probinfect1_hpv6_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$infection_hpv6_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & probinfect1_hpv6_anal[sex_exposed$HIV==1] > 0.546, 1, 0)))))
          partseroblock_hpv6 = ifelse(sex_exposed$partinfection_hpv6_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==1 & probinfect1_hpv6_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$partinfection_hpv6_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==2 & probinfect1_hpv6_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$partinfection_hpv6_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==1 & probinfect1_hpv6_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$partinfection_hpv6_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==2 & probinfect1_hpv6_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$partinfection_hpv6_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & probinfect1_hpv6_anal[sex_exposed$HIV==1] > 0.546, 1, 0)))))
          seroblock_hpv11 = ifelse(sex_exposed$infection_hpv11_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==1 & probinfect1_hpv11_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$infection_hpv11_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==2 & probinfect1_hpv11_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$infection_hpv11_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==1 & probinfect1_hpv11_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$infection_hpv11_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==2 & probinfect1_hpv11_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$infection_hpv11_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & probinfect1_hpv11_anal[sex_exposed$HIV==1] > 0.546, 1, 0)))))
          partseroblock_hpv11 = ifelse(sex_exposed$partinfection_hpv11_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==1 & probinfect1_hpv11_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$partinfection_hpv11_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==2 & probinfect1_hpv11_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$partinfection_hpv11_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==1 & probinfect1_hpv11_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$partinfection_hpv11_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==2 & probinfect1_hpv11_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$partinfection_hpv11_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & probinfect1_hpv11_anal[sex_exposed$HIV==1] > 0.546, 1, 0)))))
          seroblock_hpv16 = ifelse(sex_exposed$infection_hpv16_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==1 & probinfect1_hpv16_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$infection_hpv16_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==2 & probinfect1_hpv16_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$infection_hpv16_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==1 & probinfect1_hpv16_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$infection_hpv16_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==2 & probinfect1_hpv16_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$infection_hpv16_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & probinfect1_hpv16_anal[sex_exposed$HIV==1] > 0.546, 1, 0)))))
          partseroblock_hpv16 = ifelse(sex_exposed$partinfection_hpv16_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==1 & probinfect1_hpv16_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$partinfection_hpv16_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==2 & probinfect1_hpv16_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$partinfection_hpv16_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==1 & probinfect1_hpv16_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$partinfection_hpv16_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==2 & probinfect1_hpv16_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$partinfection_hpv16_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & probinfect1_hpv16_anal[sex_exposed$HIV==1] > 0.546, 1, 0)))))
          seroblock_hpv18 = ifelse(sex_exposed$infection_hpv18_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==1 & probinfect1_hpv18_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$infection_hpv18_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==2 & probinfect1_hpv18_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$infection_hpv18_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==1 & probinfect1_hpv18_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$infection_hpv18_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==2 & probinfect1_hpv18_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$infection_hpv18_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & probinfect1_hpv18_anal[sex_exposed$HIV==1] > 0.546, 1, 0)))))
          partseroblock_hpv18 = ifelse(sex_exposed$partinfection_hpv18_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==1 & probinfect1_hpv18_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$partinfection_hpv18_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==2 & probinfect1_hpv18_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$partinfection_hpv18_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==1 & probinfect1_hpv18_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$partinfection_hpv18_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==2 & probinfect1_hpv18_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$partinfection_hpv18_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & probinfect1_hpv18_anal[sex_exposed$HIV==1] > 0.546, 1, 0)))))
          seroblock_hpv31 = ifelse(sex_exposed$infection_hpv31_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==1 & probinfect1_hpv31_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$infection_hpv31_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==2 & probinfect1_hpv31_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$infection_hpv31_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==1 & probinfect1_hpv31_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$infection_hpv31_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==2 & probinfect1_hpv31_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$infection_hpv31_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & probinfect1_hpv31_anal[sex_exposed$HIV==1] > 0.546, 1, 0)))))
          partseroblock_hpv31 = ifelse(sex_exposed$partinfection_hpv31_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==1 & probinfect1_hpv31_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$partinfection_hpv31_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==2 & probinfect1_hpv31_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$partinfection_hpv31_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==1 & probinfect1_hpv31_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$partinfection_hpv31_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==2 & probinfect1_hpv31_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$partinfection_hpv31_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & probinfect1_hpv31_anal[sex_exposed$HIV==1] > 0.546, 1, 0)))))
          seroblock_hpv33 = ifelse(sex_exposed$infection_hpv33_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==1 & probinfect1_hpv33_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$infection_hpv33_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==2 & probinfect1_hpv33_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$infection_hpv33_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==1 & probinfect1_hpv33_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$infection_hpv33_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==2 & probinfect1_hpv33_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$infection_hpv33_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & probinfect1_hpv33_anal[sex_exposed$HIV==1] > 0.546, 1, 0)))))
          partseroblock_hpv33 = ifelse(sex_exposed$partinfection_hpv33_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==1 & probinfect1_hpv33_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$partinfection_hpv33_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==2 & probinfect1_hpv33_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$partinfection_hpv33_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==1 & probinfect1_hpv33_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$partinfection_hpv33_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==2 & probinfect1_hpv33_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$partinfection_hpv33_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & probinfect1_hpv33_anal[sex_exposed$HIV==1] > 0.546, 1, 0)))))
          seroblock_hpv45 = ifelse(sex_exposed$infection_hpv45_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==1 & probinfect1_hpv45_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$infection_hpv45_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==2 & probinfect1_hpv45_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$infection_hpv45_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==1 & probinfect1_hpv45_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$infection_hpv45_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==2 & probinfect1_hpv45_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$infection_hpv45_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & probinfect1_hpv45_anal[sex_exposed$HIV==1] > 0.546, 1, 0)))))
          partseroblock_hpv45 = ifelse(sex_exposed$partinfection_hpv45_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==1 & probinfect1_hpv45_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$partinfection_hpv45_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==2 & probinfect1_hpv45_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$partinfection_hpv45_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==1 & probinfect1_hpv45_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$partinfection_hpv45_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==2 & probinfect1_hpv45_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$partinfection_hpv45_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & probinfect1_hpv45_anal[sex_exposed$HIV==1] > 0.546, 1, 0)))))
          seroblock_hpv52 = ifelse(sex_exposed$infection_hpv52_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==1 & probinfect1_hpv52_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$infection_hpv52_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==2 & probinfect1_hpv52_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$infection_hpv52_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==1 & probinfect1_hpv52_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$infection_hpv52_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==2 & probinfect1_hpv52_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$infection_hpv52_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & probinfect1_hpv52_anal[sex_exposed$HIV==1] > 0.546, 1, 0)))))
          partseroblock_hpv52 = ifelse(sex_exposed$partinfection_hpv52_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==1 & probinfect1_hpv52_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$partinfection_hpv52_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==2 & probinfect1_hpv52_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$partinfection_hpv52_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==1 & probinfect1_hpv52_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$partinfection_hpv52_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==2 & probinfect1_hpv52_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$partinfection_hpv52_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & probinfect1_hpv52_anal[sex_exposed$HIV==1] > 0.546, 1, 0)))))
          seroblock_hpv58 = ifelse(sex_exposed$infection_hpv58_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==1 & probinfect1_hpv58_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$infection_hpv58_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==2 & probinfect1_hpv58_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$infection_hpv58_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==1 & probinfect1_hpv58_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$infection_hpv58_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_ego]==2 & probinfect1_hpv58_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$infection_hpv58_anal[sex_exposed$HIV==1]==1 & avoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & probinfect1_hpv58_anal[sex_exposed$HIV==1] > 0.546, 1, 0)))))
          partseroblock_hpv58 = ifelse(sex_exposed$partinfection_hpv58_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==1 & probinfect1_hpv58_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$partinfection_hpv58_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_partner]==1 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==2 & probinfect1_hpv58_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$partinfection_hpv58_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==1 & probinfect1_hpv58_anal[sex_exposed$HIV==1] > 0.038, 1, ifelse(sex_exposed$partinfection_hpv58_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==2 & prep_sims[[current_data]]$CIRC[exposed_hiv_partner]==2 & probinfect1_hpv58_anal[sex_exposed$HIV==1] > 0.071, 1, ifelse(sex_exposed$partinfection_hpv58_anal[sex_exposed$HIV==1]==1 & partavoid==0 & prep_sims[[current_data]]$SEROTYPE[exposed_hiv_ego]==1 & probinfect1_hpv58_anal[sex_exposed$HIV==1] > 0.546, 1, 0)))))
          
          #check if infection blocked for HPV anal, removing NAs/0s from earlier that are not coinfections
          #if (sum(sex_exposed$HIV_HPV_ANAL)>0) { sex_exposed$seroct_hpv[sex_exposed$HIV_HPV_ANAL==1] = (ifelse(sex_exposed$infection_hpv_anal[sex_exposed$HIV==1]==1 & avoid==1, 1, ifelse(sex_exposed$infection_hpv_anal[sex_exposed$HIV==1]==1 & avoid==0 & seroblock_hpv==1, 1, 0)))[which(!is.na(sex_exposed$infection_hpv_anal[sex_exposed$HIV==1]))] }
          #if (sum(sex_exposed$HIV_HPV_ANAL)>0) { sex_exposed$partseroct_hpv[sex_exposed$HIV_HPV_ANAL==1] = (ifelse(sex_exposed$partinfection_hpv_anal[sex_exposed$HIV==1]==1 & partavoid==1, 1, ifelse(sex_exposed$partinfection_hpv_anal[sex_exposed$HIV==1]==1 & partavoid==0 & partseroblock_hpv==1, 1, 0)))[which(!is.na(sex_exposed$partinfection_hpv_anal[sex_exposed$HIV==1]))] }
          if (sum(sex_exposed$HIV_HPV6_ANAL)>0) { sex_exposed$seroct_hpv6[sex_exposed$HIV_HPV6_ANAL==1] = (ifelse(sex_exposed$infection_hpv6_anal[sex_exposed$HIV==1]==1 & avoid==1, 1, ifelse(sex_exposed$infection_hpv6_anal[sex_exposed$HIV==1]==1 & avoid==0 & seroblock_hpv6==1, 1, 0)))[which(!is.na(sex_exposed$infection_hpv6_anal[sex_exposed$HIV==1]))] }
          if (sum(sex_exposed$HIV_HPV6_ANAL)>0) { sex_exposed$partseroct_hpv6[sex_exposed$HIV_HPV6_ANAL==1] = (ifelse(sex_exposed$partinfection_hpv6_anal[sex_exposed$HIV==1]==1 & partavoid==1, 1, ifelse(sex_exposed$partinfection_hpv6_anal[sex_exposed$HIV==1]==1 & partavoid==0 & partseroblock_hpv6==1, 1, 0)))[which(!is.na(sex_exposed$partinfection_hpv6_anal[sex_exposed$HIV==1]))] }
          if (sum(sex_exposed$HIV_HPV11_ANAL)>0) { sex_exposed$seroct_hpv11[sex_exposed$HIV_HPV11_ANAL==1] = (ifelse(sex_exposed$infection_hpv11_anal[sex_exposed$HIV==1]==1 & avoid==1, 1, ifelse(sex_exposed$infection_hpv11_anal[sex_exposed$HIV==1]==1 & avoid==0 & seroblock_hpv11==1, 1, 0)))[which(!is.na(sex_exposed$infection_hpv11_anal[sex_exposed$HIV==1]))] }
          if (sum(sex_exposed$HIV_HPV11_ANAL)>0) { sex_exposed$partseroct_hpv11[sex_exposed$HIV_HPV11_ANAL==1] = (ifelse(sex_exposed$partinfection_hpv11_anal[sex_exposed$HIV==1]==1 & partavoid==1, 1, ifelse(sex_exposed$partinfection_hpv11_anal[sex_exposed$HIV==1]==1 & partavoid==0 & partseroblock_hpv11==1, 1, 0)))[which(!is.na(sex_exposed$partinfection_hpv11_anal[sex_exposed$HIV==1]))] }
          if (sum(sex_exposed$HIV_HPV16_ANAL)>0) { sex_exposed$seroct_hpv16[sex_exposed$HIV_HPV16_ANAL==1] = (ifelse(sex_exposed$infection_hpv16_anal[sex_exposed$HIV==1]==1 & avoid==1, 1, ifelse(sex_exposed$infection_hpv16_anal[sex_exposed$HIV==1]==1 & avoid==0 & seroblock_hpv16==1, 1, 0)))[which(!is.na(sex_exposed$infection_hpv16_anal[sex_exposed$HIV==1]))] }
          if (sum(sex_exposed$HIV_HPV16_ANAL)>0) { sex_exposed$partseroct_hpv16[sex_exposed$HIV_HPV16_ANAL==1] = (ifelse(sex_exposed$partinfection_hpv16_anal[sex_exposed$HIV==1]==1 & partavoid==1, 1, ifelse(sex_exposed$partinfection_hpv16_anal[sex_exposed$HIV==1]==1 & partavoid==0 & partseroblock_hpv16==1, 1, 0)))[which(!is.na(sex_exposed$partinfection_hpv16_anal[sex_exposed$HIV==1]))] }
          if (sum(sex_exposed$HIV_HPV18_ANAL)>0) { sex_exposed$seroct_hpv18[sex_exposed$HIV_HPV18_ANAL==1] = (ifelse(sex_exposed$infection_hpv18_anal[sex_exposed$HIV==1]==1 & avoid==1, 1, ifelse(sex_exposed$infection_hpv18_anal[sex_exposed$HIV==1]==1 & avoid==0 & seroblock_hpv18==1, 1, 0)))[which(!is.na(sex_exposed$infection_hpv18_anal[sex_exposed$HIV==1]))] }
          if (sum(sex_exposed$HIV_HPV18_ANAL)>0) { sex_exposed$partseroct_hpv18[sex_exposed$HIV_HPV18_ANAL==1] = (ifelse(sex_exposed$partinfection_hpv18_anal[sex_exposed$HIV==1]==1 & partavoid==1, 1, ifelse(sex_exposed$partinfection_hpv18_anal[sex_exposed$HIV==1]==1 & partavoid==0 & partseroblock_hpv18==1, 1, 0)))[which(!is.na(sex_exposed$partinfection_hpv18_anal[sex_exposed$HIV==1]))] }
          if (sum(sex_exposed$HIV_HPV31_ANAL)>0) { sex_exposed$seroct_hpv31[sex_exposed$HIV_HPV31_ANAL==1] = (ifelse(sex_exposed$infection_hpv31_anal[sex_exposed$HIV==1]==1 & avoid==1, 1, ifelse(sex_exposed$infection_hpv31_anal[sex_exposed$HIV==1]==1 & avoid==0 & seroblock_hpv31==1, 1, 0)))[which(!is.na(sex_exposed$infection_hpv31_anal[sex_exposed$HIV==1]))] }
          if (sum(sex_exposed$HIV_HPV31_ANAL)>0) { sex_exposed$partseroct_hpv31[sex_exposed$HIV_HPV31_ANAL==1] = (ifelse(sex_exposed$partinfection_hpv31_anal[sex_exposed$HIV==1]==1 & partavoid==1, 1, ifelse(sex_exposed$partinfection_hpv31_anal[sex_exposed$HIV==1]==1 & partavoid==0 & partseroblock_hpv31==1, 1, 0)))[which(!is.na(sex_exposed$partinfection_hpv31_anal[sex_exposed$HIV==1]))] }
          if (sum(sex_exposed$HIV_HPV33_ANAL)>0) { sex_exposed$seroct_hpv33[sex_exposed$HIV_HPV33_ANAL==1] = (ifelse(sex_exposed$infection_hpv33_anal[sex_exposed$HIV==1]==1 & avoid==1, 1, ifelse(sex_exposed$infection_hpv33_anal[sex_exposed$HIV==1]==1 & avoid==0 & seroblock_hpv33==1, 1, 0)))[which(!is.na(sex_exposed$infection_hpv33_anal[sex_exposed$HIV==1]))] }
          if (sum(sex_exposed$HIV_HPV33_ANAL)>0) { sex_exposed$partseroct_hpv33[sex_exposed$HIV_HPV33_ANAL==1] = (ifelse(sex_exposed$partinfection_hpv33_anal[sex_exposed$HIV==1]==1 & partavoid==1, 1, ifelse(sex_exposed$partinfection_hpv33_anal[sex_exposed$HIV==1]==1 & partavoid==0 & partseroblock_hpv33==1, 1, 0)))[which(!is.na(sex_exposed$partinfection_hpv33_anal[sex_exposed$HIV==1]))] }
          if (sum(sex_exposed$HIV_HPV45_ANAL)>0) { sex_exposed$seroct_hpv45[sex_exposed$HIV_HPV45_ANAL==1] = (ifelse(sex_exposed$infection_hpv45_anal[sex_exposed$HIV==1]==1 & avoid==1, 1, ifelse(sex_exposed$infection_hpv45_anal[sex_exposed$HIV==1]==1 & avoid==0 & seroblock_hpv45==1, 1, 0)))[which(!is.na(sex_exposed$infection_hpv45_anal[sex_exposed$HIV==1]))] }
          if (sum(sex_exposed$HIV_HPV45_ANAL)>0) { sex_exposed$partseroct_hpv45[sex_exposed$HIV_HPV45_ANAL==1] = (ifelse(sex_exposed$partinfection_hpv45_anal[sex_exposed$HIV==1]==1 & partavoid==1, 1, ifelse(sex_exposed$partinfection_hpv45_anal[sex_exposed$HIV==1]==1 & partavoid==0 & partseroblock_hpv45==1, 1, 0)))[which(!is.na(sex_exposed$partinfection_hpv45_anal[sex_exposed$HIV==1]))] }
          if (sum(sex_exposed$HIV_HPV52_ANAL)>0) { sex_exposed$seroct_hpv52[sex_exposed$HIV_HPV52_ANAL==1] = (ifelse(sex_exposed$infection_hpv52_anal[sex_exposed$HIV==1]==1 & avoid==1, 1, ifelse(sex_exposed$infection_hpv52_anal[sex_exposed$HIV==1]==1 & avoid==0 & seroblock_hpv52==1, 1, 0)))[which(!is.na(sex_exposed$infection_hpv52_anal[sex_exposed$HIV==1]))] }
          if (sum(sex_exposed$HIV_HPV52_ANAL)>0) { sex_exposed$partseroct_hpv52[sex_exposed$HIV_HPV52_ANAL==1] = (ifelse(sex_exposed$partinfection_hpv52_anal[sex_exposed$HIV==1]==1 & partavoid==1, 1, ifelse(sex_exposed$partinfection_hpv52_anal[sex_exposed$HIV==1]==1 & partavoid==0 & partseroblock_hpv52==1, 1, 0)))[which(!is.na(sex_exposed$partinfection_hpv52_anal[sex_exposed$HIV==1]))] }
          if (sum(sex_exposed$HIV_HPV58_ANAL)>0) { sex_exposed$seroct_hpv58[sex_exposed$HIV_HPV58_ANAL==1] = (ifelse(sex_exposed$infection_hpv58_anal[sex_exposed$HIV==1]==1 & avoid==1, 1, ifelse(sex_exposed$infection_hpv58_anal[sex_exposed$HIV==1]==1 & avoid==0 & seroblock_hpv58==1, 1, 0)))[which(!is.na(sex_exposed$infection_hpv58_anal[sex_exposed$HIV==1]))] }
          if (sum(sex_exposed$HIV_HPV58_ANAL)>0) { sex_exposed$partseroct_hpv58[sex_exposed$HIV_HPV58_ANAL==1] = (ifelse(sex_exposed$partinfection_hpv58_anal[sex_exposed$HIV==1]==1 & partavoid==1, 1, ifelse(sex_exposed$partinfection_hpv58_anal[sex_exposed$HIV==1]==1 & partavoid==0 & partseroblock_hpv58==1, 1, 0)))[which(!is.na(sex_exposed$partinfection_hpv58_anal[sex_exposed$HIV==1]))] }
          
          rm(avoid,partavoid,seroblock_hiv,partseroblock_hiv,seroblock_hpv6,partseroblock_hpv6,seroblock_hpv11,partseroblock_hpv11,seroblock_hpv16,partseroblock_hpv16,seroblock_hpv18,partseroblock_hpv18,seroblock_hpv31,partseroblock_hpv31,seroblock_hpv33,partseroblock_hpv33,seroblock_hpv45,partseroblock_hpv45,seroblock_hpv52,partseroblock_hpv52,seroblock_hpv58,partseroblock_hpv58)
        }
        
        #determine infection under condom scenarios
        if (unique(prep_sims[[current_data]]$COND)==1)
        {
          #check if a condom was worn by either partner
          randcond = runif(nrow(sex_exposed),0,1)
          condom_worn_anal = (randcond<=prep_sims[[current_data]]$PROBCOND[sex_exposed$Ego]) | (randcond<=prep_sims[[current_data]]$PROBCOND[sex_exposed$Partner])
          condom_worn_oral = (randcond<=0.01)
          
          #check if the condom failed
          randfail = runif(nrow(sex_exposed),0,1)
          condom_success_anal = condom_worn_anal & (randfail<=0.705)
          condom_success_oral = condom_worn_oral & (randfail<=0.705)
          
          #check if infection blocked for HIV
          sex_exposed$condct_hiv[sex_exposed$HIV==1] = ifelse(sex_exposed$infection_hiv[sex_exposed$HIV==1]==1 & condom_success_anal[sex_exposed$HIV==1], 1, 0)
          sex_exposed$partcondct_hiv[sex_exposed$HIV==1] = ifelse(sex_exposed$partinfection_hiv[sex_exposed$HIV==1]==1 & condom_success_anal[sex_exposed$HIV==1], 1, 0)
          
          #check if infection blocked for HPV anal
          #sex_exposed$condct_hpv_anal[sex_exposed$HPV_ANAL==1] = ifelse(sex_exposed$infection_hpv_anal[sex_exposed$HPV_ANAL==1]==1 & condom_success_anal[sex_exposed$HPV_ANAL==1], 1, 0)
          #sex_exposed$partcondct_hpv_anal[sex_exposed$HPV_ANAL==1] = ifelse(sex_exposed$partinfection_hpv_anal[sex_exposed$HPV_ANAL==1]==1 & condom_success_anal[sex_exposed$HPV_ANAL==1], 1, 0)
          sex_exposed$condct_hpv6_anal[sex_exposed$HPV6_ANAL==1] = ifelse(sex_exposed$infection_hpv6_anal[sex_exposed$HPV6_ANAL==1]==1 & condom_success_anal[sex_exposed$HPV6_ANAL==1], 1, 0)
          sex_exposed$partcondct_hpv6_anal[sex_exposed$HPV6_ANAL==1] = ifelse(sex_exposed$partinfection_hpv6_anal[sex_exposed$HPV6_ANAL==1]==1 & condom_success_anal[sex_exposed$HPV6_ANAL==1], 1, 0)
          sex_exposed$condct_hpv11_anal[sex_exposed$HPV11_ANAL==1] = ifelse(sex_exposed$infection_hpv11_anal[sex_exposed$HPV11_ANAL==1]==1 & condom_success_anal[sex_exposed$HPV11_ANAL==1], 1, 0)
          sex_exposed$partcondct_hpv11_anal[sex_exposed$HPV11_ANAL==1] = ifelse(sex_exposed$partinfection_hpv11_anal[sex_exposed$HPV11_ANAL==1]==1 & condom_success_anal[sex_exposed$HPV11_ANAL==1], 1, 0)
          sex_exposed$condct_hpv16_anal[sex_exposed$HPV16_ANAL==1] = ifelse(sex_exposed$infection_hpv16_anal[sex_exposed$HPV16_ANAL==1]==1 & condom_success_anal[sex_exposed$HPV16_ANAL==1], 1, 0)
          sex_exposed$partcondct_hpv16_anal[sex_exposed$HPV16_ANAL==1] = ifelse(sex_exposed$partinfection_hpv16_anal[sex_exposed$HPV16_ANAL==1]==1 & condom_success_anal[sex_exposed$HPV16_ANAL==1], 1, 0)
          sex_exposed$condct_hpv18_anal[sex_exposed$HPV18_ANAL==1] = ifelse(sex_exposed$infection_hpv18_anal[sex_exposed$HPV18_ANAL==1]==1 & condom_success_anal[sex_exposed$HPV18_ANAL==1], 1, 0)
          sex_exposed$partcondct_hpv18_anal[sex_exposed$HPV18_ANAL==1] = ifelse(sex_exposed$partinfection_hpv18_anal[sex_exposed$HPV18_ANAL==1]==1 & condom_success_anal[sex_exposed$HPV18_ANAL==1], 1, 0)
          sex_exposed$condct_hpv31_anal[sex_exposed$HPV31_ANAL==1] = ifelse(sex_exposed$infection_hpv31_anal[sex_exposed$HPV31_ANAL==1]==1 & condom_success_anal[sex_exposed$HPV31_ANAL==1], 1, 0)
          sex_exposed$partcondct_hpv31_anal[sex_exposed$HPV31_ANAL==1] = ifelse(sex_exposed$partinfection_hpv31_anal[sex_exposed$HPV31_ANAL==1]==1 & condom_success_anal[sex_exposed$HPV31_ANAL==1], 1, 0)
          sex_exposed$condct_hpv33_anal[sex_exposed$HPV33_ANAL==1] = ifelse(sex_exposed$infection_hpv33_anal[sex_exposed$HPV33_ANAL==1]==1 & condom_success_anal[sex_exposed$HPV33_ANAL==1], 1, 0)
          sex_exposed$partcondct_hpv33_anal[sex_exposed$HPV33_ANAL==1] = ifelse(sex_exposed$partinfection_hpv33_anal[sex_exposed$HPV33_ANAL==1]==1 & condom_success_anal[sex_exposed$HPV33_ANAL==1], 1, 0)
          sex_exposed$condct_hpv45_anal[sex_exposed$HPV45_ANAL==1] = ifelse(sex_exposed$infection_hpv45_anal[sex_exposed$HPV45_ANAL==1]==1 & condom_success_anal[sex_exposed$HPV45_ANAL==1], 1, 0)
          sex_exposed$partcondct_hpv45_anal[sex_exposed$HPV45_ANAL==1] = ifelse(sex_exposed$partinfection_hpv45_anal[sex_exposed$HPV45_ANAL==1]==1 & condom_success_anal[sex_exposed$HPV45_ANAL==1], 1, 0)
          sex_exposed$condct_hpv52_anal[sex_exposed$HPV52_ANAL==1] = ifelse(sex_exposed$infection_hpv52_anal[sex_exposed$HPV52_ANAL==1]==1 & condom_success_anal[sex_exposed$HPV52_ANAL==1], 1, 0)
          sex_exposed$partcondct_hpv52_anal[sex_exposed$HPV52_ANAL==1] = ifelse(sex_exposed$partinfection_hpv52_anal[sex_exposed$HPV52_ANAL==1]==1 & condom_success_anal[sex_exposed$HPV52_ANAL==1], 1, 0)
          sex_exposed$condct_hpv58_anal[sex_exposed$HPV58_ANAL==1] = ifelse(sex_exposed$infection_hpv58_anal[sex_exposed$HPV58_ANAL==1]==1 & condom_success_anal[sex_exposed$HPV58_ANAL==1], 1, 0)
          sex_exposed$partcondct_hpv58_anal[sex_exposed$HPV58_ANAL==1] = ifelse(sex_exposed$partinfection_hpv58_anal[sex_exposed$HPV58_ANAL==1]==1 & condom_success_anal[sex_exposed$HPV58_ANAL==1], 1, 0)
          
          #check if infection blocked for HPV oral
          sex_exposed$condct_hpv6_oral[sex_exposed$HPV6_ORAL==1] = ifelse(sex_exposed$infection_hpv6_oral[sex_exposed$HPV6_ORAL==1]>=1 & condom_success_oral[sex_exposed$HPV6_ORAL==1], 1, 0)
          sex_exposed$partcondct_hpv6_oral[sex_exposed$HPV6_ORAL==1] = ifelse(sex_exposed$partinfection_hpv6_oral[sex_exposed$HPV6_ORAL==1]>=1 & condom_success_oral[sex_exposed$HPV6_ORAL==1], 1, 0)
          sex_exposed$condct_hpv11_oral[sex_exposed$HPV11_ORAL==1] = ifelse(sex_exposed$infection_hpv11_oral[sex_exposed$HPV11_ORAL==1]>=1 & condom_success_oral[sex_exposed$HPV11_ORAL==1], 1, 0)
          sex_exposed$partcondct_hpv11_oral[sex_exposed$HPV11_ORAL==1] = ifelse(sex_exposed$partinfection_hpv11_oral[sex_exposed$HPV11_ORAL==1]>=1 & condom_success_oral[sex_exposed$HPV11_ORAL==1], 1, 0)
          sex_exposed$condct_hpv16_oral[sex_exposed$HPV16_ORAL==1] = ifelse(sex_exposed$infection_hpv16_oral[sex_exposed$HPV16_ORAL==1]>=1 & condom_success_oral[sex_exposed$HPV16_ORAL==1], 1, 0)
          sex_exposed$partcondct_hpv16_oral[sex_exposed$HPV16_ORAL==1] = ifelse(sex_exposed$partinfection_hpv16_oral[sex_exposed$HPV16_ORAL==1]>=1 & condom_success_oral[sex_exposed$HPV16_ORAL==1], 1, 0)
          sex_exposed$condct_hpv18_oral[sex_exposed$HPV18_ORAL==1] = ifelse(sex_exposed$infection_hpv18_oral[sex_exposed$HPV18_ORAL==1]>=1 & condom_success_oral[sex_exposed$HPV18_ORAL==1], 1, 0)
          sex_exposed$partcondct_hpv18_oral[sex_exposed$HPV18_ORAL==1] = ifelse(sex_exposed$partinfection_hpv18_oral[sex_exposed$HPV18_ORAL==1]>=1 & condom_success_oral[sex_exposed$HPV18_ORAL==1], 1, 0)
          sex_exposed$condct_hpv31_oral[sex_exposed$HPV31_ORAL==1] = ifelse(sex_exposed$infection_hpv31_oral[sex_exposed$HPV31_ORAL==1]>=1 & condom_success_oral[sex_exposed$HPV31_ORAL==1], 1, 0)
          sex_exposed$partcondct_hpv31_oral[sex_exposed$HPV31_ORAL==1] = ifelse(sex_exposed$partinfection_hpv31_oral[sex_exposed$HPV31_ORAL==1]>=1 & condom_success_oral[sex_exposed$HPV31_ORAL==1], 1, 0)
          sex_exposed$condct_hpv33_oral[sex_exposed$HPV33_ORAL==1] = ifelse(sex_exposed$infection_hpv33_oral[sex_exposed$HPV33_ORAL==1]>=1 & condom_success_oral[sex_exposed$HPV33_ORAL==1], 1, 0)
          sex_exposed$partcondct_hpv33_oral[sex_exposed$HPV33_ORAL==1] = ifelse(sex_exposed$partinfection_hpv33_oral[sex_exposed$HPV33_ORAL==1]>=1 & condom_success_oral[sex_exposed$HPV33_ORAL==1], 1, 0)
          sex_exposed$condct_hpv45_oral[sex_exposed$HPV45_ORAL==1] = ifelse(sex_exposed$infection_hpv45_oral[sex_exposed$HPV45_ORAL==1]>=1 & condom_success_oral[sex_exposed$HPV45_ORAL==1], 1, 0)
          sex_exposed$partcondct_hpv45_oral[sex_exposed$HPV45_ORAL==1] = ifelse(sex_exposed$partinfection_hpv45_oral[sex_exposed$HPV45_ORAL==1]>=1 & condom_success_oral[sex_exposed$HPV45_ORAL==1], 1, 0)
          sex_exposed$condct_hpv52_oral[sex_exposed$HPV52_ORAL==1] = ifelse(sex_exposed$infection_hpv52_oral[sex_exposed$HPV52_ORAL==1]>=1 & condom_success_oral[sex_exposed$HPV52_ORAL==1], 1, 0)
          sex_exposed$partcondct_hpv52_oral[sex_exposed$HPV52_ORAL==1] = ifelse(sex_exposed$partinfection_hpv52_oral[sex_exposed$HPV52_ORAL==1]>=1 & condom_success_oral[sex_exposed$HPV52_ORAL==1], 1, 0)
          sex_exposed$condct_hpv58_oral[sex_exposed$HPV58_ORAL==1] = ifelse(sex_exposed$infection_hpv58_oral[sex_exposed$HPV58_ORAL==1]>=1 & condom_success_oral[sex_exposed$HPV58_ORAL==1], 1, 0)
          sex_exposed$partcondct_hpv58_oral[sex_exposed$HPV58_ORAL==1] = ifelse(sex_exposed$partinfection_hpv58_oral[sex_exposed$HPV58_ORAL==1]>=1 & condom_success_oral[sex_exposed$HPV58_ORAL==1], 1, 0)

          rm(randcond,randfail,condom_worn_anal,condom_success_anal,condom_worn_oral,condom_success_oral)
        }
        
        #determine infection under TAP scenarios
        if (unique(prep_sims[[current_data]]$TAP)==1)
        {
          #check if infection blocked
          sex_exposed$tapct[sex_exposed$HIV==1] = ifelse(sex_exposed$infection_hiv[sex_exposed$HIV==1]==1 & prep_sims[[current_data]]$TAPVL[exposed_hiv_partner]==1, 1, 0)
          sex_exposed$parttapct[sex_exposed$HIV==1] = ifelse(sex_exposed$partinfection_hiv[sex_exposed$HIV==1]==1 & prep_sims[[current_data]]$TAPVL[exposed_hiv_ego]==1, 1, 0)
        }
        
        #determine infection under PrEP scenarios
        if (unique(prep_sims[[current_data]]$PREP)==1)
        {
          #check if infection blocked
          sex_exposed$prepct[sex_exposed$HIV==1] = ifelse(sex_exposed$infection_hiv[sex_exposed$HIV==1]==1 & prep_sims[[current_data]]$ONPREP[exposed_hiv_ego]==1, 1, sex_exposed$prepct)
          sex_exposed$partprepct[sex_exposed$HIV==1] = ifelse(sex_exposed$partinfection_hiv[sex_exposed$HIV==1]==1 & prep_sims[[current_data]]$ONPREP[exposed_hiv_partner]==1, 1, sex_exposed$partprepct)
        }
        
        #determine infection under vaccination scenarios
        if (unique(prep_sims[[current_data]]$VAX)==1)
        {
          #calculate probabilities of vaccination success
          randvax = runif(nrow(sex_exposed),0,1)

          #check if infection blocked for HPV anal
          #sex_exposed$vaxct_hpv_anal[sex_exposed$HPV_ANAL==1] = ifelse(sex_exposed$infection_hpv_anal[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv_anal_ego]==1 & randvax[sex_exposed$HPV_ANAL==1]<=0.58, 1, ifelse(sex_exposed$infection_hpv_anal[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv_anal_ego]>=2 & randvax[sex_exposed$HPV_ANAL==1]<=0.775, 1, 0))
          #sex_exposed$partvaxct_hpv_anal[sex_exposed$HPV_ANAL==1] = ifelse(sex_exposed$partinfection_hpv_anal[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv_anal_partner]==1 & randvax[sex_exposed$HPV_ANAL==1]<=0.58, 1, ifelse(sex_exposed$partinfection_hpv_anal[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv_anal_partner]>=2 & randvax[sex_exposed$HPV_ANAL==1]<=0.775, 1, 0))
          sex_exposed$vaxct_hpv6_anal[sex_exposed$HPV6_ANAL==1] = ifelse(sex_exposed$infection_hpv6_anal[sex_exposed$HPV6_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv6_anal_ego]==1 & randvax[sex_exposed$HPV6_ANAL==1]<=0.58, 1, ifelse(sex_exposed$infection_hpv6_anal[sex_exposed$HPV6_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv6_anal_ego]>=2 & randvax[sex_exposed$HPV6_ANAL==1]<=0.775, 1, 0))
          sex_exposed$partvaxct_hpv6_anal[sex_exposed$HPV6_ANAL==1] = ifelse(sex_exposed$partinfection_hpv6_anal[sex_exposed$HPV6_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv6_anal_partner]==1 & randvax[sex_exposed$HPV6_ANAL==1]<=0.58, 1, ifelse(sex_exposed$partinfection_hpv6_anal[sex_exposed$HPV6_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv6_anal_partner]>=2 & randvax[sex_exposed$HPV6_ANAL==1]<=0.775, 1, 0))
          sex_exposed$vaxct_hpv11_anal[sex_exposed$HPV11_ANAL==1] = ifelse(sex_exposed$infection_hpv11_anal[sex_exposed$HPV11_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv11_anal_ego]==1 & randvax[sex_exposed$HPV11_ANAL==1]<=0.58, 1, ifelse(sex_exposed$infection_hpv11_anal[sex_exposed$HPV11_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv11_anal_ego]>=2 & randvax[sex_exposed$HPV11_ANAL==1]<=0.775, 1, 0))
          sex_exposed$partvaxct_hpv11_anal[sex_exposed$HPV11_ANAL==1] = ifelse(sex_exposed$partinfection_hpv11_anal[sex_exposed$HPV11_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv11_anal_partner]==1 & randvax[sex_exposed$HPV11_ANAL==1]<=0.58, 1, ifelse(sex_exposed$partinfection_hpv11_anal[sex_exposed$HPV11_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv11_anal_partner]>=2 & randvax[sex_exposed$HPV11_ANAL==1]<=0.775, 1, 0))
          sex_exposed$vaxct_hpv16_anal[sex_exposed$HPV16_ANAL==1] = ifelse(sex_exposed$infection_hpv16_anal[sex_exposed$HPV16_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv16_anal_ego]==1 & randvax[sex_exposed$HPV16_ANAL==1]<=0.58, 1, ifelse(sex_exposed$infection_hpv16_anal[sex_exposed$HPV16_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv16_anal_ego]>=2 & randvax[sex_exposed$HPV16_ANAL==1]<=0.775, 1, 0))
          sex_exposed$partvaxct_hpv16_anal[sex_exposed$HPV16_ANAL==1] = ifelse(sex_exposed$partinfection_hpv16_anal[sex_exposed$HPV16_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv16_anal_partner]==1 & randvax[sex_exposed$HPV16_ANAL==1]<=0.58, 1, ifelse(sex_exposed$partinfection_hpv16_anal[sex_exposed$HPV16_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv16_anal_partner]>=2 & randvax[sex_exposed$HPV16_ANAL==1]<=0.775, 1, 0))
          sex_exposed$vaxct_hpv18_anal[sex_exposed$HPV18_ANAL==1] = ifelse(sex_exposed$infection_hpv18_anal[sex_exposed$HPV18_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv18_anal_ego]==1 & randvax[sex_exposed$HPV18_ANAL==1]<=0.58, 1, ifelse(sex_exposed$infection_hpv18_anal[sex_exposed$HPV18_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv18_anal_ego]>=2 & randvax[sex_exposed$HPV18_ANAL==1]<=0.775, 1, 0))
          sex_exposed$partvaxct_hpv18_anal[sex_exposed$HPV18_ANAL==1] = ifelse(sex_exposed$partinfection_hpv18_anal[sex_exposed$HPV18_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv18_anal_partner]==1 & randvax[sex_exposed$HPV18_ANAL==1]<=0.58, 1, ifelse(sex_exposed$partinfection_hpv18_anal[sex_exposed$HPV18_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv18_anal_partner]>=2 & randvax[sex_exposed$HPV18_ANAL==1]<=0.775, 1, 0))
          sex_exposed$vaxct_hpv31_anal[sex_exposed$HPV31_ANAL==1] = ifelse(sex_exposed$infection_hpv31_anal[sex_exposed$HPV31_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv31_anal_ego]==1 & randvax[sex_exposed$HPV31_ANAL==1]<=0.58, 1, ifelse(sex_exposed$infection_hpv31_anal[sex_exposed$HPV31_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv31_anal_ego]>=2 & randvax[sex_exposed$HPV31_ANAL==1]<=0.775, 1, 0))
          sex_exposed$partvaxct_hpv31_anal[sex_exposed$HPV31_ANAL==1] = ifelse(sex_exposed$partinfection_hpv31_anal[sex_exposed$HPV31_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv31_anal_partner]==1 & randvax[sex_exposed$HPV31_ANAL==1]<=0.58, 1, ifelse(sex_exposed$partinfection_hpv31_anal[sex_exposed$HPV31_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv31_anal_partner]>=2 & randvax[sex_exposed$HPV31_ANAL==1]<=0.775, 1, 0))
          sex_exposed$vaxct_hpv33_anal[sex_exposed$HPV33_ANAL==1] = ifelse(sex_exposed$infection_hpv33_anal[sex_exposed$HPV33_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv33_anal_ego]==1 & randvax[sex_exposed$HPV33_ANAL==1]<=0.58, 1, ifelse(sex_exposed$infection_hpv33_anal[sex_exposed$HPV33_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv33_anal_ego]>=2 & randvax[sex_exposed$HPV33_ANAL==1]<=0.775, 1, 0))
          sex_exposed$partvaxct_hpv33_anal[sex_exposed$HPV33_ANAL==1] = ifelse(sex_exposed$partinfection_hpv33_anal[sex_exposed$HPV33_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv33_anal_partner]==1 & randvax[sex_exposed$HPV33_ANAL==1]<=0.58, 1, ifelse(sex_exposed$partinfection_hpv33_anal[sex_exposed$HPV33_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv33_anal_partner]>=2 & randvax[sex_exposed$HPV33_ANAL==1]<=0.775, 1, 0))
          sex_exposed$vaxct_hpv45_anal[sex_exposed$HPV45_ANAL==1] = ifelse(sex_exposed$infection_hpv45_anal[sex_exposed$HPV45_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv45_anal_ego]==1 & randvax[sex_exposed$HPV45_ANAL==1]<=0.58, 1, ifelse(sex_exposed$infection_hpv45_anal[sex_exposed$HPV45_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv45_anal_ego]>=2 & randvax[sex_exposed$HPV45_ANAL==1]<=0.775, 1, 0))
          sex_exposed$partvaxct_hpv45_anal[sex_exposed$HPV45_ANAL==1] = ifelse(sex_exposed$partinfection_hpv45_anal[sex_exposed$HPV45_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv45_anal_partner]==1 & randvax[sex_exposed$HPV45_ANAL==1]<=0.58, 1, ifelse(sex_exposed$partinfection_hpv45_anal[sex_exposed$HPV45_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv45_anal_partner]>=2 & randvax[sex_exposed$HPV45_ANAL==1]<=0.775, 1, 0))
          sex_exposed$vaxct_hpv52_anal[sex_exposed$HPV52_ANAL==1] = ifelse(sex_exposed$infection_hpv52_anal[sex_exposed$HPV52_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv52_anal_ego]==1 & randvax[sex_exposed$HPV52_ANAL==1]<=0.58, 1, ifelse(sex_exposed$infection_hpv52_anal[sex_exposed$HPV52_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv52_anal_ego]>=2 & randvax[sex_exposed$HPV52_ANAL==1]<=0.775, 1, 0))
          sex_exposed$partvaxct_hpv52_anal[sex_exposed$HPV52_ANAL==1] = ifelse(sex_exposed$partinfection_hpv52_anal[sex_exposed$HPV52_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv52_anal_partner]==1 & randvax[sex_exposed$HPV52_ANAL==1]<=0.58, 1, ifelse(sex_exposed$partinfection_hpv52_anal[sex_exposed$HPV52_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv52_anal_partner]>=2 & randvax[sex_exposed$HPV52_ANAL==1]<=0.775, 1, 0))
          sex_exposed$vaxct_hpv58_anal[sex_exposed$HPV58_ANAL==1] = ifelse(sex_exposed$infection_hpv58_anal[sex_exposed$HPV58_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv58_anal_ego]==1 & randvax[sex_exposed$HPV58_ANAL==1]<=0.58, 1, ifelse(sex_exposed$infection_hpv58_anal[sex_exposed$HPV58_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv58_anal_ego]>=2 & randvax[sex_exposed$HPV58_ANAL==1]<=0.775, 1, 0))
          sex_exposed$partvaxct_hpv58_anal[sex_exposed$HPV58_ANAL==1] = ifelse(sex_exposed$partinfection_hpv58_anal[sex_exposed$HPV58_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv58_anal_partner]==1 & randvax[sex_exposed$HPV58_ANAL==1]<=0.58, 1, ifelse(sex_exposed$partinfection_hpv58_anal[sex_exposed$HPV58_ANAL==1]==1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv58_anal_partner]>=2 & randvax[sex_exposed$HPV58_ANAL==1]<=0.775, 1, 0))
          
          #check if infection blocked for HPV oral
          sex_exposed$vaxct_hpv6_oral[sex_exposed$HPV6_ORAL==1] = ifelse(sex_exposed$infection_hpv6_oral[sex_exposed$HPV6_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv6_oral_ego]==1 & randvax[sex_exposed$HPV6_ORAL==1]<=0.58, 1, ifelse(sex_exposed$infection_hpv6_oral[sex_exposed$HPV6_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv6_oral_ego]>=2 & randvax[sex_exposed$HPV6_ORAL==1]<=0.775, 1, 0))
          sex_exposed$partvaxct_hpv6_oral[sex_exposed$HPV6_ORAL==1] = ifelse(sex_exposed$partinfection_hpv6_oral[sex_exposed$HPV6_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv6_oral_partner]==1 & randvax[sex_exposed$HPV6_ORAL==1]<=0.58, 1, ifelse(sex_exposed$partinfection_hpv6_oral[sex_exposed$HPV6_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv6_oral_partner]>=2 & randvax[sex_exposed$HPV6_ORAL==1]<=0.775, 1, 0))
          sex_exposed$vaxct_hpv11_oral[sex_exposed$HPV11_ORAL==1] = ifelse(sex_exposed$infection_hpv11_oral[sex_exposed$HPV11_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv11_oral_ego]==1 & randvax[sex_exposed$HPV11_ORAL==1]<=0.58, 1, ifelse(sex_exposed$infection_hpv11_oral[sex_exposed$HPV11_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv11_oral_ego]>=2 & randvax[sex_exposed$HPV11_ORAL==1]<=0.775, 1, 0))
          sex_exposed$partvaxct_hpv11_oral[sex_exposed$HPV11_ORAL==1] = ifelse(sex_exposed$partinfection_hpv11_oral[sex_exposed$HPV11_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv11_oral_partner]==1 & randvax[sex_exposed$HPV11_ORAL==1]<=0.58, 1, ifelse(sex_exposed$partinfection_hpv11_oral[sex_exposed$HPV11_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv11_oral_partner]>=2 & randvax[sex_exposed$HPV11_ORAL==1]<=0.775, 1, 0))
          sex_exposed$vaxct_hpv16_oral[sex_exposed$HPV16_ORAL==1] = ifelse(sex_exposed$infection_hpv16_oral[sex_exposed$HPV16_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv16_oral_ego]==1 & randvax[sex_exposed$HPV16_ORAL==1]<=0.58, 1, ifelse(sex_exposed$infection_hpv16_oral[sex_exposed$HPV16_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv16_oral_ego]>=2 & randvax[sex_exposed$HPV16_ORAL==1]<=0.775, 1, 0))
          sex_exposed$partvaxct_hpv16_oral[sex_exposed$HPV16_ORAL==1] = ifelse(sex_exposed$partinfection_hpv16_oral[sex_exposed$HPV16_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv16_oral_partner]==1 & randvax[sex_exposed$HPV16_ORAL==1]<=0.58, 1, ifelse(sex_exposed$partinfection_hpv16_oral[sex_exposed$HPV16_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv16_oral_partner]>=2 & randvax[sex_exposed$HPV16_ORAL==1]<=0.775, 1, 0))
          sex_exposed$vaxct_hpv18_oral[sex_exposed$HPV18_ORAL==1] = ifelse(sex_exposed$infection_hpv18_oral[sex_exposed$HPV18_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv18_oral_ego]==1 & randvax[sex_exposed$HPV18_ORAL==1]<=0.58, 1, ifelse(sex_exposed$infection_hpv18_oral[sex_exposed$HPV18_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv18_oral_ego]>=2 & randvax[sex_exposed$HPV18_ORAL==1]<=0.775, 1, 0))
          sex_exposed$partvaxct_hpv18_oral[sex_exposed$HPV18_ORAL==1] = ifelse(sex_exposed$partinfection_hpv18_oral[sex_exposed$HPV18_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv18_oral_partner]==1 & randvax[sex_exposed$HPV18_ORAL==1]<=0.58, 1, ifelse(sex_exposed$partinfection_hpv18_oral[sex_exposed$HPV18_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv18_oral_partner]>=2 & randvax[sex_exposed$HPV18_ORAL==1]<=0.775, 1, 0))
          sex_exposed$vaxct_hpv31_oral[sex_exposed$HPV31_ORAL==1] = ifelse(sex_exposed$infection_hpv31_oral[sex_exposed$HPV31_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv31_oral_ego]==1 & randvax[sex_exposed$HPV31_ORAL==1]<=0.58, 1, ifelse(sex_exposed$infection_hpv31_oral[sex_exposed$HPV31_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv31_oral_ego]>=2 & randvax[sex_exposed$HPV31_ORAL==1]<=0.775, 1, 0))
          sex_exposed$partvaxct_hpv31_oral[sex_exposed$HPV31_ORAL==1] = ifelse(sex_exposed$partinfection_hpv31_oral[sex_exposed$HPV31_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv31_oral_partner]==1 & randvax[sex_exposed$HPV31_ORAL==1]<=0.58, 1, ifelse(sex_exposed$partinfection_hpv31_oral[sex_exposed$HPV31_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv31_oral_partner]>=2 & randvax[sex_exposed$HPV31_ORAL==1]<=0.775, 1, 0))
          sex_exposed$vaxct_hpv33_oral[sex_exposed$HPV33_ORAL==1] = ifelse(sex_exposed$infection_hpv33_oral[sex_exposed$HPV33_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv33_oral_ego]==1 & randvax[sex_exposed$HPV33_ORAL==1]<=0.58, 1, ifelse(sex_exposed$infection_hpv33_oral[sex_exposed$HPV33_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv33_oral_ego]>=2 & randvax[sex_exposed$HPV33_ORAL==1]<=0.775, 1, 0))
          sex_exposed$partvaxct_hpv33_oral[sex_exposed$HPV33_ORAL==1] = ifelse(sex_exposed$partinfection_hpv33_oral[sex_exposed$HPV33_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv33_oral_partner]==1 & randvax[sex_exposed$HPV33_ORAL==1]<=0.58, 1, ifelse(sex_exposed$partinfection_hpv33_oral[sex_exposed$HPV33_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv33_oral_partner]>=2 & randvax[sex_exposed$HPV33_ORAL==1]<=0.775, 1, 0))
          sex_exposed$vaxct_hpv45_oral[sex_exposed$HPV45_ORAL==1] = ifelse(sex_exposed$infection_hpv45_oral[sex_exposed$HPV45_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv45_oral_ego]==1 & randvax[sex_exposed$HPV45_ORAL==1]<=0.58, 1, ifelse(sex_exposed$infection_hpv45_oral[sex_exposed$HPV45_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv45_oral_ego]>=2 & randvax[sex_exposed$HPV45_ORAL==1]<=0.775, 1, 0))
          sex_exposed$partvaxct_hpv45_oral[sex_exposed$HPV45_ORAL==1] = ifelse(sex_exposed$partinfection_hpv45_oral[sex_exposed$HPV45_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv45_oral_partner]==1 & randvax[sex_exposed$HPV45_ORAL==1]<=0.58, 1, ifelse(sex_exposed$partinfection_hpv45_oral[sex_exposed$HPV45_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv45_oral_partner]>=2 & randvax[sex_exposed$HPV45_ORAL==1]<=0.775, 1, 0))
          sex_exposed$vaxct_hpv52_oral[sex_exposed$HPV52_ORAL==1] = ifelse(sex_exposed$infection_hpv52_oral[sex_exposed$HPV52_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv52_oral_ego]==1 & randvax[sex_exposed$HPV52_ORAL==1]<=0.58, 1, ifelse(sex_exposed$infection_hpv52_oral[sex_exposed$HPV52_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv52_oral_ego]>=2 & randvax[sex_exposed$HPV52_ORAL==1]<=0.775, 1, 0))
          sex_exposed$partvaxct_hpv52_oral[sex_exposed$HPV52_ORAL==1] = ifelse(sex_exposed$partinfection_hpv52_oral[sex_exposed$HPV52_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv52_oral_partner]==1 & randvax[sex_exposed$HPV52_ORAL==1]<=0.58, 1, ifelse(sex_exposed$partinfection_hpv52_oral[sex_exposed$HPV52_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv52_oral_partner]>=2 & randvax[sex_exposed$HPV52_ORAL==1]<=0.775, 1, 0))
          sex_exposed$vaxct_hpv58_oral[sex_exposed$HPV58_ORAL==1] = ifelse(sex_exposed$infection_hpv58_oral[sex_exposed$HPV58_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv58_oral_ego]==1 & randvax[sex_exposed$HPV58_ORAL==1]<=0.58, 1, ifelse(sex_exposed$infection_hpv58_oral[sex_exposed$HPV58_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv58_oral_ego]>=2 & randvax[sex_exposed$HPV58_ORAL==1]<=0.775, 1, 0))
          sex_exposed$partvaxct_hpv58_oral[sex_exposed$HPV58_ORAL==1] = ifelse(sex_exposed$partinfection_hpv58_oral[sex_exposed$HPV58_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv58_oral_partner]==1 & randvax[sex_exposed$HPV58_ORAL==1]<=0.58, 1, ifelse(sex_exposed$partinfection_hpv58_oral[sex_exposed$HPV58_ORAL==1]>=1 & prep_sims[[current_data]]$HPVDOSES[exposed_hpv58_oral_partner]>=2 & randvax[sex_exposed$HPV58_ORAL==1]<=0.775, 1, 0))

          rm(randvax)
        }

        #resolve infection statistics, HIV
        sex_exposed$newHIV[sex_exposed$HIV==1] = ifelse((sex_exposed$condct_hiv[sex_exposed$HIV==1] + sex_exposed$prepct[sex_exposed$HIV==1] + sex_exposed$tapct[sex_exposed$HIV==1] + sex_exposed$seroct_hiv[sex_exposed$HIV==1])==0 & sex_exposed$infection_hiv[sex_exposed$HIV==1]==1, 1, sex_exposed$newHIV[sex_exposed$HIV==1])
        sex_exposed$newVL[sex_exposed$HIV==1] = ifelse((sex_exposed$condct_hiv[sex_exposed$HIV==1] + sex_exposed$prepct[sex_exposed$HIV==1] + sex_exposed$tapct[sex_exposed$HIV==1] + sex_exposed$seroct_hiv[sex_exposed$HIV==1])==0 & sex_exposed$infection_hiv[sex_exposed$HIV==1]==1, 2, sex_exposed$newVL[sex_exposed$HIV==1])
        sex_exposed$partnewHIV[sex_exposed$HIV==1] = ifelse((sex_exposed$partcondct_hiv[sex_exposed$HIV==1] + sex_exposed$partprepct[sex_exposed$HIV==1] + sex_exposed$parttapct[sex_exposed$HIV==1] + sex_exposed$partseroct_hiv[sex_exposed$HIV==1])==0 & sex_exposed$partinfection_hiv[sex_exposed$HIV==1]==1, 1, sex_exposed$partnewHIV[sex_exposed$HIV==1])
        sex_exposed$partnewVL[sex_exposed$HIV==1] = ifelse((sex_exposed$partcondct_hiv[sex_exposed$HIV==1] + sex_exposed$partprepct[sex_exposed$HIV==1] + sex_exposed$parttapct[sex_exposed$HIV==1] + sex_exposed$partseroct_hiv[sex_exposed$HIV==1])==0 & sex_exposed$partinfection_hiv[sex_exposed$HIV==1]==1, 2, sex_exposed$partnewVL[sex_exposed$HIV==1])
        
        #resolve infection statistics, HPV anal
        sex_exposed$prevct_hpv6_anal[sex_exposed$HPV6_ANAL==1] = ifelse((sex_exposed$condct_hpv6_anal[sex_exposed$HPV6_ANAL==1] + sex_exposed$seroct_hpv6[sex_exposed$HPV6_ANAL==1] + sex_exposed$vaxct_hpv6_anal[sex_exposed$HPV6_ANAL==1])>0 & sex_exposed$infection_hpv6_anal[sex_exposed$HPV6_ANAL==1]==1, 1, sex_exposed$prevct_hpv6_anal[sex_exposed$HPV6_ANAL==1])
        sex_exposed$partprevct_hpv6_anal[sex_exposed$HPV6_ANAL==1] = ifelse((sex_exposed$partcondct_hpv6_anal[sex_exposed$HPV6_ANAL==1] + sex_exposed$partseroct_hpv6[sex_exposed$HPV6_ANAL==1] + sex_exposed$partvaxct_hpv6_anal[sex_exposed$HPV6_ANAL==1])>0 & sex_exposed$partinfection_hpv6_anal[sex_exposed$HPV6_ANAL==1]==1, 1, sex_exposed$partprevct_hpv6_anal[sex_exposed$HPV6_ANAL==1])
        sex_exposed$prevct_hpv11_anal[sex_exposed$HPV11_ANAL==1] = ifelse((sex_exposed$condct_hpv11_anal[sex_exposed$HPV11_ANAL==1] + sex_exposed$seroct_hpv11[sex_exposed$HPV11_ANAL==1] + sex_exposed$vaxct_hpv11_anal[sex_exposed$HPV11_ANAL==1])>0 & sex_exposed$infection_hpv11_anal[sex_exposed$HPV11_ANAL==1]==1, 1, sex_exposed$prevct_hpv11_anal[sex_exposed$HPV11_ANAL==1])
        sex_exposed$partprevct_hpv11_anal[sex_exposed$HPV11_ANAL==1] = ifelse((sex_exposed$partcondct_hpv11_anal[sex_exposed$HPV11_ANAL==1] + sex_exposed$partseroct_hpv11[sex_exposed$HPV11_ANAL==1] + sex_exposed$partvaxct_hpv11_anal[sex_exposed$HPV11_ANAL==1])>0 & sex_exposed$partinfection_hpv11_anal[sex_exposed$HPV11_ANAL==1]==1, 1, sex_exposed$partprevct_hpv11_anal[sex_exposed$HPV11_ANAL==1])
        sex_exposed$prevct_hpv16_anal[sex_exposed$HPV16_ANAL==1] = ifelse((sex_exposed$condct_hpv16_anal[sex_exposed$HPV16_ANAL==1] + sex_exposed$seroct_hpv16[sex_exposed$HPV16_ANAL==1] + sex_exposed$vaxct_hpv16_anal[sex_exposed$HPV16_ANAL==1])>0 & sex_exposed$infection_hpv16_anal[sex_exposed$HPV16_ANAL==1]==1, 1, sex_exposed$prevct_hpv16_anal[sex_exposed$HPV16_ANAL==1])
        sex_exposed$partprevct_hpv16_anal[sex_exposed$HPV16_ANAL==1] = ifelse((sex_exposed$partcondct_hpv16_anal[sex_exposed$HPV16_ANAL==1] + sex_exposed$partseroct_hpv16[sex_exposed$HPV16_ANAL==1] + sex_exposed$partvaxct_hpv16_anal[sex_exposed$HPV16_ANAL==1])>0 & sex_exposed$partinfection_hpv16_anal[sex_exposed$HPV16_ANAL==1]==1, 1, sex_exposed$partprevct_hpv16_anal[sex_exposed$HPV16_ANAL==1])
        sex_exposed$prevct_hpv18_anal[sex_exposed$HPV18_ANAL==1] = ifelse((sex_exposed$condct_hpv18_anal[sex_exposed$HPV18_ANAL==1] + sex_exposed$seroct_hpv18[sex_exposed$HPV18_ANAL==1] + sex_exposed$vaxct_hpv18_anal[sex_exposed$HPV18_ANAL==1])>0 & sex_exposed$infection_hpv18_anal[sex_exposed$HPV18_ANAL==1]==1, 1, sex_exposed$prevct_hpv18_anal[sex_exposed$HPV18_ANAL==1])
        sex_exposed$partprevct_hpv18_anal[sex_exposed$HPV18_ANAL==1] = ifelse((sex_exposed$partcondct_hpv18_anal[sex_exposed$HPV18_ANAL==1] + sex_exposed$partseroct_hpv18[sex_exposed$HPV18_ANAL==1] + sex_exposed$partvaxct_hpv18_anal[sex_exposed$HPV18_ANAL==1])>0 & sex_exposed$partinfection_hpv18_anal[sex_exposed$HPV18_ANAL==1]==1, 1, sex_exposed$partprevct_hpv18_anal[sex_exposed$HPV18_ANAL==1])
        sex_exposed$prevct_hpv31_anal[sex_exposed$HPV31_ANAL==1] = ifelse((sex_exposed$condct_hpv31_anal[sex_exposed$HPV31_ANAL==1] + sex_exposed$seroct_hpv31[sex_exposed$HPV31_ANAL==1] + sex_exposed$vaxct_hpv31_anal[sex_exposed$HPV31_ANAL==1])>0 & sex_exposed$infection_hpv31_anal[sex_exposed$HPV31_ANAL==1]==1, 1, sex_exposed$prevct_hpv31_anal[sex_exposed$HPV31_ANAL==1])
        sex_exposed$partprevct_hpv31_anal[sex_exposed$HPV31_ANAL==1] = ifelse((sex_exposed$partcondct_hpv31_anal[sex_exposed$HPV31_ANAL==1] + sex_exposed$partseroct_hpv31[sex_exposed$HPV31_ANAL==1] + sex_exposed$partvaxct_hpv31_anal[sex_exposed$HPV31_ANAL==1])>0 & sex_exposed$partinfection_hpv31_anal[sex_exposed$HPV31_ANAL==1]==1, 1, sex_exposed$partprevct_hpv31_anal[sex_exposed$HPV31_ANAL==1])
        sex_exposed$prevct_hpv33_anal[sex_exposed$HPV33_ANAL==1] = ifelse((sex_exposed$condct_hpv33_anal[sex_exposed$HPV33_ANAL==1] + sex_exposed$seroct_hpv33[sex_exposed$HPV33_ANAL==1] + sex_exposed$vaxct_hpv33_anal[sex_exposed$HPV33_ANAL==1])>0 & sex_exposed$infection_hpv33_anal[sex_exposed$HPV33_ANAL==1]==1, 1, sex_exposed$prevct_hpv33_anal[sex_exposed$HPV33_ANAL==1])
        sex_exposed$partprevct_hpv33_anal[sex_exposed$HPV33_ANAL==1] = ifelse((sex_exposed$partcondct_hpv33_anal[sex_exposed$HPV33_ANAL==1] + sex_exposed$partseroct_hpv33[sex_exposed$HPV33_ANAL==1] + sex_exposed$partvaxct_hpv33_anal[sex_exposed$HPV33_ANAL==1])>0 & sex_exposed$partinfection_hpv33_anal[sex_exposed$HPV33_ANAL==1]==1, 1, sex_exposed$partprevct_hpv33_anal[sex_exposed$HPV33_ANAL==1])
        sex_exposed$prevct_hpv45_anal[sex_exposed$HPV45_ANAL==1] = ifelse((sex_exposed$condct_hpv45_anal[sex_exposed$HPV45_ANAL==1] + sex_exposed$seroct_hpv45[sex_exposed$HPV45_ANAL==1] + sex_exposed$vaxct_hpv45_anal[sex_exposed$HPV45_ANAL==1])>0 & sex_exposed$infection_hpv45_anal[sex_exposed$HPV45_ANAL==1]==1, 1, sex_exposed$prevct_hpv45_anal[sex_exposed$HPV45_ANAL==1])
        sex_exposed$partprevct_hpv45_anal[sex_exposed$HPV45_ANAL==1] = ifelse((sex_exposed$partcondct_hpv45_anal[sex_exposed$HPV45_ANAL==1] + sex_exposed$partseroct_hpv45[sex_exposed$HPV45_ANAL==1] + sex_exposed$partvaxct_hpv45_anal[sex_exposed$HPV45_ANAL==1])>0 & sex_exposed$partinfection_hpv45_anal[sex_exposed$HPV45_ANAL==1]==1, 1, sex_exposed$partprevct_hpv45_anal[sex_exposed$HPV45_ANAL==1])
        sex_exposed$prevct_hpv52_anal[sex_exposed$HPV52_ANAL==1] = ifelse((sex_exposed$condct_hpv52_anal[sex_exposed$HPV52_ANAL==1] + sex_exposed$seroct_hpv52[sex_exposed$HPV52_ANAL==1] + sex_exposed$vaxct_hpv52_anal[sex_exposed$HPV52_ANAL==1])>0 & sex_exposed$infection_hpv52_anal[sex_exposed$HPV52_ANAL==1]==1, 1, sex_exposed$prevct_hpv52_anal[sex_exposed$HPV52_ANAL==1])
        sex_exposed$partprevct_hpv52_anal[sex_exposed$HPV52_ANAL==1] = ifelse((sex_exposed$partcondct_hpv52_anal[sex_exposed$HPV52_ANAL==1] + sex_exposed$partseroct_hpv52[sex_exposed$HPV52_ANAL==1] + sex_exposed$partvaxct_hpv52_anal[sex_exposed$HPV52_ANAL==1])>0 & sex_exposed$partinfection_hpv52_anal[sex_exposed$HPV52_ANAL==1]==1, 1, sex_exposed$partprevct_hpv52_anal[sex_exposed$HPV52_ANAL==1])
        sex_exposed$prevct_hpv58_anal[sex_exposed$HPV58_ANAL==1] = ifelse((sex_exposed$condct_hpv58_anal[sex_exposed$HPV58_ANAL==1] + sex_exposed$seroct_hpv58[sex_exposed$HPV58_ANAL==1] + sex_exposed$vaxct_hpv58_anal[sex_exposed$HPV58_ANAL==1])>0 & sex_exposed$infection_hpv58_anal[sex_exposed$HPV58_ANAL==1]==1, 1, sex_exposed$prevct_hpv58_anal[sex_exposed$HPV58_ANAL==1])
        sex_exposed$partprevct_hpv58_anal[sex_exposed$HPV58_ANAL==1] = ifelse((sex_exposed$partcondct_hpv58_anal[sex_exposed$HPV58_ANAL==1] + sex_exposed$partseroct_hpv58[sex_exposed$HPV58_ANAL==1] + sex_exposed$partvaxct_hpv58_anal[sex_exposed$HPV58_ANAL==1])>0 & sex_exposed$partinfection_hpv58_anal[sex_exposed$HPV58_ANAL==1]==1, 1, sex_exposed$partprevct_hpv58_anal[sex_exposed$HPV58_ANAL==1])
        sex_exposed$newHPV6_ANAL[sex_exposed$HPV6_ANAL==1] = ifelse((sex_exposed$condct_hpv6_anal[sex_exposed$HPV6_ANAL==1] + sex_exposed$seroct_hpv6[sex_exposed$HPV6_ANAL==1] + sex_exposed$vaxct_hpv6_anal[sex_exposed$HPV6_ANAL==1])==0 & sex_exposed$infection_hpv6_anal[sex_exposed$HPV6_ANAL==1]==1, 1, sex_exposed$newHPV6_ANAL[sex_exposed$HPV6_ANAL==1])
        sex_exposed$partnewHPV6_ANAL[sex_exposed$HPV6_ANAL==1] = ifelse((sex_exposed$partcondct_hpv6_anal[sex_exposed$HPV6_ANAL==1] + sex_exposed$partseroct_hpv6[sex_exposed$HPV6_ANAL==1] + sex_exposed$partvaxct_hpv6_anal[sex_exposed$HPV6_ANAL==1])==0 & sex_exposed$partinfection_hpv6_anal[sex_exposed$HPV6_ANAL==1]==1, 1, sex_exposed$partnewHPV6_ANAL[sex_exposed$HPV6_ANAL==1])
        sex_exposed$newHPV11_ANAL[sex_exposed$HPV11_ANAL==1] = ifelse((sex_exposed$condct_hpv11_anal[sex_exposed$HPV11_ANAL==1] + sex_exposed$seroct_hpv11[sex_exposed$HPV11_ANAL==1] + sex_exposed$vaxct_hpv11_anal[sex_exposed$HPV11_ANAL==1])==0 & sex_exposed$infection_hpv11_anal[sex_exposed$HPV11_ANAL==1]==1, 1, sex_exposed$newHPV11_ANAL[sex_exposed$HPV11_ANAL==1])
        sex_exposed$partnewHPV11_ANAL[sex_exposed$HPV11_ANAL==1] = ifelse((sex_exposed$partcondct_hpv11_anal[sex_exposed$HPV11_ANAL==1] + sex_exposed$partseroct_hpv11[sex_exposed$HPV11_ANAL==1] + sex_exposed$partvaxct_hpv11_anal[sex_exposed$HPV11_ANAL==1])==0 & sex_exposed$partinfection_hpv11_anal[sex_exposed$HPV11_ANAL==1]==1, 1, sex_exposed$partnewHPV11_ANAL[sex_exposed$HPV11_ANAL==1])
        sex_exposed$newHPV16_ANAL[sex_exposed$HPV16_ANAL==1] = ifelse((sex_exposed$condct_hpv16_anal[sex_exposed$HPV16_ANAL==1] + sex_exposed$seroct_hpv16[sex_exposed$HPV16_ANAL==1] + sex_exposed$vaxct_hpv16_anal[sex_exposed$HPV16_ANAL==1])==0 & sex_exposed$infection_hpv16_anal[sex_exposed$HPV16_ANAL==1]==1, 1, sex_exposed$newHPV16_ANAL[sex_exposed$HPV16_ANAL==1])
        sex_exposed$partnewHPV16_ANAL[sex_exposed$HPV16_ANAL==1] = ifelse((sex_exposed$partcondct_hpv16_anal[sex_exposed$HPV16_ANAL==1] + sex_exposed$partseroct_hpv16[sex_exposed$HPV16_ANAL==1] + sex_exposed$partvaxct_hpv16_anal[sex_exposed$HPV16_ANAL==1])==0 & sex_exposed$partinfection_hpv16_anal[sex_exposed$HPV16_ANAL==1]==1, 1, sex_exposed$partnewHPV16_ANAL[sex_exposed$HPV16_ANAL==1])
        sex_exposed$newHPV18_ANAL[sex_exposed$HPV18_ANAL==1] = ifelse((sex_exposed$condct_hpv18_anal[sex_exposed$HPV18_ANAL==1] + sex_exposed$seroct_hpv18[sex_exposed$HPV18_ANAL==1] + sex_exposed$vaxct_hpv18_anal[sex_exposed$HPV18_ANAL==1])==0 & sex_exposed$infection_hpv18_anal[sex_exposed$HPV18_ANAL==1]==1, 1, sex_exposed$newHPV18_ANAL[sex_exposed$HPV18_ANAL==1])
        sex_exposed$partnewHPV18_ANAL[sex_exposed$HPV18_ANAL==1] = ifelse((sex_exposed$partcondct_hpv18_anal[sex_exposed$HPV18_ANAL==1] + sex_exposed$partseroct_hpv18[sex_exposed$HPV18_ANAL==1] + sex_exposed$partvaxct_hpv18_anal[sex_exposed$HPV18_ANAL==1])==0 & sex_exposed$partinfection_hpv18_anal[sex_exposed$HPV18_ANAL==1]==1, 1, sex_exposed$partnewHPV18_ANAL[sex_exposed$HPV18_ANAL==1])
        sex_exposed$newHPV31_ANAL[sex_exposed$HPV31_ANAL==1] = ifelse((sex_exposed$condct_hpv31_anal[sex_exposed$HPV31_ANAL==1] + sex_exposed$seroct_hpv31[sex_exposed$HPV31_ANAL==1] + sex_exposed$vaxct_hpv31_anal[sex_exposed$HPV31_ANAL==1])==0 & sex_exposed$infection_hpv31_anal[sex_exposed$HPV31_ANAL==1]==1, 1, sex_exposed$newHPV31_ANAL[sex_exposed$HPV31_ANAL==1])
        sex_exposed$partnewHPV31_ANAL[sex_exposed$HPV31_ANAL==1] = ifelse((sex_exposed$partcondct_hpv31_anal[sex_exposed$HPV31_ANAL==1] + sex_exposed$partseroct_hpv31[sex_exposed$HPV31_ANAL==1] + sex_exposed$partvaxct_hpv31_anal[sex_exposed$HPV31_ANAL==1])==0 & sex_exposed$partinfection_hpv31_anal[sex_exposed$HPV31_ANAL==1]==1, 1, sex_exposed$partnewHPV31_ANAL[sex_exposed$HPV31_ANAL==1])
        sex_exposed$newHPV33_ANAL[sex_exposed$HPV33_ANAL==1] = ifelse((sex_exposed$condct_hpv33_anal[sex_exposed$HPV33_ANAL==1] + sex_exposed$seroct_hpv33[sex_exposed$HPV33_ANAL==1] + sex_exposed$vaxct_hpv33_anal[sex_exposed$HPV33_ANAL==1])==0 & sex_exposed$infection_hpv33_anal[sex_exposed$HPV33_ANAL==1]==1, 1, sex_exposed$newHPV33_ANAL[sex_exposed$HPV33_ANAL==1])
        sex_exposed$partnewHPV33_ANAL[sex_exposed$HPV33_ANAL==1] = ifelse((sex_exposed$partcondct_hpv33_anal[sex_exposed$HPV33_ANAL==1] + sex_exposed$partseroct_hpv33[sex_exposed$HPV33_ANAL==1] + sex_exposed$partvaxct_hpv33_anal[sex_exposed$HPV33_ANAL==1])==0 & sex_exposed$partinfection_hpv33_anal[sex_exposed$HPV33_ANAL==1]==1, 1, sex_exposed$partnewHPV33_ANAL[sex_exposed$HPV33_ANAL==1])
        sex_exposed$newHPV45_ANAL[sex_exposed$HPV45_ANAL==1] = ifelse((sex_exposed$condct_hpv45_anal[sex_exposed$HPV45_ANAL==1] + sex_exposed$seroct_hpv45[sex_exposed$HPV45_ANAL==1] + sex_exposed$vaxct_hpv45_anal[sex_exposed$HPV45_ANAL==1])==0 & sex_exposed$infection_hpv45_anal[sex_exposed$HPV45_ANAL==1]==1, 1, sex_exposed$newHPV45_ANAL[sex_exposed$HPV45_ANAL==1])
        sex_exposed$partnewHPV45_ANAL[sex_exposed$HPV45_ANAL==1] = ifelse((sex_exposed$partcondct_hpv45_anal[sex_exposed$HPV45_ANAL==1] + sex_exposed$partseroct_hpv45[sex_exposed$HPV45_ANAL==1] + sex_exposed$partvaxct_hpv45_anal[sex_exposed$HPV45_ANAL==1])==0 & sex_exposed$partinfection_hpv45_anal[sex_exposed$HPV45_ANAL==1]==1, 1, sex_exposed$partnewHPV45_ANAL[sex_exposed$HPV45_ANAL==1])
        sex_exposed$newHPV52_ANAL[sex_exposed$HPV52_ANAL==1] = ifelse((sex_exposed$condct_hpv52_anal[sex_exposed$HPV52_ANAL==1] + sex_exposed$seroct_hpv52[sex_exposed$HPV52_ANAL==1] + sex_exposed$vaxct_hpv52_anal[sex_exposed$HPV52_ANAL==1])==0 & sex_exposed$infection_hpv52_anal[sex_exposed$HPV52_ANAL==1]==1, 1, sex_exposed$newHPV52_ANAL[sex_exposed$HPV52_ANAL==1])
        sex_exposed$partnewHPV52_ANAL[sex_exposed$HPV52_ANAL==1] = ifelse((sex_exposed$partcondct_hpv52_anal[sex_exposed$HPV52_ANAL==1] + sex_exposed$partseroct_hpv52[sex_exposed$HPV52_ANAL==1] + sex_exposed$partvaxct_hpv52_anal[sex_exposed$HPV52_ANAL==1])==0 & sex_exposed$partinfection_hpv52_anal[sex_exposed$HPV52_ANAL==1]==1, 1, sex_exposed$partnewHPV52_ANAL[sex_exposed$HPV52_ANAL==1])
        sex_exposed$newHPV58_ANAL[sex_exposed$HPV58_ANAL==1] = ifelse((sex_exposed$condct_hpv58_anal[sex_exposed$HPV58_ANAL==1] + sex_exposed$seroct_hpv58[sex_exposed$HPV58_ANAL==1] + sex_exposed$vaxct_hpv58_anal[sex_exposed$HPV58_ANAL==1])==0 & sex_exposed$infection_hpv58_anal[sex_exposed$HPV58_ANAL==1]==1, 1, sex_exposed$newHPV58_ANAL[sex_exposed$HPV58_ANAL==1])
        sex_exposed$partnewHPV58_ANAL[sex_exposed$HPV58_ANAL==1] = ifelse((sex_exposed$partcondct_hpv58_anal[sex_exposed$HPV58_ANAL==1] + sex_exposed$partseroct_hpv58[sex_exposed$HPV58_ANAL==1] + sex_exposed$partvaxct_hpv58_anal[sex_exposed$HPV58_ANAL==1])==0 & sex_exposed$partinfection_hpv58_anal[sex_exposed$HPV58_ANAL==1]==1, 1, sex_exposed$partnewHPV58_ANAL[sex_exposed$HPV58_ANAL==1])
        #sex_exposed$prevct[sex_exposed$HPV_ANAL==1] = ifelse((sex_exposed$condct_hpv_anal[sex_exposed$HPV_ANAL==1] + sex_exposed$seroct_hpv[sex_exposed$HPV_ANAL==1] + sex_exposed$vaxct_hpv_anal[sex_exposed$HPV_ANAL==1])>0 & sex_exposed$infection_hpv_anal[sex_exposed$HPV_ANAL==1]==1, 1, sex_exposed$prevct[sex_exposed$HPV_ANAL==1])
        #sex_exposed$partprevct[sex_exposed$HPV_ANAL==1] = ifelse((sex_exposed$partcondct_hpv_anal[sex_exposed$HPV_ANAL==1] + sex_exposed$partseroct_hpv[sex_exposed$HPV_ANAL==1] + sex_exposed$partvaxct_hpv_anal[sex_exposed$HPV_ANAL==1])>0 & sex_exposed$partinfection_hpv_anal[sex_exposed$HPV_ANAL==1]==1, 1, sex_exposed$partprevct[sex_exposed$HPV_ANAL==1])
        #sex_exposed$newHPV_ANAL[sex_exposed$HPV_ANAL==1] = ifelse((sex_exposed$condct_hpv_anal[sex_exposed$HPV_ANAL==1] + sex_exposed$seroct_hpv[sex_exposed$HPV_ANAL==1] + sex_exposed$vaxct_hpv_anal[sex_exposed$HPV_ANAL==1])==0 & sex_exposed$infection_hpv_anal[sex_exposed$HPV_ANAL==1]==1, 1, sex_exposed$newHPV_ANAL[sex_exposed$HPV_ANAL==1])
        #sex_exposed$partnewHPV_ANAL[sex_exposed$HPV_ANAL==1] = ifelse((sex_exposed$partcondct_hpv_anal[sex_exposed$HPV_ANAL==1] + sex_exposed$partseroct_hpv[sex_exposed$HPV_ANAL==1] + sex_exposed$partvaxct_hpv_anal[sex_exposed$HPV_ANAL==1])==0 & sex_exposed$partinfection_hpv_anal[sex_exposed$HPV_ANAL==1]==1, 1, sex_exposed$partnewHPV_ANAL[sex_exposed$HPV_ANAL==1])
        #sex_exposed$partinfectct[sex_exposed$HPV_ANAL==1] = ifelse((sex_exposed$condct_hpv_anal[sex_exposed$HPV_ANAL==1] + sex_exposed$seroct_hpv[sex_exposed$HPV_ANAL==1] + sex_exposed$vaxct_hpv_anal[sex_exposed$HPV_ANAL==1])==0 & sex_exposed$infection_hpv_anal[sex_exposed$HPV_ANAL==1]==1, 1, sex_exposed$partinfectct[sex_exposed$HPV_ANAL==1])
        #sex_exposed$infectct[sex_exposed$HPV_ANAL==1] = ifelse((sex_exposed$partcondct_hpv_anal[sex_exposed$HPV_ANAL==1] + sex_exposed$partseroct_hpv[sex_exposed$HPV_ANAL==1] + sex_exposed$partvaxct_hpv_anal[sex_exposed$HPV_ANAL==1])==0 & sex_exposed$partinfection_hpv_anal[sex_exposed$HPV_ANAL==1]==1, 1, sex_exposed$infectct[sex_exposed$HPV_ANAL==1])
        
        #resolve infection statistics, HPV oral
        sex_exposed$prevct_hpv6_oral[sex_exposed$HPV6_ORAL==1] = ifelse((sex_exposed$condct_hpv6_oral[sex_exposed$HPV6_ORAL==1] + sex_exposed$vaxct_hpv6_oral[sex_exposed$HPV6_ORAL==1])>0 & sex_exposed$infection_hpv6_oral[sex_exposed$HPV6_ORAL==1]>=1, 1, sex_exposed$prevct_hpv6_oral[sex_exposed$HPV6_ORAL==1])
        sex_exposed$partprevct_hpv6_oral[sex_exposed$HPV6_ORAL==1] = ifelse((sex_exposed$partcondct_hpv6_oral[sex_exposed$HPV6_ORAL==1] + sex_exposed$partvaxct_hpv6_oral[sex_exposed$HPV6_ORAL==1])>0 & sex_exposed$partinfection_hpv6_oral[sex_exposed$HPV6_ORAL==1]>=1, 1, sex_exposed$partprevct_hpv6_oral[sex_exposed$HPV6_ORAL==1])
        sex_exposed$prevct_hpv11_oral[sex_exposed$HPV11_ORAL==1] = ifelse((sex_exposed$condct_hpv11_oral[sex_exposed$HPV11_ORAL==1] + sex_exposed$vaxct_hpv11_oral[sex_exposed$HPV11_ORAL==1])>0 & sex_exposed$infection_hpv11_oral[sex_exposed$HPV11_ORAL==1]>=1, 1, sex_exposed$prevct_hpv11_oral[sex_exposed$HPV11_ORAL==1])
        sex_exposed$partprevct_hpv11_oral[sex_exposed$HPV11_ORAL==1] = ifelse((sex_exposed$partcondct_hpv11_oral[sex_exposed$HPV11_ORAL==1] + sex_exposed$partvaxct_hpv11_oral[sex_exposed$HPV11_ORAL==1])>0 & sex_exposed$partinfection_hpv11_oral[sex_exposed$HPV11_ORAL==1]>=1, 1, sex_exposed$partprevct_hpv11_oral[sex_exposed$HPV11_ORAL==1])
        sex_exposed$prevct_hpv16_oral[sex_exposed$HPV16_ORAL==1] = ifelse((sex_exposed$condct_hpv16_oral[sex_exposed$HPV16_ORAL==1] + sex_exposed$vaxct_hpv16_oral[sex_exposed$HPV16_ORAL==1])>0 & sex_exposed$infection_hpv16_oral[sex_exposed$HPV16_ORAL==1]>=1, 1, sex_exposed$prevct_hpv16_oral[sex_exposed$HPV16_ORAL==1])
        sex_exposed$partprevct_hpv16_oral[sex_exposed$HPV16_ORAL==1] = ifelse((sex_exposed$partcondct_hpv16_oral[sex_exposed$HPV16_ORAL==1] + sex_exposed$partvaxct_hpv16_oral[sex_exposed$HPV16_ORAL==1])>0 & sex_exposed$partinfection_hpv16_oral[sex_exposed$HPV16_ORAL==1]>=1, 1, sex_exposed$partprevct_hpv16_oral[sex_exposed$HPV16_ORAL==1])
        sex_exposed$prevct_hpv18_oral[sex_exposed$HPV18_ORAL==1] = ifelse((sex_exposed$condct_hpv18_oral[sex_exposed$HPV18_ORAL==1] + sex_exposed$vaxct_hpv18_oral[sex_exposed$HPV18_ORAL==1])>0 & sex_exposed$infection_hpv18_oral[sex_exposed$HPV18_ORAL==1]>=1, 1, sex_exposed$prevct_hpv18_oral[sex_exposed$HPV18_ORAL==1])
        sex_exposed$partprevct_hpv18_oral[sex_exposed$HPV18_ORAL==1] = ifelse((sex_exposed$partcondct_hpv18_oral[sex_exposed$HPV18_ORAL==1] + sex_exposed$partvaxct_hpv18_oral[sex_exposed$HPV18_ORAL==1])>0 & sex_exposed$partinfection_hpv18_oral[sex_exposed$HPV18_ORAL==1]>=1, 1, sex_exposed$partprevct_hpv18_oral[sex_exposed$HPV18_ORAL==1])
        sex_exposed$prevct_hpv31_oral[sex_exposed$HPV31_ORAL==1] = ifelse((sex_exposed$condct_hpv31_oral[sex_exposed$HPV31_ORAL==1] + sex_exposed$vaxct_hpv31_oral[sex_exposed$HPV31_ORAL==1])>0 & sex_exposed$infection_hpv31_oral[sex_exposed$HPV31_ORAL==1]>=1, 1, sex_exposed$prevct_hpv31_oral[sex_exposed$HPV31_ORAL==1])
        sex_exposed$partprevct_hpv31_oral[sex_exposed$HPV31_ORAL==1] = ifelse((sex_exposed$partcondct_hpv31_oral[sex_exposed$HPV31_ORAL==1] + sex_exposed$partvaxct_hpv31_oral[sex_exposed$HPV31_ORAL==1])>0 & sex_exposed$partinfection_hpv31_oral[sex_exposed$HPV31_ORAL==1]>=1, 1, sex_exposed$partprevct_hpv31_oral[sex_exposed$HPV31_ORAL==1])
        sex_exposed$prevct_hpv33_oral[sex_exposed$HPV33_ORAL==1] = ifelse((sex_exposed$condct_hpv33_oral[sex_exposed$HPV33_ORAL==1] + sex_exposed$vaxct_hpv33_oral[sex_exposed$HPV33_ORAL==1])>0 & sex_exposed$infection_hpv33_oral[sex_exposed$HPV33_ORAL==1]>=1, 1, sex_exposed$prevct_hpv33_oral[sex_exposed$HPV33_ORAL==1])
        sex_exposed$partprevct_hpv33_oral[sex_exposed$HPV33_ORAL==1] = ifelse((sex_exposed$partcondct_hpv33_oral[sex_exposed$HPV33_ORAL==1] + sex_exposed$partvaxct_hpv33_oral[sex_exposed$HPV33_ORAL==1])>0 & sex_exposed$partinfection_hpv33_oral[sex_exposed$HPV33_ORAL==1]>=1, 1, sex_exposed$partprevct_hpv33_oral[sex_exposed$HPV33_ORAL==1])
        sex_exposed$prevct_hpv45_oral[sex_exposed$HPV45_ORAL==1] = ifelse((sex_exposed$condct_hpv45_oral[sex_exposed$HPV45_ORAL==1] + sex_exposed$vaxct_hpv45_oral[sex_exposed$HPV45_ORAL==1])>0 & sex_exposed$infection_hpv45_oral[sex_exposed$HPV45_ORAL==1]>=1, 1, sex_exposed$prevct_hpv45_oral[sex_exposed$HPV45_ORAL==1])
        sex_exposed$partprevct_hpv45_oral[sex_exposed$HPV45_ORAL==1] = ifelse((sex_exposed$partcondct_hpv45_oral[sex_exposed$HPV45_ORAL==1] + sex_exposed$partvaxct_hpv45_oral[sex_exposed$HPV45_ORAL==1])>0 & sex_exposed$partinfection_hpv45_oral[sex_exposed$HPV45_ORAL==1]>=1, 1, sex_exposed$partprevct_hpv45_oral[sex_exposed$HPV45_ORAL==1])
        sex_exposed$prevct_hpv52_oral[sex_exposed$HPV52_ORAL==1] = ifelse((sex_exposed$condct_hpv52_oral[sex_exposed$HPV52_ORAL==1] + sex_exposed$vaxct_hpv52_oral[sex_exposed$HPV52_ORAL==1])>0 & sex_exposed$infection_hpv52_oral[sex_exposed$HPV52_ORAL==1]>=1, 1, sex_exposed$prevct_hpv52_oral[sex_exposed$HPV52_ORAL==1])
        sex_exposed$partprevct_hpv52_oral[sex_exposed$HPV52_ORAL==1] = ifelse((sex_exposed$partcondct_hpv52_oral[sex_exposed$HPV52_ORAL==1] + sex_exposed$partvaxct_hpv52_oral[sex_exposed$HPV52_ORAL==1])>0 & sex_exposed$partinfection_hpv52_oral[sex_exposed$HPV52_ORAL==1]>=1, 1, sex_exposed$partprevct_hpv52_oral[sex_exposed$HPV52_ORAL==1])
        sex_exposed$prevct_hpv58_oral[sex_exposed$HPV58_ORAL==1] = ifelse((sex_exposed$condct_hpv58_oral[sex_exposed$HPV58_ORAL==1] + sex_exposed$vaxct_hpv58_oral[sex_exposed$HPV58_ORAL==1])>0 & sex_exposed$infection_hpv58_oral[sex_exposed$HPV58_ORAL==1]>=1, 1, sex_exposed$prevct_hpv58_oral[sex_exposed$HPV58_ORAL==1])
        sex_exposed$partprevct_hpv58_oral[sex_exposed$HPV58_ORAL==1] = ifelse((sex_exposed$partcondct_hpv58_oral[sex_exposed$HPV58_ORAL==1] + sex_exposed$partvaxct_hpv58_oral[sex_exposed$HPV58_ORAL==1])>0 & sex_exposed$partinfection_hpv58_oral[sex_exposed$HPV58_ORAL==1]>=1, 1, sex_exposed$partprevct_hpv58_oral[sex_exposed$HPV58_ORAL==1])
        sex_exposed$newHPV6_ORAL[sex_exposed$HPV6_ORAL==1] = ifelse((sex_exposed$condct_hpv6_oral[sex_exposed$HPV6_ORAL==1] + sex_exposed$vaxct_hpv6_oral[sex_exposed$HPV6_ORAL==1])==0 & sex_exposed$infection_hpv6_oral[sex_exposed$HPV6_ORAL==1]>=1, sex_exposed$infection_hpv6_oral[sex_exposed$HPV6_ORAL==1], sex_exposed$newHPV6_ORAL[sex_exposed$HPV6_ORAL==1])
        sex_exposed$partnewHPV6_ORAL[sex_exposed$HPV6_ORAL==1] = ifelse((sex_exposed$partcondct_hpv6_oral[sex_exposed$HPV6_ORAL==1] + sex_exposed$partvaxct_hpv6_oral[sex_exposed$HPV6_ORAL==1])==0 & sex_exposed$partinfection_hpv6_oral[sex_exposed$HPV6_ORAL==1]>=1, sex_exposed$partinfection_hpv6_oral[sex_exposed$HPV6_ORAL==1], sex_exposed$partnewHPV6_ORAL[sex_exposed$HPV6_ORAL==1])
        sex_exposed$newHPV11_ORAL[sex_exposed$HPV11_ORAL==1] = ifelse((sex_exposed$condct_hpv11_oral[sex_exposed$HPV11_ORAL==1] + sex_exposed$vaxct_hpv11_oral[sex_exposed$HPV11_ORAL==1])==0 & sex_exposed$infection_hpv11_oral[sex_exposed$HPV11_ORAL==1]>=1, sex_exposed$infection_hpv11_oral[sex_exposed$HPV11_ORAL==1], sex_exposed$newHPV11_ORAL[sex_exposed$HPV11_ORAL==1])
        sex_exposed$partnewHPV11_ORAL[sex_exposed$HPV11_ORAL==1] = ifelse((sex_exposed$partcondct_hpv11_oral[sex_exposed$HPV11_ORAL==1] + sex_exposed$partvaxct_hpv11_oral[sex_exposed$HPV11_ORAL==1])==0 & sex_exposed$partinfection_hpv11_oral[sex_exposed$HPV11_ORAL==1]>=1, sex_exposed$partinfection_hpv11_oral[sex_exposed$HPV11_ORAL==1], sex_exposed$partnewHPV11_ORAL[sex_exposed$HPV11_ORAL==1])
        sex_exposed$newHPV16_ORAL[sex_exposed$HPV16_ORAL==1] = ifelse((sex_exposed$condct_hpv16_oral[sex_exposed$HPV16_ORAL==1] + sex_exposed$vaxct_hpv16_oral[sex_exposed$HPV16_ORAL==1])==0 & sex_exposed$infection_hpv16_oral[sex_exposed$HPV16_ORAL==1]>=1, sex_exposed$infection_hpv16_oral[sex_exposed$HPV16_ORAL==1], sex_exposed$newHPV16_ORAL[sex_exposed$HPV16_ORAL==1])
        sex_exposed$partnewHPV16_ORAL[sex_exposed$HPV16_ORAL==1] = ifelse((sex_exposed$partcondct_hpv16_oral[sex_exposed$HPV16_ORAL==1] + sex_exposed$partvaxct_hpv16_oral[sex_exposed$HPV16_ORAL==1])==0 & sex_exposed$partinfection_hpv16_oral[sex_exposed$HPV16_ORAL==1]>=1, sex_exposed$partinfection_hpv16_oral[sex_exposed$HPV16_ORAL==1], sex_exposed$partnewHPV16_ORAL[sex_exposed$HPV16_ORAL==1])
        sex_exposed$newHPV18_ORAL[sex_exposed$HPV18_ORAL==1] = ifelse((sex_exposed$condct_hpv18_oral[sex_exposed$HPV18_ORAL==1] + sex_exposed$vaxct_hpv18_oral[sex_exposed$HPV18_ORAL==1])==0 & sex_exposed$infection_hpv18_oral[sex_exposed$HPV18_ORAL==1]>=1, sex_exposed$infection_hpv18_oral[sex_exposed$HPV18_ORAL==1], sex_exposed$newHPV18_ORAL[sex_exposed$HPV18_ORAL==1])
        sex_exposed$partnewHPV18_ORAL[sex_exposed$HPV18_ORAL==1] = ifelse((sex_exposed$partcondct_hpv18_oral[sex_exposed$HPV18_ORAL==1] + sex_exposed$partvaxct_hpv18_oral[sex_exposed$HPV18_ORAL==1])==0 & sex_exposed$partinfection_hpv18_oral[sex_exposed$HPV18_ORAL==1]>=1, sex_exposed$partinfection_hpv18_oral[sex_exposed$HPV18_ORAL==1], sex_exposed$partnewHPV18_ORAL[sex_exposed$HPV18_ORAL==1])
        sex_exposed$newHPV31_ORAL[sex_exposed$HPV31_ORAL==1] = ifelse((sex_exposed$condct_hpv31_oral[sex_exposed$HPV31_ORAL==1] + sex_exposed$vaxct_hpv31_oral[sex_exposed$HPV31_ORAL==1])==0 & sex_exposed$infection_hpv31_oral[sex_exposed$HPV31_ORAL==1]>=1, sex_exposed$infection_hpv31_oral[sex_exposed$HPV31_ORAL==1], sex_exposed$newHPV31_ORAL[sex_exposed$HPV31_ORAL==1])
        sex_exposed$partnewHPV31_ORAL[sex_exposed$HPV31_ORAL==1] = ifelse((sex_exposed$partcondct_hpv31_oral[sex_exposed$HPV31_ORAL==1] + sex_exposed$partvaxct_hpv31_oral[sex_exposed$HPV31_ORAL==1])==0 & sex_exposed$partinfection_hpv31_oral[sex_exposed$HPV31_ORAL==1]>=1, sex_exposed$partinfection_hpv31_oral[sex_exposed$HPV31_ORAL==1], sex_exposed$partnewHPV31_ORAL[sex_exposed$HPV31_ORAL==1])
        sex_exposed$newHPV33_ORAL[sex_exposed$HPV33_ORAL==1] = ifelse((sex_exposed$condct_hpv33_oral[sex_exposed$HPV33_ORAL==1] + sex_exposed$vaxct_hpv33_oral[sex_exposed$HPV33_ORAL==1])==0 & sex_exposed$infection_hpv33_oral[sex_exposed$HPV33_ORAL==1]>=1, sex_exposed$infection_hpv33_oral[sex_exposed$HPV33_ORAL==1], sex_exposed$newHPV33_ORAL[sex_exposed$HPV33_ORAL==1])
        sex_exposed$partnewHPV33_ORAL[sex_exposed$HPV33_ORAL==1] = ifelse((sex_exposed$partcondct_hpv33_oral[sex_exposed$HPV33_ORAL==1] + sex_exposed$partvaxct_hpv33_oral[sex_exposed$HPV33_ORAL==1])==0 & sex_exposed$partinfection_hpv33_oral[sex_exposed$HPV33_ORAL==1]>=1, sex_exposed$partinfection_hpv33_oral[sex_exposed$HPV33_ORAL==1], sex_exposed$partnewHPV33_ORAL[sex_exposed$HPV33_ORAL==1])
        sex_exposed$newHPV45_ORAL[sex_exposed$HPV45_ORAL==1] = ifelse((sex_exposed$condct_hpv45_oral[sex_exposed$HPV45_ORAL==1] + sex_exposed$vaxct_hpv45_oral[sex_exposed$HPV45_ORAL==1])==0 & sex_exposed$infection_hpv45_oral[sex_exposed$HPV45_ORAL==1]>=1, sex_exposed$infection_hpv45_oral[sex_exposed$HPV45_ORAL==1], sex_exposed$newHPV45_ORAL[sex_exposed$HPV45_ORAL==1])
        sex_exposed$partnewHPV45_ORAL[sex_exposed$HPV45_ORAL==1] = ifelse((sex_exposed$partcondct_hpv45_oral[sex_exposed$HPV45_ORAL==1] + sex_exposed$partvaxct_hpv45_oral[sex_exposed$HPV45_ORAL==1])==0 & sex_exposed$partinfection_hpv45_oral[sex_exposed$HPV45_ORAL==1]>=1, sex_exposed$partinfection_hpv45_oral[sex_exposed$HPV45_ORAL==1], sex_exposed$partnewHPV45_ORAL[sex_exposed$HPV45_ORAL==1])
        sex_exposed$newHPV52_ORAL[sex_exposed$HPV52_ORAL==1] = ifelse((sex_exposed$condct_hpv52_oral[sex_exposed$HPV52_ORAL==1] + sex_exposed$vaxct_hpv52_oral[sex_exposed$HPV52_ORAL==1])==0 & sex_exposed$infection_hpv52_oral[sex_exposed$HPV52_ORAL==1]>=1, sex_exposed$infection_hpv52_oral[sex_exposed$HPV52_ORAL==1], sex_exposed$newHPV52_ORAL[sex_exposed$HPV52_ORAL==1])
        sex_exposed$partnewHPV52_ORAL[sex_exposed$HPV52_ORAL==1] = ifelse((sex_exposed$partcondct_hpv52_oral[sex_exposed$HPV52_ORAL==1] + sex_exposed$partvaxct_hpv52_oral[sex_exposed$HPV52_ORAL==1])==0 & sex_exposed$partinfection_hpv52_oral[sex_exposed$HPV52_ORAL==1]>=1, sex_exposed$partinfection_hpv52_oral[sex_exposed$HPV52_ORAL==1], sex_exposed$partnewHPV52_ORAL[sex_exposed$HPV52_ORAL==1])
        sex_exposed$newHPV58_ORAL[sex_exposed$HPV58_ORAL==1] = ifelse((sex_exposed$condct_hpv58_oral[sex_exposed$HPV58_ORAL==1] + sex_exposed$vaxct_hpv58_oral[sex_exposed$HPV58_ORAL==1])==0 & sex_exposed$infection_hpv58_oral[sex_exposed$HPV58_ORAL==1]>=1, sex_exposed$infection_hpv58_oral[sex_exposed$HPV58_ORAL==1], sex_exposed$newHPV58_ORAL[sex_exposed$HPV58_ORAL==1])
        sex_exposed$partnewHPV58_ORAL[sex_exposed$HPV58_ORAL==1] = ifelse((sex_exposed$partcondct_hpv58_oral[sex_exposed$HPV58_ORAL==1] + sex_exposed$partvaxct_hpv58_oral[sex_exposed$HPV58_ORAL==1])==0 & sex_exposed$partinfection_hpv58_oral[sex_exposed$HPV58_ORAL==1]>=1, sex_exposed$partinfection_hpv58_oral[sex_exposed$HPV58_ORAL==1], sex_exposed$partnewHPV58_ORAL[sex_exposed$HPV58_ORAL==1])
        
        ## UPDATE STATS IN MAIN DATASET ##
    
        #HIV
        #prep_sims[[current_data]]$PREP_PREVENT[exposed_hiv_ego] = prep_sims[[current_data]]$PREP_PREVENT[exposed_hiv_ego] + sex_exposed$prepct[sex_exposed$HIV==1]
        #prep_sims[[current_data]]$PREP_PREVENT[exposed_hiv_partner] = prep_sims[[current_data]]$PREP_PREVENT[exposed_hiv_partner] + sex_exposed$partprepct[sex_exposed$HIV==1]
        #prep_sims[[current_data]]$TAP_PREVENT[exposed_hpv_anal_ego] = prep_sims[[current_data]]$TAP_PREVENT[exposed_hpv_anal_ego] + sex_exposed$tapct[sex_exposed$HIV==1]
        #prep_sims[[current_data]]$TAP_PREVENT[exposed_hpv_anal_partner] = prep_sims[[current_data]]$TAP_PREVENT[exposed_hpv_anal_partner] + sex_exposed$parttapct[sex_exposed$HIV==1]
        #prep_sims[[current_data]]$CAUSE_INFECT[exposed_hiv_ego] = ifelse(sex_exposed$infectct[sex_exposed$HIV==1]==1, prep_sims[[current_data]]$CAUSE_INFECT[exposed_hiv_ego] + sex_exposed$infectct[sex_exposed$HIV==1], prep_sims[[current_data]]$CAUSE_INFECT[exposed_hiv_ego])
        #prep_sims[[current_data]]$CAUSE_INFECT[exposed_hiv_partner] = ifelse(sex_exposed$partinfectct[sex_exposed$HIV==1]==1, prep_sims[[current_data]]$CAUSE_INFECT[exposed_hiv_partner] + sex_exposed$partinfectct[sex_exposed$HIV==1], prep_sims[[current_data]]$CAUSE_INFECT[exposed_hiv_partner])
        prep_sims[[current_data]]$HIV[exposed_hiv_ego] = ifelse(sex_exposed$newHIV[sex_exposed$HIV==1]==1, 1, prep_sims[[current_data]]$HIV[exposed_hiv_ego])
        prep_sims[[current_data]]$HIV[exposed_hiv_partner] = ifelse(sex_exposed$partnewHIV[sex_exposed$HIV==1]==1, 1, prep_sims[[current_data]]$HIV[exposed_hiv_partner])
        prep_sims[[current_data]]$INCIDENT_DAYS_HIV[exposed_hiv_ego] = ifelse(sex_exposed$newHIV[sex_exposed$HIV==1]==1, 0, prep_sims[[current_data]]$INCIDENT_DAYS_HIV[exposed_hiv_ego])
        prep_sims[[current_data]]$INCIDENT_DAYS_HIV[exposed_hiv_partner] = ifelse(sex_exposed$partnewHIV[sex_exposed$HIV==1]==1, 0, prep_sims[[current_data]]$INCIDENT_DAYS_HIV[exposed_hiv_partner])
        prep_sims[[current_data]]$VL[exposed_hiv_ego] = ifelse(sex_exposed$newVL[sex_exposed$HIV==1]==2, 2, prep_sims[[current_data]]$VL[exposed_hiv_ego])
        prep_sims[[current_data]]$VL[exposed_hiv_partner] = ifelse(sex_exposed$partnewVL[sex_exposed$HIV==1]==2, 2, prep_sims[[current_data]]$VL[exposed_hiv_partner])
        #prep_sims[[current_data]]$DISCORDANT[exposed_hiv_ego] = prep_sims[[current_data]]$DISCORDANT[exposed_hiv_ego] + 1
        #prep_sims[[current_data]]$DISCORDANT[exposed_hiv_partner] = prep_sims[[current_data]]$DISCORDANT[exposed_hiv_partner] + 1

        #HPV anal
        prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv6_anal_ego] = prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv6_anal_ego] + sex_exposed$condct_hpv6_anal[sex_exposed$HPV6_ANAL==1]
        prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv6_anal_partner] = prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv6_anal_partner] + sex_exposed$partcondct_hpv6_anal[sex_exposed$HPV6_ANAL==1]
        prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv11_anal_ego] = prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv11_anal_ego] + sex_exposed$condct_hpv11_anal[sex_exposed$HPV11_ANAL==1]
        prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv11_anal_partner] = prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv11_anal_partner] + sex_exposed$partcondct_hpv11_anal[sex_exposed$HPV11_ANAL==1]
        prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv16_anal_ego] = prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv16_anal_ego] + sex_exposed$condct_hpv16_anal[sex_exposed$HPV16_ANAL==1]
        prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv16_anal_partner] = prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv16_anal_partner] + sex_exposed$partcondct_hpv16_anal[sex_exposed$HPV16_ANAL==1]
        prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv18_anal_ego] = prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv18_anal_ego] + sex_exposed$condct_hpv18_anal[sex_exposed$HPV18_ANAL==1]
        prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv18_anal_partner] = prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv18_anal_partner] + sex_exposed$partcondct_hpv18_anal[sex_exposed$HPV18_ANAL==1]
        prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv31_anal_ego] = prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv31_anal_ego] + sex_exposed$condct_hpv31_anal[sex_exposed$HPV31_ANAL==1]
        prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv31_anal_partner] = prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv31_anal_partner] + sex_exposed$partcondct_hpv31_anal[sex_exposed$HPV31_ANAL==1]
        prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv33_anal_ego] = prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv33_anal_ego] + sex_exposed$condct_hpv33_anal[sex_exposed$HPV33_ANAL==1]
        prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv33_anal_partner] = prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv33_anal_partner] + sex_exposed$partcondct_hpv33_anal[sex_exposed$HPV33_ANAL==1]
        prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv45_anal_ego] = prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv45_anal_ego] + sex_exposed$condct_hpv45_anal[sex_exposed$HPV45_ANAL==1]
        prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv45_anal_partner] = prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv45_anal_partner] + sex_exposed$partcondct_hpv45_anal[sex_exposed$HPV45_ANAL==1]
        prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv52_anal_ego] = prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv52_anal_ego] + sex_exposed$condct_hpv52_anal[sex_exposed$HPV52_ANAL==1]
        prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv52_anal_partner] = prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv52_anal_partner] + sex_exposed$partcondct_hpv52_anal[sex_exposed$HPV52_ANAL==1]
        prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv58_anal_ego] = prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv58_anal_ego] + sex_exposed$condct_hpv58_anal[sex_exposed$HPV58_ANAL==1]
        prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv58_anal_partner] = prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv58_anal_partner] + sex_exposed$partcondct_hpv58_anal[sex_exposed$HPV58_ANAL==1]
        prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv6_anal_ego] = prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv6_anal_ego] + sex_exposed$seroct_hpv6[sex_exposed$HPV6_ANAL==1]
        prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv6_anal_partner] = prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv6_anal_partner] + sex_exposed$partseroct_hpv6[sex_exposed$HPV6_ANAL==1]
        prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv11_anal_ego] = prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv11_anal_ego] + sex_exposed$seroct_hpv11[sex_exposed$HPV11_ANAL==1]
        prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv11_anal_partner] = prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv11_anal_partner] + sex_exposed$partseroct_hpv11[sex_exposed$HPV11_ANAL==1]
        prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv16_anal_ego] = prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv16_anal_ego] + sex_exposed$seroct_hpv16[sex_exposed$HPV16_ANAL==1]
        prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv16_anal_partner] = prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv16_anal_partner] + sex_exposed$partseroct_hpv16[sex_exposed$HPV16_ANAL==1]
        prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv18_anal_ego] = prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv18_anal_ego] + sex_exposed$seroct_hpv18[sex_exposed$HPV18_ANAL==1]
        prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv18_anal_partner] = prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv18_anal_partner] + sex_exposed$partseroct_hpv18[sex_exposed$HPV18_ANAL==1]
        prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv31_anal_ego] = prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv31_anal_ego] + sex_exposed$seroct_hpv31[sex_exposed$HPV31_ANAL==1]
        prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv31_anal_partner] = prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv31_anal_partner] + sex_exposed$partseroct_hpv31[sex_exposed$HPV31_ANAL==1]
        prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv33_anal_ego] = prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv33_anal_ego] + sex_exposed$seroct_hpv33[sex_exposed$HPV33_ANAL==1]
        prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv33_anal_partner] = prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv33_anal_partner] + sex_exposed$partseroct_hpv33[sex_exposed$HPV33_ANAL==1]
        prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv45_anal_ego] = prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv45_anal_ego] + sex_exposed$seroct_hpv45[sex_exposed$HPV45_ANAL==1]
        prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv45_anal_partner] = prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv45_anal_partner] + sex_exposed$partseroct_hpv45[sex_exposed$HPV45_ANAL==1]
        prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv52_anal_ego] = prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv52_anal_ego] + sex_exposed$seroct_hpv52[sex_exposed$HPV52_ANAL==1]
        prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv52_anal_partner] = prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv52_anal_partner] + sex_exposed$partseroct_hpv52[sex_exposed$HPV52_ANAL==1]
        prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv58_anal_ego] = prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv58_anal_ego] + sex_exposed$seroct_hpv58[sex_exposed$HPV58_ANAL==1]
        prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv58_anal_partner] = prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv58_anal_partner] + sex_exposed$partseroct_hpv58[sex_exposed$HPV58_ANAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv6_anal_ego] = prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv6_anal_ego] + sex_exposed$vaxct_hpv6_anal[sex_exposed$HPV6_ANAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv6_anal_partner] = prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv6_anal_partner] + sex_exposed$partvaxct_hpv6_anal[sex_exposed$HPV6_ANAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv11_anal_ego] = prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv11_anal_ego] + sex_exposed$vaxct_hpv11_anal[sex_exposed$HPV11_ANAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv11_anal_partner] = prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv11_anal_partner] + sex_exposed$partvaxct_hpv11_anal[sex_exposed$HPV11_ANAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv16_anal_ego] = prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv16_anal_ego] + sex_exposed$vaxct_hpv16_anal[sex_exposed$HPV16_ANAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv16_anal_partner] = prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv16_anal_partner] + sex_exposed$partvaxct_hpv16_anal[sex_exposed$HPV16_ANAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv18_anal_ego] = prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv18_anal_ego] + sex_exposed$vaxct_hpv18_anal[sex_exposed$HPV18_ANAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv18_anal_partner] = prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv18_anal_partner] + sex_exposed$partvaxct_hpv18_anal[sex_exposed$HPV18_ANAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv31_anal_ego] = prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv31_anal_ego] + sex_exposed$vaxct_hpv31_anal[sex_exposed$HPV31_ANAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv31_anal_partner] = prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv31_anal_partner] + sex_exposed$partvaxct_hpv31_anal[sex_exposed$HPV31_ANAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv33_anal_ego] = prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv33_anal_ego] + sex_exposed$vaxct_hpv33_anal[sex_exposed$HPV33_ANAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv33_anal_partner] = prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv33_anal_partner] + sex_exposed$partvaxct_hpv33_anal[sex_exposed$HPV33_ANAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv45_anal_ego] = prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv45_anal_ego] + sex_exposed$vaxct_hpv45_anal[sex_exposed$HPV45_ANAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv45_anal_partner] = prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv45_anal_partner] + sex_exposed$partvaxct_hpv45_anal[sex_exposed$HPV45_ANAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv52_anal_ego] = prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv52_anal_ego] + sex_exposed$vaxct_hpv52_anal[sex_exposed$HPV52_ANAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv52_anal_partner] = prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv52_anal_partner] + sex_exposed$partvaxct_hpv52_anal[sex_exposed$HPV52_ANAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv58_anal_ego] = prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv58_anal_ego] + sex_exposed$vaxct_hpv58_anal[sex_exposed$HPV58_ANAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv58_anal_partner] = prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv58_anal_partner] + sex_exposed$partvaxct_hpv58_anal[sex_exposed$HPV58_ANAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv6_anal_ego] = prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv6_anal_ego] + sex_exposed$prevct_hpv6_anal[sex_exposed$HPV6_ANAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv6_anal_partner] = prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv6_anal_partner] + sex_exposed$partprevct_hpv6_anal[sex_exposed$HPV6_ANAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv11_anal_ego] = prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv11_anal_ego] + sex_exposed$prevct_hpv11_anal[sex_exposed$HPV11_ANAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv11_anal_partner] = prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv11_anal_partner] + sex_exposed$partprevct_hpv11_anal[sex_exposed$HPV11_ANAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv16_anal_ego] = prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv16_anal_ego] + sex_exposed$prevct_hpv16_anal[sex_exposed$HPV16_ANAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv16_anal_partner] = prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv16_anal_partner] + sex_exposed$partprevct_hpv16_anal[sex_exposed$HPV16_ANAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv18_anal_ego] = prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv18_anal_ego] + sex_exposed$prevct_hpv18_anal[sex_exposed$HPV18_ANAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv18_anal_partner] = prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv18_anal_partner] + sex_exposed$partprevct_hpv18_anal[sex_exposed$HPV18_ANAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv31_anal_ego] = prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv31_anal_ego] + sex_exposed$prevct_hpv31_anal[sex_exposed$HPV31_ANAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv31_anal_partner] = prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv31_anal_partner] + sex_exposed$partprevct_hpv31_anal[sex_exposed$HPV31_ANAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv33_anal_ego] = prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv33_anal_ego] + sex_exposed$prevct_hpv33_anal[sex_exposed$HPV33_ANAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv33_anal_partner] = prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv33_anal_partner] + sex_exposed$partprevct_hpv33_anal[sex_exposed$HPV33_ANAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv45_anal_ego] = prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv45_anal_ego] + sex_exposed$prevct_hpv45_anal[sex_exposed$HPV45_ANAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv45_anal_partner] = prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv45_anal_partner] + sex_exposed$partprevct_hpv45_anal[sex_exposed$HPV45_ANAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv52_anal_ego] = prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv52_anal_ego] + sex_exposed$prevct_hpv52_anal[sex_exposed$HPV52_ANAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv52_anal_partner] = prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv52_anal_partner] + sex_exposed$partprevct_hpv52_anal[sex_exposed$HPV52_ANAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv58_anal_ego] = prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv58_anal_ego] + sex_exposed$prevct_hpv58_anal[sex_exposed$HPV58_ANAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv58_anal_partner] = prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv58_anal_partner] + sex_exposed$partprevct_hpv58_anal[sex_exposed$HPV58_ANAL==1]
        prep_sims[[current_data]]$HPV6_ANAL[exposed_hpv6_anal_ego] = ifelse(sex_exposed$newHPV6_ANAL[sex_exposed$HPV6_ANAL==1]==1, 1, prep_sims[[current_data]]$HPV6_ANAL[exposed_hpv6_anal_ego])
        prep_sims[[current_data]]$HPV6_ANAL[exposed_hpv6_anal_partner] = ifelse(sex_exposed$partnewHPV6_ANAL[sex_exposed$HPV6_ANAL==1]==1, 1, prep_sims[[current_data]]$HPV6_ANAL[exposed_hpv6_anal_partner])
        prep_sims[[current_data]]$HPV11_ANAL[exposed_hpv11_anal_ego] = ifelse(sex_exposed$newHPV11_ANAL[sex_exposed$HPV11_ANAL==1]==1, 1, prep_sims[[current_data]]$HPV11_ANAL[exposed_hpv11_anal_ego])
        prep_sims[[current_data]]$HPV11_ANAL[exposed_hpv11_anal_partner] = ifelse(sex_exposed$partnewHPV11_ANAL[sex_exposed$HPV11_ANAL==1]==1, 1, prep_sims[[current_data]]$HPV11_ANAL[exposed_hpv11_anal_partner])
        prep_sims[[current_data]]$HPV16_ANAL[exposed_hpv16_anal_ego] = ifelse(sex_exposed$newHPV16_ANAL[sex_exposed$HPV16_ANAL==1]==1, 1, prep_sims[[current_data]]$HPV16_ANAL[exposed_hpv16_anal_ego])
        prep_sims[[current_data]]$HPV16_ANAL[exposed_hpv16_anal_partner] = ifelse(sex_exposed$partnewHPV16_ANAL[sex_exposed$HPV16_ANAL==1]==1, 1, prep_sims[[current_data]]$HPV16_ANAL[exposed_hpv16_anal_partner])
        prep_sims[[current_data]]$HPV18_ANAL[exposed_hpv18_anal_ego] = ifelse(sex_exposed$newHPV18_ANAL[sex_exposed$HPV18_ANAL==1]==1, 1, prep_sims[[current_data]]$HPV18_ANAL[exposed_hpv18_anal_ego])
        prep_sims[[current_data]]$HPV18_ANAL[exposed_hpv18_anal_partner] = ifelse(sex_exposed$partnewHPV18_ANAL[sex_exposed$HPV18_ANAL==1]==1, 1, prep_sims[[current_data]]$HPV18_ANAL[exposed_hpv18_anal_partner])
        prep_sims[[current_data]]$HPV31_ANAL[exposed_hpv31_anal_ego] = ifelse(sex_exposed$newHPV31_ANAL[sex_exposed$HPV31_ANAL==1]==1, 1, prep_sims[[current_data]]$HPV31_ANAL[exposed_hpv31_anal_ego])
        prep_sims[[current_data]]$HPV31_ANAL[exposed_hpv31_anal_partner] = ifelse(sex_exposed$partnewHPV31_ANAL[sex_exposed$HPV31_ANAL==1]==1, 1, prep_sims[[current_data]]$HPV31_ANAL[exposed_hpv31_anal_partner])
        prep_sims[[current_data]]$HPV33_ANAL[exposed_hpv33_anal_ego] = ifelse(sex_exposed$newHPV33_ANAL[sex_exposed$HPV33_ANAL==1]==1, 1, prep_sims[[current_data]]$HPV33_ANAL[exposed_hpv33_anal_ego])
        prep_sims[[current_data]]$HPV33_ANAL[exposed_hpv33_anal_partner] = ifelse(sex_exposed$partnewHPV33_ANAL[sex_exposed$HPV33_ANAL==1]==1, 1, prep_sims[[current_data]]$HPV33_ANAL[exposed_hpv33_anal_partner])
        prep_sims[[current_data]]$HPV45_ANAL[exposed_hpv45_anal_ego] = ifelse(sex_exposed$newHPV45_ANAL[sex_exposed$HPV45_ANAL==1]==1, 1, prep_sims[[current_data]]$HPV45_ANAL[exposed_hpv45_anal_ego])
        prep_sims[[current_data]]$HPV45_ANAL[exposed_hpv45_anal_partner] = ifelse(sex_exposed$partnewHPV45_ANAL[sex_exposed$HPV45_ANAL==1]==1, 1, prep_sims[[current_data]]$HPV45_ANAL[exposed_hpv45_anal_partner])
        prep_sims[[current_data]]$HPV52_ANAL[exposed_hpv52_anal_ego] = ifelse(sex_exposed$newHPV52_ANAL[sex_exposed$HPV52_ANAL==1]==1, 1, prep_sims[[current_data]]$HPV52_ANAL[exposed_hpv52_anal_ego])
        prep_sims[[current_data]]$HPV52_ANAL[exposed_hpv52_anal_partner] = ifelse(sex_exposed$partnewHPV52_ANAL[sex_exposed$HPV52_ANAL==1]==1, 1, prep_sims[[current_data]]$HPV52_ANAL[exposed_hpv52_anal_partner])
        prep_sims[[current_data]]$HPV58_ANAL[exposed_hpv58_anal_ego] = ifelse(sex_exposed$newHPV58_ANAL[sex_exposed$HPV58_ANAL==1]==1, 1, prep_sims[[current_data]]$HPV58_ANAL[exposed_hpv58_anal_ego])
        prep_sims[[current_data]]$HPV58_ANAL[exposed_hpv58_anal_partner] = ifelse(sex_exposed$partnewHPV58_ANAL[sex_exposed$HPV58_ANAL==1]==1, 1, prep_sims[[current_data]]$HPV58_ANAL[exposed_hpv58_anal_partner])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV6_ANAL[exposed_hpv6_anal_ego] = ifelse(sex_exposed$newHPV6_ANAL[sex_exposed$HPV6_ANAL==1]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV6_ANAL[exposed_hpv6_anal_ego])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV6_ANAL[exposed_hpv6_anal_partner] = ifelse(sex_exposed$partnewHPV6_ANAL[sex_exposed$HPV6_ANAL==1]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV6_ANAL[exposed_hpv6_anal_partner])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV11_ANAL[exposed_hpv11_anal_ego] = ifelse(sex_exposed$newHPV11_ANAL[sex_exposed$HPV11_ANAL==1]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV11_ANAL[exposed_hpv11_anal_ego])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV11_ANAL[exposed_hpv11_anal_partner] = ifelse(sex_exposed$partnewHPV11_ANAL[sex_exposed$HPV11_ANAL==1]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV11_ANAL[exposed_hpv11_anal_partner])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV16_ANAL[exposed_hpv16_anal_ego] = ifelse(sex_exposed$newHPV16_ANAL[sex_exposed$HPV16_ANAL==1]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV16_ANAL[exposed_hpv16_anal_ego])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV16_ANAL[exposed_hpv16_anal_partner] = ifelse(sex_exposed$partnewHPV16_ANAL[sex_exposed$HPV16_ANAL==1]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV16_ANAL[exposed_hpv16_anal_partner])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV18_ANAL[exposed_hpv18_anal_ego] = ifelse(sex_exposed$newHPV18_ANAL[sex_exposed$HPV18_ANAL==1]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV18_ANAL[exposed_hpv18_anal_ego])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV18_ANAL[exposed_hpv18_anal_partner] = ifelse(sex_exposed$partnewHPV18_ANAL[sex_exposed$HPV18_ANAL==1]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV18_ANAL[exposed_hpv18_anal_partner])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV31_ANAL[exposed_hpv31_anal_ego] = ifelse(sex_exposed$newHPV31_ANAL[sex_exposed$HPV31_ANAL==1]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV31_ANAL[exposed_hpv31_anal_ego])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV31_ANAL[exposed_hpv31_anal_partner] = ifelse(sex_exposed$partnewHPV31_ANAL[sex_exposed$HPV31_ANAL==1]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV31_ANAL[exposed_hpv31_anal_partner])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV33_ANAL[exposed_hpv33_anal_ego] = ifelse(sex_exposed$newHPV33_ANAL[sex_exposed$HPV33_ANAL==1]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV33_ANAL[exposed_hpv33_anal_ego])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV33_ANAL[exposed_hpv33_anal_partner] = ifelse(sex_exposed$partnewHPV33_ANAL[sex_exposed$HPV33_ANAL==1]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV33_ANAL[exposed_hpv33_anal_partner])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV45_ANAL[exposed_hpv45_anal_ego] = ifelse(sex_exposed$newHPV45_ANAL[sex_exposed$HPV45_ANAL==1]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV45_ANAL[exposed_hpv45_anal_ego])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV45_ANAL[exposed_hpv45_anal_partner] = ifelse(sex_exposed$partnewHPV45_ANAL[sex_exposed$HPV45_ANAL==1]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV45_ANAL[exposed_hpv45_anal_partner])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV52_ANAL[exposed_hpv52_anal_ego] = ifelse(sex_exposed$newHPV52_ANAL[sex_exposed$HPV52_ANAL==1]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV52_ANAL[exposed_hpv52_anal_ego])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV52_ANAL[exposed_hpv52_anal_partner] = ifelse(sex_exposed$partnewHPV52_ANAL[sex_exposed$HPV52_ANAL==1]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV52_ANAL[exposed_hpv52_anal_partner])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV58_ANAL[exposed_hpv58_anal_ego] = ifelse(sex_exposed$newHPV58_ANAL[sex_exposed$HPV58_ANAL==1]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV58_ANAL[exposed_hpv58_anal_ego])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV58_ANAL[exposed_hpv58_anal_partner] = ifelse(sex_exposed$partnewHPV58_ANAL[sex_exposed$HPV58_ANAL==1]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV58_ANAL[exposed_hpv58_anal_partner])
        
        # prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv_anal_ego] = prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv_anal_ego] + sex_exposed$seroct_hpv[sex_exposed$HPV_ANAL==1]
        # prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv_anal_partner] = prep_sims[[current_data]]$SERO_PREVENT[exposed_hpv_anal_partner] + sex_exposed$partseroct_hpv[sex_exposed$HPV_ANAL==1]
        # prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv_anal_ego] = prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv_anal_ego] + sex_exposed$condct_hpv_anal[sex_exposed$HPV_ANAL==1]
        # prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv_anal_partner] = prep_sims[[current_data]]$COND_PREVENT_ANAL[exposed_hpv_anal_partner] + sex_exposed$partcondct_hpv_anal[sex_exposed$HPV_ANAL==1]
        # prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv_anal_ego] = prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv_anal_ego] + sex_exposed$vaxct_hpv_anal[sex_exposed$HPV_ANAL==1]
        # prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv_anal_partner] = prep_sims[[current_data]]$VAX_PREVENT_ANAL[exposed_hpv_anal_partner] + sex_exposed$partvaxct_hpv_anal[sex_exposed$HPV_ANAL==1]
        # prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv_anal_ego] = prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv_anal_ego] + sex_exposed$prevct_hpv_anal[sex_exposed$HPV_ANAL==1]
        # prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv_anal_partner] = prep_sims[[current_data]]$OVERALL_PREVENT_ANAL[exposed_hpv_anal_partner] + sex_exposed$partprevct_hpv_anal[sex_exposed$HPV_ANAL==1]
        # prep_sims[[current_data]]$HPV6_ANAL[exposed_hpv_anal_ego] = ifelse(sex_exposed$newHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV6_ANAL[exposed_hpv_anal_partner]==1, 1, prep_sims[[current_data]]$HPV6_ANAL[exposed_hpv_anal_ego])
        # prep_sims[[current_data]]$HPV6_ANAL[exposed_hpv_anal_partner] = ifelse(sex_exposed$partnewHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV6_ANAL[exposed_hpv_anal_ego]==1, 1, prep_sims[[current_data]]$HPV6_ANAL[exposed_hpv_anal_partner])
        # prep_sims[[current_data]]$INCIDENCE_DAYS_HPV6_ANAL[exposed_hpv_anal_ego] = ifelse(sex_exposed$newHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV6_ANAL[exposed_hpv_anal_partner]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV6_ANAL[exposed_hpv_anal_ego])
        # prep_sims[[current_data]]$INCIDENCE_DAYS_HPV6_ANAL[exposed_hpv_anal_partner] = ifelse(sex_exposed$partnewHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV6_ANAL[exposed_hpv_anal_ego]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV6_ANAL[exposed_hpv_anal_partner])
        # prep_sims[[current_data]]$HPV11_ANAL[exposed_hpv_anal_ego] = ifelse(sex_exposed$newHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV11_ANAL[exposed_hpv_anal_partner]==1, 1, prep_sims[[current_data]]$HPV11_ANAL[exposed_hpv_anal_ego])
        # prep_sims[[current_data]]$HPV11_ANAL[exposed_hpv_anal_partner] = ifelse(sex_exposed$partnewHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV11_ANAL[exposed_hpv_anal_ego]==1, 1, prep_sims[[current_data]]$HPV11_ANAL[exposed_hpv_anal_partner])
        # prep_sims[[current_data]]$INCIDENCE_DAYS_HPV11_ANAL[exposed_hpv_anal_ego] = ifelse(sex_exposed$newHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV11_ANAL[exposed_hpv_anal_partner]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV11_ANAL[exposed_hpv_anal_ego])
        # prep_sims[[current_data]]$INCIDENCE_DAYS_HPV11_ANAL[exposed_hpv_anal_partner] = ifelse(sex_exposed$partnewHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV11_ANAL[exposed_hpv_anal_ego]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV11_ANAL[exposed_hpv_anal_partner])
        # prep_sims[[current_data]]$HPV16_ANAL[exposed_hpv_anal_ego] = ifelse(sex_exposed$newHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV16_ANAL[exposed_hpv_anal_partner]==1, 1, prep_sims[[current_data]]$HPV16_ANAL[exposed_hpv_anal_ego])
        # prep_sims[[current_data]]$HPV16_ANAL[exposed_hpv_anal_partner] = ifelse(sex_exposed$partnewHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV16_ANAL[exposed_hpv_anal_ego]==1, 1, prep_sims[[current_data]]$HPV16_ANAL[exposed_hpv_anal_partner])
        # prep_sims[[current_data]]$INCIDENCE_DAYS_HPV16_ANAL[exposed_hpv_anal_ego] = ifelse(sex_exposed$newHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV16_ANAL[exposed_hpv_anal_partner]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV16_ANAL[exposed_hpv_anal_ego])
        # prep_sims[[current_data]]$INCIDENCE_DAYS_HPV16_ANAL[exposed_hpv_anal_partner] = ifelse(sex_exposed$partnewHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV16_ANAL[exposed_hpv_anal_ego]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV16_ANAL[exposed_hpv_anal_partner])
        # prep_sims[[current_data]]$HPV18_ANAL[exposed_hpv_anal_ego] = ifelse(sex_exposed$newHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV18_ANAL[exposed_hpv_anal_partner]==1, 1, prep_sims[[current_data]]$HPV18_ANAL[exposed_hpv_anal_ego])
        # prep_sims[[current_data]]$HPV18_ANAL[exposed_hpv_anal_partner] = ifelse(sex_exposed$partnewHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV18_ANAL[exposed_hpv_anal_ego]==1, 1, prep_sims[[current_data]]$HPV18_ANAL[exposed_hpv_anal_partner])
        # prep_sims[[current_data]]$INCIDENCE_DAYS_HPV18_ANAL[exposed_hpv_anal_ego] = ifelse(sex_exposed$newHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV18_ANAL[exposed_hpv_anal_partner]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV18_ANAL[exposed_hpv_anal_ego])
        # prep_sims[[current_data]]$INCIDENCE_DAYS_HPV18_ANAL[exposed_hpv_anal_partner] = ifelse(sex_exposed$partnewHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV18_ANAL[exposed_hpv_anal_ego]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV18_ANAL[exposed_hpv_anal_partner])
        # prep_sims[[current_data]]$HPV31_ANAL[exposed_hpv_anal_ego] = ifelse(sex_exposed$newHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV31_ANAL[exposed_hpv_anal_partner]==1, 1, prep_sims[[current_data]]$HPV31_ANAL[exposed_hpv_anal_ego])
        # prep_sims[[current_data]]$HPV31_ANAL[exposed_hpv_anal_partner] = ifelse(sex_exposed$partnewHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV31_ANAL[exposed_hpv_anal_ego]==1, 1, prep_sims[[current_data]]$HPV31_ANAL[exposed_hpv_anal_partner])
        # prep_sims[[current_data]]$INCIDENCE_DAYS_HPV31_ANAL[exposed_hpv_anal_ego] = ifelse(sex_exposed$newHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV31_ANAL[exposed_hpv_anal_partner]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV31_ANAL[exposed_hpv_anal_ego])
        # prep_sims[[current_data]]$INCIDENCE_DAYS_HPV31_ANAL[exposed_hpv_anal_partner] = ifelse(sex_exposed$partnewHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV31_ANAL[exposed_hpv_anal_ego]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV31_ANAL[exposed_hpv_anal_partner])
        # prep_sims[[current_data]]$HPV33_ANAL[exposed_hpv_anal_ego] = ifelse(sex_exposed$newHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV33_ANAL[exposed_hpv_anal_partner]==1, 1, prep_sims[[current_data]]$HPV33_ANAL[exposed_hpv_anal_ego])
        # prep_sims[[current_data]]$HPV33_ANAL[exposed_hpv_anal_partner] = ifelse(sex_exposed$partnewHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV33_ANAL[exposed_hpv_anal_ego]==1, 1, prep_sims[[current_data]]$HPV33_ANAL[exposed_hpv_anal_partner])
        # prep_sims[[current_data]]$INCIDENCE_DAYS_HPV33_ANAL[exposed_hpv_anal_ego] = ifelse(sex_exposed$newHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV33_ANAL[exposed_hpv_anal_partner]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV33_ANAL[exposed_hpv_anal_ego])
        # prep_sims[[current_data]]$INCIDENCE_DAYS_HPV33_ANAL[exposed_hpv_anal_partner] = ifelse(sex_exposed$partnewHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV33_ANAL[exposed_hpv_anal_ego]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV33_ANAL[exposed_hpv_anal_partner])
        # prep_sims[[current_data]]$HPV45_ANAL[exposed_hpv_anal_ego] = ifelse(sex_exposed$newHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV45_ANAL[exposed_hpv_anal_partner]==1, 1, prep_sims[[current_data]]$HPV45_ANAL[exposed_hpv_anal_ego])
        # prep_sims[[current_data]]$HPV45_ANAL[exposed_hpv_anal_partner] = ifelse(sex_exposed$partnewHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV45_ANAL[exposed_hpv_anal_ego]==1, 1, prep_sims[[current_data]]$HPV45_ANAL[exposed_hpv_anal_partner])
        # prep_sims[[current_data]]$INCIDENCE_DAYS_HPV45_ANAL[exposed_hpv_anal_ego] = ifelse(sex_exposed$newHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV45_ANAL[exposed_hpv_anal_partner]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV45_ANAL[exposed_hpv_anal_ego])
        # prep_sims[[current_data]]$INCIDENCE_DAYS_HPV45_ANAL[exposed_hpv_anal_partner] = ifelse(sex_exposed$partnewHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV45_ANAL[exposed_hpv_anal_ego]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV45_ANAL[exposed_hpv_anal_partner])
        # prep_sims[[current_data]]$HPV52_ANAL[exposed_hpv_anal_ego] = ifelse(sex_exposed$newHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV52_ANAL[exposed_hpv_anal_partner]==1, 1, prep_sims[[current_data]]$HPV52_ANAL[exposed_hpv_anal_ego])
        # prep_sims[[current_data]]$HPV52_ANAL[exposed_hpv_anal_partner] = ifelse(sex_exposed$partnewHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV52_ANAL[exposed_hpv_anal_ego]==1, 1, prep_sims[[current_data]]$HPV52_ANAL[exposed_hpv_anal_partner])
        # prep_sims[[current_data]]$INCIDENCE_DAYS_HPV52_ANAL[exposed_hpv_anal_ego] = ifelse(sex_exposed$newHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV52_ANAL[exposed_hpv_anal_partner]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV52_ANAL[exposed_hpv_anal_ego])
        # prep_sims[[current_data]]$INCIDENCE_DAYS_HPV52_ANAL[exposed_hpv_anal_partner] = ifelse(sex_exposed$partnewHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV52_ANAL[exposed_hpv_anal_ego]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV52_ANAL[exposed_hpv_anal_partner])
        # prep_sims[[current_data]]$HPV58_ANAL[exposed_hpv_anal_ego] = ifelse(sex_exposed$newHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV58_ANAL[exposed_hpv_anal_partner]==1, 1, prep_sims[[current_data]]$HPV58_ANAL[exposed_hpv_anal_ego])
        # prep_sims[[current_data]]$HPV58_ANAL[exposed_hpv_anal_partner] = ifelse(sex_exposed$partnewHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV58_ANAL[exposed_hpv_anal_ego]==1, 1, prep_sims[[current_data]]$HPV58_ANAL[exposed_hpv_anal_partner])
        # prep_sims[[current_data]]$INCIDENCE_DAYS_HPV58_ANAL[exposed_hpv_anal_ego] = ifelse(sex_exposed$newHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV58_ANAL[exposed_hpv_anal_partner]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV58_ANAL[exposed_hpv_anal_ego])
        # prep_sims[[current_data]]$INCIDENCE_DAYS_HPV58_ANAL[exposed_hpv_anal_partner] = ifelse(sex_exposed$partnewHPV_ANAL[sex_exposed$HPV_ANAL==1]==1 & prep_sims[[current_data]]$HPV58_ANAL[exposed_hpv_anal_ego]==1, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV58_ANAL[exposed_hpv_anal_partner])
        
        #HPV oral
        prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv6_oral_ego] = prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv6_oral_ego] + sex_exposed$condct_hpv6_oral[sex_exposed$HPV6_ORAL==1]
        prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv6_oral_partner] = prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv6_oral_partner] + sex_exposed$partcondct_hpv6_oral[sex_exposed$HPV6_ORAL==1]
        prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv11_oral_ego] = prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv11_oral_ego] + sex_exposed$condct_hpv11_oral[sex_exposed$HPV11_ORAL==1]
        prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv11_oral_partner] = prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv11_oral_partner] + sex_exposed$partcondct_hpv11_oral[sex_exposed$HPV11_ORAL==1]
        prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv16_oral_ego] = prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv16_oral_ego] + sex_exposed$condct_hpv16_oral[sex_exposed$HPV16_ORAL==1]
        prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv16_oral_partner] = prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv16_oral_partner] + sex_exposed$partcondct_hpv16_oral[sex_exposed$HPV16_ORAL==1]
        prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv18_oral_ego] = prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv18_oral_ego] + sex_exposed$condct_hpv18_oral[sex_exposed$HPV18_ORAL==1]
        prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv18_oral_partner] = prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv18_oral_partner] + sex_exposed$partcondct_hpv18_oral[sex_exposed$HPV18_ORAL==1]
        prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv31_oral_ego] = prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv31_oral_ego] + sex_exposed$condct_hpv31_oral[sex_exposed$HPV31_ORAL==1]
        prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv31_oral_partner] = prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv31_oral_partner] + sex_exposed$partcondct_hpv31_oral[sex_exposed$HPV31_ORAL==1]
        prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv33_oral_ego] = prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv33_oral_ego] + sex_exposed$condct_hpv33_oral[sex_exposed$HPV33_ORAL==1]
        prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv33_oral_partner] = prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv33_oral_partner] + sex_exposed$partcondct_hpv33_oral[sex_exposed$HPV33_ORAL==1]
        prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv45_oral_ego] = prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv45_oral_ego] + sex_exposed$condct_hpv45_oral[sex_exposed$HPV45_ORAL==1]
        prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv45_oral_partner] = prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv45_oral_partner] + sex_exposed$partcondct_hpv45_oral[sex_exposed$HPV45_ORAL==1]
        prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv52_oral_ego] = prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv52_oral_ego] + sex_exposed$condct_hpv52_oral[sex_exposed$HPV52_ORAL==1]
        prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv52_oral_partner] = prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv52_oral_partner] + sex_exposed$partcondct_hpv52_oral[sex_exposed$HPV52_ORAL==1]
        prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv58_oral_ego] = prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv58_oral_ego] + sex_exposed$condct_hpv58_oral[sex_exposed$HPV58_ORAL==1]
        prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv58_oral_partner] = prep_sims[[current_data]]$COND_PREVENT_ORAL[exposed_hpv58_oral_partner] + sex_exposed$partcondct_hpv58_oral[sex_exposed$HPV58_ORAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv6_oral_ego] = prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv6_oral_ego] + sex_exposed$vaxct_hpv6_oral[sex_exposed$HPV6_ORAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv6_oral_partner] = prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv6_oral_partner] + sex_exposed$partvaxct_hpv6_oral[sex_exposed$HPV6_ORAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv11_oral_ego] = prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv11_oral_ego] + sex_exposed$vaxct_hpv11_oral[sex_exposed$HPV11_ORAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv11_oral_partner] = prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv11_oral_partner] + sex_exposed$partvaxct_hpv11_oral[sex_exposed$HPV11_ORAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv16_oral_ego] = prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv16_oral_ego] + sex_exposed$vaxct_hpv16_oral[sex_exposed$HPV16_ORAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv16_oral_partner] = prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv16_oral_partner] + sex_exposed$partvaxct_hpv16_oral[sex_exposed$HPV16_ORAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv18_oral_ego] = prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv18_oral_ego] + sex_exposed$vaxct_hpv18_oral[sex_exposed$HPV18_ORAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv18_oral_partner] = prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv18_oral_partner] + sex_exposed$partvaxct_hpv18_oral[sex_exposed$HPV18_ORAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv31_oral_ego] = prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv31_oral_ego] + sex_exposed$vaxct_hpv31_oral[sex_exposed$HPV31_ORAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv31_oral_partner] = prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv31_oral_partner] + sex_exposed$partvaxct_hpv31_oral[sex_exposed$HPV31_ORAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv33_oral_ego] = prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv33_oral_ego] + sex_exposed$vaxct_hpv33_oral[sex_exposed$HPV33_ORAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv33_oral_partner] = prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv33_oral_partner] + sex_exposed$partvaxct_hpv33_oral[sex_exposed$HPV33_ORAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv45_oral_ego] = prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv45_oral_ego] + sex_exposed$vaxct_hpv45_oral[sex_exposed$HPV45_ORAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv45_oral_partner] = prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv45_oral_partner] + sex_exposed$partvaxct_hpv45_oral[sex_exposed$HPV45_ORAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv52_oral_ego] = prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv52_oral_ego] + sex_exposed$vaxct_hpv52_oral[sex_exposed$HPV52_ORAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv52_oral_partner] = prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv52_oral_partner] + sex_exposed$partvaxct_hpv52_oral[sex_exposed$HPV52_ORAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv58_oral_ego] = prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv58_oral_ego] + sex_exposed$vaxct_hpv58_oral[sex_exposed$HPV58_ORAL==1]
        prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv58_oral_partner] = prep_sims[[current_data]]$VAX_PREVENT_ORAL[exposed_hpv58_oral_partner] + sex_exposed$partvaxct_hpv58_oral[sex_exposed$HPV58_ORAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv6_oral_ego] = prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv6_oral_ego] + sex_exposed$prevct_hpv6_oral[sex_exposed$HPV6_ORAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv6_oral_partner] = prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv6_oral_partner] + sex_exposed$partprevct_hpv6_oral[sex_exposed$HPV6_ORAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv11_oral_ego] = prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv11_oral_ego] + sex_exposed$prevct_hpv11_oral[sex_exposed$HPV11_ORAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv11_oral_partner] = prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv11_oral_partner] + sex_exposed$partprevct_hpv11_oral[sex_exposed$HPV11_ORAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv16_oral_ego] = prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv16_oral_ego] + sex_exposed$prevct_hpv16_oral[sex_exposed$HPV16_ORAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv16_oral_partner] = prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv16_oral_partner] + sex_exposed$partprevct_hpv16_oral[sex_exposed$HPV16_ORAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv18_oral_ego] = prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv18_oral_ego] + sex_exposed$prevct_hpv18_oral[sex_exposed$HPV18_ORAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv18_oral_partner] = prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv18_oral_partner] + sex_exposed$partprevct_hpv18_oral[sex_exposed$HPV18_ORAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv31_oral_ego] = prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv31_oral_ego] + sex_exposed$prevct_hpv31_oral[sex_exposed$HPV31_ORAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv31_oral_partner] = prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv31_oral_partner] + sex_exposed$partprevct_hpv31_oral[sex_exposed$HPV31_ORAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv33_oral_ego] = prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv33_oral_ego] + sex_exposed$prevct_hpv33_oral[sex_exposed$HPV33_ORAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv33_oral_partner] = prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv33_oral_partner] + sex_exposed$partprevct_hpv33_oral[sex_exposed$HPV33_ORAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv45_oral_ego] = prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv45_oral_ego] + sex_exposed$prevct_hpv45_oral[sex_exposed$HPV45_ORAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv45_oral_partner] = prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv45_oral_partner] + sex_exposed$partprevct_hpv45_oral[sex_exposed$HPV45_ORAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv52_oral_ego] = prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv52_oral_ego] + sex_exposed$prevct_hpv52_oral[sex_exposed$HPV52_ORAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv52_oral_partner] = prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv52_oral_partner] + sex_exposed$partprevct_hpv52_oral[sex_exposed$HPV52_ORAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv58_oral_ego] = prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv58_oral_ego] + sex_exposed$prevct_hpv58_oral[sex_exposed$HPV58_ORAL==1]
        prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv58_oral_partner] = prep_sims[[current_data]]$OVERALL_PREVENT_ORAL[exposed_hpv58_oral_partner] + sex_exposed$partprevct_hpv58_oral[sex_exposed$HPV58_ORAL==1]
        prep_sims[[current_data]]$HPV6_ORAL[exposed_hpv6_oral_ego] = ifelse(sex_exposed$newHPV6_ORAL[sex_exposed$HPV6_ORAL==1]==1 | sex_exposed$newHPV6_ORAL[sex_exposed$HPV6_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV6_ORAL[exposed_hpv6_oral_ego])
        prep_sims[[current_data]]$HPV6_ORAL[exposed_hpv6_oral_partner] = ifelse(sex_exposed$partnewHPV6_ORAL[sex_exposed$HPV6_ORAL==1]==1 | sex_exposed$partnewHPV6_ORAL[sex_exposed$HPV6_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV6_ORAL[exposed_hpv6_oral_partner])
        prep_sims[[current_data]]$HPV11_ORAL[exposed_hpv11_oral_ego] = ifelse(sex_exposed$newHPV11_ORAL[sex_exposed$HPV11_ORAL==1]==1 | sex_exposed$newHPV11_ORAL[sex_exposed$HPV11_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV11_ORAL[exposed_hpv11_oral_ego])
        prep_sims[[current_data]]$HPV11_ORAL[exposed_hpv11_oral_partner] = ifelse(sex_exposed$partnewHPV11_ORAL[sex_exposed$HPV11_ORAL==1]==1 | sex_exposed$partnewHPV11_ORAL[sex_exposed$HPV11_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV11_ORAL[exposed_hpv11_oral_partner])
        prep_sims[[current_data]]$HPV16_ORAL[exposed_hpv16_oral_ego] = ifelse(sex_exposed$newHPV16_ORAL[sex_exposed$HPV16_ORAL==1]==1 | sex_exposed$newHPV16_ORAL[sex_exposed$HPV16_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV16_ORAL[exposed_hpv16_oral_ego])
        prep_sims[[current_data]]$HPV16_ORAL[exposed_hpv16_oral_partner] = ifelse(sex_exposed$partnewHPV16_ORAL[sex_exposed$HPV16_ORAL==1]==1 | sex_exposed$partnewHPV16_ORAL[sex_exposed$HPV16_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV16_ORAL[exposed_hpv16_oral_partner])
        prep_sims[[current_data]]$HPV18_ORAL[exposed_hpv18_oral_ego] = ifelse(sex_exposed$newHPV18_ORAL[sex_exposed$HPV18_ORAL==1]==1 | sex_exposed$newHPV18_ORAL[sex_exposed$HPV18_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV18_ORAL[exposed_hpv18_oral_ego])
        prep_sims[[current_data]]$HPV18_ORAL[exposed_hpv18_oral_partner] = ifelse(sex_exposed$partnewHPV18_ORAL[sex_exposed$HPV18_ORAL==1]==1 | sex_exposed$partnewHPV18_ORAL[sex_exposed$HPV18_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV18_ORAL[exposed_hpv18_oral_partner])
        prep_sims[[current_data]]$HPV31_ORAL[exposed_hpv31_oral_ego] = ifelse(sex_exposed$newHPV31_ORAL[sex_exposed$HPV31_ORAL==1]==1 | sex_exposed$newHPV31_ORAL[sex_exposed$HPV31_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV31_ORAL[exposed_hpv31_oral_ego])
        prep_sims[[current_data]]$HPV31_ORAL[exposed_hpv31_oral_partner] = ifelse(sex_exposed$partnewHPV31_ORAL[sex_exposed$HPV31_ORAL==1]==1 | sex_exposed$partnewHPV31_ORAL[sex_exposed$HPV31_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV31_ORAL[exposed_hpv31_oral_partner])
        prep_sims[[current_data]]$HPV33_ORAL[exposed_hpv33_oral_ego] = ifelse(sex_exposed$newHPV33_ORAL[sex_exposed$HPV33_ORAL==1]==1 | sex_exposed$newHPV33_ORAL[sex_exposed$HPV33_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV33_ORAL[exposed_hpv33_oral_ego])
        prep_sims[[current_data]]$HPV33_ORAL[exposed_hpv33_oral_partner] = ifelse(sex_exposed$partnewHPV33_ORAL[sex_exposed$HPV33_ORAL==1]==1 | sex_exposed$partnewHPV33_ORAL[sex_exposed$HPV33_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV33_ORAL[exposed_hpv33_oral_partner])
        prep_sims[[current_data]]$HPV45_ORAL[exposed_hpv45_oral_ego] = ifelse(sex_exposed$newHPV45_ORAL[sex_exposed$HPV45_ORAL==1]==1 | sex_exposed$newHPV45_ORAL[sex_exposed$HPV45_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV45_ORAL[exposed_hpv45_oral_ego])
        prep_sims[[current_data]]$HPV45_ORAL[exposed_hpv45_oral_partner] = ifelse(sex_exposed$partnewHPV45_ORAL[sex_exposed$HPV45_ORAL==1]==1 | sex_exposed$partnewHPV45_ORAL[sex_exposed$HPV45_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV45_ORAL[exposed_hpv45_oral_partner])
        prep_sims[[current_data]]$HPV52_ORAL[exposed_hpv52_oral_ego] = ifelse(sex_exposed$newHPV52_ORAL[sex_exposed$HPV52_ORAL==1]==1 | sex_exposed$newHPV52_ORAL[sex_exposed$HPV52_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV52_ORAL[exposed_hpv52_oral_ego])
        prep_sims[[current_data]]$HPV52_ORAL[exposed_hpv52_oral_partner] = ifelse(sex_exposed$partnewHPV52_ORAL[sex_exposed$HPV52_ORAL==1]==1 | sex_exposed$partnewHPV52_ORAL[sex_exposed$HPV52_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV52_ORAL[exposed_hpv52_oral_partner])
        prep_sims[[current_data]]$HPV58_ORAL[exposed_hpv58_oral_ego] = ifelse(sex_exposed$newHPV58_ORAL[sex_exposed$HPV58_ORAL==1]==1 | sex_exposed$newHPV58_ORAL[sex_exposed$HPV58_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV58_ORAL[exposed_hpv58_oral_ego])
        prep_sims[[current_data]]$HPV58_ORAL[exposed_hpv58_oral_partner] = ifelse(sex_exposed$partnewHPV58_ORAL[sex_exposed$HPV58_ORAL==1]==1 | sex_exposed$partnewHPV58_ORAL[sex_exposed$HPV58_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV58_ORAL[exposed_hpv58_oral_partner])

        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV6_ORAL[exposed_hpv6_oral_ego] = ifelse(sex_exposed$newHPV6_ORAL[sex_exposed$HPV6_ORAL==1]==1 | sex_exposed$newHPV6_ORAL[sex_exposed$HPV6_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV6_ORAL[exposed_hpv6_oral_ego])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV6_ORAL[exposed_hpv6_oral_partner] = ifelse(sex_exposed$partnewHPV6_ORAL[sex_exposed$HPV6_ORAL==1]==1 | sex_exposed$partnewHPV6_ORAL[sex_exposed$HPV6_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV6_ORAL[exposed_hpv6_oral_partner])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV11_ORAL[exposed_hpv11_oral_ego] = ifelse(sex_exposed$newHPV11_ORAL[sex_exposed$HPV11_ORAL==1]==1 | sex_exposed$newHPV11_ORAL[sex_exposed$HPV11_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV11_ORAL[exposed_hpv11_oral_ego])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV11_ORAL[exposed_hpv11_oral_partner] = ifelse(sex_exposed$partnewHPV11_ORAL[sex_exposed$HPV11_ORAL==1]==1 | sex_exposed$partnewHPV11_ORAL[sex_exposed$HPV11_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV11_ORAL[exposed_hpv11_oral_partner])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV16_ORAL[exposed_hpv16_oral_ego] = ifelse(sex_exposed$newHPV16_ORAL[sex_exposed$HPV16_ORAL==1]==1 | sex_exposed$newHPV16_ORAL[sex_exposed$HPV16_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV16_ORAL[exposed_hpv16_oral_ego])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV16_ORAL[exposed_hpv16_oral_partner] = ifelse(sex_exposed$partnewHPV16_ORAL[sex_exposed$HPV16_ORAL==1]==1 | sex_exposed$partnewHPV16_ORAL[sex_exposed$HPV16_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV16_ORAL[exposed_hpv16_oral_partner])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV18_ORAL[exposed_hpv18_oral_ego] = ifelse(sex_exposed$newHPV18_ORAL[sex_exposed$HPV18_ORAL==1]==1 | sex_exposed$newHPV18_ORAL[sex_exposed$HPV18_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV18_ORAL[exposed_hpv18_oral_ego])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV18_ORAL[exposed_hpv18_oral_partner] = ifelse(sex_exposed$partnewHPV18_ORAL[sex_exposed$HPV18_ORAL==1]==1 | sex_exposed$partnewHPV18_ORAL[sex_exposed$HPV18_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV18_ORAL[exposed_hpv18_oral_partner])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV31_ORAL[exposed_hpv31_oral_ego] = ifelse(sex_exposed$newHPV31_ORAL[sex_exposed$HPV31_ORAL==1]==1 | sex_exposed$newHPV31_ORAL[sex_exposed$HPV31_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV31_ORAL[exposed_hpv31_oral_ego])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV31_ORAL[exposed_hpv31_oral_partner] = ifelse(sex_exposed$partnewHPV31_ORAL[sex_exposed$HPV31_ORAL==1]==1 | sex_exposed$partnewHPV31_ORAL[sex_exposed$HPV31_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV31_ORAL[exposed_hpv31_oral_partner])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV33_ORAL[exposed_hpv33_oral_ego] = ifelse(sex_exposed$newHPV33_ORAL[sex_exposed$HPV33_ORAL==1]==1 | sex_exposed$newHPV33_ORAL[sex_exposed$HPV33_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV33_ORAL[exposed_hpv33_oral_ego])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV33_ORAL[exposed_hpv33_oral_partner] = ifelse(sex_exposed$partnewHPV33_ORAL[sex_exposed$HPV33_ORAL==1]==1 | sex_exposed$partnewHPV33_ORAL[sex_exposed$HPV33_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV33_ORAL[exposed_hpv33_oral_partner])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV45_ORAL[exposed_hpv45_oral_ego] = ifelse(sex_exposed$newHPV45_ORAL[sex_exposed$HPV45_ORAL==1]==1 | sex_exposed$newHPV45_ORAL[sex_exposed$HPV45_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV45_ORAL[exposed_hpv45_oral_ego])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV45_ORAL[exposed_hpv45_oral_partner] = ifelse(sex_exposed$partnewHPV45_ORAL[sex_exposed$HPV45_ORAL==1]==1 | sex_exposed$partnewHPV45_ORAL[sex_exposed$HPV45_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV45_ORAL[exposed_hpv45_oral_partner])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV52_ORAL[exposed_hpv52_oral_ego] = ifelse(sex_exposed$newHPV52_ORAL[sex_exposed$HPV52_ORAL==1]==1 | sex_exposed$newHPV52_ORAL[sex_exposed$HPV52_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV52_ORAL[exposed_hpv52_oral_ego])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV52_ORAL[exposed_hpv52_oral_partner] = ifelse(sex_exposed$partnewHPV52_ORAL[sex_exposed$HPV52_ORAL==1]==1 | sex_exposed$partnewHPV52_ORAL[sex_exposed$HPV52_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV52_ORAL[exposed_hpv52_oral_partner])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV58_ORAL[exposed_hpv58_oral_ego] = ifelse(sex_exposed$newHPV58_ORAL[sex_exposed$HPV58_ORAL==1]==1 | sex_exposed$newHPV58_ORAL[sex_exposed$HPV58_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV58_ORAL[exposed_hpv58_oral_ego])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV58_ORAL[exposed_hpv58_oral_partner] = ifelse(sex_exposed$partnewHPV58_ORAL[sex_exposed$HPV58_ORAL==1]==1 | sex_exposed$partnewHPV58_ORAL[sex_exposed$HPV58_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV58_ORAL[exposed_hpv58_oral_partner])

        prep_sims[[current_data]]$HPV6_ANAL[exposed_hpv6_oral_ego] = ifelse(sex_exposed$newHPV6_ORAL[sex_exposed$HPV6_ORAL==1]==2 | sex_exposed$newHPV6_ORAL[sex_exposed$HPV6_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV6_ANAL[exposed_hpv6_oral_ego])
        prep_sims[[current_data]]$HPV6_ANAL[exposed_hpv6_oral_partner] = ifelse(sex_exposed$partnewHPV6_ORAL[sex_exposed$HPV6_ORAL==1]==2 | sex_exposed$partnewHPV6_ORAL[sex_exposed$HPV6_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV6_ANAL[exposed_hpv6_oral_partner])
        prep_sims[[current_data]]$HPV11_ANAL[exposed_hpv11_oral_ego] = ifelse(sex_exposed$newHPV11_ORAL[sex_exposed$HPV11_ORAL==1]==2 | sex_exposed$newHPV11_ORAL[sex_exposed$HPV11_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV11_ANAL[exposed_hpv11_oral_ego])
        prep_sims[[current_data]]$HPV11_ANAL[exposed_hpv11_oral_partner] = ifelse(sex_exposed$partnewHPV11_ORAL[sex_exposed$HPV11_ORAL==1]==2 | sex_exposed$partnewHPV11_ORAL[sex_exposed$HPV11_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV11_ANAL[exposed_hpv11_oral_partner])
        prep_sims[[current_data]]$HPV16_ANAL[exposed_hpv16_oral_ego] = ifelse(sex_exposed$newHPV16_ORAL[sex_exposed$HPV16_ORAL==1]==2 | sex_exposed$newHPV16_ORAL[sex_exposed$HPV16_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV16_ANAL[exposed_hpv16_oral_ego])
        prep_sims[[current_data]]$HPV16_ANAL[exposed_hpv16_oral_partner] = ifelse(sex_exposed$partnewHPV16_ORAL[sex_exposed$HPV16_ORAL==1]==2 | sex_exposed$partnewHPV16_ORAL[sex_exposed$HPV16_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV16_ANAL[exposed_hpv16_oral_partner])
        prep_sims[[current_data]]$HPV18_ANAL[exposed_hpv18_oral_ego] = ifelse(sex_exposed$newHPV18_ORAL[sex_exposed$HPV18_ORAL==1]==2 | sex_exposed$newHPV18_ORAL[sex_exposed$HPV18_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV18_ANAL[exposed_hpv18_oral_ego])
        prep_sims[[current_data]]$HPV18_ANAL[exposed_hpv18_oral_partner] = ifelse(sex_exposed$partnewHPV18_ORAL[sex_exposed$HPV18_ORAL==1]==2 | sex_exposed$partnewHPV18_ORAL[sex_exposed$HPV18_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV18_ANAL[exposed_hpv18_oral_partner])
        prep_sims[[current_data]]$HPV31_ANAL[exposed_hpv31_oral_ego] = ifelse(sex_exposed$newHPV31_ORAL[sex_exposed$HPV31_ORAL==1]==2 | sex_exposed$newHPV31_ORAL[sex_exposed$HPV31_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV31_ANAL[exposed_hpv31_oral_ego])
        prep_sims[[current_data]]$HPV31_ANAL[exposed_hpv31_oral_partner] = ifelse(sex_exposed$partnewHPV31_ORAL[sex_exposed$HPV31_ORAL==1]==2 | sex_exposed$partnewHPV31_ORAL[sex_exposed$HPV31_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV31_ANAL[exposed_hpv31_oral_partner])
        prep_sims[[current_data]]$HPV33_ANAL[exposed_hpv33_oral_ego] = ifelse(sex_exposed$newHPV33_ORAL[sex_exposed$HPV33_ORAL==1]==2 | sex_exposed$newHPV33_ORAL[sex_exposed$HPV33_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV33_ANAL[exposed_hpv33_oral_ego])
        prep_sims[[current_data]]$HPV33_ANAL[exposed_hpv33_oral_partner] = ifelse(sex_exposed$partnewHPV33_ORAL[sex_exposed$HPV33_ORAL==1]==2 | sex_exposed$partnewHPV33_ORAL[sex_exposed$HPV33_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV33_ANAL[exposed_hpv33_oral_partner])
        prep_sims[[current_data]]$HPV45_ANAL[exposed_hpv45_oral_ego] = ifelse(sex_exposed$newHPV45_ORAL[sex_exposed$HPV45_ORAL==1]==2 | sex_exposed$newHPV45_ORAL[sex_exposed$HPV45_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV45_ANAL[exposed_hpv45_oral_ego])
        prep_sims[[current_data]]$HPV45_ANAL[exposed_hpv45_oral_partner] = ifelse(sex_exposed$partnewHPV45_ORAL[sex_exposed$HPV45_ORAL==1]==2 | sex_exposed$partnewHPV45_ORAL[sex_exposed$HPV45_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV45_ANAL[exposed_hpv45_oral_partner])
        prep_sims[[current_data]]$HPV52_ANAL[exposed_hpv52_oral_ego] = ifelse(sex_exposed$newHPV52_ORAL[sex_exposed$HPV52_ORAL==1]==2 | sex_exposed$newHPV52_ORAL[sex_exposed$HPV52_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV52_ANAL[exposed_hpv52_oral_ego])
        prep_sims[[current_data]]$HPV52_ANAL[exposed_hpv52_oral_partner] = ifelse(sex_exposed$partnewHPV52_ORAL[sex_exposed$HPV52_ORAL==1]==2 | sex_exposed$partnewHPV52_ORAL[sex_exposed$HPV52_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV52_ANAL[exposed_hpv52_oral_partner])
        prep_sims[[current_data]]$HPV58_ANAL[exposed_hpv58_oral_ego] = ifelse(sex_exposed$newHPV58_ORAL[sex_exposed$HPV58_ORAL==1]==2 | sex_exposed$newHPV58_ORAL[sex_exposed$HPV58_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV58_ANAL[exposed_hpv58_oral_ego])
        prep_sims[[current_data]]$HPV58_ANAL[exposed_hpv58_oral_partner] = ifelse(sex_exposed$partnewHPV58_ORAL[sex_exposed$HPV58_ORAL==1]==2 | sex_exposed$partnewHPV58_ORAL[sex_exposed$HPV58_ORAL==1]==3, 1, prep_sims[[current_data]]$HPV58_ANAL[exposed_hpv58_oral_partner])

        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV6_ANAL[exposed_hpv6_oral_ego] = ifelse(sex_exposed$newHPV6_ORAL[sex_exposed$HPV6_ORAL==1]==2 | sex_exposed$newHPV6_ORAL[sex_exposed$HPV6_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV6_ANAL[exposed_hpv6_oral_ego])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV6_ANAL[exposed_hpv6_oral_partner] = ifelse(sex_exposed$partnewHPV6_ORAL[sex_exposed$HPV6_ORAL==1]==2 | sex_exposed$partnewHPV6_ORAL[sex_exposed$HPV6_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV6_ANAL[exposed_hpv6_oral_partner])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV11_ANAL[exposed_hpv11_oral_ego] = ifelse(sex_exposed$newHPV11_ORAL[sex_exposed$HPV11_ORAL==1]==2 | sex_exposed$newHPV11_ORAL[sex_exposed$HPV11_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV11_ANAL[exposed_hpv11_oral_ego])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV11_ANAL[exposed_hpv11_oral_partner] = ifelse(sex_exposed$partnewHPV11_ORAL[sex_exposed$HPV11_ORAL==1]==2 | sex_exposed$partnewHPV11_ORAL[sex_exposed$HPV11_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV11_ANAL[exposed_hpv11_oral_partner])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV16_ANAL[exposed_hpv16_oral_ego] = ifelse(sex_exposed$newHPV16_ORAL[sex_exposed$HPV16_ORAL==1]==2 | sex_exposed$newHPV16_ORAL[sex_exposed$HPV16_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV16_ANAL[exposed_hpv16_oral_ego])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV16_ANAL[exposed_hpv16_oral_partner] = ifelse(sex_exposed$partnewHPV16_ORAL[sex_exposed$HPV16_ORAL==1]==2 | sex_exposed$partnewHPV16_ORAL[sex_exposed$HPV16_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV16_ANAL[exposed_hpv16_oral_partner])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV18_ANAL[exposed_hpv18_oral_ego] = ifelse(sex_exposed$newHPV18_ORAL[sex_exposed$HPV18_ORAL==1]==2 | sex_exposed$newHPV18_ORAL[sex_exposed$HPV18_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV18_ANAL[exposed_hpv18_oral_ego])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV18_ANAL[exposed_hpv18_oral_partner] = ifelse(sex_exposed$partnewHPV18_ORAL[sex_exposed$HPV18_ORAL==1]==2 | sex_exposed$partnewHPV18_ORAL[sex_exposed$HPV18_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV18_ANAL[exposed_hpv18_oral_partner])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV31_ANAL[exposed_hpv31_oral_ego] = ifelse(sex_exposed$newHPV31_ORAL[sex_exposed$HPV31_ORAL==1]==2 | sex_exposed$newHPV31_ORAL[sex_exposed$HPV31_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV31_ANAL[exposed_hpv31_oral_ego])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV31_ANAL[exposed_hpv31_oral_partner] = ifelse(sex_exposed$partnewHPV31_ORAL[sex_exposed$HPV31_ORAL==1]==2 | sex_exposed$partnewHPV31_ORAL[sex_exposed$HPV31_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV31_ANAL[exposed_hpv31_oral_partner])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV33_ANAL[exposed_hpv33_oral_ego] = ifelse(sex_exposed$newHPV33_ORAL[sex_exposed$HPV33_ORAL==1]==2 | sex_exposed$newHPV33_ORAL[sex_exposed$HPV33_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV33_ANAL[exposed_hpv33_oral_ego])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV33_ANAL[exposed_hpv33_oral_partner] = ifelse(sex_exposed$partnewHPV33_ORAL[sex_exposed$HPV33_ORAL==1]==2 | sex_exposed$partnewHPV33_ORAL[sex_exposed$HPV33_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV33_ANAL[exposed_hpv33_oral_partner])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV45_ANAL[exposed_hpv45_oral_ego] = ifelse(sex_exposed$newHPV45_ORAL[sex_exposed$HPV45_ORAL==1]==2 | sex_exposed$newHPV45_ORAL[sex_exposed$HPV45_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV45_ANAL[exposed_hpv45_oral_ego])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV45_ANAL[exposed_hpv45_oral_partner] = ifelse(sex_exposed$partnewHPV45_ORAL[sex_exposed$HPV45_ORAL==1]==2 | sex_exposed$partnewHPV45_ORAL[sex_exposed$HPV45_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV45_ANAL[exposed_hpv45_oral_partner])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV52_ANAL[exposed_hpv52_oral_ego] = ifelse(sex_exposed$newHPV52_ORAL[sex_exposed$HPV52_ORAL==1]==2 | sex_exposed$newHPV52_ORAL[sex_exposed$HPV52_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV52_ANAL[exposed_hpv52_oral_ego])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV52_ANAL[exposed_hpv52_oral_partner] = ifelse(sex_exposed$partnewHPV52_ORAL[sex_exposed$HPV52_ORAL==1]==2 | sex_exposed$partnewHPV52_ORAL[sex_exposed$HPV52_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV52_ANAL[exposed_hpv52_oral_partner])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV58_ANAL[exposed_hpv58_oral_ego] = ifelse(sex_exposed$newHPV58_ORAL[sex_exposed$HPV58_ORAL==1]==2 | sex_exposed$newHPV58_ORAL[sex_exposed$HPV58_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV58_ANAL[exposed_hpv58_oral_ego])
        prep_sims[[current_data]]$INCIDENCE_DAYS_HPV58_ANAL[exposed_hpv58_oral_partner] = ifelse(sex_exposed$partnewHPV58_ORAL[sex_exposed$HPV58_ORAL==1]==2 | sex_exposed$partnewHPV58_ORAL[sex_exposed$HPV58_ORAL==1]==3, 0, prep_sims[[current_data]]$INCIDENCE_DAYS_HPV58_ANAL[exposed_hpv58_oral_partner])
        
        #update number of sex partners
        prep_sims[[current_data]]$SEX_PARTNERS[sex_exposed$Ego] = prep_sims[[current_data]]$SEX_PARTNERS[sex_exposed$Ego] + 1
        prep_sims[[current_data]]$SEX_PARTNERS[sex_exposed$Partner] = prep_sims[[current_data]]$SEX_PARTNERS[sex_exposed$Partner] + 1
        
        if (length(sex_unexposed)>0)
          prep_sims[[current_data]]$SEX_PARTNERS[sex_unexposed] = prep_sims[[current_data]]$SEX_PARTNERS[sex_unexposed] + 1
        
        ## CLEAN UP ##
        
        rm(sex_exposed,sex_unexposed,exposed_hiv_ego,exposed_hiv_partner,probinfect1_hiv,probinfect2_hiv,exposed_hpv11_anal_ego,exposed_hpv11_anal_partner,exposed_hpv16_anal_ego,exposed_hpv16_anal_partner,exposed_hpv18_anal_ego,exposed_hpv18_anal_partner,exposed_hpv31_anal_ego,exposed_hpv31_anal_partner,exposed_hpv33_anal_ego,exposed_hpv33_anal_partner,exposed_hpv45_anal_ego,exposed_hpv45_anal_partner,exposed_hpv52_anal_ego,exposed_hpv52_anal_partner,exposed_hpv58_anal_ego,exposed_hpv58_anal_partner,exposed_hpv6_anal_ego,exposed_hpv6_anal_partner,probinfect1_hpv11_anal,probinfect1_hpv16_anal,probinfect1_hpv18_anal,probinfect1_hpv31_anal,probinfect1_hpv33_anal,probinfect1_hpv45_anal,probinfect1_hpv52_anal,probinfect1_hpv58_anal,probinfect1_hpv6_anal,probinfect2_hpv11_anal,probinfect2_hpv16_anal,probinfect2_hpv18_anal,probinfect2_hpv31_anal,probinfect2_hpv33_anal,probinfect2_hpv45_anal,probinfect2_hpv52_anal,probinfect2_hpv58_anal,probinfect2_hpv6_anal,exposed_hpv33_oral_ego,exposed_hpv45_oral_ego,exposed_hpv52_oral_ego,exposed_hpv58_oral_ego,exposed_hpv6_oral_ego,exposed_hpv11_oral_ego,exposed_hpv16_oral_ego,exposed_hpv18_oral_ego,exposed_hpv31_oral_ego,exposed_hpv33_oral_partner,exposed_hpv45_oral_partner,exposed_hpv52_oral_partner,exposed_hpv58_oral_partner,exposed_hpv6_oral_partner,exposed_hpv11_oral_partner,exposed_hpv16_oral_partner,exposed_hpv18_oral_partner,exposed_hpv31_oral_partner,probinfect1_hpv11_oral,probinfect1_hpv18_oral,probinfect1_hpv33_oral,probinfect1_hpv52_oral,probinfect1_hpv6_oral,probinfect2_hpv16_oral,probinfect2_hpv31_oral,probinfect2_hpv45_oral,probinfect2_hpv58_oral,probinfect1_hpv16_oral,probinfect1_hpv31_oral,probinfect1_hpv45_oral,probinfect1_hpv58_oral,probinfect2_hpv11_oral,probinfect2_hpv18_oral,probinfect2_hpv33_oral,probinfect2_hpv52_oral,probinfect2_hpv6_oral)
        gc()
        
      } else {
        
        #pathogen concordance in every partnership
        
        ## UPDATE STATS IN MAIN DATASET ##
        
        prep_sims[[current_data]]$SEX_PARTNERS[sex_unexposed] = prep_sims[[current_data]]$SEX_PARTNERS[sex_unexposed] + 1
        
        ## CLEAN UP ##
        
        rm(sex_exposed,sex_unexposed)
        gc()
        
      }
      
    }

  }
  rm(day,current_data)

  #add this simulation to the list
  names(prep_sims) = paste("simulation",sims,names(prep_sims),sep="_")
  prep_sims_50 = c(prep_sims_50,prep_sims)
  
}
rm(sims,prep_sims,seed_val_day,seed_val_population,prevention_paradigm)
prep_sims_50[[1]] = NULL
gc()


### SAVE RESULTS ###

save.image("simulation results.RData")
load("simulation results.RData")


### STEP4: TALLY RESULTS ###

#scenario labels
hpv_type = c(6, 11, 16, 18, 31, 33, 45, 52, 58)
vax_level = c(0, 13, 25, 50, 80, 100)

#create results data frame
results_infections_anal = data.frame("HPV_type"=NA,"Vax_level"=NA,"Prev_mean"=NA,"Prev_SE"=NA,"Incidence_mean"=NA,"Incidence_SE"=NA,"New_mean"=NA,"New_SE"=NA,"Total_mean"=NA,"Total_SE"=NA,"Prevent_mean"=NA,"Prevent_SE"=NA,"Vax_prevent_mean"=NA,"Vax_prevent_SE"=NA,"Sero_prevent_mean"=NA,"Sero_prevent_SE"=NA,"Cond_prevent_mean"=NA,"Cond_prevent_SE"=NA,stringsAsFactors=F)
results_infections_oral = data.frame("HPV_type"=NA,"Vax_level"=NA,"Prev_mean"=NA,"Prev_SE"=NA,"Incidence_mean"=NA,"Incidence_SE"=NA,"New_mean"=NA,"New_SE"=NA,"Total_mean"=NA,"Total_SE"=NA,"Prevent_mean"=NA,"Prevent_SE"=NA,"Vax_prevent_mean"=NA,"Vax_prevent_SE"=NA,"Cond_prevent_mean"=NA,"Cond_prevent_SE"=NA,stringsAsFactors=F)
for (i in 1:length(hpv_type))
{
  for (j in 1:length(vax_level))
  {
    stat_prev_anal = NA         #point prevalance at post simulation (1 yr)
    stat_incidence_anal = NA    #1 yr incidence (new + spontaneous clearance)
    stat_new_anal = NA          #1 yr new + spontaneous clearance
    stat_total_anal = NA        #infections at post simulation (1 yr)
    stat_prevent_anal = NA      #total preventions (aggregate across all serotypes)
    stat_prevent_vax_anal = NA  #total vax preventions (aggregate across all serotypes)
    stat_prevent_sero_anal = NA #total sero preventions (aggregate across all serotypes)
    stat_prevent_cond_anal = NA #total condom preventions (aggregate across all serotypes)
    stat_prev_oral = NA         #point prevalance at post simulation (1 yr)
    stat_incidence_oral = NA    #1 yr incidence (new + spontaneous clearance)
    stat_new_oral = NA          #1 yr new + spontaneous clearance
    stat_total_oral = NA        #infections at post simulation (1 yr)
    stat_prevent_oral = NA      #total preventions (aggregate across all serotypes)
    stat_prevent_vax_oral = NA  #total vax preventions (aggregate across all serotypes)
    stat_prevent_cond_oral = NA #total condom preventions (aggregate across all serotypes)
    
    for (k in 0:(nsims-1))
    {
      current = k*length(vax_level)
      
      if (hpv_type[i]==6) {
        stat_prev_anal = c(stat_prev_anal, (sum(prep_sims_50[[j+current]]$HPV6_ANAL))/nrow(prep_sims_50[[j+current]]))
        stat_incidence_anal = c(stat_incidence_anal, (sum(prep_sims_50[[j+current]]$HPV6_ANAL) + sum(prep_sims_50[[j+current]]$HPV6_ANAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV6_ANAL))/nrow(prep_sims_50[[j+current]]))
        stat_new_anal = c(stat_new_anal, (sum(prep_sims_50[[j+current]]$HPV6_ANAL) + sum(prep_sims_50[[j+current]]$HPV6_ANAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV6_ANAL)))
        stat_total_anal = c(stat_total_anal, (sum(prep_sims_50[[j+current]]$HPV6_ANAL)))
        stat_prevent_anal = c(stat_prevent_anal, (sum(prep_sims_50[[j+current]]$OVERALL_PREVENT_ANAL)))
        stat_prevent_vax_anal = c(stat_prevent_vax_anal, (sum(prep_sims_50[[j+current]]$VAX_PREVENT_ANAL)))
        stat_prevent_sero_anal = c(stat_prevent_sero_anal, (sum(prep_sims_50[[j+current]]$SERO_PREVENT)))
        stat_prevent_cond_anal = c(stat_prevent_cond_anal, (sum(prep_sims_50[[j+current]]$COND_PREVENT_ANAL)))
        stat_prev_oral = c(stat_prev_oral, (sum(prep_sims_50[[j+current]]$HPV6_ORAL))/nrow(prep_sims_50[[j+current]]))
        stat_incidence_oral = c(stat_incidence_oral, (sum(prep_sims_50[[j+current]]$HPV6_ORAL) + sum(prep_sims_50[[j+current]]$HPV6_ORAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV6_ORAL))/nrow(prep_sims_50[[j+current]]))
        stat_new_oral = c(stat_new_oral, (sum(prep_sims_50[[j+current]]$HPV6_ORAL) + sum(prep_sims_50[[j+current]]$HPV6_ORAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV6_ORAL)))
        stat_total_oral = c(stat_total_oral, (sum(prep_sims_50[[j+current]]$HPV6_ORAL)))
        stat_prevent_oral = c(stat_prevent_oral, (sum(prep_sims_50[[j+current]]$OVERALL_PREVENT_ORAL)))
        stat_prevent_vax_oral = c(stat_prevent_vax_oral, (sum(prep_sims_50[[j+current]]$VAX_PREVENT_ORAL)))
        stat_prevent_cond_oral = c(stat_prevent_cond_oral, (sum(prep_sims_50[[j+current]]$COND_PREVENT_ORAL)))
      } else if (hpv_type[i]==11) {
        stat_prev_anal = c(stat_prev_anal, (sum(prep_sims_50[[j+current]]$HPV11_ANAL))/nrow(prep_sims_50[[j+current]]))
        stat_incidence_anal = c(stat_incidence_anal, (sum(prep_sims_50[[j+current]]$HPV11_ANAL) + sum(prep_sims_50[[j+current]]$HPV11_ANAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV11_ANAL))/nrow(prep_sims_50[[j+current]]))
        stat_new_anal = c(stat_new_anal, (sum(prep_sims_50[[j+current]]$HPV11_ANAL) + sum(prep_sims_50[[j+current]]$HPV11_ANAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV11_ANAL)))
        stat_total_anal = c(stat_total_anal, (sum(prep_sims_50[[j+current]]$HPV11_ANAL)))
        stat_prevent_anal = c(stat_prevent_anal, (sum(prep_sims_50[[j+current]]$OVERALL_PREVENT_ANAL)))
        stat_prevent_vax_anal = c(stat_prevent_vax_anal, (sum(prep_sims_50[[j+current]]$VAX_PREVENT_ANAL)))
        stat_prevent_sero_anal = c(stat_prevent_sero_anal, (sum(prep_sims_50[[j+current]]$SERO_PREVENT)))
        stat_prevent_cond_anal = c(stat_prevent_cond_anal, (sum(prep_sims_50[[j+current]]$COND_PREVENT_ANAL)))
        stat_prev_oral = c(stat_prev_oral, (sum(prep_sims_50[[j+current]]$HPV11_ORAL))/nrow(prep_sims_50[[j+current]]))
        stat_incidence_oral = c(stat_incidence_oral, (sum(prep_sims_50[[j+current]]$HPV11_ORAL) + sum(prep_sims_50[[j+current]]$HPV11_ORAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV11_ORAL))/nrow(prep_sims_50[[j+current]]))
        stat_new_oral = c(stat_new_oral, (sum(prep_sims_50[[j+current]]$HPV11_ORAL) + sum(prep_sims_50[[j+current]]$HPV11_ORAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV11_ORAL)))
        stat_total_oral = c(stat_total_oral, (sum(prep_sims_50[[j+current]]$HPV11_ORAL)))
        stat_prevent_oral = c(stat_prevent_oral, (sum(prep_sims_50[[j+current]]$OVERALL_PREVENT_ORAL)))
        stat_prevent_vax_oral = c(stat_prevent_vax_oral, (sum(prep_sims_50[[j+current]]$VAX_PREVENT_ORAL)))
        stat_prevent_cond_oral = c(stat_prevent_cond_oral, (sum(prep_sims_50[[j+current]]$COND_PREVENT_ORAL)))
      } else if (hpv_type[i]==16) {
        stat_prev_anal = c(stat_prev_anal, (sum(prep_sims_50[[j+current]]$HPV16_ANAL))/nrow(prep_sims_50[[j+current]]))
        stat_incidence_anal = c(stat_incidence_anal, (sum(prep_sims_50[[j+current]]$HPV16_ANAL) + sum(prep_sims_50[[j+current]]$HPV16_ANAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV16_ANAL))/nrow(prep_sims_50[[j+current]]))
        stat_new_anal = c(stat_new_anal, (sum(prep_sims_50[[j+current]]$HPV16_ANAL) + sum(prep_sims_50[[j+current]]$HPV16_ANAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV16_ANAL)))
        stat_total_anal = c(stat_total_anal, (sum(prep_sims_50[[j+current]]$HPV16_ANAL)))
        stat_prevent_anal = c(stat_prevent_anal, (sum(prep_sims_50[[j+current]]$OVERALL_PREVENT_ANAL)))
        stat_prevent_vax_anal = c(stat_prevent_vax_anal, (sum(prep_sims_50[[j+current]]$VAX_PREVENT_ANAL)))
        stat_prevent_sero_anal = c(stat_prevent_sero_anal, (sum(prep_sims_50[[j+current]]$SERO_PREVENT)))
        stat_prevent_cond_anal = c(stat_prevent_cond_anal, (sum(prep_sims_50[[j+current]]$COND_PREVENT_ANAL)))
        stat_prev_oral = c(stat_prev_oral, (sum(prep_sims_50[[j+current]]$HPV16_ORAL))/nrow(prep_sims_50[[j+current]]))
        stat_incidence_oral = c(stat_incidence_oral, (sum(prep_sims_50[[j+current]]$HPV16_ORAL) + sum(prep_sims_50[[j+current]]$HPV16_ORAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV16_ORAL))/nrow(prep_sims_50[[j+current]]))
        stat_new_oral = c(stat_new_oral, (sum(prep_sims_50[[j+current]]$HPV16_ORAL) + sum(prep_sims_50[[j+current]]$HPV16_ORAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV16_ORAL)))
        stat_total_oral = c(stat_total_oral, (sum(prep_sims_50[[j+current]]$HPV16_ORAL)))
        stat_prevent_oral = c(stat_prevent_oral, (sum(prep_sims_50[[j+current]]$OVERALL_PREVENT_ORAL)))
        stat_prevent_vax_oral = c(stat_prevent_vax_oral, (sum(prep_sims_50[[j+current]]$VAX_PREVENT_ORAL)))
        stat_prevent_cond_oral = c(stat_prevent_cond_oral, (sum(prep_sims_50[[j+current]]$COND_PREVENT_ORAL)))
      } else if (hpv_type[i]==18) {
        stat_prev_anal = c(stat_prev_anal, (sum(prep_sims_50[[j+current]]$HPV18_ANAL))/nrow(prep_sims_50[[j+current]]))
        stat_incidence_anal = c(stat_incidence_anal, (sum(prep_sims_50[[j+current]]$HPV18_ANAL) + sum(prep_sims_50[[j+current]]$HPV18_ANAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV18_ANAL))/nrow(prep_sims_50[[j+current]]))
        stat_new_anal = c(stat_new_anal, (sum(prep_sims_50[[j+current]]$HPV18_ANAL) + sum(prep_sims_50[[j+current]]$HPV18_ANAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV18_ANAL)))
        stat_total_anal = c(stat_total_anal, (sum(prep_sims_50[[j+current]]$HPV18_ANAL)))
        stat_prevent_anal = c(stat_prevent_anal, (sum(prep_sims_50[[j+current]]$OVERALL_PREVENT_ANAL)))
        stat_prevent_vax_anal = c(stat_prevent_vax_anal, (sum(prep_sims_50[[j+current]]$VAX_PREVENT_ANAL)))
        stat_prevent_sero_anal = c(stat_prevent_sero_anal, (sum(prep_sims_50[[j+current]]$SERO_PREVENT)))
        stat_prevent_cond_anal = c(stat_prevent_cond_anal, (sum(prep_sims_50[[j+current]]$COND_PREVENT_ANAL)))
        stat_prev_oral = c(stat_prev_oral, (sum(prep_sims_50[[j+current]]$HPV18_ORAL))/nrow(prep_sims_50[[j+current]]))
        stat_incidence_oral = c(stat_incidence_oral, (sum(prep_sims_50[[j+current]]$HPV18_ORAL) + sum(prep_sims_50[[j+current]]$HPV18_ORAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV18_ORAL))/nrow(prep_sims_50[[j+current]]))
        stat_new_oral = c(stat_new_oral, (sum(prep_sims_50[[j+current]]$HPV18_ORAL) + sum(prep_sims_50[[j+current]]$HPV18_ORAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV18_ORAL)))
        stat_total_oral = c(stat_total_oral, (sum(prep_sims_50[[j+current]]$HPV18_ORAL)))
        stat_prevent_oral = c(stat_prevent_oral, (sum(prep_sims_50[[j+current]]$OVERALL_PREVENT_ORAL)))
        stat_prevent_vax_oral = c(stat_prevent_vax_oral, (sum(prep_sims_50[[j+current]]$VAX_PREVENT_ORAL)))
        stat_prevent_cond_oral = c(stat_prevent_cond_oral, (sum(prep_sims_50[[j+current]]$COND_PREVENT_ORAL)))
      } else if (hpv_type[i]==31) {
        stat_prev_anal = c(stat_prev_anal, (sum(prep_sims_50[[j+current]]$HPV31_ANAL))/nrow(prep_sims_50[[j+current]]))
        stat_incidence_anal = c(stat_incidence_anal, (sum(prep_sims_50[[j+current]]$HPV31_ANAL) + sum(prep_sims_50[[j+current]]$HPV31_ANAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV31_ANAL))/nrow(prep_sims_50[[j+current]]))
        stat_new_anal = c(stat_new_anal, (sum(prep_sims_50[[j+current]]$HPV31_ANAL) + sum(prep_sims_50[[j+current]]$HPV31_ANAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV31_ANAL)))
        stat_total_anal = c(stat_total_anal, (sum(prep_sims_50[[j+current]]$HPV31_ANAL)))
        stat_prevent_anal = c(stat_prevent_anal, (sum(prep_sims_50[[j+current]]$OVERALL_PREVENT_ANAL)))
        stat_prevent_vax_anal = c(stat_prevent_vax_anal, (sum(prep_sims_50[[j+current]]$VAX_PREVENT_ANAL)))
        stat_prevent_sero_anal = c(stat_prevent_sero_anal, (sum(prep_sims_50[[j+current]]$SERO_PREVENT)))
        stat_prevent_cond_anal = c(stat_prevent_cond_anal, (sum(prep_sims_50[[j+current]]$COND_PREVENT_ANAL)))
        stat_prev_oral = c(stat_prev_oral, (sum(prep_sims_50[[j+current]]$HPV31_ORAL))/nrow(prep_sims_50[[j+current]]))
        stat_incidence_oral = c(stat_incidence_oral, (sum(prep_sims_50[[j+current]]$HPV31_ORAL) + sum(prep_sims_50[[j+current]]$HPV31_ORAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV31_ORAL))/nrow(prep_sims_50[[j+current]]))
        stat_new_oral = c(stat_new_oral, (sum(prep_sims_50[[j+current]]$HPV31_ORAL) + sum(prep_sims_50[[j+current]]$HPV31_ORAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV31_ORAL)))
        stat_total_oral = c(stat_total_oral, (sum(prep_sims_50[[j+current]]$HPV31_ORAL)))
        stat_prevent_oral = c(stat_prevent_oral, (sum(prep_sims_50[[j+current]]$OVERALL_PREVENT_ORAL)))
        stat_prevent_vax_oral = c(stat_prevent_vax_oral, (sum(prep_sims_50[[j+current]]$VAX_PREVENT_ORAL)))
        stat_prevent_cond_oral = c(stat_prevent_cond_oral, (sum(prep_sims_50[[j+current]]$COND_PREVENT_ORAL)))
      } else if (hpv_type[i]==33) {
        stat_prev_anal = c(stat_prev_anal, (sum(prep_sims_50[[j+current]]$HPV33_ANAL))/nrow(prep_sims_50[[j+current]]))
        stat_incidence_anal = c(stat_incidence_anal, (sum(prep_sims_50[[j+current]]$HPV33_ANAL) + sum(prep_sims_50[[j+current]]$HPV33_ANAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV33_ANAL))/nrow(prep_sims_50[[j+current]]))
        stat_new_anal = c(stat_new_anal, (sum(prep_sims_50[[j+current]]$HPV33_ANAL) + sum(prep_sims_50[[j+current]]$HPV33_ANAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV33_ANAL)))
        stat_total_anal = c(stat_total_anal, (sum(prep_sims_50[[j+current]]$HPV33_ANAL)))
        stat_prevent_anal = c(stat_prevent_anal, (sum(prep_sims_50[[j+current]]$OVERALL_PREVENT_ANAL)))
        stat_prevent_vax_anal = c(stat_prevent_vax_anal, (sum(prep_sims_50[[j+current]]$VAX_PREVENT_ANAL)))
        stat_prevent_sero_anal = c(stat_prevent_sero_anal, (sum(prep_sims_50[[j+current]]$SERO_PREVENT)))
        stat_prevent_cond_anal = c(stat_prevent_cond_anal, (sum(prep_sims_50[[j+current]]$COND_PREVENT_ANAL)))
        stat_prev_oral = c(stat_prev_oral, (sum(prep_sims_50[[j+current]]$HPV33_ORAL))/nrow(prep_sims_50[[j+current]]))
        stat_incidence_oral = c(stat_incidence_oral, (sum(prep_sims_50[[j+current]]$HPV33_ORAL) + sum(prep_sims_50[[j+current]]$HPV33_ORAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV33_ORAL))/nrow(prep_sims_50[[j+current]]))
        stat_new_oral = c(stat_new_oral, (sum(prep_sims_50[[j+current]]$HPV33_ORAL) + sum(prep_sims_50[[j+current]]$HPV33_ORAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV33_ORAL)))
        stat_total_oral = c(stat_total_oral, (sum(prep_sims_50[[j+current]]$HPV33_ORAL)))
        stat_prevent_oral = c(stat_prevent_oral, (sum(prep_sims_50[[j+current]]$OVERALL_PREVENT_ORAL)))
        stat_prevent_vax_oral = c(stat_prevent_vax_oral, (sum(prep_sims_50[[j+current]]$VAX_PREVENT_ORAL)))
        stat_prevent_cond_oral = c(stat_prevent_cond_oral, (sum(prep_sims_50[[j+current]]$COND_PREVENT_ORAL)))
      } else if (hpv_type[i]==45) {
        stat_prev_anal = c(stat_prev_anal, (sum(prep_sims_50[[j+current]]$HPV45_ANAL))/nrow(prep_sims_50[[j+current]]))
        stat_incidence_anal = c(stat_incidence_anal, (sum(prep_sims_50[[j+current]]$HPV45_ANAL) + sum(prep_sims_50[[j+current]]$HPV45_ANAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV45_ANAL))/nrow(prep_sims_50[[j+current]]))
        stat_new_anal = c(stat_new_anal, (sum(prep_sims_50[[j+current]]$HPV45_ANAL) + sum(prep_sims_50[[j+current]]$HPV45_ANAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV45_ANAL)))
        stat_total_anal = c(stat_total_anal, (sum(prep_sims_50[[j+current]]$HPV45_ANAL)))
        stat_prevent_anal = c(stat_prevent_anal, (sum(prep_sims_50[[j+current]]$OVERALL_PREVENT_ANAL)))
        stat_prevent_vax_anal = c(stat_prevent_vax_anal, (sum(prep_sims_50[[j+current]]$VAX_PREVENT_ANAL)))
        stat_prevent_sero_anal = c(stat_prevent_sero_anal, (sum(prep_sims_50[[j+current]]$SERO_PREVENT)))
        stat_prevent_cond_anal = c(stat_prevent_cond_anal, (sum(prep_sims_50[[j+current]]$COND_PREVENT_ANAL)))
        stat_prev_oral = c(stat_prev_oral, (sum(prep_sims_50[[j+current]]$HPV45_ORAL))/nrow(prep_sims_50[[j+current]]))
        stat_incidence_oral = c(stat_incidence_oral, (sum(prep_sims_50[[j+current]]$HPV45_ORAL) + sum(prep_sims_50[[j+current]]$HPV45_ORAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV45_ORAL))/nrow(prep_sims_50[[j+current]]))
        stat_new_oral = c(stat_new_oral, (sum(prep_sims_50[[j+current]]$HPV45_ORAL) + sum(prep_sims_50[[j+current]]$HPV45_ORAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV45_ORAL)))
        stat_total_oral = c(stat_total_oral, (sum(prep_sims_50[[j+current]]$HPV45_ORAL)))
        stat_prevent_oral = c(stat_prevent_oral, (sum(prep_sims_50[[j+current]]$OVERALL_PREVENT_ORAL)))
        stat_prevent_vax_oral = c(stat_prevent_vax_oral, (sum(prep_sims_50[[j+current]]$VAX_PREVENT_ORAL)))
        stat_prevent_cond_oral = c(stat_prevent_cond_oral, (sum(prep_sims_50[[j+current]]$COND_PREVENT_ORAL)))
      } else if (hpv_type[i]==52) {
        stat_prev_anal = c(stat_prev_anal, (sum(prep_sims_50[[j+current]]$HPV52_ANAL))/nrow(prep_sims_50[[j+current]]))
        stat_incidence_anal = c(stat_incidence_anal, (sum(prep_sims_50[[j+current]]$HPV52_ANAL) + sum(prep_sims_50[[j+current]]$HPV52_ANAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV52_ANAL))/nrow(prep_sims_50[[j+current]]))
        stat_new_anal = c(stat_new_anal, (sum(prep_sims_50[[j+current]]$HPV52_ANAL) + sum(prep_sims_50[[j+current]]$HPV52_ANAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV52_ANAL)))
        stat_total_anal = c(stat_total_anal, (sum(prep_sims_50[[j+current]]$HPV52_ANAL)))
        stat_prevent_anal = c(stat_prevent_anal, (sum(prep_sims_50[[j+current]]$OVERALL_PREVENT_ANAL)))
        stat_prevent_vax_anal = c(stat_prevent_vax_anal, (sum(prep_sims_50[[j+current]]$VAX_PREVENT_ANAL)))
        stat_prevent_sero_anal = c(stat_prevent_sero_anal, (sum(prep_sims_50[[j+current]]$SERO_PREVENT)))
        stat_prevent_cond_anal = c(stat_prevent_cond_anal, (sum(prep_sims_50[[j+current]]$COND_PREVENT_ANAL)))
        stat_prev_oral = c(stat_prev_oral, (sum(prep_sims_50[[j+current]]$HPV52_ORAL))/nrow(prep_sims_50[[j+current]]))
        stat_incidence_oral = c(stat_incidence_oral, (sum(prep_sims_50[[j+current]]$HPV52_ORAL) + sum(prep_sims_50[[j+current]]$HPV52_ORAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV52_ORAL))/nrow(prep_sims_50[[j+current]]))
        stat_new_oral = c(stat_new_oral, (sum(prep_sims_50[[j+current]]$HPV52_ORAL) + sum(prep_sims_50[[j+current]]$HPV52_ORAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV52_ORAL)))
        stat_total_oral = c(stat_total_oral, (sum(prep_sims_50[[j+current]]$HPV52_ORAL)))
        stat_prevent_oral = c(stat_prevent_oral, (sum(prep_sims_50[[j+current]]$OVERALL_PREVENT_ORAL)))
        stat_prevent_vax_oral = c(stat_prevent_vax_oral, (sum(prep_sims_50[[j+current]]$VAX_PREVENT_ORAL)))
        stat_prevent_cond_oral = c(stat_prevent_cond_oral, (sum(prep_sims_50[[j+current]]$COND_PREVENT_ORAL)))
      } else if (hpv_type[i]==58) {
        stat_prev_anal = c(stat_prev_anal, (sum(prep_sims_50[[j+current]]$HPV58_ANAL))/nrow(prep_sims_50[[j+current]]))
        stat_incidence_anal = c(stat_incidence_anal, (sum(prep_sims_50[[j+current]]$HPV58_ANAL) + sum(prep_sims_50[[j+current]]$HPV58_ANAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV58_ANAL))/nrow(prep_sims_50[[j+current]]))
        stat_new_anal = c(stat_new_anal, (sum(prep_sims_50[[j+current]]$HPV58_ANAL) + sum(prep_sims_50[[j+current]]$HPV58_ANAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV58_ANAL)))
        stat_total_anal = c(stat_total_anal, (sum(prep_sims_50[[j+current]]$HPV58_ANAL)))
        stat_prevent_anal = c(stat_prevent_anal, (sum(prep_sims_50[[j+current]]$OVERALL_PREVENT_ANAL)))
        stat_prevent_vax_anal = c(stat_prevent_vax_anal, (sum(prep_sims_50[[j+current]]$VAX_PREVENT_ANAL)))
        stat_prevent_sero_anal = c(stat_prevent_sero_anal, (sum(prep_sims_50[[j+current]]$SERO_PREVENT)))
        stat_prevent_cond_anal = c(stat_prevent_cond_anal, (sum(prep_sims_50[[j+current]]$COND_PREVENT_ANAL)))
        stat_prev_oral = c(stat_prev_oral, (sum(prep_sims_50[[j+current]]$HPV58_ORAL))/nrow(prep_sims_50[[j+current]]))
        stat_incidence_oral = c(stat_incidence_oral, (sum(prep_sims_50[[j+current]]$HPV58_ORAL) + sum(prep_sims_50[[j+current]]$HPV58_ORAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV58_ORAL))/nrow(prep_sims_50[[j+current]]))
        stat_new_oral = c(stat_new_oral, (sum(prep_sims_50[[j+current]]$HPV58_ORAL) + sum(prep_sims_50[[j+current]]$HPV58_ORAL_CLEARED) - sum(prep_sims_50[[j+current]]$ORIGINAL_STATUS_HPV58_ORAL)))
        stat_total_oral = c(stat_total_oral, (sum(prep_sims_50[[j+current]]$HPV58_ORAL)))
        stat_prevent_oral = c(stat_prevent_oral, (sum(prep_sims_50[[j+current]]$OVERALL_PREVENT_ORAL)))
        stat_prevent_vax_oral = c(stat_prevent_vax_oral, (sum(prep_sims_50[[j+current]]$VAX_PREVENT_ORAL)))
        stat_prevent_cond_oral = c(stat_prevent_cond_oral, (sum(prep_sims_50[[j+current]]$COND_PREVENT_ORAL)))
      }
    }
    
    stat_prev_anal = stat_prev_anal[-1]
    stat_incidence_anal = stat_incidence_anal[-1]
    stat_new_anal = stat_new_anal[-1]
    stat_total_anal = stat_total_anal[-1]
    stat_prevent_anal = stat_prevent_anal[-1]
    stat_prevent_vax_anal = stat_prevent_vax_anal[-1]
    stat_prevent_sero_anal = stat_prevent_sero_anal[-1]
    stat_prevent_cond_anal = stat_prevent_cond_anal[-1]
    stat_prev_oral = stat_prev_oral[-1]
    stat_incidence_oral = stat_incidence_oral[-1]
    stat_new_oral = stat_new_oral[-1]
    stat_total_oral = stat_total_oral[-1]
    stat_prevent_oral = stat_prevent_oral[-1]
    stat_prevent_vax_oral = stat_prevent_vax_oral[-1]
    stat_prevent_cond_oral = stat_prevent_cond_oral[-1]

    results_infections_anal = rbind(results_infections_anal, data.frame("HPV_type"=hpv_type[i],"Vax_level"=vax_level[j],"Prev_mean"=mean(stat_prev_anal),"Prev_SE"=(sd(stat_prev_anal)/sqrt(length(stat_prev_anal))),"Incidence_mean"=mean(stat_incidence_anal),"Incidence_SE"=(sd(stat_incidence_anal)/sqrt(length(stat_incidence_anal))),"New_mean"=mean(stat_new_anal),"New_SE"=(sd(stat_new_anal)/sqrt(length(stat_new_anal))),"Total_mean"=mean(stat_total_anal),"Total_SE"=(sd(stat_total_anal)/sqrt(length(stat_total_anal))),"Prevent_mean"=mean(stat_prevent_anal),"Prevent_SE"=(sd(stat_prevent_anal)/sqrt(length(stat_prevent_anal))),"Vax_prevent_mean"=mean(stat_prevent_vax_anal),"Vax_prevent_SE"=(sd(stat_prevent_vax_anal)/sqrt(length(stat_prevent_vax_anal))),"Sero_prevent_mean"=mean(stat_prevent_sero_anal),"Sero_prevent_SE"=(sd(stat_prevent_sero_anal)/sqrt(length(stat_prevent_sero_anal))),"Cond_prevent_mean"=mean(stat_prevent_cond_anal),"Cond_prevent_SE"=(sd(stat_prevent_cond_anal)/sqrt(length(stat_prevent_cond_anal))),stringsAsFactors=F))
    results_infections_oral = rbind(results_infections_oral, data.frame("HPV_type"=hpv_type[i],"Vax_level"=vax_level[j],"Prev_mean"=mean(stat_prev_oral),"Prev_SE"=(sd(stat_prev_oral)/sqrt(length(stat_prev_oral))),"Incidence_mean"=mean(stat_incidence_oral),"Incidence_SE"=(sd(stat_incidence_oral)/sqrt(length(stat_incidence_oral))),"New_mean"=mean(stat_new_oral),"New_SE"=(sd(stat_new_oral)/sqrt(length(stat_new_oral))),"Total_mean"=mean(stat_total_oral),"Total_SE"=(sd(stat_total_oral)/sqrt(length(stat_total_oral))),"Prevent_mean"=mean(stat_prevent_oral),"Prevent_SE"=(sd(stat_prevent_oral)/sqrt(length(stat_prevent_oral))),"Vax_prevent_mean"=mean(stat_prevent_vax_oral),"Vax_prevent_SE"=(sd(stat_prevent_vax_oral)/sqrt(length(stat_prevent_vax_oral))),"Cond_prevent_mean"=mean(stat_prevent_cond_oral),"Cond_prevent_SE"=(sd(stat_prevent_cond_oral)/sqrt(length(stat_prevent_cond_oral))),stringsAsFactors=F))
  }
}
rm(i,j,k,current,stat_prev_anal,stat_incidence_anal,stat_new_anal,stat_total_anal,stat_prevent_anal,stat_prevent_vax_anal,stat_prevent_sero_anal,stat_prevent_cond_anal,stat_prev_oral,stat_incidence_oral,stat_new_oral,stat_total_oral,stat_prevent_oral,stat_prevent_vax_oral,stat_prevent_cond_oral)
results_infections_anal = results_infections_anal[-1, ]
results_infections_oral = results_infections_oral[-1, ]

#overall starting prevalence (all simulations start out the same)
sum(prep_sims_50[[1]]$ORIGINAL_STATUS_HPV_ANAL)/10000
sum(prep_sims_50[[1]]$ORIGINAL_STATUS_HPV_ORAL)/10000
sum(prep_sims_50[[1]]$ORIGINAL_STATUS_HIV)/10000

sum(prep_sims_50[[1]]$ORIGINAL_STATUS_HPV6_ANAL)/10000
sum(prep_sims_50[[1]]$ORIGINAL_STATUS_HPV11_ANAL)/10000
sum(prep_sims_50[[1]]$ORIGINAL_STATUS_HPV16_ANAL)/10000
sum(prep_sims_50[[1]]$ORIGINAL_STATUS_HPV18_ANAL)/10000
sum(prep_sims_50[[1]]$ORIGINAL_STATUS_HPV31_ANAL)/10000
sum(prep_sims_50[[1]]$ORIGINAL_STATUS_HPV33_ANAL)/10000
sum(prep_sims_50[[1]]$ORIGINAL_STATUS_HPV45_ANAL)/10000
sum(prep_sims_50[[1]]$ORIGINAL_STATUS_HPV52_ANAL)/10000
sum(prep_sims_50[[1]]$ORIGINAL_STATUS_HPV58_ANAL)/10000

sum(prep_sims_50[[1]]$ORIGINAL_STATUS_HPV6_ORAL)/10000
sum(prep_sims_50[[1]]$ORIGINAL_STATUS_HPV11_ORAL)/10000
sum(prep_sims_50[[1]]$ORIGINAL_STATUS_HPV16_ORAL)/10000
sum(prep_sims_50[[1]]$ORIGINAL_STATUS_HPV18_ORAL)/10000
sum(prep_sims_50[[1]]$ORIGINAL_STATUS_HPV31_ORAL)/10000
sum(prep_sims_50[[1]]$ORIGINAL_STATUS_HPV33_ORAL)/10000
sum(prep_sims_50[[1]]$ORIGINAL_STATUS_HPV45_ORAL)/10000
sum(prep_sims_50[[1]]$ORIGINAL_STATUS_HPV52_ORAL)/10000
sum(prep_sims_50[[1]]$ORIGINAL_STATUS_HPV58_ORAL)/10000

#overall HPV incidence at 0% vaccination level
stat_anal = NA
stat_oral = NA
for (i in 0:(nsims-1))
{
  current = (i*length(vax_level)+1)
  stat_anal = c(stat_anal, (sum(prep_sims_50[[current]]$HPV_ANAL) + sum(prep_sims_50[[current]]$HPV6_ANAL_CLEARED) + sum(prep_sims_50[[current]]$HPV11_ANAL_CLEARED) + sum(prep_sims_50[[current]]$HPV16_ANAL_CLEARED) + sum(prep_sims_50[[current]]$HPV18_ANAL_CLEARED) + sum(prep_sims_50[[current]]$HPV31_ANAL_CLEARED) + sum(prep_sims_50[[current]]$HPV33_ANAL_CLEARED) + sum(prep_sims_50[[current]]$HPV45_ANAL_CLEARED) + sum(prep_sims_50[[current]]$HPV52_ANAL_CLEARED) + sum(prep_sims_50[[current]]$HPV58_ANAL_CLEARED) - sum(prep_sims_50[[current]]$ORIGINAL_STATUS_HPV_ANAL))/10000)
  stat_oral = c(stat_oral, (sum(prep_sims_50[[current]]$HPV_ORAL) + sum(prep_sims_50[[current]]$HPV6_ORAL_CLEARED) + sum(prep_sims_50[[current]]$HPV11_ORAL_CLEARED) + sum(prep_sims_50[[current]]$HPV16_ORAL_CLEARED) + sum(prep_sims_50[[current]]$HPV18_ORAL_CLEARED) + sum(prep_sims_50[[current]]$HPV31_ORAL_CLEARED) + sum(prep_sims_50[[current]]$HPV33_ORAL_CLEARED) + sum(prep_sims_50[[current]]$HPV45_ORAL_CLEARED) + sum(prep_sims_50[[current]]$HPV52_ORAL_CLEARED) + sum(prep_sims_50[[current]]$HPV58_ORAL_CLEARED) - sum(prep_sims_50[[current]]$ORIGINAL_STATUS_HPV_ORAL))/10000)
}
mean(stat_anal[-1]); min(stat_anal[-1]); max(stat_anal[-1])
mean(stat_oral[-1]); min(stat_oral[-1]); max(stat_oral[-1])

#one year prevalence at 0% vaccination level
stat_anal = NA
stat_oral = NA
for (i in 0:(nsims-1))
{
  current = (i*length(vax_level)+1)
  stat_anal = c(stat_anal, (sum(prep_sims_50[[current]]$HPV_ANAL))/10000)
  stat_oral = c(stat_oral, (sum(prep_sims_50[[current]]$HPV_ORAL))/10000)
}
mean(stat_anal[-1]); min(stat_anal[-1]); max(stat_anal[-1])
mean(stat_oral[-1]); min(stat_oral[-1]); max(stat_oral[-1])

#high and low incidence/prevalence by serotype at 0% vaccination level
View(results_infections_anal[results_infections_anal$Vax_level==0, ])
View(results_infections_oral[results_infections_oral$Vax_level==0, ])

#preventions at 0% vaccination level
mean(results_infections_anal$Prevent_mean[results_infections_anal$Vax_level==0] / (results_infections_anal$New_mean[results_infections_anal$Vax_level==0] + results_infections_anal$Prevent_mean[results_infections_anal$Vax_level==0]))
min(results_infections_anal$Prevent_mean[results_infections_anal$Vax_level==0] / (results_infections_anal$New_mean[results_infections_anal$Vax_level==0] + results_infections_anal$Prevent_mean[results_infections_anal$Vax_level==0]))
max(results_infections_anal$Prevent_mean[results_infections_anal$Vax_level==0] / (results_infections_anal$New_mean[results_infections_anal$Vax_level==0] + results_infections_anal$Prevent_mean[results_infections_anal$Vax_level==0]))
mean(results_infections_anal$Cond_prevent_mean[results_infections_anal$Vax_level==0] / results_infections_anal$Prevent_mean[results_infections_anal$Vax_level==0])

mean(results_infections_oral$Prevent_mean[results_infections_oral$Vax_level==0] / (results_infections_oral$New_mean[results_infections_oral$Vax_level==0] + results_infections_oral$Prevent_mean[results_infections_oral$Vax_level==0]))
min(results_infections_oral$Prevent_mean[results_infections_oral$Vax_level==0] / (results_infections_oral$New_mean[results_infections_oral$Vax_level==0] + results_infections_oral$Prevent_mean[results_infections_oral$Vax_level==0]))
max(results_infections_oral$Prevent_mean[results_infections_oral$Vax_level==0] / (results_infections_oral$New_mean[results_infections_oral$Vax_level==0] + results_infections_oral$Prevent_mean[results_infections_oral$Vax_level==0]))
mean(results_infections_oral$Cond_prevent_mean[results_infections_oral$Vax_level==0] / results_infections_oral$Prevent_mean[results_infections_oral$Vax_level==0])

#preventions at varying vaccination level
# mean(results_infections_anal$Prevent_mean[results_infections_anal$Vax_level==13] / (results_infections_anal$New_mean[results_infections_anal$Vax_level==13] + results_infections_anal$Prevent_mean[results_infections_anal$Vax_level==13]))
# mean(results_infections_anal$Prevent_mean[results_infections_anal$Vax_level==25] / (results_infections_anal$New_mean[results_infections_anal$Vax_level==25] + results_infections_anal$Prevent_mean[results_infections_anal$Vax_level==25]))
# mean(results_infections_anal$Prevent_mean[results_infections_anal$Vax_level==50] / (results_infections_anal$New_mean[results_infections_anal$Vax_level==50] + results_infections_anal$Prevent_mean[results_infections_anal$Vax_level==50]))
# mean(results_infections_anal$Prevent_mean[results_infections_anal$Vax_level==80] / (results_infections_anal$New_mean[results_infections_anal$Vax_level==80] + results_infections_anal$Prevent_mean[results_infections_anal$Vax_level==80]))
# mean(results_infections_anal$Prevent_mean[results_infections_anal$Vax_level==100] / (results_infections_anal$New_mean[results_infections_anal$Vax_level==100] + results_infections_anal$Prevent_mean[results_infections_anal$Vax_level==100]))

#% reduction in incidence overall at each vaccination level
mean((results_infections_anal$Incidence_mean[results_infections_anal$Vax_level==0] - results_infections_anal$Incidence_mean[results_infections_anal$Vax_level==13]) / results_infections_anal$Incidence_mean[results_infections_anal$Vax_level==0])
mean((results_infections_anal$Incidence_mean[results_infections_anal$Vax_level==0] - results_infections_anal$Incidence_mean[results_infections_anal$Vax_level==25]) / results_infections_anal$Incidence_mean[results_infections_anal$Vax_level==0])
mean((results_infections_anal$Incidence_mean[results_infections_anal$Vax_level==0] - results_infections_anal$Incidence_mean[results_infections_anal$Vax_level==50]) / results_infections_anal$Incidence_mean[results_infections_anal$Vax_level==0])
mean((results_infections_anal$Incidence_mean[results_infections_anal$Vax_level==0] - results_infections_anal$Incidence_mean[results_infections_anal$Vax_level==80]) / results_infections_anal$Incidence_mean[results_infections_anal$Vax_level==0])
mean((results_infections_anal$Incidence_mean[results_infections_anal$Vax_level==0] - results_infections_anal$Incidence_mean[results_infections_anal$Vax_level==100]) / results_infections_anal$Incidence_mean[results_infections_anal$Vax_level==0])

mean((results_infections_oral$Incidence_mean[results_infections_oral$Vax_level==0] - results_infections_oral$Incidence_mean[results_infections_oral$Vax_level==13]) / results_infections_oral$Incidence_mean[results_infections_oral$Vax_level==0])
mean((results_infections_oral$Incidence_mean[results_infections_oral$Vax_level==0] - results_infections_oral$Incidence_mean[results_infections_oral$Vax_level==25]) / results_infections_oral$Incidence_mean[results_infections_oral$Vax_level==0])
mean((results_infections_oral$Incidence_mean[results_infections_oral$Vax_level==0] - results_infections_oral$Incidence_mean[results_infections_oral$Vax_level==50]) / results_infections_oral$Incidence_mean[results_infections_oral$Vax_level==0])
mean((results_infections_oral$Incidence_mean[results_infections_oral$Vax_level==0] - results_infections_oral$Incidence_mean[results_infections_oral$Vax_level==80]) / results_infections_oral$Incidence_mean[results_infections_oral$Vax_level==0])
mean((results_infections_oral$Incidence_mean[results_infections_oral$Vax_level==0] - results_infections_oral$Incidence_mean[results_infections_oral$Vax_level==100]) / results_infections_oral$Incidence_mean[results_infections_oral$Vax_level==0])

#% reduction in incidence by serotype
(results_infections_anal$Incidence_mean[results_infections_anal$HPV_type==6 & results_infections_anal$Vax_level==13] - results_infections_anal$Incidence_mean[results_infections_anal$HPV_type==6 & results_infections_anal$Vax_level==80]) / results_infections_anal$Incidence_mean[results_infections_anal$HPV_type==6 & results_infections_anal$Vax_level==13]
(results_infections_anal$Incidence_mean[results_infections_anal$HPV_type==11 & results_infections_anal$Vax_level==13] - results_infections_anal$Incidence_mean[results_infections_anal$HPV_type==11 & results_infections_anal$Vax_level==80]) / results_infections_anal$Incidence_mean[results_infections_anal$HPV_type==11 & results_infections_anal$Vax_level==13]
(results_infections_anal$Incidence_mean[results_infections_anal$HPV_type==16 & results_infections_anal$Vax_level==13] - results_infections_anal$Incidence_mean[results_infections_anal$HPV_type==16 & results_infections_anal$Vax_level==80]) / results_infections_anal$Incidence_mean[results_infections_anal$HPV_type==16 & results_infections_anal$Vax_level==13]
(results_infections_anal$Incidence_mean[results_infections_anal$HPV_type==18 & results_infections_anal$Vax_level==13] - results_infections_anal$Incidence_mean[results_infections_anal$HPV_type==18 & results_infections_anal$Vax_level==80]) / results_infections_anal$Incidence_mean[results_infections_anal$HPV_type==18 & results_infections_anal$Vax_level==13]
(results_infections_anal$Incidence_mean[results_infections_anal$HPV_type==31 & results_infections_anal$Vax_level==13] - results_infections_anal$Incidence_mean[results_infections_anal$HPV_type==31 & results_infections_anal$Vax_level==80]) / results_infections_anal$Incidence_mean[results_infections_anal$HPV_type==31 & results_infections_anal$Vax_level==13]
(results_infections_anal$Incidence_mean[results_infections_anal$HPV_type==33 & results_infections_anal$Vax_level==13] - results_infections_anal$Incidence_mean[results_infections_anal$HPV_type==33 & results_infections_anal$Vax_level==80]) / results_infections_anal$Incidence_mean[results_infections_anal$HPV_type==33 & results_infections_anal$Vax_level==13]
(results_infections_anal$Incidence_mean[results_infections_anal$HPV_type==45 & results_infections_anal$Vax_level==13] - results_infections_anal$Incidence_mean[results_infections_anal$HPV_type==45 & results_infections_anal$Vax_level==80]) / results_infections_anal$Incidence_mean[results_infections_anal$HPV_type==45 & results_infections_anal$Vax_level==13]
(results_infections_anal$Incidence_mean[results_infections_anal$HPV_type==52 & results_infections_anal$Vax_level==13] - results_infections_anal$Incidence_mean[results_infections_anal$HPV_type==52 & results_infections_anal$Vax_level==80]) / results_infections_anal$Incidence_mean[results_infections_anal$HPV_type==52 & results_infections_anal$Vax_level==13]
(results_infections_anal$Incidence_mean[results_infections_anal$HPV_type==58 & results_infections_anal$Vax_level==13] - results_infections_anal$Incidence_mean[results_infections_anal$HPV_type==58 & results_infections_anal$Vax_level==80]) / results_infections_anal$Incidence_mean[results_infections_anal$HPV_type==58 & results_infections_anal$Vax_level==13]

(results_infections_oral$Incidence_mean[results_infections_oral$HPV_type==6 & results_infections_oral$Vax_level==13] - results_infections_oral$Incidence_mean[results_infections_oral$HPV_type==6 & results_infections_oral$Vax_level==80]) / results_infections_oral$Incidence_mean[results_infections_oral$HPV_type==6 & results_infections_oral$Vax_level==13]
(results_infections_oral$Incidence_mean[results_infections_oral$HPV_type==11 & results_infections_oral$Vax_level==13] - results_infections_oral$Incidence_mean[results_infections_oral$HPV_type==11 & results_infections_oral$Vax_level==80]) / results_infections_oral$Incidence_mean[results_infections_oral$HPV_type==11 & results_infections_oral$Vax_level==13]
(results_infections_oral$Incidence_mean[results_infections_oral$HPV_type==16 & results_infections_oral$Vax_level==13] - results_infections_oral$Incidence_mean[results_infections_oral$HPV_type==16 & results_infections_oral$Vax_level==80]) / results_infections_oral$Incidence_mean[results_infections_oral$HPV_type==16 & results_infections_oral$Vax_level==13]
(results_infections_oral$Incidence_mean[results_infections_oral$HPV_type==18 & results_infections_oral$Vax_level==13] - results_infections_oral$Incidence_mean[results_infections_oral$HPV_type==18 & results_infections_oral$Vax_level==80]) / results_infections_oral$Incidence_mean[results_infections_oral$HPV_type==18 & results_infections_oral$Vax_level==13]
(results_infections_oral$Incidence_mean[results_infections_oral$HPV_type==31 & results_infections_oral$Vax_level==13] - results_infections_oral$Incidence_mean[results_infections_oral$HPV_type==31 & results_infections_oral$Vax_level==80]) / results_infections_oral$Incidence_mean[results_infections_oral$HPV_type==31 & results_infections_oral$Vax_level==13]
(results_infections_oral$Incidence_mean[results_infections_oral$HPV_type==33 & results_infections_oral$Vax_level==13] - results_infections_oral$Incidence_mean[results_infections_oral$HPV_type==33 & results_infections_oral$Vax_level==80]) / results_infections_oral$Incidence_mean[results_infections_oral$HPV_type==33 & results_infections_oral$Vax_level==13]
(results_infections_oral$Incidence_mean[results_infections_oral$HPV_type==45 & results_infections_oral$Vax_level==13] - results_infections_oral$Incidence_mean[results_infections_oral$HPV_type==45 & results_infections_oral$Vax_level==80]) / results_infections_oral$Incidence_mean[results_infections_oral$HPV_type==45 & results_infections_oral$Vax_level==13]
(results_infections_oral$Incidence_mean[results_infections_oral$HPV_type==52 & results_infections_oral$Vax_level==13] - results_infections_oral$Incidence_mean[results_infections_oral$HPV_type==52 & results_infections_oral$Vax_level==80]) / results_infections_oral$Incidence_mean[results_infections_oral$HPV_type==52 & results_infections_oral$Vax_level==13]
(results_infections_oral$Incidence_mean[results_infections_oral$HPV_type==58 & results_infections_oral$Vax_level==13] - results_infections_oral$Incidence_mean[results_infections_oral$HPV_type==58 & results_infections_oral$Vax_level==80]) / results_infections_oral$Incidence_mean[results_infections_oral$HPV_type==58 & results_infections_oral$Vax_level==13]

#condom and vaccination prevention at each vaccination level
mean(results_infections_anal$Cond_prevent_mean[results_infections_anal$Vax_level==0] / results_infections_anal$Prevent_mean[results_infections_anal$Vax_level==0])
mean(results_infections_anal$Vax_prevent_mean[results_infections_anal$Vax_level==0] / results_infections_anal$Prevent_mean[results_infections_anal$Vax_level==0])
mean(results_infections_anal$Sero_prevent_mean[results_infections_anal$Vax_level==0] / results_infections_anal$Prevent_mean[results_infections_anal$Vax_level==0])
mean(results_infections_anal$Cond_prevent_mean[results_infections_anal$Vax_level==13] / results_infections_anal$Prevent_mean[results_infections_anal$Vax_level==13])
mean(results_infections_anal$Vax_prevent_mean[results_infections_anal$Vax_level==13] / results_infections_anal$Prevent_mean[results_infections_anal$Vax_level==13])
mean(results_infections_anal$Sero_prevent_mean[results_infections_anal$Vax_level==13] / results_infections_anal$Prevent_mean[results_infections_anal$Vax_level==13])
mean(results_infections_anal$Cond_prevent_mean[results_infections_anal$Vax_level==25] / results_infections_anal$Prevent_mean[results_infections_anal$Vax_level==25])
mean(results_infections_anal$Vax_prevent_mean[results_infections_anal$Vax_level==25] / results_infections_anal$Prevent_mean[results_infections_anal$Vax_level==25])
mean(results_infections_anal$Sero_prevent_mean[results_infections_anal$Vax_level==25] / results_infections_anal$Prevent_mean[results_infections_anal$Vax_level==25])
mean(results_infections_anal$Cond_prevent_mean[results_infections_anal$Vax_level==50] / results_infections_anal$Prevent_mean[results_infections_anal$Vax_level==50])
mean(results_infections_anal$Vax_prevent_mean[results_infections_anal$Vax_level==50] / results_infections_anal$Prevent_mean[results_infections_anal$Vax_level==50])
mean(results_infections_anal$Sero_prevent_mean[results_infections_anal$Vax_level==50] / results_infections_anal$Prevent_mean[results_infections_anal$Vax_level==50])
mean(results_infections_anal$Cond_prevent_mean[results_infections_anal$Vax_level==80] / results_infections_anal$Prevent_mean[results_infections_anal$Vax_level==80])
mean(results_infections_anal$Vax_prevent_mean[results_infections_anal$Vax_level==80] / results_infections_anal$Prevent_mean[results_infections_anal$Vax_level==80])
mean(results_infections_anal$Sero_prevent_mean[results_infections_anal$Vax_level==80] / results_infections_anal$Prevent_mean[results_infections_anal$Vax_level==80])
mean(results_infections_anal$Cond_prevent_mean[results_infections_anal$Vax_level==100] / results_infections_anal$Prevent_mean[results_infections_anal$Vax_level==100])
mean(results_infections_anal$Vax_prevent_mean[results_infections_anal$Vax_level==100] / results_infections_anal$Prevent_mean[results_infections_anal$Vax_level==100])
mean(results_infections_anal$Sero_prevent_mean[results_infections_anal$Vax_level==100] / results_infections_anal$Prevent_mean[results_infections_anal$Vax_level==100])

mean(results_infections_oral$Cond_prevent_mean[results_infections_oral$Vax_level==0] / results_infections_oral$Prevent_mean[results_infections_oral$Vax_level==0])
mean(results_infections_oral$Vax_prevent_mean[results_infections_oral$Vax_level==0] / results_infections_oral$Prevent_mean[results_infections_oral$Vax_level==0])
mean(results_infections_oral$Cond_prevent_mean[results_infections_oral$Vax_level==13] / results_infections_oral$Prevent_mean[results_infections_oral$Vax_level==13])
mean(results_infections_oral$Vax_prevent_mean[results_infections_oral$Vax_level==13] / results_infections_oral$Prevent_mean[results_infections_oral$Vax_level==13])
mean(results_infections_oral$Cond_prevent_mean[results_infections_oral$Vax_level==25] / results_infections_oral$Prevent_mean[results_infections_oral$Vax_level==25])
mean(results_infections_oral$Vax_prevent_mean[results_infections_oral$Vax_level==25] / results_infections_oral$Prevent_mean[results_infections_oral$Vax_level==25])
mean(results_infections_oral$Cond_prevent_mean[results_infections_oral$Vax_level==50] / results_infections_oral$Prevent_mean[results_infections_oral$Vax_level==50])
mean(results_infections_oral$Vax_prevent_mean[results_infections_oral$Vax_level==50] / results_infections_oral$Prevent_mean[results_infections_oral$Vax_level==50])
mean(results_infections_oral$Cond_prevent_mean[results_infections_oral$Vax_level==80] / results_infections_oral$Prevent_mean[results_infections_oral$Vax_level==80])
mean(results_infections_oral$Vax_prevent_mean[results_infections_oral$Vax_level==80] / results_infections_oral$Prevent_mean[results_infections_oral$Vax_level==80])
mean(results_infections_oral$Cond_prevent_mean[results_infections_oral$Vax_level==100] / results_infections_oral$Prevent_mean[results_infections_oral$Vax_level==100])
mean(results_infections_oral$Vax_prevent_mean[results_infections_oral$Vax_level==100] / results_infections_oral$Prevent_mean[results_infections_oral$Vax_level==100])


### PLOT RESULTS ###

#output to tif for publication 
#tiff("Prevalence.tif",height=6,width=10,units='in',res=1200) 

#plot prevalence
barcolors = rev(c(gray.colors(length(vax_level)-1),"#FFFFFF"))
bars = barplot(matrix(data=results_infections_anal$Prev_mean, nrow=length(vax_level), ncol=length(hpv_type)), col=barcolors, beside=T, ylab="Mean Infection Prevalence", xlab="HPV Type", names.arg=paste("Type",hpv_type), ylim=c(0,0.40))
margins = par()$mar
par(xpd=T) 
legend(16,0.42, paste(vax_level,"%",sep=""), cex=0.9, fill=barcolors, title="% Vaccinated", x.intersp=0.5, horiz=T)
par(xpd=F, mar=margins)

#add starting prevalence dashed lines
for (i in 0:(length(hpv_type)-1))
{
  prev = NA
  for (j in 0:(nsims-1))
  {
    if (hpv_type[i+1]==6) {
      prev = c(prev, (sum(prep_sims_50[[j*length(vax_level)+1]]$ORIGINAL_STATUS_HPV6_ANAL)/nrow(prep_sims_50[[1]])))
    } else if (hpv_type[i+1]==11) {
      prev = c(prev, (sum(prep_sims_50[[j*length(vax_level)+1]]$ORIGINAL_STATUS_HPV11_ANAL)/nrow(prep_sims_50[[1]])))
    } else if (hpv_type[i+1]==16) {
      prev = c(prev, (sum(prep_sims_50[[j*length(vax_level)+1]]$ORIGINAL_STATUS_HPV16_ANAL)/nrow(prep_sims_50[[1]])))
    } else if (hpv_type[i+1]==18) {
      prev = c(prev, (sum(prep_sims_50[[j*length(vax_level)+1]]$ORIGINAL_STATUS_HPV18_ANAL)/nrow(prep_sims_50[[1]])))
    } else if (hpv_type[i+1]==31) {
      prev = c(prev, (sum(prep_sims_50[[j*length(vax_level)+1]]$ORIGINAL_STATUS_HPV31_ANAL)/nrow(prep_sims_50[[1]])))
    } else if (hpv_type[i+1]==33) {
      prev = c(prev, (sum(prep_sims_50[[j*length(vax_level)+1]]$ORIGINAL_STATUS_HPV33_ANAL)/nrow(prep_sims_50[[1]])))
    } else if (hpv_type[i+1]==45) {
      prev = c(prev, (sum(prep_sims_50[[j*length(vax_level)+1]]$ORIGINAL_STATUS_HPV45_ANAL)/nrow(prep_sims_50[[1]])))
    } else if (hpv_type[i+1]==52) {
      prev = c(prev, (sum(prep_sims_50[[j*length(vax_level)+1]]$ORIGINAL_STATUS_HPV52_ANAL)/nrow(prep_sims_50[[1]])))
    } else if (hpv_type[i+1]==58) {
      prev = c(prev, (sum(prep_sims_50[[j*length(vax_level)+1]]$ORIGINAL_STATUS_HPV58_ANAL)/nrow(prep_sims_50[[1]])))
    }
  }
  prev = prev[-1]
  
  lines(x=c(((i*7)+1),((i*7)+7)), y=c(mean(prev),mean(prev)),lty=2,lwd=2)
}
rm(i,j,prev)

#add bars
bars = as.vector(bars)
for (i in 1:length(bars))
{
  arrows(x0=bars[i], y0=(results_infections_anal$Prev_mean[i]-results_infections_anal$Prev_SE[i]*1.96), x1=bars[i], y1=(results_infections_anal$Prev_mean[i]+results_infections_anal$Prev_SE[i]*1.96), angle=90, length=0.05, code=3)
}
rm(i)

#close file 
#dev.off() 

#output to tif for publication 
#tiff("Incidence_anal.tif",height=6,width=10,units='in',res=1200) 

#plot anal incidence
barcolors = rev(c(gray.colors(length(vax_level)-1),"#FFFFFF"))
bars = barplot(matrix(data=results_infections_anal$Incidence_mean, nrow=length(vax_level), ncol=length(hpv_type)), col=barcolors, beside=T, ylab="Mean Infection Incidence", xlab="HPV Type", names.arg=paste("Type",hpv_type), ylim=c(0,0.15))
margins = par()$mar
par(xpd=T) 
legend(16,0.16, paste(vax_level,"%",sep=""), cex=0.9, fill=barcolors, title="% Vaccinated", x.intersp=0.5, horiz=T)
par(xpd=F, mar=margins)

#add bars
bars = as.vector(bars)
for (i in 1:length(bars))
{
  arrows(x0=bars[i], y0=(results_infections_anal$Incidence_mean[i]-results_infections_anal$Incidence_SE[i]*1.96), x1=bars[i], y1=(results_infections_anal$Incidence_mean[i]+results_infections_anal$Incidence_SE[i]*1.96), angle=90, length=0.05, code=3)
}
rm(i)

#close file 
#dev.off() 

#output to tif for publication 
#tiff("Incidence_oral.tif",height=6,width=10,units='in',res=1200) 

#plot oral incidence
barcolors = rev(c(gray.colors(length(vax_level)-1),"#FFFFFF"))
bars = barplot(matrix(data=results_infections_oral$Incidence_mean, nrow=length(vax_level), ncol=length(hpv_type)), col=barcolors, beside=T, ylab="Mean Infection Incidence", xlab="HPV Type", names.arg=paste("Type",hpv_type), ylim=c(0,0.05))
margins = par()$mar
par(xpd=T) 
legend(16,0.055, paste(vax_level,"%",sep=""), cex=0.9, fill=barcolors, title="% Vaccinated", x.intersp=0.5, horiz=T)
par(xpd=F, mar=margins)

#add bars
bars = as.vector(bars)
for (i in 1:length(bars))
{
  arrows(x0=bars[i], y0=(results_infections_oral$Incidence_mean[i]-results_infections_oral$Incidence_SE[i]*1.96), x1=bars[i], y1=(results_infections_oral$Incidence_mean[i]+results_infections_oral$Incidence_SE[i]*1.96), angle=90, length=0.05, code=3)
}
rm(i)

#close file 
#dev.off() 
